\qt@newcmd\qurantrans@es@i{En el nombre de Al.lah, el Clementísimo, el Misericordiosísimo.\qt@no{1}}
\qt@newcmd\qurantrans@es@ii{La alabanza es para Dios, Señor de los mundos,\qt@no{2}}
\qt@newcmd\qurantrans@es@iii{el Clementísimo con toda la Creación, el Misericordiosísimo con los creyentes,\qt@no{3}}
\qt@newcmd\qurantrans@es@iv{Soberano del Día de la Recompensa.\qt@no{4}}
\qt@newcmd\qurantrans@es@v{Solamente a Ti adoramos y solamente a Ti pedimos ayuda.\qt@no{5}}
\qt@newcmd\qurantrans@es@vi{Guíanos al camino recto,\qt@no{6}}
\qt@newcmd\qurantrans@es@vii{el camino de aquellos a los que Tú has agraciado; no el de aquellos con los que Tú estás disgustado, ni el de los extraviados.\qt@no{7}}
\qt@newcmd\qurantrans@es@viii{\basmalahes Alif, lam, mim\qt@no{1}}
\qt@newcmd\qurantrans@es@ix{Esta es la Escritura (Sagrada), no hay duda. En ella hay una guía para los temerosos de Dios.\qt@no{2}}
\qt@newcmd\qurantrans@es@x{Aquellos que creen en lo que está oculto a los sentidos, hacen la oración y, de lo que Nosotros les proveemos, reparten.\qt@no{3}}
\qt@newcmd\qurantrans@es@xi{Aquellos que creen en la revelación que se hizo descender para ti y en la revelación que se hizo descender antes de ti y que tienen certeza de la otra vida.\qt@no{4}}
\qt@newcmd\qurantrans@es@xii{Esos son los que siguen la guía procedente de su Señor y esos son los triunfadores.\qt@no{5}}
\qt@newcmd\qurantrans@es@xiii{Ciertamente, a aquellos que no creen en Dios, da igual que les amonestes o que no, no creerán.\qt@no{6}}
\qt@newcmd\qurantrans@es@xiv{Dios cerró y selló sus corazones y sus oídos, y sobre sus ojos hay un velo y les aguarda un castigo inmenso.\qt@no{7}}
\qt@newcmd\qurantrans@es@xv{Y entre la gente hay algunos que dicen: «¡Creemos en Dios y en el Último Día!», pero no son creyentes.\qt@no{8}}
\qt@newcmd\qurantrans@es@xvi{Pretenden engañar a Dios y a aquellos que creen, pero sólo se engañan a sí mismos, aunque no se dan cuenta.\qt@no{9}}
\qt@newcmd\qurantrans@es@xvii{En sus corazones hay una enfermedad y Dios agravará su enfermedad. Les aguarda un castigo doloroso por haber sido mentirosos.\qt@no{10}}
\qt@newcmd\qurantrans@es@xviii{Y cuando se les dice: «¡No corrompáis en la Tierra!» dicen: «¡En verdad, nosotros somos reformadores de lo que está mal!»\qt@no{11}}
\qt@newcmd\qurantrans@es@xix{¿Acaso no son ellos los corruptores? Pero no se dan cuenta.\qt@no{12}}
\qt@newcmd\qurantrans@es@xx{Y cuando se les dice: «Creed como cree el resto de la gente!», dicen: «¿Vamos a creer como creen los estúpidos?» ¿Acaso no son ellos los estúpidos? Pero no lo saben.\qt@no{13}}
\qt@newcmd\qurantrans@es@xxi{Y cuando se encuentran con aquellos que creen, dicen: «¡Creemos!» Pero cuando se quedan a solas con sus demonios, dicen: «¡En verdad, estamos con vosotros! ¡Solamente nos burlábamos de ellos!»\qt@no{14}}
\qt@newcmd\qurantrans@es@xxii{Dios sí que se burlará de ellos y les dejará que vaguen ciegos en su rebeldía.\qt@no{15}}
\qt@newcmd\qurantrans@es@xxiii{Ésos son los que han trocado la Dirección por el extravío. Por eso, su negocio no ha resultado lucrativo y no han sido bien dirigidos.\qt@no{16}}
\qt@newcmd\qurantrans@es@xxiv{Semejan a quien enciende un fuego. Pero cuando éste alumbra lo que hay en torno a él, Dios les arrebata su luz y les deja en tinieblas, sin que puedan ver.\qt@no{17}}
\qt@newcmd\qurantrans@es@xxv{Son sordos, mudos, ciegos y no rectificarán su error.\qt@no{18}}
\qt@newcmd\qurantrans@es@xxvi{También semejan a quienes, en medio de una tormenta, con un cielo lleno de nubes oscuras, de truenos y relámpagos, se tapan los oídos con sus dedos por el estruendo del rayo al caer, temiendo la muerte. Dios acorrala a los que no creen.\qt@no{19}}
\qt@newcmd\qurantrans@es@xxvii{El rayo casi les ciega. Cuando les ilumina, caminan, pero cuando se apaga, se detienen. Si Dios quisiera les arrebataría el oído y la vista. Verdaderamente, Dios tiene poder sobre todas las cosas.\qt@no{20}}
\qt@newcmd\qurantrans@es@xxviii{¡Oh humanos! ¡Adorad a vuestro Señor, el Cual os ha creado, tanto a vosotros como a los que os precedieron! ¡Quizás así tengáis temor de disgustarle!\qt@no{21}}
\qt@newcmd\qurantrans@es@xxix{Él es Quien ha dispuesto para vosotros la Tierra como un lecho y el cielo como una bóveda. Quien hace descender agua del cielo, por medio de la cual surgen los frutos con los que os suministra vuestra provisión. Así pues, no atribuyáis semejantes a Dios, a sabiendas de lo que hacéis.\qt@no{22}}
\qt@newcmd\qurantrans@es@xxx{Y si dudáis de lo que hicimos descender del cielo para Nuestro siervo, aportad vosotros un capítulo semejante e invocad a vuestros testigos aparte de Dios, si es que sois sinceros.\qt@no{23}}
\qt@newcmd\qurantrans@es@xxxi{Y si no lo hacéis, que no lo haréis, temed el fuego del infierno cuyo combustible son las gentes y las piedras y que está preparado para los que ocultan la verdad.\qt@no{24}}
\qt@newcmd\qurantrans@es@xxxii{Y anuncia a aquellos que creen y actúan rectamente que les aguardan jardines celestiales por los cuales fluyen arroyos. Cuando se les ofrezcan los frutos que de ellos proceden, dirán: «Esto es lo mismo que se nos proporcionó anteriormente», pero lo que se les dé será semejante. Allí les esperan parejas purificadas y allí estarán eternamente.\qt@no{25}}
\qt@newcmd\qurantrans@es@xxxiii{Verdaderamente, Dios no se avergüenza [para expresar Su mensaje] de poner como ejemplo a un mosquito o algo mayor. Aquellos que creen, saben que, ciertamente, es la Verdad que procede de su Señor. En cuanto a los que no creen, dicen: «¿Qué es lo que pretende Dios con ese ejemplo?» Extravía con él a muchos y guía con él a muchos. Pero no se extravían con él sino los transgresores.\qt@no{26}}
\qt@newcmd\qurantrans@es@xxxiv{Aquellos que violan el pacto establecido con Dios después de haberlo aceptado, y cortan lo que Dios ha ordenado que continúe unido corrompiendo la Tierra. Esos son los perdedores.\qt@no{27}}
\qt@newcmd\qurantrans@es@xxxv{¿Cómo podéis no creéis en Dios, cuando estabais muertos y Él os dio la vida; luego os hará morir y después os hará vivir (nuevamente), tras lo cual retornaréis a Él.\qt@no{28}}
\qt@newcmd\qurantrans@es@xxxvi{Él es quien creó para vosotros todo lo que hay en la Tierra, luego Se ocupó del cielo y lo ordenó en siete cielos. Él posee conocimiento de todas las cosas.\qt@no{29}}
\qt@newcmd\qurantrans@es@xxxvii{Y [recuerda] cuando tu Señor dijo a los ángeles: «En verdad, pondré en la Tierra un sucesor.» Dijeron: «¿Vas a poner en ella a quien corromperá y derramará la sangre, mientras que nosotros Te glorificamos con alabanzas y proclamamos Tu santidad?» Dijo Dios: «En verdad, Yo sé lo que vosotros no sabéis.»\qt@no{30}}
\qt@newcmd\qurantrans@es@xxxviii{Y enseñó a Adán los nombres de todos los seres. Luego los expuso ante los ángeles y Les dijo: «Informadme de los nombres de éstos, si es que sois veraces.»\qt@no{31}}
\qt@newcmd\qurantrans@es@xxxix{Ellos dijeron: «¡Glorificado seas! No conocemos más que aquello que Tú nos has enseñado. En verdad, Tú eres el Conocedor, el Sabio.»\qt@no{32}}
\qt@newcmd\qurantrans@es@xl{Dijo Él entonces: «¡Oh Adán! ¡Infórmales de sus nombres!» Y cuando Adán les hubo informado de sus nombres, dijo Él: «¿No os dije que, ciertamente, conozco lo oculto de los cielos y la Tierra, y que sé lo que manifestáis y lo que ocultáis?»\qt@no{33}}
\qt@newcmd\qurantrans@es@xli{Y [recuerda] cuando Nosotros dijimos a los ángeles: «¡Prosternaos ante Adán!» y todos ellos se prosternaron excepto Iblís, que se negó y se llenó de arrogancia, y fue de los que no creen.\qt@no{34}}
\qt@newcmd\qurantrans@es@xlii{Dijimos. «¡Oh Adán! Habitad tú y tu pareja en el Jardín y comed ambos de él cuanto y donde queráis, pero no os acerquéis a este árbol, pues entonces seríais de los transgresores.»\qt@no{35}}
\qt@newcmd\qurantrans@es@xliii{Pero Satanás les engañó a ambos y les sacó de aquello en lo que estaban. Y Dijimos: «¡Descended! Seréis enemigos unos de otros. La Tierra será para vosotros una morada y lugar de disfrute por un tiempo.\qt@no{36}}
\qt@newcmd\qurantrans@es@xliv{Entonces, recibió Adán de su Señor palabras y Dios le perdonó. En verdad, Él es el Perdonador, el Misericordiosísimo con los creyentes.\qt@no{37}}
\qt@newcmd\qurantrans@es@xlv{Dijimos: «¡Descended de él, todos! Y, si de Mí parte viene a vosotros una guía, quienes sigan Mi guía no habrán de temer ni estarán tristes.\qt@no{38}}
\qt@newcmd\qurantrans@es@xlvi{Pero los que no crean y desmientan Nuestras señales, esos serán la gente del Fuego, en el que estarán eternamente.»\qt@no{39}}
\qt@newcmd\qurantrans@es@xlvii{¡Oh, Hijos de Israel! Recordad Mi merced, con la cual os agracié y sed leales al pacto que tenéis conmigo que Yo seré leal al que tengo con vosotros y temedme sólo a Mí.\qt@no{40}}
\qt@newcmd\qurantrans@es@xlviii{Y creed en la revelación que hice descender, confirmando la que ya teníais. No seáis los primeros en no creer en ella. No vendáis Mis indicaciones por poco precio y temedme sólo a Mí.\qt@no{41}}
\qt@newcmd\qurantrans@es@xlix{Y no mezcléis la verdad con la falsedad, ni escondáis la verdad a sabiendas.\qt@no{42}}
\qt@newcmd\qurantrans@es@l{Haced la oración, dad la limosna obligatoria y inclinaos con los que se inclinan.\qt@no{43}}
\qt@newcmd\qurantrans@es@li{¿Acaso ordenáis a la gente que sea virtuosa y vosotros mismos lo olvidáis, a pesar de que recitáis la Escritura [Sagrada]? ¿Es que no razonáis?\qt@no{44}}
\qt@newcmd\qurantrans@es@lii{Buscad ayuda en la paciencia y en la oración. En verdad, la oración es una carga pesada, excepto para los que son humildes.\qt@no{45}}
\qt@newcmd\qurantrans@es@liii{Aquellos que creen que se encontrarán con su Señor y que retornarán a Él.\qt@no{46}}
\qt@newcmd\qurantrans@es@liv{¡Oh, Hijos de Israel! Recordad la merced con los que Yo os agracié y cómo os di preferencia sobre todos los pueblos.\qt@no{47}}
\qt@newcmd\qurantrans@es@lv{Y temed un día en el que un alma no pueda hacer nada por otra y en el que no le será aceptada la intercesión ni el rescate y no tendrá quien la auxilie.\qt@no{48}}
\qt@newcmd\qurantrans@es@lvi{Y [recordad] cuando os salvamos de la gente del Faraón, que os sometían a terribles castigos, degollando a vuestros hijos varones y dejando con vida a vuestras mujeres. Con ello vuestro Señor os sometió a una prueba enorme.\qt@no{49}}
\qt@newcmd\qurantrans@es@lvii{Y [recordad] cuando dividimos el mar para vosotros y os salvamos, y ahogamos a la gente del Faraón ante vuestros ojos.\qt@no{50}}
\qt@newcmd\qurantrans@es@lviii{Y [recordad] cuando nos citamos con Moisés durante cuarenta noches y, en su ausencia, vosotros adorasteis al becerro, obrando injustamente.\qt@no{51}}
\qt@newcmd\qurantrans@es@lix{Aunque, tras aquello, os perdonamos; para que, quizás de esa manera, fueseis agradecidos.\qt@no{52}}
\qt@newcmd\qurantrans@es@lx{Y [recordad] cuando dimos a Moisés la Escritura [Sagrada] y el Criterio. Quizás así fueseis bien guiados.\qt@no{53}}
\qt@newcmd\qurantrans@es@lxi{Y [recordad] cuando Moisés dijo a su pueblo: «¡Oh pueblo mío! En verdad, os habéis oprimido a vosotros mismos eligiendo el becerro. Volveos, pues, arrepentidos a vuestro Creador y mataos a vosotros mismos. Eso es mejor para vosotros ante vuestro Creador y quizás así os perdone. En verdad, Él es el Perdonador, el Misericordiosísimo con los creyentes.»\qt@no{54}}
\qt@newcmd\qurantrans@es@lxii{Y [recordad] cuando le dijisteis: «¡Oh Moisés! No te creeremos hasta que no veamos a Dios manifiestamente.» Y el rayo os alcanzó ante vuestros propios ojos.\qt@no{55}}
\qt@newcmd\qurantrans@es@lxiii{Luego, os devolvimos a la vida después de estar muertos. Quizás así seáis agradecidos.\qt@no{56}}
\qt@newcmd\qurantrans@es@lxiv{Y os dimos la sombra de la nube e hicimos descender sobre vosotros el maná y las codornices: «¡Comed de lo bueno de lo que os hemos provisto!» No fueron injustos con Nosotros, fueron injustos con ellos mismos.\qt@no{57}}
\qt@newcmd\qurantrans@es@lxv{Y recordad cuando Nosotros dijimos: «Entrad en esta ciudad y comed de ella cuanto queráis. Entrad por la puerta y, ante ella, prosternaos y decid: «Hitta». Perdonaremos vuestros errores e incrementaremos la recompensa de los que hagan el bien.»\qt@no{58}}
\qt@newcmd\qurantrans@es@lxvi{Pero, aquellos que eran injustos cambiaron la palabra por otra distinta. cambiaron la palabra por otra distinta. Entonces, hicimos descender un castigo del cielo sobre los injustos, por haber sido transgresores.\qt@no{59}}
\qt@newcmd\qurantrans@es@lxvii{Y [recordad] cuando Moisés pidió agua para su pueblo y le dijimos: «¡Golpea con tu bastón la roca!» Y brotaron de ella doce fuentes. Cada tribu supo con certeza de cuál beber. «¡Comed y bebed de la provisión de Dios y no causéis daño en la Tierra, corrompiendo!»\qt@no{60}}
\qt@newcmd\qurantrans@es@lxviii{Y cuando dijisteis: «¡Oh Moisés! No soportamos comer siempre lo mismo. Ruega por nosotros a tu Señor que haga salir para nosotros de lo que da la tierra, algo de legumbres, verduras, pepinos, ajos, lentejas y cebollas.» [Moisés] Dijo: «¿Cambiaréis lo que es mejor por lo que es peor? ¡Bajad a una ciudad! ¡Allí encontraréis lo que queréis!» Fueron golpeados por la humillación y la miseria e incurrieron en la ira de Dios por desmentir las indicaciones de Dios y matar a los profetas sin derecho. Eso les ocurrió porque desobedecieron y fueron transgresores.\qt@no{61}}
\qt@newcmd\qurantrans@es@lxix{En verdad, los creyentes y los judíos, los cristianos y los sabeos, quienes crean en Dios y en el Último Día y actúen rectamente, tendrán su recompensa junto a su Señor. No tendrán que temer y no estarán tristes.\qt@no{62}}
\qt@newcmd\qurantrans@es@lxx{Y (recordad) cuando aceptamos de vosotros el pacto y elevamos sobre vosotros el monte Sinaí [y dijimos:] «¡Coged con fuerza lo que os hemos entregado y recordad lo que contiene! Quizás así temáis disgustar a Dios.»\qt@no{63}}
\qt@newcmd\qurantrans@es@lxxi{Después de aquello, disteis la espalda y, si no hubiera sido por el favor de Dios sobre vosotros y por Su misericordia, habríais sido de los perdedores.\qt@no{64}}
\qt@newcmd\qurantrans@es@lxxii{Sabíais con certeza quiénes de vosotros violaron el sábado. Les dijimos: «¡Sed monos despreciables!»\qt@no{65}}
\qt@newcmd\qurantrans@es@lxxiii{E hicimos esto como un ejemplo para las generaciones presentes y futuras y como un aviso para los temerosos de Dios.\qt@no{66}}
\qt@newcmd\qurantrans@es@lxxiv{Y [recuerda] cuando Moisés dijo a su pueblo: «Dios os ordena que sacrifiquéis una vaca.» Dijeron: «¿Te burlas de nosotros?» Dijo: «¡Dios me proteja de ser como los ignorantes!»\qt@no{67}}
\qt@newcmd\qurantrans@es@lxxv{Dijeron: «Ruega a tu Señor de parte nuestra, que nos aclare cómo ha ser ella.» Dijo: «Él dice que ha de ser una vaca ni vieja ni joven, algo intermedio entre ambas cosas. ¡Haced lo que se os ordena!»\qt@no{68}}
\qt@newcmd\qurantrans@es@lxxvi{Dijeron: «Ruega a tu Señor de parte nuestra, que nos aclare cuál ha de ser su color.» Dijo: «Él dice que ha de ser una vaca de color amarillo intenso, que agrade a los que la miren.»\qt@no{69}}
\qt@newcmd\qurantrans@es@lxxvii{Dijeron: «Ruega a tu Señor de parte nuestra, que nos explique cuál ha de ser, pues todas las vacas nos parecen semejantes. En verdad, si Dios quiere, seremos bien guiados.»\qt@no{70}}
\qt@newcmd\qurantrans@es@lxxviii{Dijo: «Él dice que ha de ser una vaca que no haya sido uncida para arar la tierra, ni para el riego de los campos; sana, sin defecto o marca.» Dijeron: «Ahora has traído la Verdad.» Y la sacrificaron, pero estuvieron a punto de no hacerlo.\qt@no{71}}
\qt@newcmd\qurantrans@es@lxxix{Y recordad cuando matasteis a una persona y os acusabais unos a otros. Dios es quien sacó a la luz lo que ocultabais.\qt@no{72}}
\qt@newcmd\qurantrans@es@lxxx{Dijimos: «Golpeadle con algo de ella.» Así es como Dios resucita a los muertos y os muestra Sus señales. Quizás así razonéis.\qt@no{73}}
\qt@newcmd\qurantrans@es@lxxxi{Tras ello, vuestros corazones se endurecieron como piedras o más aún, pues, en verdad, de algunas piedras brotan ríos y otras se agrietan y sale de ellas agua y algunas de ellas se desmoronan por temor de Dios. Dios no está desatento a lo que hacéis.\qt@no{74}}
\qt@newcmd\qurantrans@es@lxxxii{¿Acaso anheláis que ellos os crean, cuando entre ellos hay un grupo que escucha la palabra de Dios y la altera después de haberla razonado y a sabiendas de lo que hace?\qt@no{75}}
\qt@newcmd\qurantrans@es@lxxxiii{Y, cuando se encuentran con aquellos que creen, dicen: «¡Creemos!”, pero cuando se quedan solos, se dicen unos a otros: ¿Es que vais a contarles lo que Dios os ha revelado, para que tengan argumentos contra vosotros ante vuestro Señor? ¿Es que no razonáis?»\qt@no{76}}
\qt@newcmd\qurantrans@es@lxxxiv{¿Acaso no saben que Dios conoce lo que ocultan y lo que manifiestan?\qt@no{77}}
\qt@newcmd\qurantrans@es@lxxxv{Entre ellos hay ignorantes que no conocen la Escritura [Sagrada]. No hacen más que suponer.\qt@no{78}}
\qt@newcmd\qurantrans@es@lxxxvi{¡Ay! de aquellos que escriben con sus manos la Escritura [Sagrada] y luego dicen: «¡Esto procede de Dios!», vendiéndolo por poco precio. ¡Ay de ellos por lo que escribieron con sus manos! y ¡Ay de ellos por lo que han obtenido!\qt@no{79}}
\qt@newcmd\qurantrans@es@lxxxvii{Dicen: «¡No nos quemará el Fuego del infierno más que unos pocos días!» Di: «¿Acaso obtuvisteis una promesa de Dios? Porque Dios no incumple Su promesa. ¿O acaso decís de Dios lo que no conocéis?»\qt@no{80}}
\qt@newcmd\qurantrans@es@lxxxviii{¡Sí! Aquellos que acumulan malas obras y están rodeados por sus pecados, esos son la gente del Fuego. En él estarán eternamente.\qt@no{81}}
\qt@newcmd\qurantrans@es@lxxxix{Pero aquellos que creen y obran rectamente, esos son la gente del Jardín. En él estarán eternamente.\qt@no{82}}
\qt@newcmd\qurantrans@es@xc{Y [recuerda] cuando hicimos un pacto con los Hijos de Israel: «Solamente adoraréis a Dios. Sed buenos con vuestros padres, con vuestros familiares, con los huérfanos y los necesitados. Hablad bien a las personas. Estableced la oración y cumplid con la limosna obligatoria.» Después, excepto unos pocos, os apartasteis e incumplisteis.\qt@no{83}}
\qt@newcmd\qurantrans@es@xci{Y [recordad] cuando concertamos un pacto con vosotros: «¡No derramaréis vuestra sangre y no os expulsaréis unos a otros de vuestras casas.» Lo aceptasteis y sois testigos de ello.\qt@no{84}}
\qt@newcmd\qurantrans@es@xcii{Pero, sois vosotros mismos los que os matáis unos a otros y expulsáis a algunos de los vuestros de sus casas, ayudándoos entre vosotros a cometer este pecado y esta violación contra ellos. En cambio, cuando llegan a vosotros prisioneros de otros, los rescatáis, cuando vosotros mismos los habíais expulsado aunque os estaba prohibido hacerlo. ¿Acaso creéis en parte de la Escritura [Sagrada] y descreéis de otra parte? Quien así actúe de entre vosotros no obtendrá más recompensa que la desgracia en esta vida, y el Día del Levantamiento seréis sometidos al peor de los castigos. Dios no está desatento de lo que hacéis.\qt@no{85}}
\qt@newcmd\qurantrans@es@xciii{Esos son los que han comprado la vida de este mundo al precio de la Otra. No se les aliviará el castigo y no serán auxiliados.\qt@no{86}}
\qt@newcmd\qurantrans@es@xciv{Verdaderamente, entregamos a Moisés la Escritura [Sagrada] y después de él seguimos enviando profetas. Y dimos a Jesús hijo de María las pruebas claras y le fortalecimos con el Espíritu Santo. ¿Es que, cada vez que os lleguen Mensajeros que vuestro ego no desea, os mostraréis arrogantes? Habéis desmentido a algunos y a otros los habéis matado.\qt@no{87}}
\qt@newcmd\qurantrans@es@xcv{Dijeron: «Nuestros corazones están cerrados.» ¡No! Lo que sucede es que Dios les ha maldecido por su incredulidad. ¡Qué pocos de ellos creen!\qt@no{88}}
\qt@newcmd\qurantrans@es@xcvi{Y cuando les llegó una Escritura procedente de Dios, confirmando lo que tenían, aunque anteriormente pedían la victoria sobre los incrédulos, cuando les llegó lo que conocían, descreyeron de ello. ¡La maldición de Dios sobre los que descreen!\qt@no{89}}
\qt@newcmd\qurantrans@es@xcvii{¡Qué malo es aquello a cambio de lo que han vendido sus almas, no creyendo en lo que Dios ha revelado por envidia de que Dios haga descender Su favor sobre quien Él quiere de Sus siervos! Por ello han incurrido en ira sobre ira. ¡Los que ocultan a Verdad tendrán un castigo humillante!\qt@no{90}}
\qt@newcmd\qurantrans@es@xcviii{Cuando se les dice: «¡Creed en la revelación que Dios hizo descender!», dicen: «¡Creemos en lo que fue hecho descender para nosotros!» Pero no creen en lo que ha venido después, aunque es la Verdad que confirma lo que ya tenían. Di: «Entonces, ¿Por qué habéis matado a los Mensajeros anteriores de Dios, si sois creyentes?»\qt@no{91}}
\qt@newcmd\qurantrans@es@xcix{«Ciertamente, vino a vosotros Moisés con las pruebas claras y, a pesar de ello, tomasteis al becerro en su ausencia. Fuisteis injustos.»\qt@no{92}}
\qt@newcmd\qurantrans@es@c{Y [recordad] cuando concertamos un pacto con vosotros y elevamos sobre vosotros el monte Sinaí. [Dijimos]: «¡Aferraos con fuerza a lo que os hemos otorgado y escuchad!» Dijeron: «¡Escuchamos y desobedecemos!» Se empaparon sus corazones [de amor] por el ternero, debido a su falta de fe. [Diles]: «¡Que malo es lo que os ordena con ello vuestra fe, si sois creyentes!»\qt@no{93}}
\qt@newcmd\qurantrans@es@ci{Di: «Si la morada de la otra vida junto a Dios es para vosotros en exclusiva y para nadie más, ¡Desead la muerte si sois veraces!»\qt@no{94}}
\qt@newcmd\qurantrans@es@cii{Pero no la desearán jamás debido a lo que cometieron con sus manos. ¡Dios conoce bien a los opresores!\qt@no{95}}
\qt@newcmd\qurantrans@es@ciii{Descubrirás que son los más ávidos de vivir, más incluso que los idólatras. Alguno de ellos desearía vivir mil años, pero no se libraría del castigo por mucho que viviese. Dios observa lo que hacen.\qt@no{96}}
\qt@newcmd\qurantrans@es@civ{Di: «Quien sea enemigo de Gabriel [Dios lo será de él]» En verdad, él fue quien trajo [el Corán] a tu corazón, con el permiso de Dios, confirmando lo que él mismo tiene en sus manos y como una guía y buena nueva para los creyentes.»\qt@no{97}}
\qt@newcmd\qurantrans@es@cv{Quien sea enemigo de Dios, de Sus ángeles, de Sus Mensajeros, de Gabriel y del [ángel] Miguel... [sepa que] en verdad, Dios es enemigo de los que no creen.\qt@no{98}}
\qt@newcmd\qurantrans@es@cvi{Ciertamente, hicimos descender sobre ti signos evidentes y no descreen de ellos excepto los transgresores.\qt@no{99}}
\qt@newcmd\qurantrans@es@cvii{¿Acaso, cada vez que establecen un pacto, un grupo de ellos ha de rechazarlo? Pero la mayoría de ellos no creen.\qt@no{100}}
\qt@newcmd\qurantrans@es@cviii{Y cuando llegó a ellos un Mensajero de parte de Dios confirmando lo que tenían, un grupo de aquellos a los que les había sido dada la Escritura [Sagrada] rechazaron la Escritura de Dios, dándole la espalda, como si no supieran [que es la Verdad].\qt@no{101}}
\qt@newcmd\qurantrans@es@cix{Ellos siguieron los que decían los demonios bajo el reinado de Salomón. Salomón no fue idólatra, fueron los demonios los que ocultaron la Verdad y enseñaron a la gente la magia y lo que se hizo descender a los dos ángeles, Harut y Marut, en Babel. Estos dos no enseñaron a nadie sin decirle previamente: «Ciertamente, somos una prueba. No perdáis la fe.» Y los demonios aprendieron de ellos dos lo que permite separar al hombre de su esposa, aunque con ello no puedan perjudicar a nadie, excepto con permiso de Dios. Aprendieron lo que les perjudicaba y no les beneficiaba. Sabían que quien comerciase con esto no tendría parte en los beneficios de la otra vida. ¡Qué malo es aquello a cambio de lo que han vendido sus almas! Si lo hubieran sabido...\qt@no{102}}
\qt@newcmd\qurantrans@es@cx{Y si ellos hubieran creído y temido desagradar a Dios... La recompensa que hay junto a Dios es mejor. Si lo hubieran sabido...\qt@no{103}}
\qt@newcmd\qurantrans@es@cxi{¡Oh, los que creéis! ¡No digáis «raina», sino decid mejor «unzurna» y escuchad! Para los que no creen hay un castigo doloroso.\qt@no{104}}
\qt@newcmd\qurantrans@es@cxii{Aquellos de entre las gentes de la Escritura [Sagrada] que no creen y los idólatras, no desean que descienda sobre vosotros ningún bien procedente de vuestro Señor, pero Dios concede Su misericordia a quien Él quiere. Dios es el Dueño del Favor Inmenso.\qt@no{105}}
\qt@newcmd\qurantrans@es@cxiii{No abrogamos ningún versículo o hacemos que se olvide, sin aportar algo mejor o igual a ello. ¿Es que no sabes que Dios tiene poder sobre todas las cosas?\qt@no{106}}
\qt@newcmd\qurantrans@es@cxiv{¿Es que no sabes que a Dios pertenecen el reino de los cielos y la Tierra y que, excepto Dios, no tenéis protector o auxiliador?\qt@no{107}}
\qt@newcmd\qurantrans@es@cxv{¿O queréis cuestionar a vuestro Mensajero como fue cuestionado Moisés anteriormente? Quien cambia la fe por la incredulidad, en verdad, se ha extraviado del camino recto.\qt@no{108}}
\qt@newcmd\qurantrans@es@cxvi{Tras haberles sido mostrada claramente la Verdad, muchos de entre las gentes de la Escritura [Sagrada] desearían, por pura envidia, que volvierais a la incredulidad después de haber creído. Perdonad, no obstante y no les prestéis atención, hasta que Dios traiga Su decreto. En verdad, Dios tiene poder sobre todas las cosas.\qt@no{109}}
\qt@newcmd\qurantrans@es@cxvii{Realizad la oración y dad la limosna obligatoria. Las buenas obras que enviéis por delante en beneficio de vuestras almas, las encontrareis de nuevo junto a Dios. En verdad, Dios observa cuanto hacéis.\qt@no{110}}
\qt@newcmd\qurantrans@es@cxviii{Y dijeron: «Sólo entrará en el Jardín quien sea judío o cristiano.» Eso es lo que ellos quisieran. Di: «Aportad vuestras pruebas, si es que sois sinceros.»\qt@no{111}}
\qt@newcmd\qurantrans@es@cxix{¡Sí! ¡Quien se someta a Dios plenamente y haga el bien, tendrá su recompensa junto a su Señor! [Quienes sean así] No tendrán que temer y no estarán tristes.\qt@no{112}}
\qt@newcmd\qurantrans@es@cxx{Los judíos dicen: «Los cristianos no están en la Verdad.» Y los cristianos dicen: «Los judíos no están en la Verdad» y eso, a pesar de que todos ellos leen la misma Escritura [Sagrada]. Hablan igual que quienes nada saben. El Día del Levantamiento Dios juzgará entre ellos sobre aquello en lo que no se ponen de acuerdo.\qt@no{113}}
\qt@newcmd\qurantrans@es@cxxi{¿Quién es más opresor que quien prohíbe que en las mezquitas de Dios sea recordado Su nombre y se esfuerza en destruirlas. Tales gentes no deben entrar en ellas excepto atemorizados. ¡Sufrirán humillación en esta vida y en la otra un castigo inmenso!\qt@no{114}}
\qt@newcmd\qurantrans@es@cxxii{A Dios pertenecen el Oriente y el Occidente. Por tanto, a donde quiera que os giréis, encontraréis el rostro de Dios. ¡En verdad, Dios todo lo abarca, es sabio!\qt@no{115}}
\qt@newcmd\qurantrans@es@cxxiii{Dijeron: «Dios tiene un hijo.» ¡Gloria a Él! ¡Más bien a Él pertenece lo que hay en los cielos y en la Tierra. Todo Le obedece.\qt@no{116}}
\qt@newcmd\qurantrans@es@cxxiv{Él es el Creador de los cielos y de la Tierra. Cuando decreta un asunto, le dice: «¡Sé!» y es.\qt@no{117}}
\qt@newcmd\qurantrans@es@cxxv{Los que no saben dicen: «¿Por qué Dios no nos habla directamente o nos trae una señal?» Eso mismo dijeron sus antepasados, Sus corazones son semejantes. En verdad, Hemos explicado claramente nuestras señales a una gente que tiene certeza.\qt@no{118}}
\qt@newcmd\qurantrans@es@cxxvi{Ciertamente, te Hemos enviado con la Verdad, portador de la buena nueva y de la advertencia y no se te pedirán cuentas por la gente del Infierno.\qt@no{119}}
\qt@newcmd\qurantrans@es@cxxvii{Ni los judíos ni los cristianos estarán satisfechos de ti hasta que no sigas sus creencias. Di: «¡Ciertamente, la guía de Dios es la Guía!». Y si siguieras sus deseos después del conocimiento que te ha llegado, no tendrías protector ni auxiliador de parte de Dios.\qt@no{120}}
\qt@newcmd\qurantrans@es@cxxviii{Aquellos a quienes Nosotros dimos la Escritura [Sagrada] y la leen como debe ser leída, esos son los que creen en Él. Y quienes descreen de Él, esos son los perdedores.\qt@no{121}}
\qt@newcmd\qurantrans@es@cxxix{¡Oh, Hijos de Israel! Recordad Mi merced, con la cual os agracié, y que Yo os di preferencia sobre todas las naciones,\qt@no{122}}
\qt@newcmd\qurantrans@es@cxxx{y temed un día en el que nadie pueda favorecer a nadie y en el que no serán aceptados el rescate, ni la intercesión, ni el auxilio.\qt@no{123}}
\qt@newcmd\qurantrans@es@cxxxi{Y [recuerda] cuando su Señor puso a prueba a Abraham con tareas que él cumplió. Dijo Él: «En verdad, te pondré como Imam para los hombres.» [Abraham] dijo: «¿Y a mi descendencia?» [Dios] dijo: «Mi alianza no incluirá a [quienes sean] opresores.»\qt@no{124}}
\qt@newcmd\qurantrans@es@cxxxii{Y [recuerda] cuando establecimos la Casa como un lugar de reunión y de seguridad para las gentes. «¡Tomad el sitio de Abraham como un lugar de oración!» Y encargamos a Abraham e Ismael que purificasen Mi casa para los que la circunvalan y los que permanecen en ella en adoración y los que inclinan su cabeza y los que ponen su frente en el suelo.\qt@no{125}}
\qt@newcmd\qurantrans@es@cxxxiii{Y [recuerda] cuando Abraham dijo: «¡Señor mío! Haz esta tierra segura y provee de frutos a quienes de sus habitantes crean en Dios y en el Último Día.» Dios dijo: «Y a quien no crea le permitiré disfrutar un poco y luego le arrastraré hacia el castigo del Fuego.» ¡Qué mal destino!\qt@no{126}}
\qt@newcmd\qurantrans@es@cxxxiv{Y [recuerda] cuando Abraham levantó los pilares de la Casa junto con Ismael [y suplicó]: «¡Señor nuestro, acéptanoslo! ¡En verdad, Tú eres Quien todo lo oye, Quien todo lo sabe!»\qt@no{127}}
\qt@newcmd\qurantrans@es@cxxxv{«¡Señor nuestro! Haz de nosotros dos gente sometida a Ti y de nuestra descendencia una nación a Ti sometida y muéstranos los ritos de la adoración y perdónanos. En verdad, Tú eres Quien acepta el arrepentimiento, el Misericordiosísimo con los creyentes.»\qt@no{128}}
\qt@newcmd\qurantrans@es@cxxxvi{«¡Señor nuestro! Desígnales, de entre ellos, un Mensajero que les recite Tus versículos y les enseñe la Escritura [Sagrada], la Sabiduría y les purifique. En verdad, Tú eres el Poderoso, el Sabio.»\qt@no{129}}
\qt@newcmd\qurantrans@es@cxxxvii{¿Quién, excepto quien tenga obnubilada su alma, puede abandonar la creencia de Abraham? Ciertamente, le elegimos en este mundo y, en verdad, en el otro es de los justos.\qt@no{130}}
\qt@newcmd\qurantrans@es@cxxxviii{Cuando su Señor le dijo: «¡Sométete!» Dijo: «¡Me someto al Señor de los mundos!»\qt@no{131}}
\qt@newcmd\qurantrans@es@cxxxix{Y Abraham se lo encomendó a sus hijos y también Jacob: «¡Oh hijos míos! ¡Ciertamente, Dios ha escogido para vosotros la religión, no muráis sin ser musulmanes!\qt@no{132}}
\qt@newcmd\qurantrans@es@cxl{¿Acaso fuisteis testigos cuando Jacob, estaba en presencia de la muerte y dijo a sus hijos: “¿Qué adoraréis después de mí?». Ellos dijeron: «Adoraremos a tu Dios y Dios de tus padres, Abraham, Ismael e Isaac. Un Dios Único, al Cual nos sometemos.»\qt@no{133}}
\qt@newcmd\qurantrans@es@cxli{Aquella fue una nación que pasó. Ellos obtendrán la recompensa de lo que hicieron y vosotros obtendréis la recompensa de lo que hayáis hecho y no seréis interrogados por lo que ellos hicieron.\qt@no{134}}
\qt@newcmd\qurantrans@es@cxlii{Dicen: «¡Sed judíos o cristianos y estaréis bien guiados!» Di: «¡Seguiremos la creencia de Abraham que era hanif y no era de los idólatras!»\qt@no{135}}
\qt@newcmd\qurantrans@es@cxliii{Decid: «Creemos en Dios y en lo que nos fue revelado y en lo que fue revelado a Abraham, a Ismael, a Isaac, a Jacob y a las Tribus, y en lo que fue dado a Moisés y a Jesús, y en lo que fue dado a los profetas por su Señor. No hacemos diferencias entre ninguno de ellos y nos sometemos a Él.»\qt@no{136}}
\qt@newcmd\qurantrans@es@cxliv{Y, si creen en lo mismo que vosotros creéis, estarán, ciertamente, guiados y si dan la espalda estarán, ciertamente, opuestos [a la Verdad] y Dios será suficiente para ti frente a ellos. Él es Quien que todo lo oye, Quien todo lo sabe.\qt@no{137}}
\qt@newcmd\qurantrans@es@cxlv{Tinte de Dios. ¿Quién es mejor que Dios tintando? Nosotros somos Sus siervos.\qt@no{138}}
\qt@newcmd\qurantrans@es@cxlvi{Di: «¿Vais a disputarnos a Dios, cuando Él es nuestro Señor y el vuestro y nosotros somos responsables de nuestros actos y vosotros de los vuestros y nosotros somos puros con Él?»\qt@no{139}}
\qt@newcmd\qurantrans@es@cxlvii{¿O diréis que Abraham, Ismael, Isaac, Jacob y las tribus fueron judíos o cristianos? Di: «¿Quién es más sabio, vosotros o Dios?» y «¿Quién es más injusto que quien oculta un testimonio que le viene de Dios? Dios no está desatento a lo que hacéis.»\qt@no{140}}
\qt@newcmd\qurantrans@es@cxlviii{Aquella fue una nación que ha pasado. Obtendrán la recompensa de lo que hicieron y vosotros obtendréis la recompensa de lo que hayáis hecho y no seréis interrogados por lo que ellos hicieron.\qt@no{141}}
\qt@newcmd\qurantrans@es@cxlix{Los estúpidos de entre las gentes, dirán: «¿Qué les ha hecho dar la espalda a la qibla a la que se orientaban?» Di: «A Dios pertenecen el Oriente y el Occidente. Él guía a quien quiere a un camino recto.»\qt@no{142}}
\qt@newcmd\qurantrans@es@cl{Así mismo hemos hecho de vosotros una comunidad moderada, para que seáis testigos sobre la gente y sea el Mensajero testigo sobre vosotros. No establecimos la Qibla hacía la que te orientabas antes, sino para distinguir a quienes seguían al Mensajero de quienes se volvieron atrás. En verdad, esto es algo arduo, excepto para aquellos a quienes Dios guía. Dios no permitirá que se pierda vuestra fe. En verdad, Dios es benévolo con la gente, Misericordiosísimo.\qt@no{143}}
\qt@newcmd\qurantrans@es@cli{Vemos que, a veces, tornas tu rostro hacia el cielo. Así que te volveremos hacia una Qibla que te satisfaga. Vuelve, pues, tu rostro hacia la Mezquita Sagrada, y donde quiera que estéis, volved vuestros rostros en dirección a ella. Ciertamente, aquellos a quienes les fue dada la Escritura [Sagrada] saben con certeza que esto es la Verdad procedente de vuestro Señor. Y Dios no está descuidado de lo que hacen.\qt@no{144}}
\qt@newcmd\qurantrans@es@clii{Aquellos a quienes les fue dada la Escritura [Sagrada] no seguirán tu Qibla aunque vayas a ellos con toda clase de señales, y tú no seguirás la Qibla de ellos, ni unos ni otros seguirán la Qibla del otro. Y, si siguieras sus deseos después del conocimiento que ha venido a ti, serías entonces, ciertamente, uno de los opresores.\qt@no{145}}
\qt@newcmd\qurantrans@es@cliii{Aquellos a quienes dimos la Escritura [Sagrada], le conocen como conocen a sus hijos y, ciertamente, un grupo de ellos esconde la Verdad a sabiendas de lo que hacen.\qt@no{146}}
\qt@newcmd\qurantrans@es@cliv{La Verdad procede de tu Señor, por tanto, no seas de los que dudan.\qt@no{147}}
\qt@newcmd\qurantrans@es@clv{Para cada cual existe una dirección a la que volverse. ¡Id por delante, pues, en la realización de buenas obras! Donde quiera que estéis, Dios os reunirá. En verdad, Dios tiene poder sobre toda cosa.\qt@no{148}}
\qt@newcmd\qurantrans@es@clvi{Donde quiera que vayas, vuelve tu rostro en dirección a la Mezquita Sagrada. Ciertamente, esa es la Verdad que provienen de tu Señor. Dios no está descuidado de lo que hacéis.\qt@no{149}}
\qt@newcmd\qurantrans@es@clvii{Y, donde quiera que vayas, vuelve tu rostro en dirección a la Mezquita Sagrada y, donde quiera que estéis, volved vuestros rostros en dirección a ella, para que las gentes no tengan argumentos contra vosotros, ni siquiera los opresores. Y nos les temáis a ellos, temedme a Mí, de manera que Yo pueda completar mi bendición sobre vosotros y así podáis ser guiados.\qt@no{150}}
\qt@newcmd\qurantrans@es@clviii{Por eso, os hemos enviado un Mensajero de entre vosotros mismos, que os recita Nuestros versículos, os purifica y os enseña la Escritura [Sagrada] y la Sabiduría y os enseña lo que no sabíais.\qt@no{151}}
\qt@newcmd\qurantrans@es@clix{Recordadme, pues, y Yo os recordaré y sed agradecidos conmigo y no ocultéis Mis favores.\qt@no{152}}
\qt@newcmd\qurantrans@es@clx{¡Oh vosotros, los que creéis! Buscad ayuda en la paciencia y en la oración. Ciertamente, Dios está con los que son pacientes.\qt@no{153}}
\qt@newcmd\qurantrans@es@clxi{Y no digáis de quienes fueron matados en la senda de Dios que están muertos, pues están vivos, aunque vosotros no os deis cuenta.\qt@no{154}}
\qt@newcmd\qurantrans@es@clxii{En verdad, os pondremos a prueba con algo de temor, de hambre, de merma de riquezas, vidas y frutos. Pero ¡Da la buena nueva a los que sean pacientes!\qt@no{155}}
\qt@newcmd\qurantrans@es@clxiii{Aquellos que, cuando les aflige una desgracia, dicen: «¡En verdad, pertenecemos a Dios y, en verdad, a Él retornamos!»\qt@no{156}}
\qt@newcmd\qurantrans@es@clxiv{Ellos son los que obtienen las bendiciones y la misericordia de su Señor y ellos son los bien guiados.\qt@no{157}}
\qt@newcmd\qurantrans@es@clxv{Ciertamente, algunos de los ritos de Dios son en Safa y Marwa. Por tanto, quién peregrine a la Casa de Dios o la visite, no comete pecado yendo de una a otra. Y quien haga el bien voluntariamente, sepa que, ciertamente, Dios es agradecido, sabio.\qt@no{158}}
\qt@newcmd\qurantrans@es@clxvi{A quienes ocultan las pruebas claras y la guía que hicimos descender, después de haberlas explicado claramente a la gente en la Escritura [Sagrada], Dios les maldice y les maldicen los hombres.\qt@no{159}}
\qt@newcmd\qurantrans@es@clxvii{Pero a aquellos que se arrepientan y rectifiquen y manifiesten claramente la Verdad, a esos Yo los perdonaré. Yo soy el Perdonador, el Misericordiosísimo con los creyentes.\qt@no{160}}
\qt@newcmd\qurantrans@es@clxviii{En verdad, aquellos que no crean y mueran sin creer, incurrirán en la maldición de Dios, de los ángeles y de las gentes todas.\qt@no{161}}
\qt@newcmd\qurantrans@es@clxix{Maldecidos eternamente, no se les aliviará el castigo y no se les dará respiro.\qt@no{162}}
\qt@newcmd\qurantrans@es@clxx{Vuestro Dios es un Dios Único. No hay más Dios que Él, el Clementísimo con toda la Creación, el Misericordiosísimo con los creyentes.\qt@no{163}}
\qt@newcmd\qurantrans@es@clxxi{En la Creación de los cielos y de la Tierra y en la diferencia entre la noche y el día, en la nave que surca el mar con lo que beneficia a la gente, en el agua que hizo descender Dios de los cielos con la cual vivifica la tierra tras haber estado muerta, diseminando por ella todo tipo de animales; en la variación de los vientos y en las nubes situadas entre el cielo y la Tierra, hay, ciertamente, señales para la gente que razona.\qt@no{164}}
\qt@newcmd\qurantrans@es@clxxii{Y entre la gente, hay quienes toman a otros, aparte de Dios, y les aman como sólo se ama a Dios. Pero los creyentes a quien más aman es a Dios. Cuando los opresores vean el castigo de Dios, comprenderán que la fuerza pertenece a Dios y que Dios es duro en el castigo.\qt@no{165}}
\qt@newcmd\qurantrans@es@clxxiii{Cuando los que fueron seguidos repudien a quienes les seguían y vean el castigo y se corten los lazos que les unían,\qt@no{166}}
\qt@newcmd\qurantrans@es@clxxiv{aquellos que les seguían dirán: «Si tuviéramos otra oportunidad, les repudiaríamos igual que ellos nos han repudiado a nosotros.» Así les hará ver Dios sus obras, para su propia desgracia. Y nunca saldrán del Fuego.\qt@no{167}}
\qt@newcmd\qurantrans@es@clxxv{¡Oh gentes! ¡Comed de lo lícito y bueno que hay en la Tierra y no sigáis los pasos de Satanás. En verdad, él es para vosotros un enemigo declarado.\qt@no{168}}
\qt@newcmd\qurantrans@es@clxxvi{En verdad, os ordena el mal y la indecencia y que digáis de Dios lo que no sabéis.\qt@no{169}}
\qt@newcmd\qurantrans@es@clxxvii{Y cuando se les dice: «Seguid lo que Dios ha revelado», dicen: «Seguiremos aquello que hacían nuestros padres». Pero ¿Y si sus padres no razonaban en absoluto y no estaban bien guiados?\qt@no{170}}
\qt@newcmd\qurantrans@es@clxxviii{El ejemplo de los que no creen es como el de quien grita al ganado, que no oye de él más que una llamada y un grito. Son sordos, mudos, ciegos, no razonan.\qt@no{171}}
\qt@newcmd\qurantrans@es@clxxix{¡Oh, los que creéis! Comed de lo bueno que Nosotros os hemos proporcionado y agradeced a Dios si es sólo a Él a quien adoráis.\qt@no{172}}
\qt@newcmd\qurantrans@es@clxxx{En verdad, Él os ha prohibido la carroña, la sangre, la carne del cerdo y la de todo animal sacrificado en nombre de otro que no sea Dios. Pero quien se vea obligado, no por ánimo de transgredir, ni por soberbia, no será culpable. En verdad, Dios es perdonador. Misericordiosísimo con los creyentes.\qt@no{173}}
\qt@newcmd\qurantrans@es@clxxxi{En verdad, quienes esconden algo de lo que Dios ha revelado de la Escritura [Sagrada] y lo venden por poco precio, no introducen en sus estómagos más que fuego. Dios no les hablará el Día del Levantamiento, ni les purificará y tendrán un castigo doloroso.\qt@no{174}}
\qt@newcmd\qurantrans@es@clxxxii{Esos son los que han vendido la Guía a cambio del extravío y el perdón a cambio del castigo. ¿Cómo podrán soportar el Fuego?\qt@no{175}}
\qt@newcmd\qurantrans@es@clxxxiii{Esto es así porque Dios ha hecho descender la Escritura [Sagrada] con la Verdad. Y, ciertamente, quienes no están de acuerdo con la Escritura [Sagrada] están en una posición muy alejada de la Verdad.\qt@no{176}}
\qt@newcmd\qurantrans@es@clxxxiv{La virtud no consiste en que volváis vuestros rostros hacia Oriente u Occidente. La virtud consiste en creer en Dios y en el Último Día, en los ángeles, en la Escritura [Sagrada] y en los profetas. En dar de los bienes, por mucho amor que se les tenga, a los familiares, a los huérfanos, a los necesitados, a los mendigos, a los viajeros y para liberar esclavos. En hacer la oración, dar la limosna obligatoria, cumplir los compromisos cuando se contraen y en ser pacientes ante las dificultades y las desgracias y en tiempos de peligro. ¡Estos son los sinceros y los temerosos de desagradar a Dios!\qt@no{177}}
\qt@newcmd\qurantrans@es@clxxxv{¡Oh, los que creéis! ¡Ha sido decretada para vosotros la ley del talión en caso de asesinato: el libre por el libre y el esclavo por el esclavo y la hembra por la hembra! Pero, si alguien rebaja a su hermano la condena, que no le presione en el pago de lo establecido y que éste le compense bondadosamente por la sangre derramada. Esto es un alivio procedente de vuestro Señor y una misericordia. Y quien, después de esto, viole la ley, recibirá un castigo doloroso.\qt@no{178}}
\qt@newcmd\qurantrans@es@clxxxvi{En la ley del talión hay vida para vosotros. ¡Oh gente dotada de entendimiento! Quizás así seáis temerosos de Dios.\qt@no{179}}
\qt@newcmd\qurantrans@es@clxxxvii{Se os ha prescrito que, cuando se le presente a uno de vosotros la muerte, si deja algunos bienes, testamente a favor de sus padres y de sus familiares cercanos, según el uso establecido. Esto es un deber para los temerosos de Dios.\qt@no{180}}
\qt@newcmd\qurantrans@es@clxxxviii{Y si alguien lo cambia después de haberlo oído, ciertamente, el pecado será de aquellos que lo cambien. Ciertamente, Dios todo lo oye, todo lo sabe.\qt@no{181}}
\qt@newcmd\qurantrans@es@clxxxix{Y quien tema una arbitrariedad o una injusticia por parte del testador y procure un arreglo entre las partes afectadas, no comete pecado. Ciertamente Dios es Perdonador, Misericordiosísimo con los creyentes.\qt@no{182}}
\qt@newcmd\qurantrans@es@cxc{¡Oh, los que creéis! Se os ha ordenado que ayunéis, de la misma manera que fue ordenado a quienes os precedieron. Quizás así seáis temerosos de Dios.\qt@no{183}}
\qt@newcmd\qurantrans@es@cxci{Son unos días determinados. Pero, quien de vosotros esté enfermo o de viaje, que ayune un número igual de días en otro momento. Y aquellos para quienes sea de gran dificultad que, en compensación, den de comer a una persona necesitada. Pero quien voluntariamente quiera dar más alimento, mejor para él. Aunque, si queréis saberlo, ayunar es mejor para vosotros.\qt@no{184}}
\qt@newcmd\qurantrans@es@cxcii{El mes de Ramadán, en el cual fue hecho descender el Corán, como una guía para la gente, como indicaciones claras de la Guía y del Discernimiento. Por tanto, quien de vosotros esté presente ese mes, que ayune en él. Y quien esté enfermo o de viaje, que ayune un número igual de días en otro momento. Quiere Dios para vosotros la facilidad y no quiere para vosotros la dificultad y quiere que completéis el número de días y que ensalcéis a Dios por haberos guiado y así, quizás, seáis de los que agradecen.\qt@no{185}}
\qt@newcmd\qurantrans@es@cxciii{Y cuando Mis siervos te pregunten por Mí, [diles que] en verdad, Yo estoy cerca y respondo la súplica del suplicante cuando Me suplica. Por tanto que Me respondan y crean en Mí, para que, quizás así, sean bien dirigidos.\qt@no{186}}
\qt@newcmd\qurantrans@es@cxciv{Durante las noches del mes del ayuno, es lícito para vosotros la unión con vuestras mujeres. Ellas son una vestidura para vosotros y vosotros sois una vestidura para ellas. Dios supo que os traicionabais a vosotros mismos, así que os perdonó y os excusó. Así pues, ahora, yaced con ellas y buscad lo que Dios ha decretado para vosotros. Y comed y bebed hasta que podáis distinguir la línea blanca de la línea negra al amanecer. Después, completad el ayuno hasta la noche. Y no tengáis relación sexual con ellas mientras estéis de retiro en las mezquitas. Esos son los límites de Dios, así pues, no os acerquéis a ellos. De esta manera aclara Dios sus indicaciones a las gentes. Quizás así sean temerosos.\qt@no{187}}
\qt@newcmd\qurantrans@es@cxcv{Y no os comáis vuestras riquezas unos a otros de forma ilícita ni ofrezcáis de ellas a los jueces para comeros parte de las riquezas de la gente injustamente y a sabiendas de lo que hacéis.\qt@no{188}}
\qt@newcmd\qurantrans@es@cxcvi{Te preguntarán sobre las fases crecientes de la Luna. Di: «Sirven a la gente para computar el tiempo y para determinar la fecha de la peregrinación.» La virtud no consiste en que entréis en las casas por la parte trasera, sino en que tengáis temor de desagradar a Dios. ¡Entrad en las casas por sus puertas y temed disgustar a Dios! Quizás así tengáis éxito.\qt@no{189}}
\qt@newcmd\qurantrans@es@cxcvii{Y combatid en la senda de Dios contra aquellos que os combatan, pero no seáis agresores. Ciertamente, Dios no ama a los agresores.\qt@no{190}}
\qt@newcmd\qurantrans@es@cxcviii{Matadles donde quiera que os encontréis con ellos y expulsadles de donde ellos os expulsaron. La idolatría es peor que matar. Y no combatáis contra ellos junto a la Mezquita Sagrada mientras ellos no os combatan allí. Pero si os combaten ¡combatidles! Esa es la recompensa de los idólatras.\qt@no{191}}
\qt@newcmd\qurantrans@es@cxcix{Pero si cesan, sepan que, ciertamente, Dios es perdonador, Misericordiosísimo.\qt@no{192}}
\qt@newcmd\qurantrans@es@cc{Combatid contra ellos hasta que no quede idolatría y la creencia sea sólo en Dios. Y si cesan su ataque que no haya más hostilidades que contra los tiranos.\qt@no{193}}
\qt@newcmd\qurantrans@es@cci{El mes sagrado por el mes sagrado. A las cosas sagradas también se les aplica la ley del Talión. Y a quien os ataque, atacadle en la misma medida en que él os atacó. Y temed disgustar a Dios y sabed que Dios está con quienes temen disgustarle.\qt@no{194}}
\qt@newcmd\qurantrans@es@ccii{Repartid de vuestra riqueza, por amor a Dios. No os destruyáis con vuestra propia mano y haced el bien. Ciertamente Dios ama a quienes hacen el bien.\qt@no{195}}
\qt@newcmd\qurantrans@es@cciii{Completad el Hach y la ‘Umra por Dios. Y si no podéis hacerlo, sacrificad un animal. Y no afeitéis vuestras cabezas hasta que el animal esté en el lugar del sacrificio. Y quien de vosotros esté enfermo o tenga un daño en la cabeza, que lo compense ayunando o dando limosna o sacrificando un animal. Y cuando estéis a salvo, quien una la peregrinación menor a la mayor, que sacrifique un animal según sus posibilidades. Y quien no encuentre cómo, que ayune tres días durante la peregrinación mayor y siete cuando haya regresado, completando así diez. Esto incumbe a aquel cuya familia no viva cerca de la Mezquita Sagrada. ¡Temed disgustar a Dios y sabed que Dios es severo en el castigo.\qt@no{196}}
\qt@newcmd\qurantrans@es@cciv{La peregrinación mayor se lleva a cabo en meses determinados. Por tanto, quien se proponga realizar la peregrinación mayor en ellos, que no mantenga relaciones sexuales, ni peque, ni dispute durante ella. El bien que realicéis, Dios lo sabrá. Y tomad provisiones, pero, desde luego, la mejor provisión es el temor de disgustar a Dios. Así pues, ¡Temed disgustarme! ¡Oh, los dotados de discernimiento!\qt@no{197}}
\qt@newcmd\qurantrans@es@ccv{No pecáis al buscar el favor de vuestro Señor. Y, cuando partáis de Arafat, recordad a Dios junto a Mashar al-Haram. Recordad como os guió cuando, anteriormente, erais de los extraviados.\qt@no{198}}
\qt@newcmd\qurantrans@es@ccvi{Partid, pues, de donde parte toda la gente y pedid el perdón de Dios. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{199}}
\qt@newcmd\qurantrans@es@ccvii{Y cuando hayáis cumplido con vuestros ritos recordad a Dios como recordáis a vuestros padres o con un recuerdo aún mayor. Hay entre las gentes quien dice: «¡Señor nuestro! ¡Danos en esta vida!» y no tendrán parte en lo bueno de la otra.\qt@no{200}}
\qt@newcmd\qurantrans@es@ccviii{Y, entre ellos, están los que dicen: «¡Señor nuestro! ¡Danos lo bueno en esta vida y lo bueno en la otra y protégenos del castigo del Fuego!»\qt@no{201}}
\qt@newcmd\qurantrans@es@ccix{Ellos obtendrán la recompensa de lo que hayan realizado. ¡Dios es rápido haciendo las cuentas!\qt@no{202}}
\qt@newcmd\qurantrans@es@ccx{Recordad a Dios en días determinados. Y, quien lo limite a dos días, no peca y quien lo prolongue tampoco peca. Eso es para quien tema desagradar a Dios. Temed desagradar a Dios y sabed que seréis congregados hacia Él.\qt@no{203}}
\qt@newcmd\qurantrans@es@ccxi{Y entre las gentes, hay quien te sorprende con su manera de hablar de la vida de este mundo y que pone a Dios como testigo de lo que hay en su corazón, pero es el más acérrimo adversario.\qt@no{204}}
\qt@newcmd\qurantrans@es@ccxii{Y, cuando te da la espalda, se esfuerza por corromper en la Tierra y destruir la cosecha y el ganado. Y Dios no ama la corrupción.\qt@no{205}}
\qt@newcmd\qurantrans@es@ccxiii{Y si se le dice: «¡Teme desagradar a Dios!» se apodera de él un orgullo pecador. El Fuego del Infierno será su retribución. ¡Qué mal lugar para descansar!\qt@no{206}}
\qt@newcmd\qurantrans@es@ccxiv{Y, entre las gentes, hay quien sacrifica su persona buscando satisfacer a Dios. Y Dios es benévolo con los siervos.\qt@no{207}}
\qt@newcmd\qurantrans@es@ccxv{¡Oh, los que creéis! ¡Entrad todos en la Paz y no sigáis la senda extraviada de Satanás, que es vuestro enemigo declarado!\qt@no{208}}
\qt@newcmd\qurantrans@es@ccxvi{Y si os equivocáis después de haber llegado a vosotros las pruebas claras, sabed que Dios es poderoso, sabio.\qt@no{209}}
\qt@newcmd\qurantrans@es@ccxvii{¿Acaso piensan que vendrán a ellos Dios y los ángeles entre las sombras de una nube a resolver el asunto? ¡Todos los asuntos regresan a Dios!\qt@no{210}}
\qt@newcmd\qurantrans@es@ccxviii{Pregunta a los Hijos de Israel cuántas señales claras les dimos. Quien cambie la bendición de Dios, después de lo que le ha llegado... Ciertamente Dios es severo en el castigo.\qt@no{211}}
\qt@newcmd\qurantrans@es@ccxix{La vida de este mundo ha sido embellecida para los que no creen, que se burlan de aquellos que creen. Pero, aquellos que temen desagradar a Dios estarán por encima de ellos el Día del Levantamiento. Y Dios provee sin medida a quien Él quiere.\qt@no{212}}
\qt@newcmd\qurantrans@es@ccxx{La Humanidad constituía una sola comunidad y después Dios designó a los profetas como portadores de buenas nuevas y advertidores [del castigo] e hizo descender con ellos la Escritura [Sagrada] con la Verdad para que juzgasen entre los hombres en aquello en lo que no se ponían de acuerdo. Después de haber llegado a ellos las pruebas claras, aquellos a los que les fueron dadas no discreparon, excepto algunos por envidia entre ellos. A aquellos que creían, Dios, por su voluntad, les guió a la Verdad de aquello en lo que discrepaban. Dios guía a quien Él quiere al camino recto.\qt@no{213}}
\qt@newcmd\qurantrans@es@ccxxi{¿Acaso contabais con entrar en el Jardín sin soportar cosas parecidas a las que sufrieron los que vinieron antes de vosotros? Sufrieron la pena y la dificultad, y tal conmoción que el Mensajero y los que creyeron con él dijeron: «¿Cuándo llegará el auxilio de Dios?» ¿Acaso el auxilio de Dios no está cercano?\qt@no{214}}
\qt@newcmd\qurantrans@es@ccxxii{Te preguntan qué es lo que deben gastar. Di: «Los bienes que repartáis, que sea a vuestros padres, a los familiares, a los huérfanos, a los necesitados y a los viajeros.» Dios conoce perfectamente el bien que hacéis.\qt@no{215}}
\qt@newcmd\qurantrans@es@ccxxiii{Ha sido decretado para vosotros el combate, aunque os disguste. Puede que algo os disguste y, sin embargo, sea un bien para vosotros. Y puede que algo os agrade y sea un perjuicio para vosotros. Dios sabe y vosotros no sabéis.\qt@no{216}}
\qt@newcmd\qurantrans@es@ccxxiv{Te preguntan sobre la conveniencia de combatir en el mes sagrado. Di: «Combatir en él es algo grave. Pero poner obstáculos en el camino de Dios y no creer en Él, no respetar la Mezquita Sagrada y expulsar de ella a su gente es más grave ante Dios.» La incredulidad es peor que combatir. Y no cesarían de combatiros hasta apartaros de vuestra fe, si pudieran. Y, quienes de vosotros abandonen su religión y mueran sin ser creyentes, habrán invalidado todos sus buenos actos en esta vida y en la otra. Esos serán la gente que morará eternamente en el Fuego.\qt@no{217}}
\qt@newcmd\qurantrans@es@ccxxv{En verdad, aquellos que creen y emigran y se esfuerzan en la senda de Dios, pueden esperar la misericordia de Dios. Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{218}}
\qt@newcmd\qurantrans@es@ccxxvi{Te preguntan sobre los embriagantes y los juegos de azar. Di: «En ambos hay un gran perjuicio y también un beneficio para la gente, pero el perjuicio que hay en ambos es mayor que el beneficio.» Y te preguntan qué deben repartir. Di: «Lo que excede a las propias necesidades.» De esta manera os aclara Dios sus señales. Quizás así reflexionéis\qt@no{219}}
\qt@newcmd\qurantrans@es@ccxxvii{sobre esta vida y sobre la otra. Te preguntan sobre los huérfanos. Di: «Mejorar su vida está bien. Y, si mezcláis [vuestros bienes] con los de ellos, [tratadles] como hermanos vuestros.» Dios distingue al corruptor del reformador. Si Dios hubiera querido os lo habría puesto difícil. Dios es, ciertamente, poderoso, sabio.\qt@no{220}}
\qt@newcmd\qurantrans@es@ccxxviii{Y no os caséis con las idólatras hasta que crean. Una esclava creyente es mejor que una mujer libre idólatra, aunque ésta os guste más. Y no caséis [a vuestras mujeres] con los idólatras hasta que éstos crean. Un esclavo creyente es mejor que un hombre libre idólatra, aunque éste os guste más. Esos invitan al Fuego y Dios invita al Jardín y al perdón, si Él quiere. Y aclara Sus señales a la gente. ¡Quizás así se dejen amonestar!\qt@no{221}}
\qt@newcmd\qurantrans@es@ccxxix{Te preguntan sobre la menstruación. Di: «Es molesta e impura. Absteneos, pues, de las mujeres durante la menstruación y no os acerquéis a ellas hasta que se hayan purificado. Y, una vez que estén purificadas, id a ellas tal como Dios os ha ordenado.» En verdad, Dios ama a quienes se vuelven a Él arrepentidos y ama a los que se purifican.\qt@no{222}}
\qt@newcmd\qurantrans@es@ccxxx{Vuestras mujeres son un campo de labranza para vosotros. Id, pues, a vuestro campo como deseéis. Y enviad algo por delante para vosotros mismos. Temed desagradar a Dios y sabed que os encontraréis con Él. ¡Y anuncia buenas nuevas a los creyentes!\qt@no{223}}
\qt@newcmd\qurantrans@es@ccxxxi{Y no pongáis a Dios por testigo en vuestros juramentos, de manera que os impida practicar la bondad. Y sed temerosos de Dios y haced el bien entre la gente. Dios todo lo oye, todo lo sabe.\qt@no{224}}
\qt@newcmd\qurantrans@es@ccxxxii{Dios no os tiene en cuenta lo vano de vuestros juramentos, pero sí que tiene en cuenta la intención de vuestros corazones. Dios es perdonador, indulgente.\qt@no{225}}
\qt@newcmd\qurantrans@es@ccxxxiii{Aquellos que juren a sus esposas no mantener relaciones con ellas, tendrán cuatro meses de plazo y, si se retractan, en verdad, Dios es perdonador, Misericordiosísimo con los creyentes.\qt@no{226}}
\qt@newcmd\qurantrans@es@ccxxxiv{Pero, si se deciden por el divorcio... Dios todo lo oye, todo lo sabe.\qt@no{227}}
\qt@newcmd\qurantrans@es@ccxxxv{Las divorciadas deberán esperar tres menstruaciones completas y no es lícito para ellas que oculten lo que Dios haya creado en su seno, si creen en Dios y en el Último Día. Sus esposos tienen más derecho a retornar a ellas durante este tiempo, si desean arreglarlo. Y las mujeres tienen derechos equivalentes a sus obligaciones, conforme a lo razonable. Y los hombres un grado sobre ellas. Dios es todopoderoso, sabio.\qt@no{228}}
\qt@newcmd\qurantrans@es@ccxxxvi{El divorcio [de la misma esposa es permisible] dos veces. Así pues, o se la toma tratándola como es debido o se la deja ir buenamente. Y no es lícito para vosotros que toméis nada de lo que les disteis, excepto que ambos teman no respetar los límites impuestos por Dios. Pero si teméis que no respeten los límites impuestos por Dios, no hay inconveniente para ninguno de los dos en que ella obtenga su libertad compensando al esposo. Esas son las leyes de Dios ¡No las violéis! Y quienes violen las leyes de Dios serán los opresores.\qt@no{229}}
\qt@newcmd\qurantrans@es@ccxxxvii{Y si la divorcia de nuevo, ya no será lícita para él tras ello, hasta que se case con otro esposo diferente. Y sí éste la divorcia, no hay inconveniente en que ambos vuelvan, si creen que respetarán las leyes de Dios. Estas son las leyes de Dios, que Él explica a gente que sabe.\qt@no{230}}
\qt@newcmd\qurantrans@es@ccxxxviii{Y, cuando divorciéis a vuestras mujeres y éstas hayan cumplido su plazo de espera, tomadlas como es debido o dejadlas ir como es debido, pero no las retengáis causándoles molestias, transgrediendo las leyes de Dios, pues, quien actúe así, será injusto consigo mismo. No toméis las señales de Dios a burla y recordad la bendición de Dios para vosotros y lo que Él os reveló de la Escritura [Sagrada] y de la Sabiduría, para advertiros con ello. Temed a Dios y sabed que Dios tiene conocimiento de todas las cosas.\qt@no{231}}
\qt@newcmd\qurantrans@es@ccxxxix{Y cuando hayáis divorciado a las mujeres y éstas hayan cumplido su plazo de espera, no les impidáis que vuelvan a casarse con sus esposos anteriores si lo desean de mutuo acuerdo. Se exhorta a ello a quien de vosotros crea en Dios y en el Último Día. Eso es más correcto para vosotros y más puro. Dios sabe y vosotros no sabéis.\qt@no{232}}
\qt@newcmd\qurantrans@es@ccxl{Las madres amamantarán a sus hijos dos años completos si quiere consumar el periodo de lactancia. Y el progenitor la proveerá de alimento y vestido de manera adecuada. No se obliga a nadie más allá de su capacidad. No será perjudicada una madre por su hijo ni un padre por su hijo. Y lo mismo se aplica al heredero. Y si ambos, de mutuo acuerdo y consultándose, desean destetar al hijo antes de tiempo, no cometen falta. Y si deseáis que otra persona amamante a vuestros hijos, no cometéis falta mientras lo paguéis conforme a lo que es justo. ¡Temed a Dios y sabed que Dios observa lo que hacéis!\qt@no{233}}
\qt@newcmd\qurantrans@es@ccxli{Y, las esposas de quienes fallezcan deberán esperar cuatro meses y diez días y, cuando completen su plazo, no cometéis falta alguna por lo que ellas hagan consigo mismas, conforme a lo establecido. Dios está informado de lo que hacéis.\qt@no{234}}
\qt@newcmd\qurantrans@es@ccxlii{Y no cometéis falta si insinuáis a las mujeres vuestra intención de contraer matrimonio o lo guardáis escondido en vuestras almas. Dios sabe que pronto pensaréis en ellas [para el matrimonio]. Pero no les prometáis nada en secreto. Mejor, habladles como es debido y no formalicéis el contrato de matrimonio hasta que no concluya su periodo de espera. Y sabed que Dios conoce lo que hay en vuestras almas. Tened, pues, cuidado de Él. Pero sabed que Dios es perdonador, indulgente.\qt@no{235}}
\qt@newcmd\qurantrans@es@ccxliii{No cometéis falta si divorciáis a las mujeres que aun no habéis tocado ni asignado dote. Proveedlas, no obstante, adecuadamente. El acaudalado conforme a sus posibilidades y el pobre conforme a las suyas. Eso es un deber para los virtuosos.\qt@no{236}}
\qt@newcmd\qurantrans@es@ccxliv{Y, si las divorciáis antes de haberlas tocado pero después de haberles asignado dote, entonces [entregadles] la mitad de lo asignado, excepto que ellas, o aquel en cuyas manos esté el contrato de matrimonio, renuncien a ello. Y renunciar está más cerca del temor de Dios. Y no olvidéis favoreceros entre vosotros. Ciertamente, Dios observa lo que hacéis.\qt@no{237}}
\qt@newcmd\qurantrans@es@ccxlv{Cuidad vuestras oraciones y, [especialmente], la oración del medio, y permaneced ante Dios con humildad.\qt@no{238}}
\qt@newcmd\qurantrans@es@ccxlvi{Y, si tenéis temor, pues a pie o montados. Y cuando estéis seguros, recordad a Dios y cómo Él os enseñó lo que no sabíais.\qt@no{239}}
\qt@newcmd\qurantrans@es@ccxlvii{Y aquellos de vosotros que mueran dejando esposas deben testar para sus esposas la manutención de un año sin echarlas. Pero si ellas se marchan, entonces no cometéis falta por lo que ellas hagan con sus personas buenamente. Dios es poderoso, sabio.\qt@no{240}}
\qt@newcmd\qurantrans@es@ccxlviii{Y a las divorciadas proveedlas adecuadamente. Eso es una obligación para los temerosos de Dios.\qt@no{241}}
\qt@newcmd\qurantrans@es@ccxlix{Así os explica Dios sus versículos. Quizás así razonéis.\qt@no{242}}
\qt@newcmd\qurantrans@es@ccl{¿No has visto a aquellos que salieron de sus casas por miles, temiendo la muerte? Dios les dijo: «¡Morid!» y luego les dio la vida. Ciertamente, Dios favorece a la gente, pero la mayoría de la gente no lo agradece.\qt@no{243}}
\qt@newcmd\qurantrans@es@ccli{¡Combatid en la senda de Dios! Y sabed que Dios todo lo oye, todo lo sabe.\qt@no{244}}
\qt@newcmd\qurantrans@es@cclii{¿Quién hará a Dios un préstamo generoso? Dios se lo devolverá multiplicado. Dios es quien da la estrechez y el desahogo y a Él regresaréis.\qt@no{245}}
\qt@newcmd\qurantrans@es@ccliii{Acaso no has visto a los notables de los Hijos de Israel cuando, después de Moisés, le dijeron a su profeta: «Desígnanos un rey para que luchemos por la causa de Dios.» Él dijo: «Puede que no acudáis al combate si se os convoca a él.» Ellos dijeron: «¿Cómo no vamos a combatir en la senda de Dios cuando se nos ha expulsado de nuestras casas y [alejado] de nuestros hijos?» Pero cuando se les ordenó que combatieran, excepto unos pocos, todos dieron la espalda. Dios conoce bien a los injustos.\qt@no{246}}
\qt@newcmd\qurantrans@es@ccliv{Su profeta les dijo: «Dios os ha designado a Saúl para que sea vuestro rey.» Ellos dijeron: «¿Cómo puede él reinar sobre nosotros, teniendo nosotros más derecho a reinar, ya que a él no le ha sido concedida una gran riqueza?» Él dijo: «Ciertamente, Dios le ha preferido a vosotros y le ha otorgado más conocimiento y fuerza física.» Dios da Su reino a quien Él quiere. Ciertamente, la bondad de Dios todo lo alcanza, Él todo lo sabe.\qt@no{247}}
\qt@newcmd\qurantrans@es@cclv{Y su profeta les dijo: «En verdad, la señal de su reinado será que vendrá a vosotros, transportada por los ángeles, el Arca portadora de la tranquilidad, que procede de vuestro Señor y de las reliquias que dejaron la familia de Moisés y la familia de Aarón. En ello hay una señal para vosotros, si sois creyentes.»\qt@no{248}}
\qt@newcmd\qurantrans@es@cclvi{Y, cuando Saúl salió con el ejercito, les dijo: «Dios os pone a prueba con un río. Quien beba de él no será de los míos, pero quien no beba de él, excepto un sorbo con el hueco de su mano, será, ciertamente, de los míos.» Pero, excepto unos pocos, todos bebieron abundantemente de él, así que, cuando lo hubieron atravesado, él y los que con él habían creído, dijeron: «Hoy no podremos vencer a Goliat y a sus ejércitos.» Los que contaban encontrarse con Dios, dijeron: «¡Cuántas veces un grupo reducido ha vencido a un grupo numeroso, con el permiso de Dios! ¡Dios está con quienes son pacientes!»\qt@no{249}}
\qt@newcmd\qurantrans@es@cclvii{Y cuando salieron al encuentro de Goliat y sus ejércitos, dijeron: «¡Señor nuestro! ¡Fortalece nuestra paciencia, afirma nuestros pasos y auxílianos contra la nación de los que no creen!»\qt@no{250}}
\qt@newcmd\qurantrans@es@cclviii{Y les derrotaron, con el permiso de Dios. David mató a Goliat y Dios le entregó el gobierno y la sabiduría, y le enseñó lo que Él quiso. Si Dios no hubiera defendido a unos hombres por medio de otros, seguramente, la Tierra se habría corrompido. Pero Dios otorga Sus favores a las criaturas.\qt@no{251}}
\qt@newcmd\qurantrans@es@cclix{Estos son los versículos de Dios, conteniendo la Verdad [de lo que sucedió], que Nosotros recitamos para ti. Y, ciertamente, [ello es una señal de que tú] eres uno de los Mensajeros.\qt@no{252}}
\qt@newcmd\qurantrans@es@cclx{Estos son los Mensajeros. A algunos de ellos les hemos favorecido sobre los otros. Dios habló a algunos y a otros les elevó en dignidad. Dimos a Jesús hijo de María las pruebas claras y le fortalecimos con el Espíritu Santo. Si Dios hubiera querido, sus seguidores no habrían peleado entre ellos después de haberles llegado las pruebas claras. Pero discreparon. Algunos de ellos creyeron y otros no creyeron. Aunque, si Dios hubiera querido, no habrían peleado entre ellos. Pero Dios hace lo que quiere.\qt@no{253}}
\qt@newcmd\qurantrans@es@cclxi{¡Oh, los que creéis! Dad de lo que os hemos proporcionado, antes de que llegue un día en el que no sirvan ni el comercio, ni la amistad ni la intercesión ¡Los que ocultan la Verdad, esos son los opresores!\qt@no{254}}
\qt@newcmd\qurantrans@es@cclxii{¡Al.lah! ¡No hay más dios que Él! El Vivo, El Soporte de la Vida. No le afectan la somnolencia ni el sueño. A Él pertenece todo lo que existe en los cielos y en la Tierra. ¿Quién puede interceder por alguien ante Él, si no es con Su permiso? Él conoce lo que hay ante ellos y lo que hay tras ellos mientras que ellos no abarcan nada de Su conocimiento, excepto lo que Él quiera (enseñarles). Su Trono se extiende sobre los cielos y la Tierra y cuidar de ello no Le causa fatiga. Él es el Altísimo, El Inmenso.\qt@no{255}}
\qt@newcmd\qurantrans@es@cclxiii{No se puede forzar a nadie a aceptar la religión. El buen camino ha quedado claramente diferenciado del extravío. Así que, quien descrea de los falsos dioses y crea en Dios, se habrá aferrado al asidero más firme, en el que no hay fisuras. Dios todo lo oye, todo lo sabe.\qt@no{256}}
\qt@newcmd\qurantrans@es@cclxiv{Dios es el Protector y Amigo de aquellos que creen. Él les saca de las tinieblas hacia la Luz. Pero, aquellos que no creen, tienen por maestros a los falsos ídolos que los llevan de la Luz a las tinieblas. Esos son la gente del Fuego en el cual estarán eternamente.\qt@no{257}}
\qt@newcmd\qurantrans@es@cclxv{¿No te has fijado en el que disputaba con Abraham sobre su Señor, porque Dios le había otorgado el gobierno? Cuando Abraham dijo: «Mi Señor es Quien da la vida y la muerte», él dijo: «Yo doy vida y muerte.» Dijo Abraham: «Ciertamente, Dios trae el Sol por el Oriente. Tráelo pues, tú por el Occidente.» Así fue confundido el que ocultaba la Verdad. Dios no guía a los opresores.\qt@no{258}}
\qt@newcmd\qurantrans@es@cclxvi{O en aquel que pasó por una ciudad en ruinas, caídas las paredes sobre los techos. Dijo: «¿Cómo la devolverá Dios a la vida después de haber muerto?» Entonces, Dios le hizo estar muerto durante cien años y luego le resucitó. Dijo: «¿Cuánto tiempo has permanecido así?» Dijo: «He permanecido así un día o parte de un día.» Dijo: «¡No! ¡Has permanecido así cien años! Mira tu comida y tu bebida, no han cambiado, pero mira a tu asno. Haremos de ti una señal para la gente. Mira, pues, los huesos, cómo los recomponemos y los recubrimos de carne.» Cuando fue evidente para él, dijo: «Ahora sé que Dios tiene poder sobre todas las cosas.»\qt@no{259}}
\qt@newcmd\qurantrans@es@cclxvii{Y [recuerda] cuando Abraham dijo: «¡Señor mío! ¡Muéstrame como das vida a lo que está muerto!» Dijo [Dios]: «¿Acaso no crees?» Respondió: «¡Sí, por supuesto! Es para que mi corazón tenga certeza.» Él [Dios] dijo: «Toma cuatro pájaros. Córtalos en trozos. Luego, pon una parte de ellos en cada montaña. Luego ¡Llámales! Vendrán a ti rápidamente. Y sabe que Dios es poderoso, sabio.»\qt@no{260}}
\qt@newcmd\qurantrans@es@cclxviii{Aquellos que gastan su riqueza en la senda de Dios son semejantes a una semilla que produce siete espigas, en cada una de las cuales hay cien granos. Así incrementa Dios los bienes de quien Él quiere. La bondad de Dios todo lo alcanza, Él todo lo sabe.\qt@no{261}}
\qt@newcmd\qurantrans@es@cclxix{Quienes gastan sus riquezas en la senda de Dios sin, a continuación, hacer alarde de lo que han gastado ni ofender, tendrán su recompensa junto a su Señor y no tendrán temor ni estarán tristes.\qt@no{262}}
\qt@newcmd\qurantrans@es@cclxx{Una palabra amable y un perdón son mejores que una caridad seguida de una ofensa. Dios se basta a Sí mismo, es Indulgente.\qt@no{263}}
\qt@newcmd\qurantrans@es@cclxxi{¡Oh, los que creéis! No arruinéis vuestros actos de caridad con reproches y ofensas, como el que gasta sus riquezas por ostentación ante la gente pero no cree en Dios ni en el Último Día. Ese es semejante a una roca sobre la que hay tierra. Cae sobre ella un aguacero y la deja desnuda. No podrán beneficiarse de nada de lo que obtuvieron. Y Dios no guía a la gente que no cree.\qt@no{264}}
\qt@newcmd\qurantrans@es@cclxxii{Pero, aquellos que gastan de su riqueza por deseo de agradar a Dios y edificación de su propia alma, son como un jardín en una colina. Cae sobre él un aguacero y da de frutos el doble. Y si no le cae la lluvia lo hace el rocío. Y Dios observa lo que hacéis.\qt@no{265}}
\qt@newcmd\qurantrans@es@cclxxiii{¿Desearía alguno de vosotros poseer un jardín de palmeras y viñedos por el que corriesen los arroyos y hubiera toda clase de frutos y que le en el que llegase la vejez siendo sus hijos débiles aún y que un huracán de fuego cayera sobre él [el jardín] y se lo quemara? De esa manera os aclara Dios sus señales. Quizás así reflexionéis.\qt@no{266}}
\qt@newcmd\qurantrans@es@cclxxiv{¡Oh, los que creéis! Repartid de las cosas buenas que obtuvisteis y de lo que hicimos salir de la tierra para vosotros y no escojáis lo malo para repartir, cuando vosotros mismos no lo aceptaríais a no ser con los ojos cerrados. Y sabed que Dios todo lo posee, es digno de alabanza.\qt@no{267}}
\qt@newcmd\qurantrans@es@cclxxv{Satanás os atemoriza con la pobreza y os ordena la avaricia, pero Dios os promete Su perdón y Su favor. Y la bondad de Dios todo lo alcanza, Él todo lo sabe.\qt@no{268}}
\qt@newcmd\qurantrans@es@cclxxvi{Otorga la sabiduría a quien Él quiere. Y, a quien le es dada la sabiduría, recibe un bien abundante. Pero no reflexionan más que los dotados de intelecto.\qt@no{269}}
\qt@newcmd\qurantrans@es@cclxxvii{Cualquier caridad que repartáis por orden de Dios o por propia iniciativa, ciertamente, Dios lo sabe. Y los opresores no tendrán quien les auxilie.\qt@no{270}}
\qt@newcmd\qurantrans@es@cclxxviii{Si hacéis caridad abiertamente, eso está bien, pero si la ocultáis y dais a los necesitados, eso es mejor para vosotros y servirá de compensación por algunas de vuestras malas acciones. Y Dios está informado de lo que hacéis.\qt@no{271}}
\qt@newcmd\qurantrans@es@cclxxix{No es responsabilidad tuya guiarles, sino que es Dios quien guía a quien Él quiere. Y los bienes que repartáis os benefician a vosotros mismos. No gastéis sino es buscando agradar a Dios. Y lo bueno que deis, volverá a vosotros y no seréis oprimidos.\qt@no{272}}
\qt@newcmd\qurantrans@es@cclxxx{Que sea para los necesitados que se encuentran en dificultades por su dedicación a la causa de Dios, sin poder desplazarse por la Tierra. El ignorante piensa que son ricos, por su discreción. Los reconocerás por sus señales. Ellos no piden a la gente, molestándola. Cualquier bien que gastéis, ciertamente, Dios sabe de ello.\qt@no{273}}
\qt@newcmd\qurantrans@es@cclxxxi{Aquellos que reparten sus bienes de noche y de día, en secreto y abiertamente, tendrán su recompensa junto a su Señor y no tendrán que temer y no estarán tristes.\qt@no{274}}
\qt@newcmd\qurantrans@es@cclxxxii{Aquellos que comen de la usura, no se levantarán sino como se levanta quien ha sido tocado de locura por Satanás, y no pueden mantener su equilibrio, por haber dicho: «Ciertamente, la venta es igual que la usura.», cuando Dios ha hecho lícita la venta y ha prohibido la usura. A quien le llegó una exhortación procedente de su Señor y renunció, podrá quedarse lo que obtuvo y su caso será remitido a Dios. Pero quien reincida, será de la gente del Fuego, en el que estarán eternamente.\qt@no{275}}
\qt@newcmd\qurantrans@es@cclxxxiii{Dios destruye la usura e incrementa la caridad. Dios no ama a quien es incrédulo y pecador.\qt@no{276}}
\qt@newcmd\qurantrans@es@cclxxxiv{Ciertamente, aquellos que creen y actúan rectamente, hacen la oración y pagan la limosna obligatoria purificadora de la riqueza, obtendrán su recompensa junto a su Señor, no tendrán que temer y no estarán tristes.\qt@no{277}}
\qt@newcmd\qurantrans@es@cclxxxv{¡Oh, los que creéis! ¡Temed desagradar a Dios y renunciad a los beneficios de la usura restantes, si es que sois creyentes!\qt@no{278}}
\qt@newcmd\qurantrans@es@cclxxxvi{Pero si no lo hacéis, estad seguros de que Dios y Su Mensajero os declaran la guerra. Y si os arrepentís, os pertenecerá vuestro capital original. No oprimiréis y no seréis oprimidos.\qt@no{279}}
\qt@newcmd\qurantrans@es@cclxxxvii{Y si tuviera dificultad, dadle un plazo hasta que pueda y si renunciáis a ello, mejor para vosotros. ¡Si supieseis...!\qt@no{280}}
\qt@newcmd\qurantrans@es@cclxxxviii{Y temed un día en el que seréis devueltos a Dios y a cada cual le será entregada la recompensa de lo que hizo. Y no serán tratados injustamente.\qt@no{281}}
\qt@newcmd\qurantrans@es@cclxxxix{¡Oh, los que creéis! Cuando contraigáis una deuda por un plazo determinado, escribidlo. Que alguien de entre vosotros lo escriba honestamente y que no se niegue a hacerlo, tal como Dios le ha enseñado. Así pues, que escriba y que el deudor le dicte y que tema desagradar a Dios, su Señor, y no omita nada. Y si el deudor fuese necio o débil mental o incapaz de dictar, que su representante legal dicte con honestidad. Y que dos hombres de entre vosotros sean testigos. Y si no hubiese dos hombres, que sean un hombre y dos mujeres que os satisfagan como testigos, de manera que si alguna de ellas se equivoca, una le haga recordar a la otra. Los testigos no deberán negarse, cuando sean requeridos. Y no consideréis fatigoso el escribirlo, sea la suma pequeña o grande, consignando su plazo de vencimiento. Esto es más equitativo para vosotros ante Dios, hace más seguro el testimonio y da menos lugar a dudas. Excepto si la transacción entre vosotros se realiza al contado, sin intermediarios, pues en ese caso, no hay inconveniente si no la escribís. Pero, tomad testigos cuando realicéis transacciones comerciales y que no se moleste o perjudique al notario ni a los testigos. Y si lo hacéis, cometéis un pecado. Y temed a Dios y Dios os enseñará. Dios tiene el conocimiento de todas las cosas.\qt@no{282}}
\qt@newcmd\qurantrans@es@ccxc{Y si estuvieseis de viaje y no encontraseis un notario, entregad una fianza. Pero si uno confía en el otro, aquel al que le fue entregado el depósito, cuando le sea reclamado, que lo entregue y que tema a Dios, su Señor. Y no ocultéis vuestro testimonio. Quien lo oculte tiene, verdaderamente, un corazón pecador. Y Dios sabe lo que hacéis.\qt@no{283}}
\qt@newcmd\qurantrans@es@ccxci{A Dios pertenece lo que hay en los cielos y lo que hay en la Tierra y, tanto si manifestáis lo que hay en vuestras almas como si lo ocultáis, Dios os pedirá cuentas de ello. Perdona a quien Él quiere y castiga a quien Él quiere. Dios tiene poder sobre todas las cosas.\qt@no{284}}
\qt@newcmd\qurantrans@es@ccxcii{El Mensajero cree en lo que fue hecho descender a él procedente de su Señor y (también) los creyentes. Todos ellos creen en Dios y en Sus ángeles y en Sus Libros y en Sus Mensajeros. No hacemos diferencia entre ninguno de Sus Mensajeros. Y dijeron: «Oímos y obedecimos. [Rogamos] Tu perdón, Señor nuestro. Hacia Ti es el retorno.»\qt@no{285}}
\qt@newcmd\qurantrans@es@ccxciii{Dios no responsabiliza a ninguna alma más allá de su capacidad. El bien que haya realizado será para su propio bien y el mal que haya cometido será para su propio perjuicio. ¡Señor nuestro! ¡No nos castigues por nuestros olvidos o errores! ¡Señor nuestro! ¡No nos impongas una carga como la que impusiste a quienes nos precedieron! ¡Señor nuestro! ¡No nos impongas una carga que no podamos soportar! ¡Discúlpanos y perdónanos y ten misericordia de nosotros! Tú eres nuestro Protector, auxílianos pues ante el pueblo de los que ocultan la Verdad.\qt@no{286}}
\qt@newcmd\qurantrans@es@ccxciv{\basmalahes Alif, lam, mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@ccxcv{¡Dios! No hay más dios que Él, el Vivo, el Sustentador de la vida.\qt@no{2}}
\qt@newcmd\qurantrans@es@ccxcvi{Él hizo descender sobre ti la Escritura [Sagrada] con la Verdad, confirmando las Escrituras anteriores e hizo descender la Torá y el Evangelio\qt@no{3}}
\qt@newcmd\qurantrans@es@ccxcvii{anteriormente, como una guía para las gentes. He hizo descender el Criterio. Ciertamente, los que no crean en las señales de Dios tendrán un severo castigo. Y Dios es poderoso, dueño de la venganza.\qt@no{4}}
\qt@newcmd\qurantrans@es@ccxcviii{En verdad, ante Dios no queda oculto nada de lo que hay en la Tierra o en el cielo.\qt@no{5}}
\qt@newcmd\qurantrans@es@ccxcix{Él es quien os da forma en el seno materno como quiere. No hay más dios que Él, el Poderoso, el Sabio.\qt@no{6}}
\qt@newcmd\qurantrans@es@ccc{Él es quien hizo descender sobre ti la Escritura [Sagrada] en la que hay versículos unívocos que son como la Madre de la Escritura [Sagrada] y otros que son equívocos. Aquellos cuyos corazones están desviados siguen los que son equívocos, buscando crear problemas y pretendiendo interpretar su simbolismo. Pero su simbolismo sólo lo conoce Dios. Los arraigados en el conocimiento dicen: «Creemos en Él. Todo procede de nuestro Señor.» Pero no reflexionan más que los dotados de intelecto.\qt@no{7}}
\qt@newcmd\qurantrans@es@ccci{¡Señor nuestro! ¡No desvíes nuestros corazones después de haberlos guiado y otórganos una misericordia procedente de Ti! Ciertamente Tú eres el Generoso.\qt@no{8}}
\qt@newcmd\qurantrans@es@cccii{¡Señor nuestro! ¡Tú eres quien reunirá a la gente un día sobre el que no hay duda que ha de llegar! Dios no transgrede Su promesa.\qt@no{9}}
\qt@newcmd\qurantrans@es@ccciii{En verdad, a quienes no creen, ni sus riquezas ni sus hijos les servirán de nada ante Dios. Ellos serán el combustible del fuego [del infierno].\qt@no{10}}
\qt@newcmd\qurantrans@es@ccciv{Como sucedió con la gente del Faraón y los que les precedieron, que desmentían Nuestras señales y Dios les castigó por sus pecados. Dios es severo en la retribución.\qt@no{11}}
\qt@newcmd\qurantrans@es@cccv{Di a los que no creen: «Pronto seréis vencidos y reunidos en el Infierno.» ¡Que mal lugar de descanso!\qt@no{12}}
\qt@newcmd\qurantrans@es@cccvi{Hubo, en verdad, una señal para vosotros en los dos grupos que se enfrentaron. Un grupo combatía en la senda de Dios y al otro, que no creía, le pareció a simple vista que eran el doble. Dios fortalece con Su ayuda a quien quiere. En verdad, en esto hay una lección para los que son observadores.\qt@no{13}}
\qt@newcmd\qurantrans@es@cccvii{Fue adornado para la gente el amor por las pasiones: las mujeres, los hijos, la acumulación de oro y plata por quintales y los caballos de raza, los ganados y los campos de cultivo. Esos son los placeres de la vida en este mundo. Pero junto a Dios está el mejor destino.\qt@no{14}}
\qt@newcmd\qurantrans@es@cccviii{Di: «¿Puedo informaros de algo mejor para vosotros que todo eso? Para aquellos que temen desagradar a Dios hay junto a su Señor Jardines de cuyas profundidades brotan los ríos, en los que estarán eternamente, parejas purificadas y satisfacción de Dios.» Y Dios observa a Sus siervos.\qt@no{15}}
\qt@newcmd\qurantrans@es@cccix{Aquellos que dicen: «¡Señor nuestro! ¡Hemos creído, por tanto, perdona nuestros pecados y líbranos del castigo del Fuego!»\qt@no{16}}
\qt@newcmd\qurantrans@es@cccx{Los pacientes, los sinceros, los humildes, los caritativos y los que piden perdón antes del alba.\qt@no{17}}
\qt@newcmd\qurantrans@es@cccxi{Dios, los ángeles y los que tienen conocimiento atestiguan que no hay más dios que Él, el Equitativo. No hay más dios que Él, el Poderoso, el Sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@cccxii{Ciertamente, la religión ante Dios es el Islam. Aquellos a quienes les fue dada la Escritura [Sagrada] no disintieron unos de otros después de haberles llegado el conocimiento sino por envidia entre ellos. Y quien no crea en las señales de Dios [sepa que] Dios es rápido haciendo la cuenta.\qt@no{19}}
\qt@newcmd\qurantrans@es@cccxiii{Así pues, si te discuten di: «Me he sometido a Dios y también los que me siguen.» Y di a quienes les fue dada la Escritura [Sagrada] y [también] a los que no poseen instrucción: «¿Os sometéis?» Si se someten, ciertamente, serán guiados. Pero si dan la espalda, en verdad, tu responsabilidad es sólo informarles. Y Dios observa a Sus siervos.\qt@no{20}}
\qt@newcmd\qurantrans@es@cccxiv{En verdad, a aquellos que no creen en las señales de Dios y matan a los profetas sin derecho y matan a quienes proclaman la justicia, infórmales de (que les aguarda) un castigo doloroso.\qt@no{21}}
\qt@newcmd\qurantrans@es@cccxv{Esos son los que han arruinado sus obras en esta vida y en la otra y no tendrán quien les auxilie.\qt@no{22}}
\qt@newcmd\qurantrans@es@cccxvi{Has visto a aquellos a quienes les fue entregada una parte de la Escritura [Sagrada]? Se les invita a la Escritura de Dios para que juzgue entre ellos, pero parte de ellos dan la espalda y se niegan [a aceptar la Verdad].\qt@no{23}}
\qt@newcmd\qurantrans@es@cccxvii{Eso es porque dicen: «No nos tocará el Fuego más que unos pocos días.» Sus propias invenciones les han cegado.\qt@no{24}}
\qt@newcmd\qurantrans@es@cccxviii{¿Qué harán cuando les reunamos para un día sobre el que no hay duda [que ha de venir] y cada alma sea recompensada por lo que hizo y no sean tratados injustamente?\qt@no{25}}
\qt@newcmd\qurantrans@es@cccxix{Di: «¡Oh Dios, Soberano de todo gobierno! Tú das el gobierno a quien quieres y se lo quitas a quien quieres y das poder a quien quieres y humillas a quien quieres. En Tu mano está todo bien. En verdad, Tú tienes poder sobre todas las cosas.»\qt@no{26}}
\qt@newcmd\qurantrans@es@cccxx{«Tú introduces la noche en el día e introduces el día en la noche y haces salir lo vivo de lo muerto y lo muerto de lo vivo. Y provees sin límite a quien quieres.»\qt@no{27}}
\qt@newcmd\qurantrans@es@cccxxi{¡Que los creyentes no tomen por amigos a los que no creen en lugar de a los que creen! Dios no tendrá nada con quien haga eso, excepto que disimule por temor a ellos. Dios os advierte que tengáis cuidado con Él [si Le desobedecéis]. Y a Dios retornamos.\qt@no{28}}
\qt@newcmd\qurantrans@es@cccxxii{Di: «Tanto si ocultáis lo que hay en vuestros pechos, como si lo manifestáis, Dios lo conoce y conoce lo que hay en los cielos y en la Tierra. Y Dios tiene poder sobre todas las cosas.»\qt@no{29}}
\qt@newcmd\qurantrans@es@cccxxiii{El día en que cada alma encuentre ante sí lo que hizo de bien y lo que hizo de mal, deseará que haya una gran distancia entre ello y él mismo. Dios os advierte que tengáis cuidado con Él [si Le desobedecéis]. Y Dios es piadoso con Sus siervos.\qt@no{30}}
\qt@newcmd\qurantrans@es@cccxxiv{Di: «Si amáis a Dios seguidme, Dios os amará y perdonará vuestros pecados. Dios es Perdonador, Misericordiosísimo con los creyentes.»\qt@no{31}}
\qt@newcmd\qurantrans@es@cccxxv{Di: «¡Obedeced a Dios y al Mensajero!» Pero si dan la espalda, en verdad, Dios no ama a los que no creen.\qt@no{32}}
\qt@newcmd\qurantrans@es@cccxxvi{En verdad, Dios eligió a Adán, a Noé, a la familia de Abraham y a la familia de Imran sobre todo el mundo.\qt@no{33}}
\qt@newcmd\qurantrans@es@cccxxvii{Descendientes unos de otros. Dios todo lo oye, todo lo sabe.\qt@no{34}}
\qt@newcmd\qurantrans@es@cccxxviii{[Recuerda] cuando dijo la mujer de Imran: «¡Señor mío! En verdad, he hecho voto de consagrar a Ti lo que llevo en mi seno ¡Acéptamelo! En verdad, Tú eres Quien todo lo oye, Quien todo lo sabe.»\qt@no{35}}
\qt@newcmd\qurantrans@es@cccxxix{Y cuando dio a luz una niña, dijo: «¡Señor, he dado a luz una hembra!» Pero Dios sabía mejor que ella lo que había dado a luz y [que] una hembra no es lo mismo que un varón. «En verdad, la he llamado María y he puesto a ella y a su descendencia bajo Tu protección de Satanás maldecido y lapidado.»\qt@no{36}}
\qt@newcmd\qurantrans@es@cccxxx{Su Señor la aceptó complacido, la hizo crecer bien y la puso bajo la tutela de Zacarías. Siempre que Zacarías entraba a visitarla a su oratorio, encontraba junto a ella provisiones. Decía: «Oh María ¿De dónde te viene esto?» Ella decía: «De Dios.» En verdad, Dios provee sin medida a quien Él quiere.\qt@no{37}}
\qt@newcmd\qurantrans@es@cccxxxi{Allí mismo rogó Zacarías a su Señor. Dijo: «¡Señor mío, otórgame una descendencia buena, que venga de Ti! ¡En verdad, Tú [siempre] escuchas la súplica!»\qt@no{38}}
\qt@newcmd\qurantrans@es@cccxxxii{Entonces, los ángeles le llamaron mientras él permanecía en pie rezando en su oratorio: «Dios te da la buena nueva de [el nacimiento de] Juan como confirmador de una palabra que viene de Dios. Será eminente y casto y un profeta de entre los justos.\qt@no{39}}
\qt@newcmd\qurantrans@es@cccxxxiii{Dijo: «¡Señor mío! ¿Cómo podré tener un hijo cuando me ha llegado la vejez y mi esposa es estéril?» Dijo: «Así será. Dios hace lo que quiere.»\qt@no{40}}
\qt@newcmd\qurantrans@es@cccxxxiv{Dijo: «Señor mío, dame un signo.» Dijo: «Tu signo será que no podrás hablar a la gente durante tres días salvo por señas. Recuerda mucho a tu Señor y glorifícale mañana y tarde.»\qt@no{41}}
\qt@newcmd\qurantrans@es@cccxxxv{Y [recuerda] cuando los ángeles dijeron: «¡Oh María! En verdad, Dios te ha escogido y purificado y te ha elegido entre todas las mujeres.»\qt@no{42}}
\qt@newcmd\qurantrans@es@cccxxxvi{«¡Oh María! ¡Se humilde ante tu Señor y prostérnate e inclínate con los que se inclinan!»\qt@no{43}}
\qt@newcmd\qurantrans@es@cccxxxvii{Esto son noticias del mundo oculto a los sentidos que te revelamos. Tu no estabas con ellos cuando echaban a suertes con sus cálamos [para ver] quién de ellos se encargaba de la tutela de María, ni estabas con ellos cuando disputaban.\qt@no{44}}
\qt@newcmd\qurantrans@es@cccxxxviii{[Y recuerda] cuando le dijeron los ángeles: «¡Oh María! ¡Dios te anuncia una palabra que de Él procede! Su nombre es El Mesías, Jesús hijo de María. Será honorable en esta vida y en la otra y de los cercanos [a Dios].\qt@no{45}}
\qt@newcmd\qurantrans@es@cccxxxix{Y hablará a las gentes desde la cuna y de adulto y será de los justos.»\qt@no{46}}
\qt@newcmd\qurantrans@es@cccxl{Ella dijo: «¡Señor mío! ¿Cómo tendré un hijo si no me ha tocado varón?» Dijo: «Así será. Dios crea lo que quiere. Cuando decreta un asunto, le dice: ¡Sé! y es.»\qt@no{47}}
\qt@newcmd\qurantrans@es@cccxli{«Y Él le enseñará la Escritura [Sagrada] y la Sabiduría y la Torá y el Evangelio.»\qt@no{48}}
\qt@newcmd\qurantrans@es@cccxlii{Y [será Jesús] un profeta [enviado] a los Hijos de Israel [que proclamará]: «En verdad, he venido a vosotros con una señal procedente de vuestro Señor. Crearé para vosotros, del barro, algo con la forma de un pájaro, luego soplaré sobre él y será un pájaro [vivo], con el permiso de Dios. Y sanaré al ciego y al leproso y resucitaré al muerto, con el permiso de Dios. Y os informaré de lo que coméis y de lo que guardáis en vuestras casas [sin haberlo visto]. En verdad, en ello hay una señal [de que yo soy un profeta] para vosotros, si es que sois creyentes,\qt@no{49}}
\qt@newcmd\qurantrans@es@cccxliii{[que vengo] confirmando lo que ya teníais en vuestras manos procedente de la Torá y haciendo lícito para vosotros algunas cosas que se os habían prohibido. Puesto que he venido a vosotros con un signo que procede de vuestro Señor ¡Temed a Dios y obedecedme!\qt@no{50}}
\qt@newcmd\qurantrans@es@cccxliv{En verdad, Dios es mi Señor y vuestro Señor, así pues ¡Adoradle! ¡Este es el camino recto!»\qt@no{51}}
\qt@newcmd\qurantrans@es@cccxlv{Pero cuando Jesús sintió la falta de fe de ellos, dijo: «¿Quiénes serán mis partidarios [en la defensa de la causa que lleva] hacia Dios?» Los apóstoles dijeron: «Nosotros somos los partidarios de Dios. Hemos creído en Dios. Testifica, pues, que nosotros somos musulmanes [a Él sometidos].\qt@no{52}}
\qt@newcmd\qurantrans@es@cccxlvi{¡Señor nuestro! ¡Hemos creído en lo que hiciste descender y hemos seguido al Mensajero! ¡Inscríbenos, pues, con los que dan testimonio!»\qt@no{53}}
\qt@newcmd\qurantrans@es@cccxlvii{Y conspiraron [contra Jesús sus enemigos] y Dios [también] conspiró. Pero Dios es Quien mejor trama.\qt@no{54}}
\qt@newcmd\qurantrans@es@cccxlviii{[Recuerda] cuando dijo Dios: «¡Oh Jesús! Te tomaré y te elevaré hacia Mí y te purificaré [de las calumnias] de los que no creen. Y colocaré a los que te siguen por encima de los que no creen, hasta el Día del Levantamiento. Luego regresaréis hacia Mí y juzgaré entre vosotros sobre aquello en lo que manteníais diferencias.\qt@no{55}}
\qt@newcmd\qurantrans@es@cccxlix{En cuanto a aquellos que no creen, les castigaré con un severo castigo en esta vida y en la otra y no tendrán quien les auxilie.\qt@no{56}}
\qt@newcmd\qurantrans@es@cccl{En cambio, aquellos que crean y obren rectamente serán adecuadamente recompensados. Dios no ama a los opresores.»\qt@no{57}}
\qt@newcmd\qurantrans@es@cccli{Esto que te recitamos procede de las señales y del Recuerdo Sabio.\qt@no{58}}
\qt@newcmd\qurantrans@es@ccclii{Verdaderamente, ante Dios el caso de Jesús es semejante al de Adán. Él lo creó de barro y tras ello le dijo: «¡Sé!» y fue.\qt@no{59}}
\qt@newcmd\qurantrans@es@cccliii{La Verdad procede de tu Señor. ¡No seas pues de los escépticos!\qt@no{60}}
\qt@newcmd\qurantrans@es@cccliv{Por tanto, a quien te discuta sobre ello, después del conocimiento que ha venido a ti, dile: «¡Venid! ¡Llamemos a nuestros hijos y a los vuestros, a nuestras mujeres y a las vuestras y a nosotros mismos y a vosotros mismos y supliquemos [el juicio de Dios] y que la maldición de Dios caiga sobre los mentirosos!»\qt@no{61}}
\qt@newcmd\qurantrans@es@ccclv{Este es, ciertamente, el relato verdadero. No hay más dios que Dios. Y, ciertamente, Dios es el Poderoso, el Sabio.\qt@no{62}}
\qt@newcmd\qurantrans@es@ccclvi{Y si dan la espalda, en verdad, Dios es quien mejor conoce a los corruptores.\qt@no{63}}
\qt@newcmd\qurantrans@es@ccclvii{Di: «¡Oh gente de la Escritura [Sagrada]! Venid a una palabra igual para vosotros y nosotros: Que no adoraremos más que a Dios y que no asociaremos nada a Él y que no nos tomaremos unos a otros como señores junto a Dios.» Y si dan la espalda, decidles entonces: «Sed testigos de que nosotros somos musulmanes.»\qt@no{64}}
\qt@newcmd\qurantrans@es@ccclviii{¡Oh gente de la Escritura [Sagrada]! ¿Por qué discutís sobre Abraham, si la Torá y el Evangelio no fueron hechos descender sino después de él? ¿Es que no razonáis?\qt@no{65}}
\qt@newcmd\qurantrans@es@ccclix{Vosotros sois aquellos que discutíais sobre lo que conocíais ¿Por qué discutís sobre lo que no tenéis conocimiento? Dios sabe y vosotros no sabéis.\qt@no{66}}
\qt@newcmd\qurantrans@es@ccclx{Abraham no era judío ni era cristiano, sino que era un buscador de la Verdad, sometido a Dios [muslim] y no era de los politeístas.\qt@no{67}}
\qt@newcmd\qurantrans@es@ccclxi{En verdad, la gente más cercana a Abraham son aquellos que le seguían y éste profeta y aquellos que creen [en él]. Y Dios es el amigo y guardián de los creyentes.\qt@no{68}}
\qt@newcmd\qurantrans@es@ccclxii{Un grupo de la gente de la Escritura [Sagrada] desearían extraviaros, pero sólo se extravían ellos mismos y no se dan cuenta.\qt@no{69}}
\qt@newcmd\qurantrans@es@ccclxiii{¡Oh gente de la Escritura [Sagrada]! ¿Por qué no creéis en las señales de Dios si sois testigos?\qt@no{70}}
\qt@newcmd\qurantrans@es@ccclxiv{¡Oh gente de la Escritura [Sagrada]! ¿Por qué vestís la Verdad con la falsedad y ocultáis la Verdad, a sabiendas de lo que hacéis?\qt@no{71}}
\qt@newcmd\qurantrans@es@ccclxv{Un grupo de la gente de la Escritura [Sagrada] dice: «Creed al principio de la mañana en lo que fue hecho descender sobre los creyentes y dejad de creer al final de ella, quizás así ellos retornen [de sus creencias a las vuestras].\qt@no{72}}
\qt@newcmd\qurantrans@es@ccclxvi{Y no creáis en nadie excepto en quien siga vuestra religión.» Di: «La guía [verdadera] es la guía de Dios y [no creáis] que le fue dado a alguien algo como lo que os fue dado a vosotros o que ellos pueden discutir con vosotros ante vuestro Señor.» Di: «En verdad, el favor está en las manos de Dios y se lo otorga a quien Él quiere. Y la bondad de Dios todo lo alcanza, Él todo lo sabe.\qt@no{73}}
\qt@newcmd\qurantrans@es@ccclxvii{Distingue con Su misericordia a quien Él quiere. Dios es el dueño del Favor Inmenso.»\qt@no{74}}
\qt@newcmd\qurantrans@es@ccclxviii{Y entre la gente de la Escritura [Sagrada] los hay que si les confías un quintal te lo devuelven [intacto] y quienes si les confías una moneda no te la devuelven sino es reclamándosela con insistencia. Eso es porque ellos dicen: «No tenemos obligaciones con los que no son judíos.» Pero mienten sobre Dios a sabiendas.\qt@no{75}}
\qt@newcmd\qurantrans@es@ccclxix{¡Sí! Quien sea leal a su compromiso y tema a Dios, sepa que, en verdad, Dios ama a quienes son temerosos.\qt@no{76}}
\qt@newcmd\qurantrans@es@ccclxx{En verdad, aquellos que venden el compromiso con Dios y sus promesas por un precio pequeño no tendrán parte en la otra vida y Dios no les hablará ni les mirará el Día del Levantamiento ni les purificará y tendrán un castigo doloroso.\qt@no{77}}
\qt@newcmd\qurantrans@es@ccclxxi{Y, en verdad, hay un grupo de ellos que complican con sus lenguas la Escritura [Sagrada para que penséis que [lo que dicen] pertenece a la Escritura, pero no es de la Escritura y dicen: «Esto proviene de Dios», pero no proviene de Dios y atribuyen a Dios mentiras a sabiendas [de lo que hacen].\qt@no{78}}
\qt@newcmd\qurantrans@es@ccclxxii{No es apropiado de un ser humano al que Dios entrega la Escritura [Sagrada], el juicio y la profecía que luego diga a la gente: «Sed mis siervos en lugar de [siervos de] Dios», sino [más bien que les diga]: «Sed espirituales ya que enseñáis la Escritura [Sagrada] y la estudiáis.»\qt@no{79}}
\qt@newcmd\qurantrans@es@ccclxxiii{Y Él no os ordena que toméis por señores a los ángeles ni a los profetas ¿Va Él a ordenaros que dejéis de creer después de que sois creyentes?\qt@no{80}}
\qt@newcmd\qurantrans@es@ccclxxiv{Y [recuerda] cuando Dios hizo un pacto con los profetas: «Puesto que os he dado parte de la Escritura [Sagrada] y Sabiduría, cuando venga a vosotros un Mensajero confirmando lo que tenéis, creed en él y ayudadle.» Dijo Él: «¿Acordasteis y aceptasteis Mi pacto en estos términos?» Dijeron: «Lo acordamos.» Dijo Él: «Pues dad testimonio de ello y Yo seré con vosotros uno de los que atestiguan.»\qt@no{81}}
\qt@newcmd\qurantrans@es@ccclxxv{Y, quienes tras esto den la espalda, esos serán los transgresores.\qt@no{82}}
\qt@newcmd\qurantrans@es@ccclxxvi{¿Acaso buscan algo diferente a la religión de Dios cuando quienes están en los cielos y en la Tierra se someten a Él voluntaria u obligadamente y a Él serán devueltos?\qt@no{83}}
\qt@newcmd\qurantrans@es@ccclxxvii{Di: «Creemos en Dios y en la revelación que fue hecha descender para nosotros y en la que fue hecha descender para Abraham, Ismael, Isaac, Jacob y las tribus, y en lo que le fue dado a Moisés y a Jesús y a los profetas procedente de su Señor. No hacemos diferencias entre ninguno de ellos y nos sometemos a Él.»\qt@no{84}}
\qt@newcmd\qurantrans@es@ccclxxviii{Y a quien desee otra creencia diferente al Islam no se le aceptará y en la otra vida será de los perdedores.\qt@no{85}}
\qt@newcmd\qurantrans@es@ccclxxix{¿Cómo va Dios a guiar a un pueblo que descree después de haber creído, habiendo sido testigos de que el Mensajero es verdadero y habiéndoles llegado las pruebas claras? Dios no guía a la gente opresora.\qt@no{86}}
\qt@newcmd\qurantrans@es@ccclxxx{Su recompensa es que serán maldecidos por Dios y por los ángeles y por la gente conjuntamente.\qt@no{87}}
\qt@newcmd\qurantrans@es@ccclxxxi{En ese [estado de maldición] permanecerán eternamente. No se les aliviará el castigo ni tendrán respiro.\qt@no{88}}
\qt@newcmd\qurantrans@es@ccclxxxii{Excepto a quienes se arrepientan tras ello y se corrijan pues, en verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{89}}
\qt@newcmd\qurantrans@es@ccclxxxiii{En verdad, a quienes no crean después de haber tenido fe e incrementen su incredulidad, no les será aceptado su arrepentimiento. Esos son los extraviados.\qt@no{90}}
\qt@newcmd\qurantrans@es@ccclxxxiv{En verdad, a aquellos que no creen y mueren sin ser creyentes, aunque ofrecieran como recate la Tierra llena de oro, no se les aceptaría. Les aguarda un castigo doloroso y no tendrán quien les auxilie.\qt@no{91}}
\qt@newcmd\qurantrans@es@ccclxxxv{No obtendréis la virtud hasta que no gastéis en caridad de aquello que amáis. Y cualquier cosa que gastéis Dios lo sabrá.\qt@no{92}}
\qt@newcmd\qurantrans@es@ccclxxxvi{Todos los alimentos [puros] eran lícitos para los Hijos de Israel excepto aquello que Israel se prohibió a sí mismo antes de que descendiera la Torá. Di: «Traed la Torá y leedla si es que decís la verdad.»\qt@no{93}}
\qt@newcmd\qurantrans@es@ccclxxxvii{Quienes inventen mentiras sobre Dios después de esto, esos serán los opresores.\qt@no{94}}
\qt@newcmd\qurantrans@es@ccclxxxviii{Di: «Dios ha dicho la Verdad. Seguid, pues, las creencias de Abraham, que era un buscador de la Verdad y no uno de los politeístas.»\qt@no{95}}
\qt@newcmd\qurantrans@es@ccclxxxix{En verdad, la primera Casa establecida para la humanidad como bendición y guía es, sin duda, la de Bakka.\qt@no{96}}
\qt@newcmd\qurantrans@es@cccxc{En ella hay signos claros, [entre ellos] la morada de Abraham. Y quien entre en ella estará seguro. Dios ha ordenado a las gentes la peregrinación a la Casa, si disponen de medios. Y quien reniegue (de su obligación y no realice la peregrinación, sepa que) Dios no necesita de nadie.\qt@no{97}}
\qt@newcmd\qurantrans@es@cccxci{Di: «¡Oh gente de la Escritura [Sagrada]! ¿Por qué no creéis en las señales de Dios? Dios es testigo de lo que hacéis.»\qt@no{98}}
\qt@newcmd\qurantrans@es@cccxcii{Di: «¡Oh gente de la Escritura «Sagrada»! ¿Por qué dificultáis la senda de Dios a los que creen y tratáis de complicarla, cuando sois testigos [de que es verdadera]? Dios no está desatento a lo que hacéis.»\qt@no{99}}
\qt@newcmd\qurantrans@es@cccxciii{¡Oh los que creéis! Si obedecéis a un grupo de los que recibieron la Escritura [Sagrada] conseguirán que, después de haber creído, regreséis a la incredulidad.\qt@no{100}}
\qt@newcmd\qurantrans@es@cccxciv{¿Cómo podéis no creer cuando se os recitan los versículos de Dios y entre vosotros está Su Mensajero y quien se refugie en Dios será guiado a un camino recto?\qt@no{101}}
\qt@newcmd\qurantrans@es@cccxcv{¡Oh los que creéis! ¡Temed a Dios como debe ser temido y no muráis sin estar a Él sometidos!\qt@no{102}}
\qt@newcmd\qurantrans@es@cccxcvi{Y aferraos a la cuerda de Dios todos juntos y no os dividáis. Y recordad la merced de Dios con vosotros cuando erais enemigos y Él unió vuestros corazones y os convertisteis, por Su merced, en hermanos y estabais al borde del abismo del Fuego y os salvo de él. Así es como Dios os explica claramente sus signos. Quizás así os guiéis\qt@no{103}}
\qt@newcmd\qurantrans@es@cccxcvii{y surja de vosotros una comunidad que invite al bien, ordene hacer lo que es correcto y prohíba hacer el mal. Esos serán los triunfadores.\qt@no{104}}
\qt@newcmd\qurantrans@es@cccxcviii{Y no seáis como aquellos que se dividieron y se enfrentaron después de haber venido a ellos las pruebas claras. Esos tendrán un castigo inmenso\qt@no{105}}
\qt@newcmd\qurantrans@es@cccxcix{el día en que unos rostros se iluminen y otros se ensombrezcan. En cuanto a aquellos que sus rostros se ensombrezcan [se les dirá]: «¿Descreísteis después de haber tenido fe? Saboread ahora el castigo por aquello en lo que dejasteis de creer.»\qt@no{106}}
\qt@newcmd\qurantrans@es@cd{Pero aquellos cuyos rostros se iluminen estarán eternamente en la misericordia de Dios.\qt@no{107}}
\qt@newcmd\qurantrans@es@cdi{Esas son las señales de Dios. Te las recitamos conforme a la Verdad. Y Dios no desea oprimir a nadie.\qt@no{108}}
\qt@newcmd\qurantrans@es@cdii{Y a Dios pertenece lo que hay en los cielos y en la Tierra. Todo será devuelto a Dios.\qt@no{109}}
\qt@newcmd\qurantrans@es@cdiii{Sois la mejor comunidad que se ha creado para los seres humanos. Ordenáis el bien, prohibís el mal y creéis en Dios. Y si la gente de la Escritura [Sagrada] creyera, sería mejor para ellos. Entre ellos los hay que son creyentes, pero la mayoría de ellos son pecadores.\qt@no{110}}
\qt@newcmd\qurantrans@es@cdiv{Jamás podrán perjudicaros excepto muy poco y si combaten contra vosotros huirán dándoos la espalda y entonces no serán auxiliados.\qt@no{111}}
\qt@newcmd\qurantrans@es@cdv{La humillación les golpeará donde quiera que se encuentren, excepto que Dios les proteja o les protejan los hombres. Han conseguido enfadar a Dios y les ha golpeado la miseria por haber desmentido las señales de Dios y porque, sin tener derecho, mataron a los profetas y porque fueron desobedientes y transgresores.\qt@no{112}}
\qt@newcmd\qurantrans@es@cdvi{No todos son iguales. Entre la gente de la Escritura [Sagrada] hay una comunidad recta que recita los versículos de Dios en mitad de la noche y humillan sus frentes hasta el suelo en adoración.\qt@no{113}}
\qt@newcmd\qurantrans@es@cdvii{Creen en Dios y en el Último Día y ordenan lo que está bien y prohíben el mal. Compiten con premura en [la realización de] buenas acciones y son de los justos.\qt@no{114}}
\qt@newcmd\qurantrans@es@cdviii{Y el bien que hacen no les será ignorado. Dios conoce bien a los que son temerosos.\qt@no{115}}
\qt@newcmd\qurantrans@es@cdix{En verdad, a aquellos que no creen, ni sus riquezas ni sus hijos les servirán de nada ante Dios. Esos son la gente del Fuego, en el cual permanecerán eternamente.\qt@no{116}}
\qt@newcmd\qurantrans@es@cdx{Lo que gastan en esta vida es semejante a un viento helado que azota los cultivos de unas gentes que se han oprimido a sí mismas y los destruye. No es Dios quien les oprimió, sino ellos mismos quienes se oprimen.\qt@no{117}}
\qt@newcmd\qurantrans@es@cdxi{¡Oh los que creéis! No toméis como amigos íntimos a quienes no sean de los vuestros. No dejarán de intentar corromperos. Les gustaría veros en dificultades. El odio asoma por sus bocas pero lo que ocultan sus pechos es peor aun. Os hemos explicado las señales claramente, si lo pensáis.\qt@no{118}}
\qt@newcmd\qurantrans@es@cdxii{Vosotros les amáis pero ellos no os aman. Y [eso es porque] vosotros creéis en todas las Escrituras [Sagradas]. Y cuando se encuentran con vosotros dicen: «¡Creemos!» Pero cuando están solos se muerden las puntas de los dedos del odio que os tienen. Di: «¡Que vuestro odio os mate!» En verdad, Dios conoce bien lo que hay en el interior de los pechos.\qt@no{119}}
\qt@newcmd\qurantrans@es@cdxiii{Si os ocurre algo bueno les molesta y si os sobreviene una dificultad se alegran por ello, pero si sois pacientes y temerosos de Dios, sus intrigas no os perjudicarán en absoluto. En verdad, Dios tiene bajo control lo que ellos hacen.\qt@no{120}}
\qt@newcmd\qurantrans@es@cdxiv{Y [recuerda] cuando al principio de la mañana te alejaste de tu familia para situar a los creyentes en sus puestos de batalla. Dios todo lo oye, todo lo sabe.\qt@no{121}}
\qt@newcmd\qurantrans@es@cdxv{[Y recuerda también] cuando dos grupos de los vuestros flaquearon y proyectaron desertar y Dios les infundió ánimo. ¡Que los creyentes depositen su confianza únicamente en Dios!\qt@no{122}}
\qt@newcmd\qurantrans@es@cdxvi{Ciertamente Él os ayudó en Badr cuando estabais en inferioridad. Temed, pues, a Dios. Quizás así agradezcáis.\qt@no{123}}
\qt@newcmd\qurantrans@es@cdxvii{[Y recuerda el día de Badr] cuando decías a los creyentes: «¿Acaso para vosotros no es suficiente que vuestro Señor os refuerce con tres mil ángeles descendiendo [de los cielos]?\qt@no{124}}
\qt@newcmd\qurantrans@es@cdxviii{Sí, si sois pacientes y temerosos y os atacan de improviso, [hoy también] Dios os reforzará con cinco mil ángeles portadores de distintivos.»\qt@no{125}}
\qt@newcmd\qurantrans@es@cdxix{Y Dios no lo hace sino [para alegraros] con una buena noticia y para tranquilizar vuestros corazones, pues la victoria solamente proviene de Dios [que es] el Poderoso, el Sabio,\qt@no{126}}
\qt@newcmd\qurantrans@es@cdxx{y para destruir a una parte de los que no creen o para derrotarles y que regresen fracasados [a La Meca].\qt@no{127}}
\qt@newcmd\qurantrans@es@cdxxi{Tú no eres en absoluto responsable de este asunto o de si Dios les perdona o les castiga porque son opresores.\qt@no{128}}
\qt@newcmd\qurantrans@es@cdxxii{A Dios pertenece lo que hay en los cielos y en la Tierra. Perdona a quien Él quiere y castiga a quien Él quiere. Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{129}}
\qt@newcmd\qurantrans@es@cdxxiii{Oh los que creéis! ¡No os alimentéis de la usura, doblando una y otra vez [vuestros capitales]! Temed a Dios. Quizás así tengáis éxito.\qt@no{130}}
\qt@newcmd\qurantrans@es@cdxxiv{Y temed el Fuego que ha sido preparado para los que no creen.\qt@no{131}}
\qt@newcmd\qurantrans@es@cdxxv{Y obedeced a Dios y al Mensajero, para que así se tenga clemencia con vosotros.\qt@no{132}}
\qt@newcmd\qurantrans@es@cdxxvi{Y apresuraos hacia el perdón de vuestro Señor y hacia un jardín cuya extensión es como los cielos y la Tierra y que ha ido preparado para los temerosos de Dios,\qt@no{133}}
\qt@newcmd\qurantrans@es@cdxxvii{aquellos que reparten de sus riquezas en la prosperidad y en la adversidad y aquellos que contienen su ira y perdonan a las personas, pues Dios ama a los que hacen el bien.\qt@no{134}}
\qt@newcmd\qurantrans@es@cdxxviii{Y aquellos que, cuando cometen un pecado o son injustos consigo mismos, recuerdan a Dios y buscan el perdón por sus pecados, pues ¿Quién perdona los pecados sino Dios? y no reinciden en lo que hicieron [mal] ahora que lo saben.\qt@no{135}}
\qt@newcmd\qurantrans@es@cdxxix{Esos obtendrán en recompensa el perdón de su Señor y jardines de cuyas profundidades brotan los arroyos, en los que estarán eternamente. ¡Qué hermosa es la recompensa de los que obran [bien]!\qt@no{136}}
\qt@newcmd\qurantrans@es@cdxxx{Antes de vosotros también hubo tradiciones. Viajad, pues, por la Tierra y observad cual fue el fin de los desmentidores [de la Verdad].\qt@no{137}}
\qt@newcmd\qurantrans@es@cdxxxi{Eso es una evidencia para toda la humanidad y una guía y una advertencia para los temerosos de Dios.\qt@no{138}}
\qt@newcmd\qurantrans@es@cdxxxii{Y no desfallezcáis ni os apenéis pues, si tenéis fe, seréis los vencedores.\qt@no{139}}
\qt@newcmd\qurantrans@es@cdxxxiii{Si sufrís una herida, ellos también sufrieron una herida semejante. Nosotros hacemos que días así se alternen entre las gentes, para que conozca Dios quienes son los creyentes y tomar de entre vosotros mártires. Y Dios no ama a los opresores.\qt@no{140}}
\qt@newcmd\qurantrans@es@cdxxxiv{Y para que Dios ponga a prueba a quienes tienen fe [y les perdone] y extermine a los que no creen.\qt@no{141}}
\qt@newcmd\qurantrans@es@cdxxxv{¿O acaso contabais con entrar en el Jardín sin que Dios sepa previamente quiénes de vosotros se han esforzado y conozca a los que tienen paciencia?\qt@no{142}}
\qt@newcmd\qurantrans@es@cdxxxvi{Ciertamente, deseabais la muerte antes de encontraros con ellos y, ciertamente, la visteis con vuestros propios ojos y observasteis [como es].\qt@no{143}}
\qt@newcmd\qurantrans@es@cdxxxvii{Y Muhammad no es más que un Mensajero. Antes de él hubo también otros Mensajeros. ¿Acaso si muere o es matado volveréis a vuestras creencias anteriores? Pues [sabed que] quien vuelva a sus creencias anteriores no puede perjudicar a Dios en absoluto. Y Dios pronto recompensará a los agradecidos.\qt@no{144}}
\qt@newcmd\qurantrans@es@cdxxxviii{Nadie puede morir sin permiso de Dios y según un plazo fijado previamente. Y a quien desee la recompensa de esta vida le daremos de ella y a quien desee la recompensa de la otra vida le daremos de ella. Y pronto recompensaremos a los que son agradecidos.\qt@no{145}}
\qt@newcmd\qurantrans@es@cdxxxix{¡Cuántos profetas combatieron, y muchos de sus seguidores espirituales con ellos, y no se desanimaron por las dificultades que hubieron de soportar en la senda de Dios ni mostraron debilidad ni se abatieron! Dios ama a los pacientes.\qt@no{146}}
\qt@newcmd\qurantrans@es@cdxl{Y lo único que dijeron fue: «¡Dios nuestro, perdónanos los pecados y los excesos cometidos y consolida nuestros pasos y auxílianos ante la gente que no cree!»\qt@no{147}}
\qt@newcmd\qurantrans@es@cdxli{Y Dios les dio la recompensa de esta vida y la buena recompensa de la otra. Dios ama a los virtuosos.\qt@no{148}}
\qt@newcmd\qurantrans@es@cdxlii{¡Oh los que creéis! Si obedecéis a aquellos que no creen, harán que volváis hacia atrás y os convertiréis en perdedores.\qt@no{149}}
\qt@newcmd\qurantrans@es@cdxliii{[Ellos no son vuestros protectores] sino que Dios es vuestro Protector y Señor y el mejor auxiliador.\qt@no{150}}
\qt@newcmd\qurantrans@es@cdxliv{Pronto infundiremos el terror en el corazón de los que no creen por haber adorado a otros como a Dios, cuando Él no había hecho descender sobre esos poder alguno. Y su morada será el Fuego. ¡Qué mala es la morada de los opresores!\qt@no{151}}
\qt@newcmd\qurantrans@es@cdxlv{Ciertamente, Dios cumplió la promesa que os hizo cuando los estabais venciendo con Su permiso, hasta que [al final de la batalla] flaqueasteis y discutisteis y desobedecisteis [al Mensajero] después que Dios os hizo ver [la victoria] que queríais. Entre vosotros los hay que aman esta vida y los hay que aman la otra. Luego os cambió por ellos para poneros a prueba y [tras ello] ciertamente, os perdonó, pues Dios reserva su favor para los creyentes.\qt@no{152}}
\qt@newcmd\qurantrans@es@cdxlvi{[Y recordad] cuando os marchasteis sin preocuparos por nadie y el Mensajero os llamaba a proteger la retaguardia. Él os compensó una tristeza con otra para que no estuvieseis tristes por lo que habíais perdido ni por la desgracia que os había ocurrido. Y Dios está bien informado de lo que hacéis.\qt@no{153}}
\qt@newcmd\qurantrans@es@cdxlvii{Luego, tras la aflicción, hizo descender sobre vosotros seguridad [en forma de] un sueño ligero que envolvió a un grupo de vosotros mientras que otro grupo, más preocupado por ellos mismos, pensaban sobre Dios lo que no es verdad, con dudas propias de la época de la ignorancia, diciendo: «¿Tenemos nosotros algo que ver en este asunto?» Di: «En verdad, todo el asunto pertenece a Dios.» Esconden en sus corazones lo que no manifiestan ante ti. Dicen: «Si hubiéramos tenido algo que ver en el asunto no nos habrían matado aquí.» Diles: «Aunque hubierais permanecido en vuestras casas, a aquellos para los que estaba escrita, la muerte les habría sorprendido en sus lechos.» Fue así para que Dios pusiera a prueba lo que tenéis en vuestros pechos y para purificar lo que hay en vuestros corazones. Dios conoce bien lo que hay en los pechos.\qt@no{154}}
\qt@newcmd\qurantrans@es@cdxlviii{En verdad, a aquellos de vosotros que dieron la espalda el día en que se encontraron los dos ejércitos, Satanás les hizo tropezar por algo que habían cometido, pero Dios les ha perdonado. En verdad, Dios es perdonador, indulgente.\qt@no{155}}
\qt@newcmd\qurantrans@es@cdxlix{¡Oh, los que creéis! No seáis como aquellos que no creen y dijeron de sus hermanos cuando salían de viaje o iban de incursión: «Si se hubieran quedado junto a nosotros no habrían muerto ni les habrían matado.» ¡Haga Dios que eso les remuerda en los corazones! Dios da la vida y la muerte y Dios observa lo que hacéis.\qt@no{156}}
\qt@newcmd\qurantrans@es@cdl{Y si sois matados por la causa de Dios o morís, el perdón y la misericordia de Dios es mejor que lo que ellos reúnen.\qt@no{157}}
\qt@newcmd\qurantrans@es@cdli{Y si morís o sois matados, ciertamente, regresaréis a Dios.\qt@no{158}}
\qt@newcmd\qurantrans@es@cdlii{En verdad, por una misericordia de Dios, fuiste blando con ellos, pues, si hubieras sido seco y duro de corazón, rápidamente se hubieran apartado de ti. Por tanto, perdónales y pide el perdón para ellos y consúltales en el asunto. Después, cuando tomes una decisión, confía en Dios. En verdad, Dios ama a los que confían en Él.\qt@no{159}}
\qt@newcmd\qurantrans@es@cdliii{Si Dios os ayuda, nadie podrá venceros y si os abandona ¿Quién podrá ayudaros después de Él? ¡Que los creyentes confíen en Dios!\qt@no{160}}
\qt@newcmd\qurantrans@es@cdliv{No es propio de un profeta el fraude. Y quien defraude vendrá el Día del Levantamiento con lo que defraudó. Luego, cada uno recibirá la recompensa de lo que haya hecho y nadie será tratado injustamente.\qt@no{161}}
\qt@newcmd\qurantrans@es@cdlv{¿Acaso quien persigue la satisfacción de Dios es igual que quien disgusta a Dios y su morada es el Infierno? ¡Qué mal destino!\qt@no{162}}
\qt@newcmd\qurantrans@es@cdlvi{Cada uno de ellos tendrá un grado de proximidad junto a Dios. Y Dios observa lo que hacen.\qt@no{163}}
\qt@newcmd\qurantrans@es@cdlvii{En verdad, Dios agracia a los creyentes al designar un Mensajero de entre ellos mismos, que les recita Sus versículos y les purifica y les instruye en la Escritura [Sagrada] y en la Sabiduría, cuando antes estaban en un extravío evidente.\qt@no{164}}
\qt@newcmd\qurantrans@es@cdlviii{Acaso cuando os sobreviene una desgracia, habiendo vosotros provocado una des gracia doblemente grande, decís: «¿De dónde nos viene esto?» Di: «De vosotros mismos.» En verdad, Dios tiene poder sobre todas las cosas.\qt@no{165}}
\qt@newcmd\qurantrans@es@cdlix{Y lo que os afligió el día en que se enfrentaron los dos grupos fue con el permiso de Dios y para conocer quiénes eran creyentes\qt@no{166}}
\qt@newcmd\qurantrans@es@cdlx{y quiénes eran hipócritas. Se les dijo: «¡Venid! ¡Combatid en la senda de Dios o defendeos!» Dijeron: «Si supiéramos que habría un combate, sin duda que os seguiríamos.» Ese día, ellos estaban más cerca de la incredulidad que de la fe. Dicen con sus bocas lo que no hay en sus corazones. Pero Dios conoce mejor lo que esconden.\qt@no{167}}
\qt@newcmd\qurantrans@es@cdlxi{[Los hipócritas son] aquellos que, mientras se quedaban sentados, decían de sus hermanos: «Si nos hubieran obedecido no les habrían matado.» Di: «¡Apartad la muerte de vosotros mismos, si es que sois veraces!»\qt@no{168}}
\qt@newcmd\qurantrans@es@cdlxii{Y no creáis en absoluto que aquellos que han sido matados en la senda de Dios están muertos. Sino que están vivos y provistos de todo junto a su Señor.\qt@no{169}}
\qt@newcmd\qurantrans@es@cdlxiii{Contentos por el favor que Dios les ha otorgado y felicitándose por aquellos que todavía no les han alcanzado y han quedado atrás, porque no tienen por qué temer y no estarán tristes.\qt@no{170}}
\qt@newcmd\qurantrans@es@cdlxiv{Regocijándose de la merced y el favor de Dios y porque Dios no deja que se pierda la recompensa de los creyentes,\qt@no{171}}
\qt@newcmd\qurantrans@es@cdlxv{aquellos que respondieron a la llamada de Dios y del Mensajero aun después de haber sido heridos. Para los que han actuado bien y han sido temerosos de desagradar a Dios hay una recompensa inmensa.\qt@no{172}}
\qt@newcmd\qurantrans@es@cdlxvi{Aquellos a quienes las gentes les dijeron: «En verdad, la gente se ha juntado contra vosotros ¡Temedles!» Y eso incremento su fe y dijeron: «¡Dios nos basta! ¡Él es el mejor protector!»\qt@no{173}}
\qt@newcmd\qurantrans@es@cdlxvii{Y han regresado, por una Gracia y un Favor de Dios, sin sufrir mal. Buscaron la satisfacción de Dios y Dios es el Dueño del Favor inmenso.\qt@no{174}}
\qt@newcmd\qurantrans@es@cdlxviii{En verdad, vosotros sois el Demonio. Él asusta [solamente] a quienes son amigos suyos. ¡Así que no tengáis miedo de ellos, tened miedo de Mí, si es que sois creyentes!\qt@no{175}}
\qt@newcmd\qurantrans@es@cdlxix{Que no te entristezcan aquellos que se precipitan al mundo de la incredulidad. En verdad, ellos no perjudican en nada a Dios. Dios quiere que no tengan parte en la otra vida. Y para ellos hay un castigo inmenso.\qt@no{176}}
\qt@newcmd\qurantrans@es@cdlxx{En verdad, aquellos que compran la incredulidad con la fe no perjudican a Dios en nada y para ellos hay un castigo doloroso.\qt@no{177}}
\qt@newcmd\qurantrans@es@cdlxxi{Que aquellos que no creen no piensen que si les damos un plazo es para su bien. En verdad, les concedemos un plazo para que acumulen malas acciones. Para ellos hay un castigo humillante.\qt@no{178}}
\qt@newcmd\qurantrans@es@cdlxxii{Dios no va a dejar a los creyentes en el estado en el que os encontráis, sin separar al malo del bueno, ni va Dios a mostraros lo que está oculto a los sentidos, pero Dios escoge de entre Sus profetas a quien Él quiere. Así pues, creed en Dios y en Sus Mensajeros. Si creéis y teméis tendréis una recompensa inmensa.\qt@no{179}}
\qt@newcmd\qurantrans@es@cdlxxiii{Y no crean aquellos que son tacaños con lo que Dios les ha favorecido que eso es un bien para ellos, pues es para su mal. El día del Levantamiento llevarán al cuello lo que acumularon en su avaricia. A Dios pertenece la herencia de los cielos y de la Tierra y Dios está bien informado de lo que hacéis.\qt@no{180}}
\qt@newcmd\qurantrans@es@cdlxxiv{Dios, sin duda, ha escuchado las palabras de aquellos que dijeron: «En verdad, Dios es pobre y nosotros somos ricos.» Tomaremos nota de lo que han dicho y de que mataron sin derecho a los profetas y les diremos: «Saboread el tormento del Fuego.\qt@no{181}}
\qt@newcmd\qurantrans@es@cdlxxv{Eso es por lo que hicisteis, pues Dios no oprime a los siervos.»\qt@no{182}}
\qt@newcmd\qurantrans@es@cdlxxvi{Esos son quienes dijeron: «En verdad, Dios ha establecido una alianza con nosotros para que no creamos en ningún Mensajero hasta que venga a nosotros con una ofrenda que el fuego devore.» Di: «Antes de mí vinieron a vosotros, por cierto, Mensajeros con las señales claras y con lo que habéis dicho ¿Por qué, pues, los matasteis, si sois sinceros?»\qt@no{183}}
\qt@newcmd\qurantrans@es@cdlxxvii{Y si te desmienten, en verdad, antes de ti fueron desmentidos otros Mensajeros que vinieron con las señales claras, y con los Salmos y con la Escritura Luminosa.\qt@no{184}}
\qt@newcmd\qurantrans@es@cdlxxviii{Todo ser saboreará la muerte. Pero, hasta el Día del Levantamiento no recibiréis toda vuestra recompensa. Quien sea librado del Fuego e introducido en el Jardín, sin duda habrá triunfado. La vida de este mundo no es más que disfrute de la vanidad.\qt@no{185}}
\qt@newcmd\qurantrans@es@cdlxxix{Ciertamente, seréis puestos a prueba en vuestras riquezas y en vuestras personas y, ciertamente, de quienes tuvieron la Escritura [Sagrada] antes que vosotros y de los politeístas, escucharéis muchos insultos. Pero si sois pacientes y temerosos de Dios, eso sí que, en verdad, es dar muestra de firmeza en los asuntos.\qt@no{186}}
\qt@newcmd\qurantrans@es@cdlxxx{Y [recordad] cuando Dios estableció un acuerdo con aquellos a quienes les fue dada la Escritura [Sagrada]: «Explicádsela a la gente y no la ocultéis.» Pero ellos le dieron la espalda y la vendieron por poco precio. ¡Qué mal negocio hicieron!\qt@no{187}}
\qt@newcmd\qurantrans@es@cdlxxxi{No creas que aquellos que se alegran de lo que han hecho [malo] y quieren que se les agradezca lo que no han hecho, están a salvo del castigo. ¡Tendrán un castigo doloroso!\qt@no{188}}
\qt@newcmd\qurantrans@es@cdlxxxii{¡A Dios pertenece el reino de los cielos y de la Tierra, y Dios tiene poder sobre todas las cosas!\qt@no{189}}
\qt@newcmd\qurantrans@es@cdlxxxiii{En verdad, en la Creación de los cielos y de la Tierra y en la diferencia entre la noche y el día, hay señales para los dotados de intelecto.\qt@no{190}}
\qt@newcmd\qurantrans@es@cdlxxxiv{Aquellos que recuerdan a Dios de pie, sentados o acostados, y que reflexionan sobre la Creación de los cielos y la Tierra [y dicen]: «¡Oh, Señor nuestro! ¡No has creado todo esto en vano! ¡Glorificado seas! ¡Líbranos del castigo del Fuego!\qt@no{191}}
\qt@newcmd\qurantrans@es@cdlxxxv{¡Señor nuestro! ¡A quien Tú [por sus actos] introduces en el Fuego, ciertamente, lo has humillado merecidamente! ¡Los opresores no tendrán quien les auxilie!\qt@no{192}}
\qt@newcmd\qurantrans@es@cdlxxxvi{¡Señor nuestro! ¡En verdad, hemos escuchado a uno que convocaba a la fe!: “¡Creed en vuestro Señor!” y hemos creído. ¡Señor nuestro! ¡Perdona, pues, nuestros pecados y cubre nuestras malas acciones y, al morir, reúnenos con los buenos!\qt@no{193}}
\qt@newcmd\qurantrans@es@cdlxxxvii{¡Señor nuestro! ¡Danos lo que nos has prometido por medio de Tus profetas! ¡Y no nos avergüences el Día del Levantamiento! ¡En verdad, Tú no incumples lo prometido!»\qt@no{194}}
\qt@newcmd\qurantrans@es@cdlxxxviii{Su Señor les respondió a su súplica: «En verdad, Yo no dejo que se pierda la obra de nadie que obre bien, sea hombre o mujer. Procedéis unos de otros. Ocultaré los pecados de aquellos que emigraron y fueron sacados de sus casas y fueron molestados por Mi causa y combatieron y fueron matados, y Les haré entrar en Jardines por los cuales fluyen arroyos. ¡Recompensa procedente de Dios! ¡Y Dios tiene junto a Él la mejor recompensa!»\qt@no{195}}
\qt@newcmd\qurantrans@es@cdlxxxix{¡Que no te impresione el ir y venir de aquellos que no creen!\qt@no{196}}
\qt@newcmd\qurantrans@es@cdxc{¡ [Tendrán] un pequeño disfrute y luego su morada será el infierno de Yahannam! ¡Qué mal lecho!\qt@no{197}}
\qt@newcmd\qurantrans@es@cdxci{Pero, para aquellos que temieron disgustar a su Señor hay Jardines de cuyas profundidades brotan ríos, en los que estarán eternamente hospedados junto a Dios. ¡Y lo que hay junto a Dios es mejor para los buenos!\qt@no{198}}
\qt@newcmd\qurantrans@es@cdxcii{Y, en verdad, de entre la gente de la Escritura [Sagrada], hay quienes creen en Dios y en lo que fue hecho descender para vosotros y en lo que fue hecho descender para ellos. Humildes ante Dios, no venden las señales de Dios a poco precio. Esos tendrán su recompensa junto a su Señor. En verdad, Dios es rápido haciendo las cuentas.\qt@no{199}}
\qt@newcmd\qurantrans@es@cdxciii{¡Oh, creyentes! ¡Sed pacientes y aguantad con firmeza y manteneos preparados para el combate y temed a Dios! ¡Quizás, así, tengáis éxito!\qt@no{200}}
\qt@newcmd\qurantrans@es@cdxciv{\basmalahes ¡Oh gentes! ¡Temed a vuestro Señor, que os creó de una sola alma y que creó de ella a su pareja y que, a partir de ambos, ha hecho surgir hombres y mujeres en abundancia! Y temed a Dios, en cuyo nombre os pedís unos a otros y [cuidad] las relaciones familiares. En verdad, Dios os observa.\qt@no{1}}
\qt@newcmd\qurantrans@es@cdxcv{Y dad a los huérfanos sus bienes y no deis lo malo en lugar de lo bueno y no os comáis sus bienes juntándolos con los vuestros. En verdad, sería un gran pecado.\qt@no{2}}
\qt@newcmd\qurantrans@es@cdxcvi{Y si teméis no ser justos con los huérfanos, casaos con [otras de] las mujeres que os gusten, dos, tres o cuatro. Pero si, aún así, teméis no ser justos, hacedlo [sólo] con una o con una de vuestras esclavas. Eso estará más cerca de no ser injustos.\qt@no{3}}
\qt@newcmd\qurantrans@es@cdxcvii{Y entregad a las mujeres sus dotes como una obligación, pero si ellas os perdonan una parte, usadla lícita y gustosamente.\qt@no{4}}
\qt@newcmd\qurantrans@es@cdxcviii{Y no deis a los incapacitados mentales los bienes que Dios os ha proporcionado para vuestro funcionamiento y proveedles de ellos y vestidles y habladles con dulzura.\qt@no{5}}
\qt@newcmd\qurantrans@es@cdxcix{Examinad a los huérfanos hasta que lleguen a la edad de casarse y, si los consideráis maduros, entregadles sus bienes y no os los comáis, derrochándolos prematuramente, antes de que se hagan mayores. Y el que sea rico, que se abstenga de ellos, y el que sea pobre que use lo justo. Cuando les entreguéis sus bienes, hacedlo ante testigos. Y Dios es suficiente para llevar la cuenta.\qt@no{6}}
\qt@newcmd\qurantrans@es@d{A los hombres les corresponde una parte de lo que han dejado sus padres y familiares cercanos y a las mujeres una parte de lo que han dejado los padres y familiares cercanos, sea poco o mucho, es la parte establecida.\qt@no{7}}
\qt@newcmd\qurantrans@es@di{Y si en el reparto están presentes los familiares, los huérfanos y los necesitados, dadles de ello y habladles con amabilidad.\qt@no{8}}
\qt@newcmd\qurantrans@es@dii{Aquellos que si dejasen tras de sí hijos menores de edad temerían por ellos, que se preocupen [por los huérfanos] y que sean temerosos de desagradar a Dios y les hablen con ternura y cariño.\qt@no{9}}
\qt@newcmd\qurantrans@es@diii{En verdad, aquellos que devoran injustamente los bienes de los huérfanos, solamente introducen fuego en sus vientres y pronto arderán en el Fuego abrasador.\qt@no{10}}
\qt@newcmd\qurantrans@es@div{Dios os ordena en lo relativo a vuestros hijos que la parte del varón sea igual a la parte de dos hembras y si [vuestros hijos] fueran dos mujeres o más de dos, recibirán dos tercios de lo que dejó [el fallecido]. Si sólo fuera una, le corresponde la mitad. Y a los padres de él corresponde una sexta parte para cada uno, en caso de que dejéis hijos. Si no dejáis hijos y los padres son los [únicos] herederos, a la madre de él le corresponde un tercio Pero si él deja hermanos, a la madre le corresponde un sexto. Esto, después de haber cumplido con las disposiciones testamentarias o las deudas pendientes. No sabéis quien será más beneficioso para vosotros, si vuestros padres o vuestros hijos. Esto es lo que Dios ha ordenado. En verdad, Dios todo lo conoce, es sabio.\qt@no{11}}
\qt@newcmd\qurantrans@es@dv{Y a vosotros os corresponde la mitad de lo que dejen vuestras esposas si no tienen hijos. Pero si tienen hijos, a vosotros os corresponde un cuarto de lo que dejen, después de cumplir con los legados testamentarios que ella haya dispuesto y con las deudas. Y a ellas les corresponde un cuarto de lo que dejéis si no tenéis hijos. Pero si tenéis hijos, a ellas les corresponde la octava parte de lo que dejéis, después de cumplir con los legados testamentarios que hayáis dispuesto y pagar las deudas. Y si un hombre o una mujer de quien se hereda, fuera kalála y tiene un hermano o una hermana, a cada uno de ellos le corresponde un sexto y si fueran más se repartirán un tercio después de cumplir con los legados las deudas, sin perjudicar a nadie. Esto es lo dispuesto por Dios. Dios es sabio, magnánimo.\qt@no{12}}
\qt@newcmd\qurantrans@es@dvi{Estas son las disposiciones establecidas por Dios y, a quien obedezca a Dios y a Su profeta, Él le hará entrar en Jardines de cuyas profundidades brotan los ríos, en los que morará eternamente. ¡Ese es el éxito inmenso!\qt@no{13}}
\qt@newcmd\qurantrans@es@dvii{Y a quien desobedezca a Dios y a Su profeta y traspase Sus límites, Él le hará entrar en un Fuego en el que permanecerá eternamente y recibirá un castigo humillante.\qt@no{14}}
\qt@newcmd\qurantrans@es@dviii{Si alguna de vuestras mujeres casadas comete pecado, buscad a cuatro de entre vosotros que atestigüen contra ella. Si lo atestiguan, recluidlas en (sus) casas hasta que les llegue la muerte o Dios les procure una vía.\qt@no{15}}
\qt@newcmd\qurantrans@es@dix{Y si dos de los vuestros (que no estén casados) cometen pecado, castigad a ambos. Pero, si se arrepienten y se reforman, dejadles en paz. En verdad, Dios es perdonador, misericordiosísimo.\qt@no{16}}
\qt@newcmd\qurantrans@es@dx{En verdad, el perdón de Dios es para aquellos que hacen elmal por ignorancia y luego se arrepienten inmediatamente. A esos Dios les perdona. Dios es conocedor, sabio.\qt@no{17}}
\qt@newcmd\qurantrans@es@dxi{Pero el perdón no es para aquellos que saben que hacen el mal hasta que les llega la muerte y, entonces, dicen: «Ahora me arrepiento», ni para aquellos que mueren sin creer. Para ellos tenemos previsto un castigo doloroso.\qt@no{18}}
\qt@newcmd\qurantrans@es@dxii{¡Oh los que creéis! No es lícito para vosotros que heredéis de vuestras mujeres contra su voluntad, ni que las presionéis para recuperar algo de lo que les habéis dado, excepto si son culpables de un acto claramente deshonroso. Y convivid con ellas conforme a lo que es correcto, pues si os resultan odiosas, quizás odiéis algo en lo que Dios ha puesto un gran bien.\qt@no{19}}
\qt@newcmd\qurantrans@es@dxiii{Y si queréis cambiar una esposa por otra y habéis dado a una de ellas un quintal [de oro], no toméis nada de ello ¿Acaso lo tomaríais cometiendo una infamia y un pecado evidente?\qt@no{20}}
\qt@newcmd\qurantrans@es@dxiv{Y ¿Cómo lo tomaríais, después de haber tenido una relación intima el uno con el otro y de haber ellas obtenido de vosotros un compromiso firme?\qt@no{21}}
\qt@newcmd\qurantrans@es@dxv{Y no os caséis con las mujeres con quienes se casaron vuestros padres, exceptuando lo que ya hicisteis. En verdad, sería algo indecente y aborrecible y un mal camino.\qt@no{22}}
\qt@newcmd\qurantrans@es@dxvi{Desde ahora, quedan prohibidas para vosotros vuestras madres, vuestras hijas, vuestras hermanas, vuestras tías paternas y maternas, las hijas de vuestros hermanos y hermanas y vuestras madres y hermanas de leche y vuestras suegras, las hijas de vuestras esposas, que están bajo vuestra custodia, una vez que hayáis consumado el matrimonio con sus madres, pero si no lo habéis consumado no cometéis pecado con ello; las esposas de vuestros propios hijos y que os unáis con dos hermanas al mismo tiempo, excepto si lo hicisteis en el pasado. En verdad, Dios es perdonador, misericordiosísimo.\qt@no{23}}
\qt@newcmd\qurantrans@es@dxvii{Ni [podéis casaros] con las mujeres casadas, excepto que sean propiedad vuestra. Es un decreto de Dios para vosotros. Y, a parte de esos casos, es lícito para vosotros buscar la unión con ellas si las solicitáis con vuestros bienes, buscando el matrimonio y no la fornicación. Y si os casáis temporalmente con ellas, dadles su dote obligatoriamente. Y no cometéis falta en lo que, aparte de la dote, convengáis de mutuo acuerdo. En verdad, Dios todo lo conoce, es sabio.\qt@no{24}}
\qt@newcmd\qurantrans@es@dxviii{Y quién de vosotros no disponga de medios suficientes para casarse con una creyente libre, que lo haga con una de vuestras jóvenes siervas creyentes. Dios es Quien mejor conoce vuestra fe. Descendéis unos de otros. Casaos, pues, con ellas con permiso de la familia a la que pertenecen y dadles su dote conforme a lo que es justo, como a mujeres honradas, no como a prostitutas o a las que toman amantes. Si se casan y luego cometen algo deshonesto, tendrán la mitad de castigo que las mujeres libres. Esto es para quienes de vosotros teman caer en el pecado de fornicación, pero es mejor para vosotros si tenéis paciencia. Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{25}}
\qt@newcmd\qurantrans@es@dxix{Dios quiere aclararos las cosas y guiaros a las costumbres de los que existieron antes de vosotros para perdonaros. Dios es conocedor, sabio.\qt@no{26}}
\qt@newcmd\qurantrans@es@dxx{Dios quiere perdonaros y aquellos que siguen a sus apetitos quieren que os desviéis completamente.\qt@no{27}}
\qt@newcmd\qurantrans@es@dxxi{Dios quiere aligerar vuestra carga, pues el ser humano fue creado débil.\qt@no{28}}
\qt@newcmd\qurantrans@es@dxxii{¡Oh los que creéis! No os comáis la riqueza unos a otros ilegalmente. Es diferente si comerciáis de común acuerdo. Y no os matéis vosotros mismos. En verdad, Dios ha sido misericordiosísimo con vosotros.\qt@no{29}}
\qt@newcmd\qurantrans@es@dxxiii{Y a quien obre así, violando la ley y oprimiendo, le arrojaremos al Fuego. Eso es fácil para Dios.\qt@no{30}}
\qt@newcmd\qurantrans@es@dxxiv{Si os abstenéis de cometer los pecados graves que os han sido prohibidos, ocultaremos vuestras pequeñas malas acciones y os introduciremos en una morada generosa.\qt@no{31}}
\qt@newcmd\qurantrans@es@dxxv{Y no deseéis aquello con lo que Dios ha favorecido a unos sobre otros. Los hombres tienen una parte de lo que realizan y las mujeres una parte de lo que realizan. Y pedid a Dios que os otorgue de Su favor. En verdad, Dios conoce bien todas las cosas.\qt@no{32}}
\qt@newcmd\qurantrans@es@dxxvi{Nosotros hemos designado, para todos, herederos de lo que dejan los padres y los familiares cercanos. Y a aquellos con los que tenéis un compromiso establecido, dadles su parte. Ciertamente Dios es testigo de todo.\qt@no{33}}
\qt@newcmd\qurantrans@es@dxxvii{Los hombres son los encargados de proteger y atender a las mujeres por aquello con lo que Dios ha favorecido a unos sobre otros y por lo que gastan de sus bienes. Y las casadas virtuosas son discretas y protegen en ausencia [de sus esposos] lo que Dios ha encargado proteger. Y a aquellas de las que temáis una conducta rebelde y obstinada, amonestadlas [primero], y [si no surte efecto] abandonadlas en el lecho y [en última instancia] golpeadlas. Pero si os obedecen, no hagáis nada contra ellas. Dios es Excelso, Grande.\qt@no{34}}
\qt@newcmd\qurantrans@es@dxxviii{Y si teméis una ruptura entre ellos dos, designar un árbitro entre los familiares de él y otro árbitro entre los familiares de ella. Si ellos desean reconciliarse, Dios hará que se pongan de acuerdo. En verdad, Dios es buen conocedor, está informado de todo.\qt@no{35}}
\qt@newcmd\qurantrans@es@dxxix{Y adorad a Dios y no adoréis nada junto a Él. Y sed buenos con vuestros padres, con vuestros familiares, los huérfanos, los necesitados, los vecinos cercanos y los vecinos lejanos, con el compañero de viaje, con el viajero y con vuestros esclavos. En verdad, Dios no ama a quien sea un fanfarrón arrogante.\qt@no{36}}
\qt@newcmd\qurantrans@es@dxxx{Esos que son avaros y que llevan a la gente a la avaricia y ocultan los favores que Dios les ha otorgado. Hemos preparado para los que no creen un castigo humillante,\qt@no{37}}
\qt@newcmd\qurantrans@es@dxxxi{y para los que gastan sus riquezas para ser vistos por las gentes y no creen en Dios ni en el Último Día y para quien tiene a Satanás por compañero. ¡Qué mal compañero!\qt@no{38}}
\qt@newcmd\qurantrans@es@dxxxii{¿Qué les hubiese costado creer en Dios y en el Último Día y haber gastado de lo que Dios les había proveído? ¡Dios les conoce bien!\qt@no{39}}
\qt@newcmd\qurantrans@es@dxxxiii{En verdad, Dios no oprime ni una pizca de un átomo y si se realiza una buena acción Él la multiplicará y otorgará una gran recompensa.\qt@no{40}}
\qt@newcmd\qurantrans@es@dxxxiv{¿Qué pasará entonces, cuando traigamos un testigo de cada comunidad y te traigamos a ti como testigo de estos?\qt@no{41}}
\qt@newcmd\qurantrans@es@dxxxv{Ese día, aquellos que no creyeron y desobedecieron al Mensajero querrán que la Tierra se los trague y no podrán ocultar a Dios nada de lo que hicieron.\qt@no{42}}
\qt@newcmd\qurantrans@es@dxxxvi{¡Oh los que creéis! No os acerquéis a la oración estando ebrios hasta que sepáis lo que decís, ni si estáis impuros, hasta que os hayáis lavado, excepto si estáis de viaje. Y si estáis enfermos o de viaje o uno de vosotros viene de hacer sus necesidades, o tuvisteis contacto con mujeres y no encontráis agua, purificaos con tierra pura, pasándola por vuestro rostro y vuestras manos. Ciertamente, Dios es indulgente, perdonador.\qt@no{43}}
\qt@newcmd\qurantrans@es@dxxxvii{¿No has visto a quienes les fue dada parte de la Escritura [Sagrada]? Compran el extravío y quieren que también vosotros extraviéis el Camino.\qt@no{44}}
\qt@newcmd\qurantrans@es@dxxxviii{Y Dios es Quien mejor conoce a vuestros enemigos. Y Dios es suficiente como protector y como auxiliador.\qt@no{45}}
\qt@newcmd\qurantrans@es@dxxxix{Algunos judíos alteran el significado de las palabras y dicen: “Oímos y desobedecemos” y “Oye sin escuchar” y “Raina”, distorsionándola con sus lenguas e insultando a las creencias religiosas. Si hubieran dicho: «Oímos y obedecemos» y «¡Escucha! y ¡Míranos!» habría sido mejor para ellos y más correcto, pero Dios les maldijo por su falta de fe, pues de ellos no creen más que unos pocos.\qt@no{46}}
\qt@newcmd\qurantrans@es@dxl{¡Oh, aquellos a quienes les fue dada la Escritura [Sagrada]! ¡Creed en lo que hicimos descender confirmando lo que teníais, antes de que borremos los rostros y los volvamos del revés o los maldigamos como maldijimos a las gentes del sabt [sábado]! La orden de Dios es para ser cumplida.\qt@no{47}}
\qt@newcmd\qurantrans@es@dxli{En verdad, Dios no perdona que se adore a nadie junto a Él pero, excepto eso, perdona a quien Él quiere. Y quien adora a otros junto a Dios ha cometido un pecado inmenso.\qt@no{48}}
\qt@newcmd\qurantrans@es@dxlii{¿No has visto a quienes se consideran puros? Pero es Dios Quien purifica a quien Él quiere y nadie será oprimido en lo más mínimo.\qt@no{49}}
\qt@newcmd\qurantrans@es@dxliii{Observa como inventan mentiras sobre Dios. Eso es suficiente como pecado evidente.\qt@no{50}}
\qt@newcmd\qurantrans@es@dxliv{¡No has visto a quienes les fue dada una parte de la Escritura [Sagrada] y creen en los espíritus mágicos malignos y en los falsos ídolos y dicen de los que no son creyentes: «Esos están mejor guiados que los creyentes.»\qt@no{51}}
\qt@newcmd\qurantrans@es@dxlv{Esos son a quienes Dios maldijo y no encontrarás quien auxilie a quien Dios maldice.\qt@no{52}}
\qt@newcmd\qurantrans@es@dxlvi{¿Acaso tienen parte en el gobierno? Si así fuera no darían a la gente lo más mínimo.\qt@no{53}}
\qt@newcmd\qurantrans@es@dxlvii{¿O es que envidian a la gente por lo que Dios les ha otorgado de Su favor? Pues, a la familia de Abraham le dimos, en verdad, la Escritura [Sagrada] y la Sabiduría y les dimos un Gobierno inmenso.\qt@no{54}}
\qt@newcmd\qurantrans@es@dxlviii{De ellos los hay que creen en él y los hay que se apartan de él. El Infierno será suficiente fuego para abrasarles.\qt@no{55}}
\qt@newcmd\qurantrans@es@dxlix{En verdad, a aquellos que no creen en Nuestras señales, les haremos arder en un Fuego en el que cada vez que sus pieles se quemen se las sustituiremos por otras distintas, para que saboreen el castigo. En verdad, Dios es poderoso, sabio.\qt@no{56}}
\qt@newcmd\qurantrans@es@dl{Y, a aquellos que creen y obran rectamente, pronto les haremos entrar en un Jardín de cuyas profundidades brotan los ríos, en el que estarán eternamente. En ellos tendrán parejas purificadas y les colocaremos bajo densas sombras.\qt@no{57}}
\qt@newcmd\qurantrans@es@dli{En verdad, Dios os ordena devolver a sus propietarios los depósitos que se os confiaron y que, si juzgáis entre la gente, lo hagáis con justicia. ¡Qué excelente es aquello de lo que Dios os advierte! En verdad, Dios todo lo oye, todo lo ve.\qt@no{58}}
\qt@newcmd\qurantrans@es@dlii{¡Oh, los que creéis! ¡Obedeced a Dios y obedeced al Mensajero y a los que de vosotros tienen autoridad! Y si discutís sobre algo, remitidlo a Dios y al Mensajero si creéis en Dios y en el Último Día. Eso es un bien y la mejor solución.\qt@no{59}}
\qt@newcmd\qurantrans@es@dliii{¿No has visto a esos que proclaman que creen en lo que fue hecho descender para ti y en lo que fue hecho descender ante de ti? Quieren recurrir al juicio de los tiranos, a pesar de que se les ha ordenado no creer en ellos y quiere el Demonio extraviarles lo más lejos posible.\qt@no{60}}
\qt@newcmd\qurantrans@es@dliv{Y cuando se les dice: «Venid a lo que hizo descender Dios y [venid] hacia el Mensajero» ya ves cómo los hipócritas se apartan totalmente de ti.\qt@no{61}}
\qt@newcmd\qurantrans@es@dlv{Y cómo, cuando les aflige una desgracia por lo que hicieron con sus propias manos, vienen a ti jurando por Dios: «No deseamos más que el bien y la concordia.»\qt@no{62}}
\qt@newcmd\qurantrans@es@dlvi{Dios conoce bien lo que hay en sus corazones, así que apártate de ellos y amonéstales y háblales con elocuencia que llegue a sus almas.\qt@no{63}}
\qt@newcmd\qurantrans@es@dlvii{Y no Hemos enviado Mensajero alguno sino para que sea obedecido, con el permiso de Dios. Si, cuando fueron injustos consigo mismos, hubieran venido a ti y hubieran pedido el perdón de Dios y el Mensajero hubiera pedido perdón para ellos, habrían encontrado a Dios perdonador y misericordiosísimo con los creyentes.\qt@no{64}}
\qt@newcmd\qurantrans@es@dlviii{Pero no. Juro por tu Señor que no creerán hasta que no te hayan hecho que juzgues sobre lo que disputan entre ellos. Entonces ya no encontrarán en sus almas como escapar de tu veredicto y se someterán plenamente.\qt@no{65}}
\qt@newcmd\qurantrans@es@dlix{Si Nosotros hubiéramos decretado para ellos: «¡Mataos unos a otros!» o «¡Abandonad vuestros hogares!» sólo unos pocos de ellos lo habrían hecho. Pero, si hubiesen realizado aquello a lo que se les exhortó, habría sido mejor para ellos y su fe habría salido fortalecida.\qt@no{66}}
\qt@newcmd\qurantrans@es@dlx{Y, entonces les habríamos otorgado por Nuestra parte una recompensa inmensa\qt@no{67}}
\qt@newcmd\qurantrans@es@dlxi{y les habríamos guiado al camino recto.\qt@no{68}}
\qt@newcmd\qurantrans@es@dlxii{Y quien obedezca a Dios y al Mensajero estará con aquellos a los que Dios ha agraciado: los profetas, los veraces, los mártires y los justos. ¡Qué excelentes compañeros!\qt@no{69}}
\qt@newcmd\qurantrans@es@dlxiii{¡Este el favor que proviene de Dios! Y es suficiente con que Dios conozca.\qt@no{70}}
\qt@newcmd\qurantrans@es@dlxiv{¡Oh los que creéis! Tomad precauciones y salid a combatir formando destacamentos fuertes o todos juntos.\qt@no{71}}
\qt@newcmd\qurantrans@es@dlxv{En verdad, entre vosotros hay quien se queda atrás y si os aflige una desgracia dice: «Por una merced de Dios no estaba con ellos.»\qt@no{72}}
\qt@newcmd\qurantrans@es@dlxvi{Pero si Dios os favorece, dice, como si entre vosotros y él no existiera una amistad: «¡Ojalá hubiera estado con ellos! ¡Habría obtenido un éxito inmenso!»\qt@no{73}}
\qt@newcmd\qurantrans@es@dlxvii{¡Que combatan por la causa de Dios aquellos que han vendido su vida en este mundo a cambio de la otra! Y, a quien combate por la causa de Dios, tanto si es matado como si vence, Nosotros le daremos una recompensa inmensa.\qt@no{74}}
\qt@newcmd\qurantrans@es@dlxviii{¿Es que no vais a combatir por la causa de Dios y de los hombres, mujeres y niños oprimidos que dicen: «¡Señor nuestro! Sácanos de este país de gentes opresoras y tráenos a alguien que, de Tu parte, nos proteja y auxilie.»\qt@no{75}}
\qt@newcmd\qurantrans@es@dlxix{Los que creen combaten por la causa de Dios y los que no creen combaten por la causa de los tiranos. ¡Combatid, pues, a los amigos de Satanás! Ciertamente, la intriga de Satanás es débil.\qt@no{76}}
\qt@newcmd\qurantrans@es@dlxx{¿No has visto a aquellos a quienes se les dijo: «Apartad vuestras manos [de las armas], estableced la oración y dad la limosna ritual» que cuando se les ordena ir al combate temen a los hombres como si fueran Dios o más aun y dicen: «¡Señor nuestro! ¿Por qué nos has ordenado ir al combate? Si al menos nos lo aplazaras un poco...»? Di: «El disfrute de esta vida es poco y la otra Vida es mejor para quien teme desagradar a Dios. Y no seréis oprimidos lo más mínimo.\qt@no{77}}
\qt@newcmd\qurantrans@es@dlxxi{Dondequiera que os encontréis os hallará la muerte, aunque os escondierais en torres fortificadas.» Si les acontece algo bueno dicen: «Esto procede de Dios», pero si les ocurre algo malo dicen: «Esto procede de ti.» Di: «Todo viene de Dios.» Lo que ocurre con esa gente es que apenas entienden lo que sucede.\qt@no{78}}
\qt@newcmd\qurantrans@es@dlxxii{Lo bueno que te sucede proviene de Dios y lo malo que te sucede proviene de ti mismo. Te hemos enviado a los hombres como un Mensajero. Basta Dios como testigo.\qt@no{79}}
\qt@newcmd\qurantrans@es@dlxxiii{Quien obedece al Mensajero, ciertamente, obedece a Dios. En cuanto a quienes (te) den la espalda, no te hemos enviado a ellos para que seas su protector.\qt@no{80}}
\qt@newcmd\qurantrans@es@dlxxiv{Dicen: «Obedecemos» pero cuando salen de tu presencia, un grupo de ellos conspira en la noche en contra de lo que tú dices. Pero Dios toma nota de lo que traman de noche. ¡No te preocupes por ellos y confía en Dios! ¡Dios es suficiente protector!\qt@no{81}}
\qt@newcmd\qurantrans@es@dlxxv{¿Acaso no meditan el Corán? Si procediera de otro distinto que Dios, sin duda, habrían encontrado en él abundantes contradicciones.\qt@no{82}}
\qt@newcmd\qurantrans@es@dlxxvi{Y, cuando llega a ellos un asunto del que sentirse seguros o del que temer, lo difunden [sin verificarlo], pero si lo hubiesen remitido al Mensajero y a los que tienen autoridad entre ellos, aquellos que deseaban saber la verdad de primera mano la habrían sabido. Y si no fuese por el favor de Dios sobre vosotros y por Su misericordia, habríais seguido a Satanás, exceptuando a unos pocos.\qt@no{83}}
\qt@newcmd\qurantrans@es@dlxxvii{Así pues ¡Combate por la causa de Dios! No eres responsable más que de ti mismo. Y anima a los creyentes [a combatir]. Es posible que Dios contenga el ímpetu de los que no creen. Y Dios posee mayor fuerza y es más severo castigando.\qt@no{84}}
\qt@newcmd\qurantrans@es@dlxxviii{Quien interceda por una buena causa recibirá parte de ella y quien interceda por una mala causa soportará parte de ella. Y Dios es el protector de todas las cosas.\qt@no{85}}
\qt@newcmd\qurantrans@es@dlxxix{Y cuando os saluden, responded con un saludo mejor o semejante. En verdad, Dios lleva la cuenta de todo.\qt@no{86}}
\qt@newcmd\qurantrans@es@dlxxx{Al.lah. No hay más dios que Él. Él os reunirá para el Día del Levantamiento, no hay duda de ello. Y ¿Quién es más veraz que Dios al hablar?\qt@no{87}}
\qt@newcmd\qurantrans@es@dlxxxi{¿Por qué, respecto a los hipócritas, os dividís en dos grupos, si Dios ya los ha rechazado por lo que hicieron? ¿Queréis guiar a quien Dios ha extraviado? Pues no encontrarás camino para aquel a quien Dios extravía.\qt@no{88}}
\qt@newcmd\qurantrans@es@dlxxxii{Ellos quisieran que vosotros no creyeseis, de la misma manera que ellos no creen, para que fueseis iguales. Así que no toméis amigos de entre ellos hasta que emigren por la causa de Dios. Y si [os] dan la espalda, apresadlos y matadlos donde quiera que les encontréis. Y no aceptéis su amistad ni su ayuda,\qt@no{89}}
\qt@newcmd\qurantrans@es@dlxxxiii{exceptuando a quienes se unan a un pueblo con el que tengáis establecido un pacto o que vengan a vosotros con el pecho oprimido por tener que combatir contra vosotros o contra su propio pueblo. Si Dios hubiera querido les habría dado poder contra vosotros y os habrían combatido. Por tanto, si se apartan de vosotros y no os hacen la guerra y os ofrecen la paz, Dios no os deja vía de actuación contra ellos.\qt@no{90}}
\qt@newcmd\qurantrans@es@dlxxxiv{Pronto encontraréis a otros que desean estar a salvo de vosotros y a salvo de su propia gente pero que, cada vez que se les invita a la idolatría, recaen en ella. Por tanto, si no se abstienen de pelear contra vosotros y no vienen a vosotros con ofertas de paz y manteniendo sus manos quietas, apresadles o matadles dondequiera que os enfrentéis a ellos. Es para ir contra ellos para lo que os dimos un poder evidente.\qt@no{91}}
\qt@newcmd\qurantrans@es@dlxxxv{Un creyente no puede matar a otro creyente, excepto por error. Y, quien mate a un creyente por error, deberá pagar a su familia el precio de la sangre establecido, excepto si ellos renuncian (a la indemnización), y liberar a un esclavo creyente. Si él pertenecía a un pueblo enemigo vuestro, pero era creyente, deberéis liberar a un esclavo creyente. Y si era de un pueblo con el que tenéis establecido un pacto, pagaréis el precio de la sangre establecido y liberaréis un esclavo creyente. Y quien no tenga posibilidad, que ayune dos meses seguidos. Perdón que procede de Dios. Y Dios todo lo sabe, es sabio.\qt@no{92}}
\qt@newcmd\qurantrans@es@dlxxxvi{Y quien mate a un creyente premeditadamente tendrá como recompensa el Fuego del Infierno en el que estará eternamente y Dios le odiará, le maldecirá y le castigará con un castigo inmenso.\qt@no{93}}
\qt@newcmd\qurantrans@es@dlxxxvii{¡Oh los que creéis! Cuando salgáis de expedición por la causa de Dios, distinguid cuidadosamente y no digáis a quien se encuentre con vosotros pacíficamente: «Tú no eres creyente», buscando los bienes de la vida de aquí, pues junto a Dios hay un botín abundante. Así erais vosotros anteriormente y Dios os favoreció. Por tanto, distinguid. En verdad, Dios está bien informado de todo cuanto hacéis.\qt@no{94}}
\qt@newcmd\qurantrans@es@dlxxxviii{No son lo mismo los creyentes que se quedan en casa, excepto si sufren alguna enfermedad o impedimento, y los que se esfuerzan por la causa de Dios con sus bienes y sus personas. Dios ha favorecido a los que se esfuerzan por la causa de Dios con sus bienes y con sus personas, situándoles en una categoría superior a los que se quedan en sus casas. Dios ha prometido a todos ellos una buena recompensa, pero a los que se esfuerzan, Dios les favorecerá con una recompensa inmensamente mayor que a los que permanecen en sus casas.\qt@no{95}}
\qt@newcmd\qurantrans@es@dlxxxix{Categorías y perdón y misericordia que provienen de Él, pues Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{96}}
\qt@newcmd\qurantrans@es@dxc{En verdad, a aquellos a quienes los ángeles se lleven mientras eran injustos con sus propias almas les dirán: «¿Qué hacíais?» Dirán: «Estábamos oprimidos en la Tierra.» Ellos dirán. «¿Acaso no era la Tierra de Dios suficientemente amplia para que hubieseis emigrado?» La morada de estos será el fuego del Infierno. ¡Qué mal destino!\qt@no{97}}
\qt@newcmd\qurantrans@es@dxci{Exceptuando aquellos hombres, mujeres y niños que verdaderamente estaban oprimidos y no disponían de medios ni de una guía para el camino.\qt@no{98}}
\qt@newcmd\qurantrans@es@dxcii{A esos posiblemente Dios les perdone, pues Dios es indulgente, perdonador.\qt@no{99}}
\qt@newcmd\qurantrans@es@dxciii{Y quien emigre por la causa de Dios, encontrará en la Tierra refugio abundante y amplio. Y la recompensa de quien salga de su casa, emigrando hacia Dios y Su Mensajero, y le sorprenda la muerte, recae sobre Dios. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{100}}
\qt@newcmd\qurantrans@es@dxciv{Y cuando viajéis por la Tierra no cometéis pecado si acortáis vuestras oraciones si teméis que os ataquen los que no creen, pues, en verdad, los que no creen son para vosotros un enemigo manifiesto.\qt@no{101}}
\qt@newcmd\qurantrans@es@dxcv{Cuando estés entre ellos dirigiendo su oración, que un grupo de ellos rece contigo y que tomen sus armas y cuando se hayan prosternado que se echen atrás y que venga otro grupo que no haya rezado y rece contigo. Y que tomen precauciones y sus armas. Los que no creen, si descuidaseis vuestras armas y vuestros escudos, os atacarían con una carga fulminante. No cometéis falta si, molestos por la lluvia o por que estáis enfermos, dejáis a un lado vuestras armas, pero tomad precauciones. En verdad, Dios ha preparado a los que no creen un castigo humillante.\qt@no{102}}
\qt@newcmd\qurantrans@es@dxcvi{Y cuando terminéis vuestra oración, recordad a Dios, de pie, sentados o acostados. Y cuando estéis tranquilos, haced vuestra oración. En verdad, es obligatorio para los creyentes realizar la oración es los momentos fijados.\qt@no{103}}
\qt@newcmd\qurantrans@es@dxcvii{Y no debilitéis la persecución de esa gente. Si sufrís, ellos también sufren como sufrís vosotros, pero vosotros esperáis de Dios lo que ellos no esperan. Y Dios todo lo conoce, es sabio.\qt@no{104}}
\qt@newcmd\qurantrans@es@dxcviii{En verdad, hicimos descender para ti la Escritura [Sagrada] con la Verdad, para que juzgues entre los hombres mediante lo que Dios te ha hecho ver. Y no seas defensor de los traidores.\qt@no{105}}
\qt@newcmd\qurantrans@es@dxcix{Y pedid el perdón de Dios. Ciertamente, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{106}}
\qt@newcmd\qurantrans@es@dc{Y no discutáis a favor de quienes se traicionan constantemente a sí mismos. Dios no ama a quien es traidor, pecador.\qt@no{107}}
\qt@newcmd\qurantrans@es@dci{Se avergüenzan ante la gente pero no se avergüenzan ante Dios, aunque Él está junto a ellos cuando conspiran por la noche diciendo lo que a Él no le satisface. Y Dios tiene bajo control lo que hacen.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcii{¡Ah! Vosotros los defendéis en esta vida, pero ¿Quién hablará en su favor ante Dios el Día del Levantamiento o quién será su abogado?\qt@no{109}}
\qt@newcmd\qurantrans@es@dciii{Quien haga un mal u oprima a su propia alma y luego pida el perdón de Dios, encontrara a Dios perdonador, misericordiosísimo con los creyentes.\qt@no{110}}
\qt@newcmd\qurantrans@es@dciv{Y quien comete un pecado, ciertamente, lo comete contra sí mismo. Y Dios todo los conoce, es sabio.\qt@no{111}}
\qt@newcmd\qurantrans@es@dcv{Quien, pues, comete un error o un pecado y luego acusa de ello a un inocente, cargará con una infamia y un pecado evidente.\qt@no{112}}
\qt@newcmd\qurantrans@es@dcvi{Si no fuera por el favor y la misericordia de Dios sobre ti, un grupo de ellos habría tratado de extraviarte, pero no se extravían más que a sí mismos. Y no pueden perjudicarte en nada. Dios ha hecho descender sobre ti la Escritura [Sagrada] y la Sabiduría y te ha enseñado lo que no sabías. El favor que Dios te hizo es inmenso.\qt@no{113}}
\qt@newcmd\qurantrans@es@dcvii{No hay nada bueno en muchas de las conversaciones que mantienen en secreto, exceptuando a quien ordena la limosna, el bien o la reconciliación entre la gente. Y a quien haga eso buscando la satisfacción de Dios, Nosotros le daremos una recompensa inmensa.\qt@no{114}}
\qt@newcmd\qurantrans@es@dcviii{Y a quien discuta al Mensajero, después de habérsele manifestado claramente la guía, y siga otro camino diferente al de los creyentes, le alejaremos en la medida en que él se aleje y le haremos entrar en el Infierno. ¡Qué mal destino!\qt@no{115}}
\qt@newcmd\qurantrans@es@dcix{En verdad, Dios no perdona a quien adora a otro distinto a Él pero, aparte de eso, perdona a quien Él quiere. Y quien adore a otro que a Dios se habrá extraviado profundamente.\qt@no{116}}
\qt@newcmd\qurantrans@es@dcx{Lo que adoran aparte de Él, no son más que ídolos femeninos y no adoran más que a un Satanás rebelde\qt@no{117}}
\qt@newcmd\qurantrans@es@dcxi{a quien Dios ha maldecido y que dice: «Tomaré a un número determinado de Tus siervos\qt@no{118}}
\qt@newcmd\qurantrans@es@dcxii{y les extraviaré. Les haré concebir falsas esperanzas y les ordenaré que corten las orejas del ganado y que alteren la Creación de Dios.» Y quien tome a Satanás por amigo y protector, en lugar de a Dios se habrá perdido de manera evidente.\qt@no{119}}
\qt@newcmd\qurantrans@es@dcxiii{Les hace promesas y les hace concebir falsas esperanzas, pero lo que Satanás les promete es sólo ilusión.\qt@no{120}}
\qt@newcmd\qurantrans@es@dcxiv{Su morada será el Infierno y no hallarán manera de escapar de él.\qt@no{121}}
\qt@newcmd\qurantrans@es@dcxv{Y, a aquellos que creen y obran rectamente, les haremos entrar en Jardines de cuyas profundidades brotan los ríos, en los que estarán eternamente; hasta el final de los tiempos. La promesa de Dios es verdadera y ¿Quién es más veraz al hablar que Dios?\qt@no{122}}
\qt@newcmd\qurantrans@es@dcxvi{[La superioridad] no es por deseo vuestro o por deseo de la gente de la Escritura [Sagrada]. Quien obre mal será retribuido por ello y, excepto Dios, no encontrará ni amigo ni auxiliar.\qt@no{123}}
\qt@newcmd\qurantrans@es@dcxvii{Y, quien haga buenas acciones, sea varón o hembra, y sea creyente, entrará en el Jardín y no será oprimido en lo más mínimo.\qt@no{124}}
\qt@newcmd\qurantrans@es@dcxviii{Y ¿Quién posee mejores creencias que quien inclina su rostro en señal de sometimiento a Dios y es bueno y sigue la creencia de Abraham, el buscador de la Verdad?\qt@no{125}}
\qt@newcmd\qurantrans@es@dcxix{A Dios pertenece lo que hay en los cielos y lo que hay en la Tierra y Dios todo lo abarca.\qt@no{126}}
\qt@newcmd\qurantrans@es@dcxx{Te piden tu opinión sobre las mujeres. Di: «Dios os da su parecer sobre ello [en lo que os fue recitado] en la Escritura [Sagrada] sobre ellas. Y en lo que os fue recitado sobre las huérfanas a las cuales no habéis entregado lo que fue dispuesto para ellas y con las cuales no deseáis casaros, y sobre los niños oprimidos, y que debéis dar a los huérfanos un trato equitativo. Y lo que hagáis de bien, Dios, con seguridad, lo sabrá.»\qt@no{127}}
\qt@newcmd\qurantrans@es@dcxxi{Y si una mujer siente que su esposo la rechaza o la evita, no hacen mal si ambos lo arreglan pacíficamente. Y hacer las paces es mejor. Las almas son propensas a la codicia, pero si sois virtuosos y temerosos de Dios [sabed que] ciertamente, Dios está bien informado de todo lo que hacéis.\qt@no{128}}
\qt@newcmd\qurantrans@es@dcxxii{Y, jamás podréis ser justos con vuestras mujeres, aun deseándolo, pero no os inclinéis totalmente [hacia una] dejando [a las otras] como suspendidas en el aire. Si lo arregláis y sois temerosos de Dios [encontraréis] que, ciertamente, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{129}}
\qt@newcmd\qurantrans@es@dcxxiii{Y, si se separan, Dios cubrirá las necesidades de cada uno de ellos con algo de Su abundancia. Dios todo lo alcanza, es sabio.\qt@no{130}}
\qt@newcmd\qurantrans@es@dcxxiv{A Dios pertenece todo lo que hay en los cielos y en la Tierra. Y, ciertamente, Nosotros ordenamos a quienes les fue dada la Escritura [Sagrada] antes de vosotros y, [también], a vosotros, que fuerais buenos, temeroso de Dios. Pero, si no creéis, [sabed que] en verdad, a Dios pertenece lo que hay en los cielos y en la Tierra. Y Dios es rico por Sí mismo, digno de ser alabado.\qt@no{131}}
\qt@newcmd\qurantrans@es@dcxxv{Y a Dios pertenece lo que hay en los cielos en la Tierra y es suficiente con tener a Dios de abogado.\qt@no{132}}
\qt@newcmd\qurantrans@es@dcxxvi{Si Él quisiera ¡Oh gentes! os llevaría y traería a otros. Dios tiene suficiente poder para hacerlo.\qt@no{133}}
\qt@newcmd\qurantrans@es@dcxxvii{Quien desee la recompensa de este mundo, [sepa que] junto a Dios están la recompensa de este mundo y la del Otro. Y Dios todo lo oye, todo lo ve.\qt@no{134}}
\qt@newcmd\qurantrans@es@dcxxviii{¡Oh, los que creéis! Proteged la justicia testificando para Dios, aunque sea contra vosotros mismos o contra vuestros padres o familiares cercanos, sean ricos o pobres, ya que Dios tiene mayor derecho que ellos. Y no sigáis vuestras pasiones, para que seáis justos. Y, si distorsionáis vuestro testimonio u os negáis a darlo, Dios está bien informado de lo que hacéis.\qt@no{135}}
\qt@newcmd\qurantrans@es@dcxxix{¡Oh los que creéis! Creed en Dios y en Su Mensajero y en la Escritura [Sagrada] que ha ido descendiendo sobre Su Mensajero y en la Escritura [Sagrada] que hicimos descender anteriormente. Y quien no crea en Dios y en Sus ángeles y en Sus Escrituras y en Sus Mensajeros y en el Último Día, en verdad, se habrá extraviado profundamente.\qt@no{136}}
\qt@newcmd\qurantrans@es@dcxxx{En verdad, a aquellos que creen, luego descreen, luego creen, luego descreen, incrementando su incredulidad, Dios no les perdonará jamás ni les guiará al camino [recto].\qt@no{137}}
\qt@newcmd\qurantrans@es@dcxxxi{Informa a los hipócritas que tendrán un castigo doloroso.\qt@no{138}}
\qt@newcmd\qurantrans@es@dcxxxii{Aquellos que toman como amigos a los que no creen en lugar de a los creyentes. ¿Acaso buscan el poder junto a ellos? Pues, en verdad, el poder pertenece por entero a Dios.\qt@no{139}}
\qt@newcmd\qurantrans@es@dcxxxiii{Él os reveló en la Escritura [Sagrada] que, cuando oigáis que las indicaciones de Dios no son creídas y se hace burla de ellas, no os sentéis con ellos hasta que hablen de otra cosa, pues, entonces, seríais como ellos. En verdad, Dios reunirá a los hipócritas y a los que no creen en el Infierno. Todos juntos.\qt@no{140}}
\qt@newcmd\qurantrans@es@dcxxxiv{[Los hipócritas son] aquellos que permanecen a la expectativa y si Dios os envía una victoria, dicen: «¿Acaso no estamos con vosotros?» pero si los que no creen consiguen ganar una victoria parcial, dicen: «¿Acaso no podíamos haber cabalgado contra vosotros y, en cambio os defendimos de los creyentes?» Pero Dios juzgará entre vosotros el Día del Levantamiento. Y Dios no permitirá, en absoluto, que los no creyentes se sitúen sobre los creyentes.\qt@no{141}}
\qt@newcmd\qurantrans@es@dcxxxv{Los hipócritas tratan de engañar a Dios pero es Él Quien les engaña. Cuando se levantan para la oración lo hacen con pereza, para que la gente les vea, y recuerdan muy poco a Dios.\qt@no{142}}
\qt@newcmd\qurantrans@es@dcxxxvi{Siempre vacilantes, no van hacia los unos ni hacia los otros. No encontrarás un camino para aquel a quien Dios extravía.\qt@no{143}}
\qt@newcmd\qurantrans@es@dcxxxvii{¡Oh, los que creéis! No toméis a los que no son creyentes como amigos en lugar de a los creyentes. ¿Queréis poner a Dios en contra vuestra?\qt@no{144}}
\qt@newcmd\qurantrans@es@dcxxxviii{En verdad, os hipócritas estarán en lo más profundo del Fuego y no encontrarás quien les auxilie.\qt@no{145}}
\qt@newcmd\qurantrans@es@dcxxxix{Exceptuando a quienes se arrepientan y se corrijan y se aferren a Dios y purifiquen sus creencias para Dios, pues esos estarán con los creyentes. Y Dios dará a los creyentes una recompensa inmensa.\qt@no{146}}
\qt@newcmd\qurantrans@es@dcxl{¿Por qué iba Dios a castigaros si sois agradecidos y creyentes? Dios es agradecido, sapientísimo.\qt@no{147}}
\qt@newcmd\qurantrans@es@dcxli{A Dios no le gusta que nadie vaya proclamando abiertamente el mal, excepto si es oprimido. Dios todo lo oye, todo lo sabe.\qt@no{148}}
\qt@newcmd\qurantrans@es@dcxlii{Si manifestáis el bien o lo ocultáis o perdonáis un agravio, [sabed que] ciertamente, Dios es perdonador, poderosísimo.\qt@no{149}}
\qt@newcmd\qurantrans@es@dcxliii{En verdad, aquellos que no creen en Dios y en Sus Mensajeros y quieren hacer diferencias entre Dios y Sus Mensajeros y dicen: «Creemos en algunos pero no creemos en otros» queriendo tomar una postura intermedia entre unos y otros,\qt@no{150}}
\qt@newcmd\qurantrans@es@dcxliv{son los verdaderos incrédulos. Y hemos preparado para los incrédulos un castigo humillante.\qt@no{151}}
\qt@newcmd\qurantrans@es@dcxlv{Y, a quienes creen en Dios y en Sus Mensajeros y no hacen diferencia entre ninguno de ellos, Él les dará su recompensa. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{152}}
\qt@newcmd\qurantrans@es@dcxlvi{La gente de la Escritura [Sagrada] te pide que hagas descender para ellos una Escritura del Cielo. A Moisés le pidieron cosas más grandes, pues dijeron: «Haznos ver a Dios claramente» y el rayo los aniquiló por su injusticia. Luego adoraron al becerro, después de haber venido a ellos las pruebas claras [de cuál era la Verdad] y, [no obstante], Les perdonamos aquello y dimos a Moisés una autoridad evidente.\qt@no{153}}
\qt@newcmd\qurantrans@es@dcxlvii{Y elevamos sobre ellos el monte Sinaí como señal del pacto que habíamos realizado con ellos y les dijimos: «Entrad por la puerta prosternados» y les dijimos: «No violéis el sábado» e hicimos con ellos un pacto solemne.\qt@no{154}}
\qt@newcmd\qurantrans@es@dcxlviii{Y, por haber roto su pacto y por no haber creído en las señales de Dios y por haber matado a los profetas sin derecho y por haber dicho: «Nuestros corazones están cerrados.» ¡No es eso! Sino que Dios ha imprimido la incredulidad en ellos y sólo unos pocos creerán.\qt@no{155}}
\qt@newcmd\qurantrans@es@dcxlix{Y por no haber creído en Dios y haber dicho de María una inmensa calumnia\qt@no{156}}
\qt@newcmd\qurantrans@es@dcl{y por haber dicho: «Ciertamente, hemos matado al Mesías, Jesús hijo de María, el Mensajero de Dios.» Pero no le mataron ni le crucificaron, sino que se hizo que les pareciera eso. Y, los que discuten sobre él, tienen dudas acerca de ello. No tienen conocimiento de ello, sólo siguen conjeturas. ¡Pero no lo mataron! ¡Eso es seguro!\qt@no{157}}
\qt@newcmd\qurantrans@es@dcli{sino que Dios lo elevó hacia Él. Dios es poderosos, sabio.\qt@no{158}}
\qt@newcmd\qurantrans@es@dclii{Entre la gente de la Escritura [Sagrada] no habrá nadie que no crea en él antes de su muerte y el Día del Levantamiento él será testigo sobre ellos.\qt@no{159}}
\qt@newcmd\qurantrans@es@dcliii{Por ser opresores y por impedir a tanta gente seguir el camino de Dios, prohibimos a los judíos cosas buenas que anteriormente les habíamos permitido\qt@no{160}}
\qt@newcmd\qurantrans@es@dcliv{y por practicar la usura, que les había sido prohibida, y por comerse las riquezas de la gente sin derecho. Y, para los que de ellos no creen, hemos preparado un castigo dolorosísimo.\qt@no{161}}
\qt@newcmd\qurantrans@es@dclv{Pero, a quienes de ellos estén firmemente arraigados en el conocimiento, a los que sean creyentes, a los que crean en lo que fue hecho descender a ti y en lo que fue hecho descender antes de ti, a los que hagan la oración y a los que den la limosna purificadora de la riqueza y crean en Dios y en el Último Día, les otorgaremos una recompensa inmensa.\qt@no{162}}
\qt@newcmd\qurantrans@es@dclvi{En verdad, Nosotros te hemos enviado la revelación [¡Oh Muhammad!], tal como enviamos la revelación a Noé y a los profetas que vinieron tras él. Y enviamos la revelación a Abraham, Ismael, Isaac, Jacob, a las tribus [de los Hijos de Israel], y a Jesús, Job, Jonás, Aarón y a Salomón. Y a David le otorgamos los Salmos.\qt@no{163}}
\qt@newcmd\qurantrans@es@dclvii{Y [hemos enviado] Mensajeros de los que te hemos relatado su historia anteriormente y otros Mensajeros de los que no te hemos relatado su historia. Y Dios habló a Moisés directamente.\qt@no{164}}
\qt@newcmd\qurantrans@es@dclviii{Mensajeros portadores de buenas nuevas y advertidores, para que, tras el envío de los Mensajeros, los seres humanos no tuviesen argumento alguno contra Dios. Y Dios es poderoso, sabio.\qt@no{165}}
\qt@newcmd\qurantrans@es@dclix{Pero Dios atestigua que lo que Él hizo descender para ti lo hizo descender mediante el conocimiento que posee y los ángeles también lo atestiguan. Y basta Dios de testigo.\qt@no{166}}
\qt@newcmd\qurantrans@es@dclx{En verdad, aquellos que no creen y ponen dificultades [a los que quieren seguir] en la senda de Dios, se han extraviado enormemente.\qt@no{167}}
\qt@newcmd\qurantrans@es@dclxi{En verdad, Dios no perdonará a quienes no creyeron y oprimieron, ni guiará su camino\qt@no{168}}
\qt@newcmd\qurantrans@es@dclxii{excepto en dirección al Infierno, en el que estarán eternamente; para siempre. Eso para Dios es fácil de hacer.\qt@no{169}}
\qt@newcmd\qurantrans@es@dclxiii{¡Oh, gentes! ¡Ha venido a vosotros el Mensajero con la Verdad que procede de vuestro Señor! ¡Creed, pues! ¡Eso será mejor para vosotros! Y si no creéis, (sabed que) ciertamente a Dios pertenece lo que hay en los cielos y en la Tierra y Dios todo lo conoce, es sabio.\qt@no{170}}
\qt@newcmd\qurantrans@es@dclxiv{¡Oh, gente de la Escritura [Sagrada]! No exageréis en vuestra religión y no digáis de Dios más que la verdad. En verdad, el Mesías Jesús hijo de María es un profeta de Dios, Su palabra depositada en María y un espíritu procedente de Él. Creed, pues, en Dios y en Sus Mensajeros y no digáis «Tres». ¡Acabad con eso! Es mejor para vosotros. En verdad, Dios es uno. ¡Glorificado sea! ¡Cómo va a tener Él un hijo! ¡A Él pertenece lo que hay en los cielos y en la Tierra! ¡Y Dios se basta para administrarlo!\qt@no{171}}
\qt@newcmd\qurantrans@es@dclxv{El Mesías no tiene a menos ser un siervo de Dios ni tampoco los arcángeles querubines. Y, pronto congregará junto a Él a todos los que tengan a menos adorarle y sean arrogantes.\qt@no{172}}
\qt@newcmd\qurantrans@es@dclxvi{Pero a aquellos que crean y actúen rectamente Él les entregará toda su recompensa y les añadirá de Su merced. Y a aquellos que tuvieron a menos «servirle» y fueron arrogantes Él les castigará con un castigo dolorosísimo y no encontraran, aparte de Dios, protector ni auxiliador.\qt@no{173}}
\qt@newcmd\qurantrans@es@dclxvii{¡Oh gentes! Ha venido a vosotros una prueba clara procedente de vuestro Señor e hicimos descender hacia vosotros una luz esclarecedora.\qt@no{174}}
\qt@newcmd\qurantrans@es@dclxviii{Y a aquellos que crean en Dios y se aferren a ella, pronto se les introducirá en una misericordia y en una merced que proceden de Él y les guiará hacia Él por un camino recto.\qt@no{175}}
\qt@newcmd\qurantrans@es@dclxix{Te piden tu juicio. Di: «Dios os da su juicio sobre la kalála: Si un hombre muere y no tiene hijos y tiene una hermana, para ella es la mitad de lo que dejó y él heredará de ella si ella no tiene hijos. Y si son dos hermanas, ellas recibirán dos tercios de lo que él dejó. Y si son varios hermanos y hermanas, a cada varón le corresponde la misma parte que a dos hembras.» Dios os lo explica claramente para que no os extraviéis. Y Dios conoce bien todas las cosas.\qt@no{176}}
\qt@newcmd\qurantrans@es@dclxx{\basmalahes ¡Oh, los que creéis! Respetad los compromisos. Es licito para vosotros [comer la carne de] los animales de los rebaños, excepto de aquellos que se os va a comunicar. La caza no es lícita para vosotros mientras estéis consagrados [durante la peregrinación]. En verdad, Dios decreta lo que desea.\qt@no{1}}
\qt@newcmd\qurantrans@es@dclxxi{Oh, los que creéis! No profanéis los sacramentos de Dios, ni el mes sagrado, ni las ofrendas, ni las guirnaldas, ni molestéis a quienes se dirigen a la Casa Sagrada buscando la misericordia de su Señor y Su satisfacción. Y, cuando salgáis e vuestro estado de consagración, podéis cazar. Y que los malos sentimientos hacia un pueblo que os impedía llegar a la Mezquita Sagrada no os inciten a la injusticia. Y ayudaos mutuamente a hacer el bien y al temor de Dios, pero no colaboréis en el pecado y la agresión. Y sed temerosos de Dios. Ciertamente, Dios castiga con severidad.\qt@no{2}}
\qt@newcmd\qurantrans@es@dclxxii{Se os prohíbe [comer] la carne de los animales muertos, la sangre, la carne del cerdo y de lo que se ha ofrecido a otro distinto a Dios; el animal estrangulado o golpeado hasta morir o muerto por una caída o por una cornada, o lo devorado por una fiera, excepto lo que podáis purificar, y lo sacrificado sobre las piedras, así como dividir [la carne] consultando la suerte de las flechas. Todo ello es una trasgresión. Hoy, los que no creen, han desesperado de que vuestra religión decline. Por tanto, no les temáis a ellos, temed de Mí. Hoy he completado vuestra religión y he consumado Mi bendición sobre vosotros y estoy satisfecho de haberos dado como creencia el Islam. Y quien se vea obligado por el hambre, no por ánimo de pecar, encontrará que Dios es, verdaderamente, perdonador, misericordiosísimo con los creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@dclxxiii{Te preguntan que es lícito para ellos. Di: «Son lícitas para vosotros las cosas buenas y puras, y [la caza] con los animales de presa que habéis enseñado con lo que Dios os enseñó a vosotros. Comed, pues, de lo que capturen para vosotros y mencionad el nombre de Dios sobre ello. Y sed temerosos de Dios. Ciertamente, Dios es rápido haciendo la cuenta.»\qt@no{4}}
\qt@newcmd\qurantrans@es@dclxxiv{Hoy se han hecho lícitas para vosotros las cosas buenas y puras. Y los alimentos de aquellos a quienes les fue dada la Escritura [Sagrada] se han hecho lícitos para vosotros y vuestros alimentos lícitos para ellos. Y las mujeres honestas de entre las creyentes y las mujeres honestas de entre aquellos a quienes les fue dada la Escritura [Sagrada] antes de vosotros, cuando les hayáis dado su dote en matrimonio, no tomándolas como fornicadoras o como amantes. Y quien abandone la fe, habrá malogrado sus obras y en la otra Vida será de los perdedores.\qt@no{5}}
\qt@newcmd\qurantrans@es@dclxxv{¡Oh, los que creéis! Cuando os pongáis en pie para la oración, lavad vuestra cara y vuestras manos hasta los codos y pasad la mano [húmeda] por vuestras cabezas y por vuestros pies hasta los empeines. Y, si estáis impuros, purificaos y si estáis enfermos o de viaje o alguno de vosotros viene de hacer sus necesidades o habéis mantenido relaciones con las mujeres y no encontráis agua, purificaos con tierra pura, pasando las manos con ella por vuestros rostros y por vuestras manos. Dios no desea imponeros una carga, sino que quiere que os purifiquéis y completar Su favor sobre vosotros para que así, quizás, agradezcáis.\qt@no{6}}
\qt@newcmd\qurantrans@es@dclxxvi{Y recordad el favor que Dios os hizo y el pacto que Él estableció con vosotros, cuando dijisteis: «¡Oímos y obedecemos!» Y sed temerosos de Dios. Dios sabe bien lo que hay en lo más profundo de los corazones.\qt@no{7}}
\qt@newcmd\qurantrans@es@dclxxvii{¡Oh, los que creéis! Proteged la justicia por Dios, dando testimonio equitativo y no dejéis que los malos sentimientos contra un pueblo os lleven a no ser justos. ¡Sed justos! Eso está más cerca del temor de Dios. Y temed a Dios. En verdad, Dios está bien informado de cuanto hacéis.\qt@no{8}}
\qt@newcmd\qurantrans@es@dclxxviii{Dios prometió a quienes creen y actúan rectamente que serán perdonados y obtendrán una recompensa inmensa.\qt@no{9}}
\qt@newcmd\qurantrans@es@dclxxix{Y, aquellos que no creen y desmienten Nuestras señales, son la gente del Infierno.\qt@no{10}}
\qt@newcmd\qurantrans@es@dclxxx{¡Oh los que creéis! Recordad el favor de Dios cuando un grupo quería poneros las manos encima y Él refrenó sus manos (para que no fueran) contra vosotros. Y temed a Dios, pues, en Dios es en quien confían los creyentes.\qt@no{11}}
\qt@newcmd\qurantrans@es@dclxxxi{Ciertamente, Dios estableció un pacto con los Hijos de Israel y designamos entre ellos doce jefes. Y Dios dijo: «¡Estoy con vosotros! Si realizáis la oración, entregáis la limosna ritual, creéis en Mis Mensajeros, les dais vuestro apoyo y hacéis a Dios un préstamo generoso, Yo cubriré vuestras faltas y os introduciré en Jardines de cuyas profundidades brotan los ríos. Y, quien de vosotros, después de esto, descrea, ciertamente, se habrá extraviado del camino recto.»\qt@no{12}}
\qt@newcmd\qurantrans@es@dclxxxii{Y, por haber violado su pacto, les maldijimos y endurecimos sus corazones. Desvirtúan el significado de las palabras y olvidan parte de aquello a lo que, con ellas, se les llamaba la atención. No cesarás de descubrir la traición en ellos, exceptuando a unos pocos. Perdónales y discúlpales. En verdad, Dios ama a los virtuosos.\qt@no{13}}
\qt@newcmd\qurantrans@es@dclxxxiii{Y establecimos un pacto con los que decían: «Ciertamente, somos nazarenos.» Pero olvidaron una parte de lo que se les recordaba en él, por lo que suscitamos entre ellos la enemistad y el odio hasta el Día del Levantamiento. Dios les mostrará claramente lo que estaban haciendo.\qt@no{14}}
\qt@newcmd\qurantrans@es@dclxxxiv{¡Oh, gente de la Escritura [Sagrada]! Ha venido a vosotros Nuestro Mensajero mostrando claramente mucho de lo que ocultabais de la Escritura y eliminando mucho. Ha venido a vosotros, procedente de Dios, una Luz y una Escritura clara.\qt@no{15}}
\qt@newcmd\qurantrans@es@dclxxxv{Con ella, Dios guía por caminos de paz a quien busca Su satisfacción. Él les lleva de las tinieblas a la Luz y les guía hacia el camino recto.\qt@no{16}}
\qt@newcmd\qurantrans@es@dclxxxvi{Ciertamente, aquellos que dicen: «El Mesías hijo de María es Dios» niegan la Verdad. Di: «Si Dios quisiera aniquilar al Mesías hijo de María, a su madre y todos los seres de la Tierra ¿Quién podría impedirlo?» A Dios pertenece el gobierno de los cielos y la Tierra y de lo que hay entre ellos. Él crea lo que desea. Dios tiene poder sobre todas las cosas.\qt@no{17}}
\qt@newcmd\qurantrans@es@dclxxxvii{Y los judíos y los cristianos dicen: «Somos los hijos de Dios y Sus preferidos.» Di: «¿Entonces, por qué os castiga por vuestros pecados? Sólo sois otros seres humanos de los [muchos] que Él ha creado.» Él perdona a quien quiere y castiga a quien quiere. Y a Dios pertenece el gobierno de los cielos y la Tierra y de lo que hay entre ambos y todo regresa a Él.\qt@no{18}}
\qt@newcmd\qurantrans@es@dclxxxviii{¡Oh, gente de la Escritura [Sagrada]! Ha venido a vosotros Nuestro Mensajero, tras un periodo sin Mensajeros, para explicaros [las enseñanzas divinas], no fueseis a decir: «No ha venido a nosotros nadie que nos comunicara la buena nueva ni nos advirtiese del castigo.» Así pues, ha venido a vosotros un portador de la buena nueva y advertidor del castigo. Y Dios tiene poder sobre todas las cosas.\qt@no{19}}
\qt@newcmd\qurantrans@es@dclxxxix{Y (recuerda) cuando Moisés dijo a su pueblo: «¡Oh, pueblo mío! Recordad la merced de Dios con vosotros, poniendo entre vosotros profetas y haciendo de vosotros soberanos y otorgándoos lo que no le había sido dado a ninguna otra nación.»\qt@no{20}}
\qt@newcmd\qurantrans@es@dcxc{«¡Oh, pueblo mío! Entrad en la tierra sagrada que Dios ha dispuesto para vosotros y no retrocedáis pues os convertiríais en perdedores.»\qt@no{21}}
\qt@newcmd\qurantrans@es@dcxci{Ellos dijeron: «¡Oh, Moisés! En verdad, en ella habita un pueblo de gigantes y no entraremos en ella mientras ellos no salgan. Si ellos la abandonan nosotros entraremos.»\qt@no{22}}
\qt@newcmd\qurantrans@es@dcxcii{Dos hombres de los que temían a Dios y a los que Dios había agraciado dijeron: «Atacadles por la puerta. Cuando consigáis entrar, habréis vencido. Y confiad en Dios si sois creyentes.»\qt@no{23}}
\qt@newcmd\qurantrans@es@dcxciii{Dijeron: «¡Oh, Moisés! Jamás entraremos mientras ellos continúen allí. ¡Id tú y tu Señor y combatidles! Nosotros nos quedaremos aquí sentados.\qt@no{24}}
\qt@newcmd\qurantrans@es@dcxciv{Dijo [Moisés]: ¡Dios mío! No tengo poder excepto sobre mí mismo y sobre mi hermano. Aléjanos de la gente trasgresora.»\qt@no{25}}
\qt@newcmd\qurantrans@es@dcxcv{Dijo [Dios]: «Estará prohibida para ellos. Cuarenta años vagarán por la Tierra. No te entristezcas por ese pueblo trasgresor.»\qt@no{26}}
\qt@newcmd\qurantrans@es@dcxcvi{Relátales la verdadera historia de los dos hijos de Adán, cuando ambos realizaron una ofrenda a Dios y a uno de ellos le fue aceptada pero al otro no. [Éste] Dijo: «¡Juro que te mataré!» Dijo [el otro]: «Dios sólo acepta la ofrenda de quienes son temerosos.\qt@no{27}}
\qt@newcmd\qurantrans@es@dcxcvii{Si levantas tu mano para matarme yo no levantaré la mía para matarte. En verdad, temo a Dios, el Señor de los mundos.\qt@no{28}}
\qt@newcmd\qurantrans@es@dcxcviii{Deseo que cargues con mi pecado y con el tuyo y que seas de la gente del Fuego. Esa es la recompensa de los opresores.»\qt@no{29}}
\qt@newcmd\qurantrans@es@dcxcix{Su alma le fue haciendo aceptable la idea de matar a su hermano y le mató, convirtiéndose con ello en uno de los perdedores.\qt@no{30}}
\qt@newcmd\qurantrans@es@dcc{Entonces, Dios envió un cuervo que escarbó en la tierra para hacerle ver como sepultar el cadáver de su hermano. Dijo: «¡Ay de mí! ¿Es que soy incapaz de hacer como este cuervo?» Y enterró el cadáver de su hermano y fue de los que se arrepienten.\qt@no{31}}
\qt@newcmd\qurantrans@es@dcci{Por esa razón, dispusimos para los Hijos de Israel que, quien matara a un ser humano sin que este hubiera cometido un crimen o hubiera corrompido en la Tierra, fuese considerado como quien mata a toda la humanidad y quien e salvase, como quien salva a toda la humanidad. Ciertamente, llegaron a ellos Nuestros Mensajeros con las pruebas claras, pero, tras ello y a pesar de ello, muchos de ellos cometieron excesos en la Tierra.\qt@no{32}}
\qt@newcmd\qurantrans@es@dccii{En verdad, la retribución de quienes hagan la guerra a Dios y a Su Mensajero y se dediquen a corromper la Tierra, será la muerte o la crucifixión o que se les corte la mano y el pie opuesto o que se les expulse de su territorio. Esto será para ellos una humillación en esta vida y en la otra tendrán un castigo inmenso.\qt@no{33}}
\qt@newcmd\qurantrans@es@dcciii{Excepto a quienes se arrepientan antes de caer en vuestras manos. Y sabed que Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{34}}
\qt@newcmd\qurantrans@es@dcciv{¡Oh, los que creéis! Temed a Dios y buscad la manera de acercaros a Él y esforzaos por Su causa, quizás, así, tengáis éxito.\qt@no{35}}
\qt@newcmd\qurantrans@es@dccv{En verdad, a quienes no creen, aunque poseyeran todo cuanto hay en la Tierra y otro tanto y lo entregaran para redimirse con ello del castigo del Día del Levantamiento, no les sería aceptado y tendrán un castigo inmenso.\qt@no{36}}
\qt@newcmd\qurantrans@es@dccvi{Querrán escapar del Fuego, pero no saldrán de él y sufrirán un castigo constante.\qt@no{37}}
\qt@newcmd\qurantrans@es@dccvii{Y, al ladrón y a la ladrona, cortadles la mano en pago de lo que hicieron, como escarmiento procedente de Dios. Y Dios es poderoso, sabio.\qt@no{38}}
\qt@newcmd\qurantrans@es@dccviii{Pero, Dios perdonará a quien, tras su mal comportamiento, se arrepienta y repare el mal que cometió. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{39}}
\qt@newcmd\qurantrans@es@dccix{¿Acaso no sabes que a Dios pertenece la soberanía de los cielos y la Tierra? Él castiga a quien quiere y perdona a quien quiere. Dios tiene poder sobre todas las cosas.\qt@no{40}}
\qt@newcmd\qurantrans@es@dccx{¡Oh, Mensajero! No te entristezcas por quienes se precipitan a la incredulidad. Son de los que dicen «creemos» con sus bocas pero que no creen con sus corazones. Ni por los judíos que prestan oídos a la mentira y espían para otras gentes que no han venido a ti. Sacan las palabras (de la Sagrada Escritura) de su contexto. Dicen: «Si emiten este juicio, aceptadlo y si no rechazadlo.» No podrás interceder ante Dios a favor de quien Dios quiera castigar. Esos son aquéllos a los que Dios no quiere purificar sus corazones. Sufrirán la humillación en esta vida y en la otra un castigo inmenso.\qt@no{41}}
\qt@newcmd\qurantrans@es@dccxi{Prestan oído a las mentiras y se alimentan de bienes ilícitos. Si vienen a ti, juzga su asunto o déjales que se arreglen entre ellos. Si te inhibes, no podrán perjudicarte en absoluto, pero si juzgas, júzgales con equidad. Ciertamente, Dios ama a quienes son equitativos.\qt@no{42}}
\qt@newcmd\qurantrans@es@dccxii{Pero ¿Cómo pueden querer que tú seas su juez, teniendo ellos la Torá con el juicio de Dios? Luego, tras ello, dan la espalda. No son creyentes.\qt@no{43}}
\qt@newcmd\qurantrans@es@dccxiii{Ciertamente, hicimos descender la Torá. En ella hay guía y luz. Los profetas, obedeciendo a Dios, administraban justicia con ella entre los judíos [y también] los rabinos y sabios, pues se les pidió que protegiesen la Escritura de Dios y dieran testimonio de ella. Así pues, no tengáis miedo de la gente, temedme a Mí y no vendáis Mis indicaciones por poco precio. Quienes no juzguen con los que Dios ha hecho descender, serán los que ocultan la Verdad.\qt@no{44}}
\qt@newcmd\qurantrans@es@dccxiv{Y, en ella, les ordenamos: vida por vida, ojo por ojo, nariz por nariz, oreja por oreja, diente por diente y por cada herida una compensación. Y, a quien renuncie a la compensación, se le perdonarán sus pecados. Y, quienes no juzguen conforme a lo que Dios hizo descender, serán los opresores.\qt@no{45}}
\qt@newcmd\qurantrans@es@dccxv{Y, tras ellos, enviamos a Jesús hijo de María, confirmando la Torá que ellos tenían en sus manos. Y le dimos el Evangelio, en el cual hay guía y luz y confirmación de lo que tienen en la Torá, y que es una guía y una amonestación para los temerosos de Dios.\qt@no{46}}
\qt@newcmd\qurantrans@es@dccxvi{¡Que la gente del Evangelio juzgue conforme a lo que Dios ha hecho descender en él! Y, quienes no juzguen conforme a los que Dios hizo descender, esos serán los pecadores.\qt@no{47}}
\qt@newcmd\qurantrans@es@dccxvii{Hicimos descender para ti la Escritura que contiene la Verdad y que confirma la Escritura que ya tenían en sus manos y la protege. Juzga, pues, entre ellos con lo que Dios hizo descender. Y no sigas sus deseos, contrariando la Verdad que ha venido a ti. A cada uno de vosotros le hemos asignado un código legal y un camino de salvación y, si Dios hubiera querido, habría hecho que fueseis una sola comunidad, pero lo hace así para probar vuestra fe en lo que os ha dado. ¡Competid, pues, en buenas acciones! El lugar de retorno de todos vosotros es Dios. Él os aclarará aquello en lo que manteníais diferencias.\qt@no{48}}
\qt@newcmd\qurantrans@es@dccxviii{Juzga entre ellos con lo que Dios hizo descender y no sigas sus deseos. Y ten cuidado con ellos para que no te desvíen de algo de lo que hizo descender Dios para ti. Y si te dan la espalda, sabe que Dios quiere castigarles por algunos de sus pecados. En verdad, muchos de los seres humanos son transgresores de la ley.\qt@no{49}}
\qt@newcmd\qurantrans@es@dccxix{¿Desean seguir juzgando como en los tiempos de la ignorancia? Para quienes tienen certeza ¿Quién puede juzgar mejor que Dios?\qt@no{50}}
\qt@newcmd\qurantrans@es@dccxx{¡Oh, los que creéis! No toméis a los judíos ni a los cristianos de amigos y aliados. Algunos de ellos son aliados unos de otros. Y, quien de vosotros les tome por amigos, será uno de ellos. En verdad, Dios no guía a la gente opresora.\qt@no{51}}
\qt@newcmd\qurantrans@es@dccxxi{Ves a los que tienen una enfermedad en su corazón precipitarse hacia ellos diciendo: «¡Tememos sufrir un giro de la fortuna!» Pero puede que Dios traiga la victoria o que, procedente de Él, suceda algo que les haga arrepentirse de lo que guardaban en secreto en sus almas.\qt@no{52}}
\qt@newcmd\qurantrans@es@dccxxii{Y los creyentes dirán: «¿Son esos los que con solemnidad juraban por Dios que estaban contigo?» Han invalidado sus buenas obras y se han convertido en perdedores.\qt@no{53}}
\qt@newcmd\qurantrans@es@dccxxiii{¡Oh, los que creéis! Quien de vosotros reniegue de sus creencias religiosas [sepa que] vendrá Dios con una gente a la que Él ama y por la que es amado, [que será] humilde con los creyentes y severa con los que ocultan la Verdad. Esforzados por la causa de Dios y que no temen la maldición de ningún calumniador. Este es el favor de Dios, que otorga a quien Él quiere. Y Dios todo lo abarca, todo lo conoce.\qt@no{54}}
\qt@newcmd\qurantrans@es@dccxxiv{En verdad, vuestros amigos y protectores son solamente Dios y Su Mensajero y aquellos que tienen fe, que hacen la oración y dan limosna mientras están inclinados rezando.\qt@no{55}}
\qt@newcmd\qurantrans@es@dccxxv{Y quienes tomen como amigos y protectores a Dios, a Su Mensajero y a los que tienen fe, sepan que los del partido de Dios son los vencedores.\qt@no{56}}
\qt@newcmd\qurantrans@es@dccxxvi{¡Oh, creyentes! No toméis como amigos a quienes, habiendo recibido la Escritura [Sagrada] antes que vosotros, toman vuestras creencias religiosas a burla y juego, ni tampoco a los que no creen. Y temed a Dios si sois creyentes.\qt@no{57}}
\qt@newcmd\qurantrans@es@dccxxvii{Y cuando llamáis a la oración lo toman a burla y a juego. Eso es porque son una gente que no razona.\qt@no{58}}
\qt@newcmd\qurantrans@es@dccxxviii{Di: «¡Oh, gente de la Escritura [Sagrada]! ¿Nos rechazáis por alguna otra razón que por haber creído en Dios y en lo que nos fue revelado y en lo que fue revelado antes de nosotros y porque la mayoría de vosotros sois transgresores?»\qt@no{59}}
\qt@newcmd\qurantrans@es@dccxxix{Di: «¿Queréis que os informe de quién está peor retribuido por Dios que quienes hacen esto? Aquel a quien Dios ha maldecido y aquel con el que Él está irritado. A algunos de ellos Él los convirtió en monos y en cerdos porque adoraban a los ídolos. Esos son quienes tienen una situación peor y los más extraviados del camino recto.»\qt@no{60}}
\qt@newcmd\qurantrans@es@dccxxx{Y, cuando vienen a vosotros dicen: «Creemos», pero entran incrédulos y lo mismo salen. Y Dios es quien mejor conoce lo que ellos ocultan.\qt@no{61}}
\qt@newcmd\qurantrans@es@dccxxxi{Y ves como muchos de ellos se precipitan al pecado y a la agresión y se alimentan del soborno y de ganancias ilegales. ¡Qué malo es lo que hacen!\qt@no{62}}
\qt@newcmd\qurantrans@es@dccxxxii{¿Por qué los rabinos y los doctores de la ley no les prohíben sus palabras pecadoras y alimentarse de bienes ilícitos? ¡Qué malo es lo que hacen!\qt@no{63}}
\qt@newcmd\qurantrans@es@dccxxxiii{Los judíos dicen: «La mano de Dios está atada.» ¡Que sus manos sean atadas y sean maldecidos por lo que dijeron! Al contrario, Sus manos están abiertas y Él reparte Sus bienes como quiere. Con certeza, lo que descendió para ti procedente de tu Señor incrementará en muchos de ellos la rebeldía y la falta de fe. Hemos sembrado entre ellos la enemistad y el odio hasta el Día del Levantamiento. Cada vez que enciendan el fuego de la guerra Dios lo apagará. Se esfuerzan por corromper la Tierra y a Dios no le gusta la corrupción.\qt@no{64}}
\qt@newcmd\qurantrans@es@dccxxxiv{Y, si la gente de la Escritura [Sagrada] creyera y tuviera temor de Dios, perdonaríamos sus malos actos y les introduciríamos en los Jardines de la Delicia.\qt@no{65}}
\qt@newcmd\qurantrans@es@dccxxxv{Y, si llevasen a la práctica los preceptos de la Torá y el Evangelio y lo que descendió para ellos procedente de su Señor, se alimentarían de lo que hay sobre ellos y bajo sus pies. Entre ellos hay una comunidad que es moderada, pero ¡Qué malo es lo que hacen muchos otros!\qt@no{66}}
\qt@newcmd\qurantrans@es@dccxxxvi{¡Oh, Mensajero! ¡Transmite lo que ha descendido a ti procedente de tu Señor! Y, si no lo haces, será como si no hubieses transmitido nada de Su mensaje y Dios te protegerá de las gentes. En verdad, Dios no guía a la gente que no cree.\qt@no{67}}
\qt@newcmd\qurantrans@es@dccxxxvii{Di: «¡Oh, gente de la Escritura [Sagrada]! No estaréis en nada mientras no observéis la Torá, el Evangelio y lo que descendió para vosotros procedente de vuestro Señor.» Pero lo que descendió para ti procedente de tu Señor incrementa en muchos de ellos la rebeldía y la falta de fe. No te apenes, pues, por la gente que no tiene fe.\qt@no{68}}
\qt@newcmd\qurantrans@es@dccxxxviii{En verdad, los creyentes, los judíos, los sabeos y los cristianos, quienes crean en Dios y en Último Día y obren rectamente, no tendrán por qué temer y no estarán tristes.\qt@no{69}}
\qt@newcmd\qurantrans@es@dccxxxix{Hicimos un pacto con los Hijos de Israel y les enviamos Mensajeros. Siempre que llegó a ellos un Mensajero con lo que no deseaba su ego, a unos les desmintieron y a otros les mataron.\qt@no{70}}
\qt@newcmd\qurantrans@es@dccxl{Creyeron que no serían puestos a prueba y [actuaron como] ciegos y sordos [ante la Verdad]. Después Dios aceptó su arrepentimiento y, [nuevamente] muchos de ellos [volvieron a comportarse como] ciegos y sordos. Pero Dios observa lo que hacen.\qt@no{71}}
\qt@newcmd\qurantrans@es@dccxli{En verdad, no creen quienes dicen: «Ciertamente, el Mesías hijo de María es Dios.» Pero el Mesías dijo: «¡Oh, Hijos de Israel! Adorad a Dios, mi Señor y vuestro Señor.» A quién equipare a alguien junto a Dios, Dios le vedará [la entrada en] el Jardín y su morada será el Fuego. Los opresores no tendrán quien les auxilie.\qt@no{72}}
\qt@newcmd\qurantrans@es@dccxlii{En verdad, no creen quienes dicen: «Ciertamente, Dios es el tercero de tres» cuando no hay más que un solo Dios. Si no se retractan de lo que dicen, quienes de ellos ocultan la Verdad sufrirán un castigo doloroso.\qt@no{73}}
\qt@newcmd\qurantrans@es@dccxliii{¿Es que no se volverán hacia Dios arrepentidos y Le pedirán perdón? Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{74}}
\qt@newcmd\qurantrans@es@dccxliv{No es el Mesías hijo de María sino un Mensajero de Dios. Antes que él han pasado otros Mensajeros. Y su madre decía la verdad. Ambos comían alimentos. Mira como les aclaramos las señales y mira como se extravían después.\qt@no{75}}
\qt@newcmd\qurantrans@es@dccxlv{Di: «¿Adoraréis aparte de Dios a quienes no tienen poder para perjudicaros o beneficiaros?» Y Dios es Quien todo lo oye, Quien todo lo sabe.\qt@no{76}}
\qt@newcmd\qurantrans@es@dccxlvi{Di: «¡Oh, gente de la Escritura [Sagrada]! No exageréis en vuestras creencias faltando a la Verdad y no sigáis las pasiones de una gente que ya se había extraviado anteriormente e hicieron que muchos se extraviaran y que se han apartado del camino recto.»\qt@no{77}}
\qt@newcmd\qurantrans@es@dccxlvii{Aquellos de los Hijos de Israel que se alejaron de la fe, fueron maldecidos por boca de David y de Jesús hijo de María por haber desobedecido y haberse extralimitado.\qt@no{78}}
\qt@newcmd\qurantrans@es@dccxlviii{No se prohibían unos a otros las malas acciones que cometían. ¡Qué mal estaba lo que hacían!\qt@no{79}}
\qt@newcmd\qurantrans@es@dccxlix{Ves a muchos de ellos que toman amigos entre los que no tienen fe. ¡Qué malo es lo que han enviado por delante [a la otra vida] para sus almas! Dios está disgustado con ellos y serán castigados eternamente.\qt@no{80}}
\qt@newcmd\qurantrans@es@dccl{Y si hubieran creído en Dios y en el Profeta y en lo que fue hecho descender a él, no les habrían tomado como amigos, pero muchos de ellos son transgresores.\qt@no{81}}
\qt@newcmd\qurantrans@es@dccli{Con seguridad, encontrarás que los peores enemigos de los creyentes son los judíos y los politeístas y que los más afectuosos con los creyentes son los que dicen: «Ciertamente, somos cristianos.» Eso es porque algunos de ellos son sacerdotes y monjes, y porque no son arrogantes.\qt@no{82}}
\qt@newcmd\qurantrans@es@dcclii{Y, cuando escuchan la revelación que descendió para el Mensajero, veras sus ojos inundados de lágrimas por lo que reconocen de la Verdad. Dicen: «¡Señor nuestro! Creemos. Escribe pues nuestros nombres con los que dan testimonio.\qt@no{83}}
\qt@newcmd\qurantrans@es@dccliii{¿Por qué no íbamos a creer en Dios y en la Verdad que ha venido a nosotros, si anhelamos que nuestro Señor nos admita entre la gente recta?»\qt@no{84}}
\qt@newcmd\qurantrans@es@dccliv{Por lo que dijeron, Dios les recompensará con Jardines de cuyas profundidades brotan los ríos, en los que estarán eternamente. Esa es la recompensa de quienes hacen el bien.\qt@no{85}}
\qt@newcmd\qurantrans@es@dcclv{Y quienes no crean y desmientan Nuestras señales serán gente del Infierno.\qt@no{86}}
\qt@newcmd\qurantrans@es@dcclvi{¡Oh, los que creéis! No prohibáis las cosas buenas que Dios ha hecho lícitas para vosotros y no os extralimitéis. En verdad, Dios no ama a los transgresores.\qt@no{87}}
\qt@newcmd\qurantrans@es@dcclvii{Y comed de lo lícito y bueno que Dios os proporciona. Y temed a Dios, en Quien creéis.\qt@no{88}}
\qt@newcmd\qurantrans@es@dcclviii{Dios no tendrá en cuenta vuestros juramentos hechos a la ligera, pero sí os toma en cuenta los juramentos con los que os comprometéis conscientemente. En compensación, alimentaréis a diez necesitados de manera similar a como alimentáis a vuestras familias o les vestiréis o liberaréis un esclavo. Y quien no pueda, que ayune tres días. Esa es la compensación por vuestros juramentos incumplidos. Cumplid vuestros juramentos. De esta manera os aclara Dios sus señales. Quizás seáis agradecidos.\qt@no{89}}
\qt@newcmd\qurantrans@es@dcclix{¡Oh, los que creéis! Ciertamente, el vino, los juegos de azar, las piedras de altar [los ídolos] y las flechas adivinatorias, son cosas abominables hechas por Satanás. Por tanto, absteneos de ellas, quizás así triunféis.\qt@no{90}}
\qt@newcmd\qurantrans@es@dcclx{Ciertamente, Satanás quiere crear entre vosotros la enemistad y el odio, con el vino y los juegos de azar y apartándoos del recuerdo de Dios y de la oración. ¿Os abstendréis de ello?\qt@no{91}}
\qt@newcmd\qurantrans@es@dcclxi{¡Obedecer a Dios y obedeced al Mensajero y sed precavidos! Pero si dais la espalda, sabed que Nuestro Mensajero sólo es responsable de transmitir la revelación con claridad.\qt@no{92}}
\qt@newcmd\qurantrans@es@dcclxii{Quienes creen y hacen el bien no están en pecado por lo que comieron anteriormente, mientras sean temerosos y creyentes y hagan el bien, luego sean temerosos y crean, luego sean temerosos y virtuosos. Dios ama a quienes son virtuosos.\qt@no{93}}
\qt@newcmd\qurantrans@es@dcclxiii{Oh, los que creéis! Verdaderamente, Dios os pone a prueba con parte de lo que cazáis con vuestras manos y lanzas. Dios quiere saber quién Le teme en secreto. Y quien tras esto viole la ley, sufrirá un castigo doloroso.\qt@no{94}}
\qt@newcmd\qurantrans@es@dcclxiv{¡Oh, los que creéis! No cacéis mientras estéis consagrados a la peregrinación. Quien de vosotros cace intencionadamente, que lo compense sacrificando un animal de su ganado semejante al que mató, conforme al juicio de dos personas justas de entre vosotros, como una ofrenda a la Kaaba. O lo compensará alimentando a los necesitados, o ayunando en proporción equivalente, para que pruebe las malas consecuencias de su acto. Dios perdona lo pasado, pero Dios se vengará del que reincida. Dios es poderoso, dueño de la venganza.\qt@no{95}}
\qt@newcmd\qurantrans@es@dcclxv{Es lícita para vosotros la pesca del mar y los alimentos que hay en él. Son provisiones para vosotros y para los viajeros. Pero os está prohibida la caza de la tierra mientras dure vuestra condición de peregrinos. Y sed temerosos de Dios, hacia Quien seréis congregados.\qt@no{96}}
\qt@newcmd\qurantrans@es@dcclxvi{Dios ha dispuesto la Kaaba, la Casa Sagrada, los meses sagrados, las ofrendas y las guirnaldas, para el bienestar de las gentes. Eso es para que sepáis que Dios conoce lo que hay en los cielos y en la Tierra y que Dios conoce bien todas las cosas.\qt@no{97}}
\qt@newcmd\qurantrans@es@dcclxvii{Sabed que Dios es severo castigando y que Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{98}}
\qt@newcmd\qurantrans@es@dcclxviii{El Mensajero sólo tiene la responsabilidad de transmitir la revelación. Y Dios conoce lo que mostráis y lo que ocultáis.\qt@no{99}}
\qt@newcmd\qurantrans@es@dcclxix{Di: «El mal y el bien no son iguales, aunque te sorprenda la abundancia de mal.» Así pues, temed a Dios ¡Oh, gente dotada de intelecto! para que podáis triunfar.\qt@no{100}}
\qt@newcmd\qurantrans@es@dcclxx{¡Oh, los que creéis! No preguntéis sobre cosas que, si se os revelasen, os perturbarían. Pero si preguntáis por ellas, cuando desciende el Corán os serán reveladas y Dios lo disculpará. Dios es perdonador, indulgente.\qt@no{101}}
\qt@newcmd\qurantrans@es@dcclxxi{Ciertamente, hubo antes de vosotros un pueblo que hizo las mismas preguntas y eso les llevó a la incredulidad.\qt@no{102}}
\qt@newcmd\qurantrans@es@dcclxxii{Dios no ha establecido Bahira, ni Saiba, ni Wasila, ni Ham, pero los que ocultan la Verdad inventan mentiras sobre Dios y la mayoría de ellos no razonan.\qt@no{103}}
\qt@newcmd\qurantrans@es@dcclxxiii{Y cuando se les dice: «Venid a lo que Dios ha revelado y al Mensajero», dicen: «Es suficiente para nosotros lo que encontramos que nuestros antepasados seguían.» ¿Cómo es eso? ¿Y si sus antepasados no sabían nada y no estaban bien guiados?\qt@no{104}}
\qt@newcmd\qurantrans@es@dcclxxiv{¡Oh, los que creéis! Vuestra responsabilidad es cuidar de vuestras propias almas. Mientras vosotros estéis bien guiados nadie que se extravíe podrá perjudicaros. Todos vosotros regresaréis hacia Dios y seréis informados de los que hacíais.\qt@no{105}}
\qt@newcmd\qurantrans@es@dcclxxv{¡Oh, los que creéis! Cuando a alguno de vosotros se le presente la muerte, que dos hombres justos de entre vosotros sean testigos de su testamento, u otros dos que no sean de los vuestros, si estáis de viaje y se os presenta a dificultad de la muerte. Haced que ambos se queden después de la oración y que juren por Dios: «No alteraremos nuestro testimonio a ningún precio, aunque se trate de un familiar y no ocultaremos el testimonio que pertenece a Dios, pues entonces seríamos unos pecadores.»\qt@no{106}}
\qt@newcmd\qurantrans@es@dcclxxvi{Pero si se descubre que ambos son culpables de un pecado, que otros dos, de entre los familiares cercanos perjudicados por el testimonio de los primeros, ocupen su lugar y juren por Dios que: «Nuestro testimonio es más verídico que el de los dos primeros y no hemos sido transgresores, pues, en ese caso, seríamos de los opresores.»\qt@no{107}}
\qt@newcmd\qurantrans@es@dcclxxvii{Así será más posible que el testimonio que presten se ajuste a la verdad o teman que otros presten juramento después del suyo. Y temed desobedecer a Dios y escuchad. Dios no guía a la gente transgresora.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcclxxviii{[Temed] un día en el que Dios reúna a los profetas y les pregunte: «¿Cómo respondieron las gentes a vuestra llamada?» Y ellos digan: «No lo sabemos. En verdad, Tú Eres el conocedor de lo oculto.»\qt@no{109}}
\qt@newcmd\qurantrans@es@dcclxxix{Y recuerda cuando Dios dijo: «¡Oh, Jesús hijo de María! Recuerda Mi favor sobre ti y sobre tu madre, pues te fortalecí con el Espíritu Santo y hablaste a las gentes en la cuna y de adulto. Y cuando te enseñé la Escritura Sagrada y la Sabiduría y la Torá y el Evangelio y creaste de barro formas de pájaros con Mi permiso y soplaste en ellas y fueron pájaros con Mi permiso. Y cuando curaste al ciego y al leproso con Mi permiso e hiciste salir al muerto de la tumba con Mi permiso. Y cuando impedí a los Hijos de Israel que te atacasen, cuando fuiste a ellos con las pruebas claras y los que de entre ellos no creían dijeron: “Eso no es otra cosa sino brujería evidente.»\qt@no{110}}
\qt@newcmd\qurantrans@es@dcclxxx{Y cuando inspiré a los apóstoles para que tuvieran fe en Mí y en Mi Mensajero y dijeron: «Creemos. Sé testigo de que nos sometemos a Ti, de que somos musulmanes.»\qt@no{111}}
\qt@newcmd\qurantrans@es@dcclxxxi{Y cuando dijeron los apóstoles: «¡Oh, Jesús hijo de María! ¿Podrá tu Señor hacer que descienda para nosotros una mesa desde el cielo?» Dijo [Jesús]: «¡Temed a Dios si sois creyentes!»\qt@no{112}}
\qt@newcmd\qurantrans@es@dcclxxxii{Dijeron: «Queremos comer de ella y aportar certeza a nuestros corazones y saber que nos has dicho la Verdad y ser así de los que dan testimonio de ella.»\qt@no{113}}
\qt@newcmd\qurantrans@es@dcclxxxiii{Dijo Jesús hijo de María: «¡Oh, Dios Señor nuestro! Haz descender a nosotros una mesa desde el cielo que sea una fiesta para todos nosotros, del primero al último y una señal procedente de Ti. ¡Provéenos, pues Tú eres el mejor de los proveedores!»\qt@no{114}}
\qt@newcmd\qurantrans@es@dcclxxxiv{Dijo [Dios]: «En verdad, haré que descienda a vosotros, pero, a quién de vosotros oculte la Verdad después de esto, le castigaré con un castigo con el que no He castigado jamás a nadie en todos los mundos.»\qt@no{115}}
\qt@newcmd\qurantrans@es@dcclxxxv{Y [recuerda] cuando dijo Dios: «¡Oh, Jesús hijo de María! ¿Has dicho tú a los hombres: Tomadme a mí y a mi madre como dioses y no a Dios?» [Jesús] Dijo: «¡Glorificado seas! No soy quién para decir de mí lo que no es cierto. Si lo hubiese dicho Tú lo habrías sabido. Tú sabes lo que hay en mi alma pero yo no sé lo que hay en Tu esencia. Ciertamente Tú eres Quien conoce todas las cosas ocultas.\qt@no{116}}
\qt@newcmd\qurantrans@es@dcclxxxvi{No les he dicho más que aquello que Tú me ordenaste: ¡Adorad a Dios, Señor mío y Señor vuestro! y mientras estuve entre ellos di testimonio de ello y cuando me llevaste a Ti, Tú fuiste su cuidador y guardián. Tú eres testigo de todo.\qt@no{117}}
\qt@newcmd\qurantrans@es@dcclxxxvii{Si les castigas, ellos son solamente Tus siervos y si les perdonas, Tú eres, ciertamente, poderoso, sabio.»\qt@no{118}}
\qt@newcmd\qurantrans@es@dcclxxxviii{Dice Dios: «Hoy es el día en el que los sinceros se beneficiarán de su sinceridad. Hay para ellos Jardines de cuyas profundidades brotan los ríos, en los que estarán eternamente, para siempre. Dios estará satisfecho de ellos y ellos estarán satisfechos de Él. Ese es el triunfo inmenso.»\qt@no{119}}
\qt@newcmd\qurantrans@es@dcclxxxix{A Dios pertenece el gobierno de los cielos y de la Tierra y de lo que hay entre ambos y Él tiene poder sobre todas las cosas.\qt@no{120}}
\qt@newcmd\qurantrans@es@dccxc{\basmalahes Alabado sea Dios, Quien ha creado los cielos y la Tierra y ha establecido las tinieblas y la luz, aunque los que no creen equiparan a su Señor con otros.\qt@no{1}}
\qt@newcmd\qurantrans@es@dccxci{Él es Quien os ha creado de barro y luego ha decretado un plazo. Un plazo determinado que sólo Él conoce. A pesar de ello, aún dudáis.\qt@no{2}}
\qt@newcmd\qurantrans@es@dccxcii{Él es Dios en los cielos y en la Tierra. Conoce lo que ocultáis y lo que manifestáis y conoce la recompensa de vuestros actos.\qt@no{3}}
\qt@newcmd\qurantrans@es@dccxciii{No llega a ellos una señal de las señales de su Señor sin que se aparten de ella.\qt@no{4}}
\qt@newcmd\qurantrans@es@dccxciv{Desmintieron la Verdad cuando llegó a ellos, pero tendrán noticias de aquello de lo que se burlaban.\qt@no{5}}
\qt@newcmd\qurantrans@es@dccxcv{¿Acaso no ven a cuántos pueblos hemos Nosotros destruido antes de ellos? Pueblos a los que dimos medios que no os damos a vosotros. Pero Nosotros enviamos el cielo sobre ellos cargado de lluvias, e hicimos que los ríos corriesen bajo ellos y les destruimos por sus pecados e hicimos surgir, tras ellos, otros pueblos.\qt@no{6}}
\qt@newcmd\qurantrans@es@dccxcvi{Aunque hubiésemos hecho descender para ti [¡Oh, Muhammad!] una Escritura en un pergamino que ellos pudiesen tocar con sus manos, los que no creen habrían dicho: «¡Esto no es sino magia manifiesta!»\qt@no{7}}
\qt@newcmd\qurantrans@es@dccxcvii{Y dicen: «¿Por qué no se hizo que descendiera a él un ángel?» Si Nosotros hubiéramos enviado un ángel, el asunto habría quedado decretado y ellos no habrían tenido un plazo.\qt@no{8}}
\qt@newcmd\qurantrans@es@dccxcviii{Y, si hubiésemos hecho de él un ángel, ciertamente, le habríamos hecho hombre y les habríamos confundido igual que se confundieron anteriormente.\qt@no{9}}
\qt@newcmd\qurantrans@es@dccxcix{Ciertamente, ya se burlaron de los Mensajeros anteriores a ti pero, quienes se burlaban de ellos fueron cercados por aquello de lo que se burlaban.\qt@no{10}}
\qt@newcmd\qurantrans@es@dccc{Di: «Viajad por la Tierra y observad cual fue el final de los desmentidores.»\qt@no{11}}
\qt@newcmd\qurantrans@es@dccci{Di: «¿A quién pertenece lo que hay en los cielos y en la Tierra?» Di: «A Dios. Él se ha impuesto a Sí mismo la misericordia. Os congregará hacia el Día del Levantamiento. De eso no hay duda.» Los que se han perdido a sí mismos, esos no son creyentes.\qt@no{12}}
\qt@newcmd\qurantrans@es@dcccii{A Él pertenece lo que tiene lugar en la noche y el día. Y Él todo lo oye, todo lo sabe.\qt@no{13}}
\qt@newcmd\qurantrans@es@dccciii{Di: «¿Tomaréis por amigo y protector a otro que a Dios, el Creador de los cielos y de la Tierra, siendo Él el que alimenta y no es alimentado?» Di: «Se me ordenó que fuese el primero en someterme y que no fuese de los que adoran a nadie junto a Él.»\qt@no{14}}
\qt@newcmd\qurantrans@es@dccciv{Di: «En verdad, temo el castigo de un día inmenso si desobedezco a mi Señor.»\qt@no{15}}
\qt@newcmd\qurantrans@es@dcccv{Él habrá tenido misericordia de quien ese día sea apartado de él. Ese es el éxito evidente.\qt@no{16}}
\qt@newcmd\qurantrans@es@dcccvi{Y si Dios te aflige con una desgracia, nadie excepto Él podrá evitarlo. Y si te favorece con un bien, Él tiene poder sobre todo.\qt@no{17}}
\qt@newcmd\qurantrans@es@dcccvii{Él es Quien tiene el dominio sobre sus siervos. Él es el Sabio, el Bien Informado.\qt@no{18}}
\qt@newcmd\qurantrans@es@dcccviii{Di: «¿Quién aporta el mayor testimonio?» Di: «Dios. Él es testigo entre yo y vosotros. Él me ha revelado este Corán para que, con él, os advierta a vosotros y a quien le llegue. ¿Daréis vosotros testimonio de que junto a Dios existen otros dioses?» Di: «Yo no atestiguaré.» Di: «En verdad, Él es un dios Único y, ciertamente, yo me aparto de lo que adoráis junto a Él.\qt@no{19}}
\qt@newcmd\qurantrans@es@dcccix{Aquellos a quienes Nosotros dimos la Escritura [Sagrada] le conocen como conocen a sus hijos. Quienes se han perdido a sí mismos, no son creyentes.\qt@no{20}}
\qt@newcmd\qurantrans@es@dcccx{¿Quién es más opresor que quien inventa una mentira sobre Dios o desmiente Sus señales? En verdad, los opresores no triunfarán.\qt@no{21}}
\qt@newcmd\qurantrans@es@dcccxi{Y el día que Nosotros les reunamos a todos, diremos a quienes adoraron a otros como sólo se debe adorar a Dios: «¿Dónde están aquellos a quienes adorabais y a quienes suplicabais?»\qt@no{22}}
\qt@newcmd\qurantrans@es@dcccxii{Su única excusa será decir: «Juramos por Dios, nuestro Señor, que no éramos politeístas.»\qt@no{23}}
\qt@newcmd\qurantrans@es@dcccxiii{¡Mira como mienten sobre ellos mismos y como les abandonan sus invenciones!\qt@no{24}}
\qt@newcmd\qurantrans@es@dcccxiv{Entre ellos, hay algunos que te escuchan, pero Nosotros hemos puesto sobre sus corazones un denso velo para que no comprendan y hemos endurecido sus oídos y, aunque vieran toda clase de señales [de la Verdad], no creerían en ella. Incluso, aunque vengan a discutir contigo, los que no creen dicen: «Esos no son más que mitos de los hombres primitivos.»\qt@no{25}}
\qt@newcmd\qurantrans@es@dcccxv{Apartan de él y ellos mismos se alejan. Así sólo se destruyen a sí mismos, pero no se dan cuenta.\qt@no{26}}
\qt@newcmd\qurantrans@es@dcccxvi{Si los pudieras ver, cuando, parados ante el Fuego, digan: «¡Ojalá se nos permitiera dar marcha atrás! No desmentiríamos las señales de nuestro Señor y seríamos de los creyentes.»\qt@no{27}}
\qt@newcmd\qurantrans@es@dcccxvii{Se les hará evidente lo que antes ocultaban. Pero si se les hiciera regresar repetirían lo que se les había prohibido. En verdad, son mentirosos.\qt@no{28}}
\qt@newcmd\qurantrans@es@dcccxviii{Dicen: «No existe más vida que la de este mundo y no seremos resucitados.»\qt@no{29}}
\qt@newcmd\qurantrans@es@dcccxix{Si les vieses cuando estén ante su Señor [el Día del Juicio Final]. Él dirá: «¿Acaso no es esto verdad?» Dirán: «Sí, lo juramos por nuestro Señor.» Él dirá: «Probad, pues, el castigo por haber ocultado la Verdad.»\qt@no{30}}
\qt@newcmd\qurantrans@es@dcccxx{Con certeza, habrán perdido quienes desmintieron el encuentro con Dios. Cuando les llegue la Hora súbitamente, dirán: «¡Ay de nosotros! ¡Qué descuidados fuimos!» Cargarán sus pecados sobre sus espaldas. ¿No es acaso una mala carga?\qt@no{31}}
\qt@newcmd\qurantrans@es@dcccxxi{La vida de este mundo no es sino juego y distracción. Pero, para quienes son temerosos, la morada de la otra vida es mejor. ¿Es que no razonáis?\qt@no{32}}
\qt@newcmd\qurantrans@es@dcccxxii{Nosotros sabemos que te entristece lo que dicen. Pero no es a ti a quien desmienten, sino las señales de Dios lo que los opresores repudian.\qt@no{33}}
\qt@newcmd\qurantrans@es@dcccxxiii{Ciertamente, antes de ti, otros Mensajeros fueron desmentidos, pero fueron pacientes con lo que se les desmentía y perseguía hasta que les llegó Nuestro auxilio. Nadie puede cambiar las palabras de Dios. Ya han llegado a ti algunas noticias de los Mensajeros.\qt@no{34}}
\qt@newcmd\qurantrans@es@dcccxxiv{Y si te resulta penoso que se aparten de ti, busca si puedes un túnel en la Tierra o una escalera para subir al cielo y traerles una señal. Si Dios quisiera, les habría reunido y guiado. Así que, no seas jamás de los ignorantes.\qt@no{35}}
\qt@newcmd\qurantrans@es@dcccxxv{Solamente aquellos que escuchan responderán [a tu llamada ¡Oh, Mensajero!] En cuanto a los muertos, Dios les resucitará y, entonces, se les hará regresar a Él.\qt@no{36}}
\qt@newcmd\qurantrans@es@dcccxxvi{Dicen: «¿Por qué no ha descendido a él ninguna señal milagrosa procedente de su Señor?» Di: «Dios tiene poder para enviar una señal.» Pero la mayoría de ellos no saben.\qt@no{37}}
\qt@newcmd\qurantrans@es@dcccxxvii{No existe animal en la Tierra ni ave que vuele con sus dos alas que no forme comunidades como las vuestras. No hemos omitido nada en la Escritura [Sagrada]. Luego, serán congregados hacia su Señor.\qt@no{38}}
\qt@newcmd\qurantrans@es@dcccxxviii{Pero quienes desmienten Nuestras señales están sordos y mudos en las tinieblas. Dios extravía a quien Él quiere y a quien Él quiere le pone en el camino recto.\qt@no{39}}
\qt@newcmd\qurantrans@es@dcccxxix{Di: «¡Decidme la verdad si sois sinceros! Si os alcanzase el castigo de Dios u os llegase la Hora ¿Invocaríais a otro que a Dios?\qt@no{40}}
\qt@newcmd\qurantrans@es@dcccxxx{¡No! Sino que sólo a Él invocaríais y Él, si quisiera, os concedería aquello que Le hubieseis pedido y olvidaría la idolatría que cometéis.»\qt@no{41}}
\qt@newcmd\qurantrans@es@dcccxxxi{Ciertamente, hemos enviado [profetas] a otras comunidades antes de ti e hicimos que soportasen dificultades y preocupaciones para que suplicasen con humildad.\qt@no{42}}
\qt@newcmd\qurantrans@es@dcccxxxii{Si hubiesen suplicado humildemente cuando les alcanzó Nuestro rigor... Pero se endurecieron sus corazones y Satanás les embelleció su comportamiento.\qt@no{43}}
\qt@newcmd\qurantrans@es@dcccxxxiii{Y, cuando olvidaron lo que se les había recordado, abrimos para ellos las puertas de todas las cosas, hasta que hubieron disfrutado de todo lo que les fue dado. Entonces, les tomamos por sorpresa y fueron presa de la desesperación.\qt@no{44}}
\qt@newcmd\qurantrans@es@dcccxxxiv{Así fue destruida hasta las raíces la comunidad de aquellos que eran opresores. ¡Alabado sea Dios, Señor de los mundos!\qt@no{45}}
\qt@newcmd\qurantrans@es@dcccxxxv{Di: «¿Qué pensaríais si Dios os arrebatase el oído y la vista y sellase vuestros corazones? ¿Qué otro dios sino Dios podría devolvéroslos?» Ved las diferentes maneras en que explicamos las señales, aunque ellos dan la espalda y se alejan.\qt@no{46}}
\qt@newcmd\qurantrans@es@dcccxxxvi{Di: «¿Qué pensaríais si os llegase el castigo de Dios por sorpresa o abiertamente? ¿Quién sería destruida sino la gente opresora?»\qt@no{47}}
\qt@newcmd\qurantrans@es@dcccxxxvii{No enviamos a los profetas sino como portadores de buenas nuevas y advertidores del castigo. Por tanto, quienes crean y corrijan sus malas acciones no tendrán que temer y no estarán tristes.\qt@no{48}}
\qt@newcmd\qurantrans@es@dcccxxxviii{Y quienes desmientan Nuestras señales sufrirán el castigo por haber transgredido.\qt@no{49}}
\qt@newcmd\qurantrans@es@dcccxxxix{Di: «Yo no os digo que posea los tesoros de Dios, ni conozco lo que está oculto a los sentidos, ni os digo que yo sea un ángel. Sólo sigo lo que me ha sido revelado.» Di: «¿Son iguales el ciego y el que ve? ¿Es que no razonáis?»\qt@no{50}}
\qt@newcmd\qurantrans@es@dcccxl{Y advierte con él a quienes teman ser congregados hacia su Señor que no tienen otro protector ni intercesor que Él, para que así sean temerosos.\qt@no{51}}
\qt@newcmd\qurantrans@es@dcccxli{Y no rechaces a quienes suplican a su Señor día y noche, deseando contemplar Su rostro. Tú no eres en absoluto responsable de sus cuentas ni ellos son responsables en absoluto de tu cuenta y si les rechazases serías de los opresores.\qt@no{52}}
\qt@newcmd\qurantrans@es@dcccxlii{Así es como examinamos a algunos de ellos mediante otros, para que digan: «¿Son estos a quienes Dios a favorecido de entre nosotros?» ¿Acaso no es Dios quien mejor conoce a quienes son agradecidos?\qt@no{53}}
\qt@newcmd\qurantrans@es@dcccxliii{Y cuando vengan a ti quienes creen en Nuestras señales di: «La paz sea con vosotros. Vuestro Señor ha dispuesto para Sí mismo la misericordia. Quien de vosotros obre mal por ignorancia y tras ello se arrepienta y corrija el mal cometido... Él es perdonador, misericordiosísimo con los creyentes.»\qt@no{54}}
\qt@newcmd\qurantrans@es@dcccxliv{Así explicamos las señales, para mostrar claramente el camino de los pecadores.\qt@no{55}}
\qt@newcmd\qurantrans@es@dcccxlv{Di: «Se me ha prohibido adorar a quien invocáis en lugar de a Dios.» Di: «No seguiré vuestras pasiones, pues me extraviaría y no sería de los guiados.»\qt@no{56}}
\qt@newcmd\qurantrans@es@dcccxlvi{Di: «En verdad, yo me baso en una prueba clara procedente de mi Señor y vosotros la desmentís. Yo no puedo otorgaros lo que pedís con tanta urgencia. El Juicio pertenece a Dios en exclusiva. Él dictamina la Verdad y Él es el mejor de los jueces.»\qt@no{57}}
\qt@newcmd\qurantrans@es@dcccxlvii{Di: «Si yo poseyera aquello con lo que me urgís, el asunto entre vosotros y yo habría ya quedado resuelto. Dios es Quien mejor conoce a los opresores.\qt@no{58}}
\qt@newcmd\qurantrans@es@dcccxlviii{Él posee las Llaves de lo Oculto que nadie conoce más que Él. Y Él conoce lo que hay en la tierra y en el mar. No cae ni una sola hoja de un árbol sin que Él lo sepa, ni existe una semilla en la oscuridad de la tierra, ni nada fresco o seco que no esté consignado en una Escritura clara.»\qt@no{59}}
\qt@newcmd\qurantrans@es@dcccxlix{«Él es Quien os recoge por la noche y Quien conoce lo que obtenéis durante el día, luego os da la vida durante él, para que se cumpla un plazo establecido. Luego regresaréis a Él. Luego Él os informará sobre lo que hacíais.»\qt@no{60}}
\qt@newcmd\qurantrans@es@dcccl{«Y Él es Quien posee el dominio completo sobre Sus siervos y Quien os envía protectores, hasta que, cuando a uno de vosotros le llega la muerte, Nuestros enviados toman su alma. Y ellos no son negligentes.»\qt@no{61}}
\qt@newcmd\qurantrans@es@dcccli{«Luego son devueltos a Dios, su verdadero amigo y protector. ¿Acaso el Juicio no pertenece a Él? Él es el más rápido en hacer la cuenta.»\qt@no{62}}
\qt@newcmd\qurantrans@es@dccclii{Di: «¿Quién os salva de las tinieblas de la tierra y el mar, cuando Le invocáis con humildad y temor: Si nos salva de ésta, seremos, ciertamente, de los agradecidos?»\qt@no{63}}
\qt@newcmd\qurantrans@es@dcccliii{Di: «Es Dios Quien os salva de ella y de toda dificultad. Tras ello, volvéis al politeísmo.»\qt@no{64}}
\qt@newcmd\qurantrans@es@dcccliv{Di: «Él es Quien tiene poder para enviaros un castigo de arriba o de abajo o para confundiros en facciones diferentes y hacer que probéis la violencia unos de otros.» Observa como exponemos Nuestras señales. Quizás así comprendan.\qt@no{65}}
\qt@newcmd\qurantrans@es@dccclv{Tu pueblo lo ha desmentido, a pesar de que es la Verdad. Di: «Yo no soy vuestro tutor.»\qt@no{66}}
\qt@newcmd\qurantrans@es@dccclvi{Cada profecía tiene su momento preestablecido y pronto sabréis.\qt@no{67}}
\qt@newcmd\qurantrans@es@dccclvii{Cuando veas a quienes se burlan de Nuestras señales aléjate de ellos hasta que se ocupen de otra cosa diferente y si Satanás te hace olvidar, cuando recuerdes no te sientes con la gente opresora.\qt@no{68}}
\qt@newcmd\qurantrans@es@dccclviii{Quienes son temerosos de Dios no son en absoluto responsables de las cuentas que ellos tengan que rendir, pero sí de llamarles al recuerdo de Dios. Quizás así se vuelvan temerosos.\qt@no{69}}
\qt@newcmd\qurantrans@es@dccclix{Abandona a quienes toman sus creencias a juego y distracción y han sido seducidos por la vida de este mundo. Y amonéstales con él. ¡Que cada alma se proteja de lo que obtendrá por sus malas acciones! Pues no tendrá, aparte de Dios, protector ni intercesor y no le será aceptada ningún tipo de compensación. Esos son quienes sufrirán las consecuencias de lo que obtuvieron con sus malas acciones. Les aguarda una bebida de agua hirviendo y un castigo doloroso por haber ocultado la Verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@dccclx{Di: «¿Acaso invocaremos, aparte de Dios, a quien no puede beneficiarnos ni perjudicarnos y daremos marcha atrás después de que Dios nos hubo guiado, como quien ha sido seducido por los demonios y va desorientado por la Tierra, aunque Sus compañeros le llaman al buen camino, diciéndole: Ven a nosotros.?» Di: «En verdad, la guía de Dios es la Guía y se nos ha ordenado que nos sometamos al Señor del Universo,\qt@no{71}}
\qt@newcmd\qurantrans@es@dccclxi{que hagamos la oración y que seamos temerosos de Él. Y Él es hacia Quien seréis congregados.»\qt@no{72}}
\qt@newcmd\qurantrans@es@dccclxii{Él es Quien ha creado los cielos y la Tierra con la Verdad. Y el día que Él dice: «Sé», y es. Su palabra es la Verdad. A Él pertenecerá la Soberanía el Día en que sea tañida la trompeta. Él es Quien conoce lo oculto y lo manifiesto. Él es el Sabio, el Bien Informado.\qt@no{73}}
\qt@newcmd\qurantrans@es@dccclxiii{Y [recuerda] cuando Abraham dijo a su padre Azar: «¿Tomas a los ídolos por divinidades? Verdaderamente, veo a ti y a tu pueblo en un extravío evidente.»\qt@no{74}}
\qt@newcmd\qurantrans@es@dccclxiv{Así mismo, mostramos a Abraham el gobierno de los cielos y de la Tierra para que fuese de los que tienen certeza.\qt@no{75}}
\qt@newcmd\qurantrans@es@dccclxv{Cuando le envolvió la noche, vio una estrella. Dijo: «¡Éste es mi Señor!». Pero cuando se ocultó, dijo: «¡No quiero lo que desaparece!»\qt@no{76}}
\qt@newcmd\qurantrans@es@dccclxvi{Entonces, al ver la Luna naciente, dijo: «¡Éste es mi Señor!», pero cuando se ocultó, dijo: «¡Si mi Señor no me guía, sin duda seré de la gente extraviada!»\qt@no{77}}
\qt@newcmd\qurantrans@es@dccclxvii{Cuando vio el Sol naciente, dijo: «¡Éste es mi Señor! ¡Éste es el mayor!» Pero cuando se ocultó, dijo: «¡Oh, pueblo mío! ¡Soy inocente de aquello que adoráis junto a Dios!\qt@no{78}}
\qt@newcmd\qurantrans@es@dccclxviii{En verdad, he vuelto mi rostro hacia Quien ha creado los cielos y la Tierra, como un buscador de la Verdad, pues no soy de los politeístas.»\qt@no{79}}
\qt@newcmd\qurantrans@es@dccclxix{Su pueblo discutió con él. Dijo: «¿Discutís conmigo sobre Dios cuando Él me ha guiado? Yo no temo aquello que vosotros adoráis junto a Él, excepto aquello que mi Señor quiera. Mi Señor, con Su conocimiento, abarca todas las cosas. ¿Es que no recapacitaréis?\qt@no{80}}
\qt@newcmd\qurantrans@es@dccclxx{¿Cómo puedo temer a los dioses que adoráis y vosotros no temer adorar a otras cosas como dioses junto a Dios, algo para lo que Él no os ha concedido permiso alguno? ¿Quién de las dos partes tiene más derecho a sentirse seguro? [Responded] si es que sabéis.»\qt@no{81}}
\qt@newcmd\qurantrans@es@dccclxxi{Quienes creen y no mezclan su fe con opresión, disfrutarán de seguridad y serán bien guiados.\qt@no{82}}
\qt@newcmd\qurantrans@es@dccclxxii{Estos son los argumentos que Nosotros dimos a Abraham frente a su pueblo. Nosotros elevamos el rango de quien queremos. En verdad, tu Señor es Sabio, conocedor de todo.\qt@no{83}}
\qt@newcmd\qurantrans@es@dccclxxiii{Y le otorgamos a Isaac y a Jacob y les guiamos como antes habíamos guiado a Noé. Y de él descienden David y Salomón, Job, José, Moisés y Aarón. Así es como recompensamos a los que hacen el bien.\qt@no{84}}
\qt@newcmd\qurantrans@es@dccclxxiv{Y [también] Zacarías, Juan, Jesús y Elías. Todos ellos eran de los justos.\qt@no{85}}
\qt@newcmd\qurantrans@es@dccclxxv{E Ismael, Eliseo, Jonás y Lot. A todos ellos les distinguimos por encima de los demás seres del Universo,\qt@no{86}}
\qt@newcmd\qurantrans@es@dccclxxvi{así como a algunos de sus antepasados y descendientes y hermanos. Les escogimos y les guiamos al camino recto.\qt@no{87}}
\qt@newcmd\qurantrans@es@dccclxxvii{Esta es la guía de Dios, con la que guía a quien Él quiere de Sus siervos. Pero, si hubiesen sido politeístas, todo lo que hubiesen hecho no habría valido de nada.\qt@no{88}}
\qt@newcmd\qurantrans@es@dccclxxviii{Es a ellos a quienes Nosotros dimos la Escritura [Sagrada], la Sabiduría y la Profecía. Pero si descreen de ella, Nosotros se la hemos encomendado a una gente que jamás dejará de creer en ella.\qt@no{89}}
\qt@newcmd\qurantrans@es@dccclxxix{Esos son a quienes Dios ha guiado. Así pues, ¡Sigue su guía! Di: «No os pido una recompensa a cambio. No es más que un recuerdo para todos los seres del Universo.»\qt@no{90}}
\qt@newcmd\qurantrans@es@dccclxxx{Y no valoran a Dios como Él debe ser valorado, cuando dicen: «Dios no ha hecho que descienda revelación alguna sobre ningún ser humano.» Di: «¿Entonces, quién hizo descender la Escritura que trajo Moisés como luz y guía para las gentes, que ponéis [por escrito] en pergaminos que mostráis, aunque ocultáis mucho de ella, y [mediante la cual] se os ha enseñado lo que ni vosotros ni vuestros padres sabíais?» Di: «Dios.» Luego, déjales que, en su obstinación, lo tomen a juego.\qt@no{91}}
\qt@newcmd\qurantrans@es@dccclxxxi{Ésta es una Escritura bendita que Nosotros hemos hecho descender confirmando lo que ellos tienen en sus manos, para que adviertas a la Madre de las Ciudades y a quienes viven en sus alrededores. Y, quienes creen en la otra vida, creen en ella y son cuidadosos de sus oraciones.\qt@no{92}}
\qt@newcmd\qurantrans@es@dccclxxxii{Y ¿Quién es más opresor que quien inventa mentiras sobre Dios o dice: «He recibido una revelación» cuando no le ha sido revelado nada, o quien dice: «Haré que descienda algo como lo que Dios hace descender?» Si vieras a los opresores en las dificultades de la muerte, cuando los ángeles con las manos extendidas hacia ellos [les digan]: «¡Entregad vuestras almas! Hoy seréis recompensados con el castigo humillante que merecéis por lo que dijisteis sobre Dios sin ser cierto y por haberos ensoberbecido ante Sus señales.»\qt@no{93}}
\qt@newcmd\qurantrans@es@dccclxxxiii{«Ciertamente, habéis venido a Nosotros solos, igual que os creamos la primera vez, dejando a vuestras espaldas lo que os habíamos concedido y no vemos junto a vosotros a vuestros intercesores, aquellos de quienes proclamabais que participaban en la decisión de vuestro destino. Se ha cortado la relación entre vosotros y lo que proclamabais os ha extraviado.»\qt@no{94}}
\qt@newcmd\qurantrans@es@dccclxxxiv{En verdad, Dios es Quien hace germinar la semilla y el hueso de los frutos. Hace salir lo vivo de lo muerto y lo muerto de lo vivo. Ese es Dios. ¿Cómo podéis, pues, desviaros [de la Verdad]?\qt@no{95}}
\qt@newcmd\qurantrans@es@dccclxxxv{Él hace despuntar la mañana y puso la noche para el reposo y el Sol y la Luna para llevar la cuenta. Éste es el decreto del Poderoso, el Conocedor.\qt@no{96}}
\qt@newcmd\qurantrans@es@dccclxxxvi{Y es Él Quien os puso las estrellas para que os guiéis por ellas en medio de la oscuridad de la tierra y del mar. Hemos expuesto nuestras señales para una gente que sabe.\qt@no{97}}
\qt@newcmd\qurantrans@es@dccclxxxvii{Y Él es Quien os ha creado de una sola alma, unos constantes en su fe y otros inconstantes. Hemos expuesto las señales para una gente que reflexiona.\qt@no{98}}
\qt@newcmd\qurantrans@es@dccclxxxviii{Y Él es Quien hace descender agua del cielo. Mediante ella hacemos surgir toda clase de plantas, de las que hacemos salir vegetales y de ellos semillas de granos superpuestos. Y de la palmera, cuando brota, racimos apretados [de dátiles] y jardines de viñas, olivos y granados, similares y diferentes. ¡Mirad sus frutos cuando fructifican y maduran! En verdad, en todo ello hay señales para una gente que tiene fe.\qt@no{99}}
\qt@newcmd\qurantrans@es@dccclxxxix{Y ellos ponen junto a Dios a los genios como socios Suyos, cuando Él los ha creado y, sin conocimiento, Le atribuyen hijos e hijas. ¡Glorificado y ensalzado sea Él por encima de cuanto Le atribuyen!\qt@no{100}}
\qt@newcmd\qurantrans@es@dcccxc{Él es el Originador de los cielos y la Tierra ¿Cómo podría Él tener un hijo cuando no tiene esposa? Él ha creado todas las cosas y Él conoce todas las cosas.\qt@no{101}}
\qt@newcmd\qurantrans@es@dcccxci{Este es Dios, vuestro Señor. No hay más dios que Él, el Creador de todo. Así pues, ¡Adoradle! Él es Quien cuida de todo.\qt@no{102}}
\qt@newcmd\qurantrans@es@dcccxcii{La vista no puede percibirle, pero Él percibe toda visión. Él es el Sutil, el Bien Informado.\qt@no{103}}
\qt@newcmd\qurantrans@es@dcccxciii{Han venido a vosotros visiones claras de vuestro Señor, así pues, quien vea claro lo hará en beneficio de su propia alma y quien se ciegue se perjudicará a sí mismo. Yo no soy vuestro cuidador.\qt@no{104}}
\qt@newcmd\qurantrans@es@dcccxciv{Así mostramos las señales de diferentes maneras, aunque ellos digan: «¡Tú lo has estudiado!», para dejárselo claro a una gente que tiene conocimiento.\qt@no{105}}
\qt@newcmd\qurantrans@es@dcccxcv{¡Sigue lo que te fue revelado procedente de tu Señor! No hay más dios que Él. Y apártate de los politeístas.\qt@no{106}}
\qt@newcmd\qurantrans@es@dcccxcvi{Si Dios quisiera no adorarían a otros dioses, pero no te pusimos como responsable de sus actos, ni eres su abogado defensor.\qt@no{107}}
\qt@newcmd\qurantrans@es@dcccxcvii{Y no insultes a quienes ellos invocan en lugar de Dios, para que ellos no insulten a Dios, reaccionando con hostilidad y sin conocimiento. De esta misma manera hemos embellecido a cada comunidad su proceder. Luego regresarán hacia su Señor y Él les informará de lo que en realidad hacían.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcccxcviii{Juran por Dios con solemnes juramentos que si llegase a ellos una señal, creerían sin duda en ella. Di: «En verdad, las señales pertenecen solamente a Dios.» Pero ¿No os dais cuenta de que si les llegasen no creerían?\qt@no{109}}
\qt@newcmd\qurantrans@es@dcccxcix{Cambiaremos el estado de sus corazones y su visión de la misma forma que no creyeron en ella la primera vez y les dejaremos que, en su rebeldía, vaguen extraviados.\qt@no{110}}
\qt@newcmd\qurantrans@es@cm{Aunque Nosotros hubiésemos hecho que descendieran sobre ellos los ángeles y que les hablasen los muertos y les hubiésemos mostrado todas las cosas, no habrían creído, excepto si Dios hubiese querido, pero la mayoría de ellos son ignorantes.\qt@no{111}}
\qt@newcmd\qurantrans@es@cmi{Así es como dispusimos para cada profeta enemigos, demonios de entre los hombres y los genios, que se susurran unos a otros palabras encantadoras y engañosas. Y, si tu Señor hubiese querido, no lo habrían hecho, así que apártate de ellos y de lo que inventan,\qt@no{112}}
\qt@newcmd\qurantrans@es@cmii{para que se inclinen hacia ello los corazones de quienes no creen en la otra vida y para que se complazcan en ello y cometan los pecados que deseen cometer.\qt@no{113}}
\qt@newcmd\qurantrans@es@cmiii{[Di:] «¿Buscaré a otro juez que no sea Dios, cuando es Él Quien ha hecho descender la Escritura que contiene la explicación de todas las cosas?» Aquellos a quienes Nosotros dimos la Escritura saben que ella fue revelada por tu Señor con la Verdad, por tanto, no seas de los que dudan.\qt@no{114}}
\qt@newcmd\qurantrans@es@cmiv{La palabra de tu Señor es de una veracidad y justicia absolutas. Nada puede cambiar Sus palabras y Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{115}}
\qt@newcmd\qurantrans@es@cmv{Si obedecieses a la mayoría de los que habitan la Tierra te extraviarían de la senda de Dios. Sólo siguen suposiciones, no hacen sino especular.\qt@no{116}}
\qt@newcmd\qurantrans@es@cmvi{En verdad, tu Señor es Quien mejor conoce a quien se extravía de Su senda y es Quien mejor conoce a los bien guiados.\qt@no{117}}
\qt@newcmd\qurantrans@es@cmvii{Comed de las cosas sobre las que fue pronunciado el nombre de Dios si es que creéis en Sus signos.\qt@no{118}}
\qt@newcmd\qurantrans@es@cmviii{Ya no tenéis motivo para no comer de aquello sobre lo que ha sido mencionado el nombre de Dios, excepto si os vieseis obligados a ello, pues se os ha explicado claramente lo que os ha sido prohibido. Verdaderamente, muchos, siguiendo sus pasiones y su falta de conocimiento, extravían a otros. En verdad, tu Señor es Quien mejor conoce a los transgresores.\qt@no{119}}
\qt@newcmd\qurantrans@es@cmix{Renunciad a vuestros pecados ocultos o manifiestos. En verdad, quienes cometen pecados serán recompensados conforme a lo que cometían.\qt@no{120}}
\qt@newcmd\qurantrans@es@cmx{Y no comáis de aquello sobre lo que no ha sido mencionado el nombre de Dios. Eso sería un pecado. En verdad, los demonios susurran a sus amigos argumentos para que discutan con vosotros y, si les obedecieseis, seríais politeístas.\qt@no{121}}
\qt@newcmd\qurantrans@es@cmxi{¿Acaso quien estaba muerto y Nosotros le dimos la vida y pusimos para él una luz con la que caminar entre la gente, es igual que quien está en las tinieblas, sin poder salir de ellas? Así es como hacemos que a los incrédulos les parezca bien lo que hacen.\qt@no{122}}
\qt@newcmd\qurantrans@es@cmxii{Y así es como hemos puesto en cada ciudad a los mayores pecadores para que hagan sus planes. Pero sólo planean contra sí mismos, sin darse cuenta.\qt@no{123}}
\qt@newcmd\qurantrans@es@cmxiii{Y cuando llega a ellos una señal, dicen: «No creeremos hasta que se nos dé algo como lo que les fue dado a los Mensajeros de Dios.» Pero Dios sabe mejor a quién otorga Su mensaje. Quienes pecaron sufrirán pronto la humillación ante Dios y un severo castigo por lo que planeaban.\qt@no{124}}
\qt@newcmd\qurantrans@es@cmxiv{Dios ensancha el pecho de aquel a quien Él quiere guiar para que acepte el Islam, pero hace que el pecho de quien Él quiere extraviar se oprima y estreche como si ascendiera al cielo. Así es como Dios debilita a quienes no creen.\qt@no{125}}
\qt@newcmd\qurantrans@es@cmxv{Este es el camino recto de tu Señor. Hemos explicado Nuestras señales para una gente que se deja amonestar.\qt@no{126}}
\qt@newcmd\qurantrans@es@cmxvi{Para ellos será la Morada de la Paz junto a su Señor y Él será su protector y amigo por lo que hacían.\qt@no{127}}
\qt@newcmd\qurantrans@es@cmxvii{Y el día en que Él les congregue a todos [les dirá]: «¡Oh, comunidad de genios! ¡Extraviasteis a muchos humanos!» Y sus amigos entre los humanos dirán: «¡Señor nuestro! ¡Nos hemos aprovechado unos de otros y se ha cumplido el plazo que Tú nos diste!» [Dios] Dirá: «El Fuego será vuestra morada. En él estaréis eternamente, excepto que Dios quiera otra cosa.» En verdad, tu Señor es Sabio, Conocedor.\qt@no{128}}
\qt@newcmd\qurantrans@es@cmxviii{Así es como ponemos a unos opresores sobre otros, por lo que obtuvieron con sus actos.\qt@no{129}}
\qt@newcmd\qurantrans@es@cmxix{«¡Oh, comunidad de genios y de humanos! ¿Acaso no os llegaron Mensajeros surgidos de entre vosotros que os comunicaron Mis versículos y os advirtieron de la llegada de este Día para vosotros?» Dirán: «¡Damos testimonio de ello contra nosotros mismos!» Les sedujo la vida de este mundo y darán testimonio contra ellos mismos de que ocultaron la Verdad y no creyeron en ella.\qt@no{130}}
\qt@newcmd\qurantrans@es@cmxx{Esto es porque tu Señor nunca destruiría las ciudades injustamente, sin haber advertido a sus gentes.\qt@no{131}}
\qt@newcmd\qurantrans@es@cmxxi{Todos tendrán el rango adecuado a lo que hayan hecho. Y tu Señor no está desatento a lo que hacen.\qt@no{132}}
\qt@newcmd\qurantrans@es@cmxxii{Tu Señor es rico por Sí mismo, Dueño de la misericordia. Si quisiera os haría desaparecer y pondría en vuestro lugar a quien Él quisiera, de la misma manera que os hizo surgir a vosotros de los descendientes de otras gentes.\qt@no{133}}
\qt@newcmd\qurantrans@es@cmxxiii{En verdad, aquello que se os ha prometido llegará y no podréis impedirlo.\qt@no{134}}
\qt@newcmd\qurantrans@es@cmxxiv{Di: «¡Oh, pueblo mío! Obrad conforme a vuestra capacidad que yo también actuaré [conforme a mi obligación] y pronto sabréis quien tendrá un buen final. En verdad, los opresores no triunfarán.»\qt@no{135}}
\qt@newcmd\qurantrans@es@cmxxv{Y [los idólatras] disponen para Dios, de lo que Él ha creado, una parte de las cosechas y del ganado y dicen, conforme a sus creencias: «Esto es para Dios y esto es para nuestros socios.» Pero lo que es para sus socios no llega a Dios mientras que lo que es para Dios sí llega a sus socios. ¡Qué mal juzgan!\qt@no{136}}
\qt@newcmd\qurantrans@es@cmxxvi{Así es como sus socios han hecho que a la mayoría de los idólatras les parezca bien matar a sus propios hijos, para así destruirles y deformar sus creencias religiosas. Pero, si Dios hubiese querido, no lo habrían hecho. Así pues, apártate de ellos y de lo que ellos inventan.\qt@no{137}}
\qt@newcmd\qurantrans@es@cmxxvii{Y dicen, conforme a sus creencias: «Este ganado y estas cosechas son sagrados y sólo podrán alimentarse de ellos quienes nosotros queramos.» Y [dicen:] «Hay ganado cuya espalda está prohibida». Y hay ganado sobre el que no mencionan el nombre de Dios, inventando mentiras sobre Él. Pronto Él les recompensará por las mentiras que inventaron.\qt@no{138}}
\qt@newcmd\qurantrans@es@cmxxviii{Y dicen: «Lo que hay en las entrañas de este ganado está reservado para nuestros varones y prohibido para nuestras esposas, pero si estuviera muerto [al nacer] todos tienen parte en ello.» Él pronto les retribuirá por lo que atribuyen. En verdad, Él es sabio, conocedor.\qt@no{139}}
\qt@newcmd\qurantrans@es@cmxxix{Habrán fracasado quienes maten a sus hijos estúpidamente y sin conocimiento y quienes prohíban lo que Dios les ha suministrado, inventando mentiras que atribuyen a Dios. Con certeza, se habrán extraviado y jamás encontrarán guía.\qt@no{140}}
\qt@newcmd\qurantrans@es@cmxxx{Él es Quien ha producido jardines con árboles entrelazados y sin entrelazar, palmeras y cereales variados y comestibles, olivos y granados semejantes y diferentes. ¡Comed de su fruto cuando fructifiquen y el día de la cosecha entregad la parte que corresponda! Y no malgastéis. En verdad, Él no ama a los derrochadores.\qt@no{141}}
\qt@newcmd\qurantrans@es@cmxxxi{Y Él es Quien ha producido algunas bestias grandes para la carga y otras pequeñas. ¡Comed de lo que Dios os ha proveído y no sigáis las huellas de Satanás! Ciertamente, él es para vosotros un enemigo evidente.\qt@no{142}}
\qt@newcmd\qurantrans@es@cmxxxii{[Él ha creado para vosotros] ocho pares [de reses]. Una pareja de ganado ovino y otra de caprino. Di: «¿Ha prohibido Él [comer] los dos machos o las dos hembras, o lo que llevan en sus senos las hembras? Informadme con conocimiento, si decís la verdad.»\qt@no{143}}
\qt@newcmd\qurantrans@es@cmxxxiii{Y una pareja de camélidos y otra de ganado bovino. Di: «¿Ha prohibido Él [comer] los dos machos o las dos hembras, o lo que llevan en sus senos las hembras? ¿O fuisteis testigos cuando Dios dispuso esto?» ¿Quién es más opresor que quien inventa mentiras sobre Dios, para extraviar a la gente, sin poseer conocimiento? En verdad, Dios no guía a la gente opresora.»\qt@no{144}}
\qt@newcmd\qurantrans@es@cmxxxiv{Di: «No encuentro en lo que me fue revelado que se prohíba a nadie comer ningún alimento, excepto carroña o sangre derramada o carne de cerdo, pues es, en verdad, impura; o aquello sobre lo que, con pecado, se haya pronunciado al sacrificarlo otro nombre distinto al de Dios. Pero quien se vea obligado y no lo haga por deseo o por rebeldía [no peca]. En verdad, tu Señor es perdonador, misericordiosísimo con los creyentes.\qt@no{145}}
\qt@newcmd\qurantrans@es@cmxxxv{Y a los judíos les prohibimos todo lo que tiene la pezuña entera y del ganado bovino, ovino y caprino les prohibimos la grasa, excepto la que tengan en los lomos, la que rodea las vísceras o la que va unida a los huesos. Así les retribuimos por ser opresores y, ciertamente, Nosotros decimos la Verdad.\qt@no{146}}
\qt@newcmd\qurantrans@es@cmxxxvi{Y si te desmienten, di: «Vuestro Señor es dueño de una amplia misericordia pero no apartará Su castigo de la gente pecadora.»\qt@no{147}}
\qt@newcmd\qurantrans@es@cmxxxvii{Los politeístas dirán: «Si Dios hubiera querido no habríamos sido idólatras ni tampoco nuestros antepasados, ni habríamos prohibido nada.» Así mismo mintieron los que vinieron antes de ellos, hasta que probaron Nuestro castigo. Di: «¿Os ha sido revelado algún conocimiento? Si es así, ¡Mostrádnoslo! No seguís más que especulaciones y no sois sino fabricantes de mentiras.»\qt@no{148}}
\qt@newcmd\qurantrans@es@cmxxxviii{Di: «A Dios pertenece el argumento definitivo y si Él hubiese querido os habría guiado a todos.»\qt@no{149}}
\qt@newcmd\qurantrans@es@cmxxxix{Di: «Traed a vuestros testigos, que den testimonio de que Dios a prohibido esto.» Y, si testifican, tú no testifiques con ellos, ni sigas los deseos de quienes deniegan Nuestras señales y de quienes no creen en la otra vida y equiparan a otros con su Señor.\qt@no{150}}
\qt@newcmd\qurantrans@es@cmxl{Di: «Venid, yo os diré lo que vuestro Señor os ha prohibido: Que no consideréis Dios a nadie más que a Él y que seáis buenos con vuestros padres. Que no matéis a vuestros hijos por miedo a la pobreza, pues Nosotros os proveeremos a vosotros y a ellos. Que no os aproximéis a lo pecaminoso e indecente, sea manifiesto o privado y que no matéis a nadie que Dios haya prohibido matar, excepto con causa justificada. Esto es lo que Él ha dispuesto para vosotros. Quizás así razonéis.»\qt@no{151}}
\qt@newcmd\qurantrans@es@cmxli{«Y no os aproximéis a las propiedades de los huérfanos, excepto de la mejor manera posible, hasta que ellos lleguen a la edad adulta. Sed justos al dar la medida y el peso.» No obligamos a nadie más allá de su capacidad. «Cuando habléis sed verídicos, incluso aunque perjudique a un familiar. Cumplid con el pacto hecho con Dios. Esto es lo que Él ha dispuesto para vosotros. Quizás así os dejéis amonestar.»\qt@no{152}}
\qt@newcmd\qurantrans@es@cmxlii{Éste es mi camino recto. ¡Seguidlo, pues! Y no sigáis los caminos que os apartarían de Su camino. «Esto es lo que Él ha dispuesto para vosotros. Quizás así seáis temerosos.»\qt@no{153}}
\qt@newcmd\qurantrans@es@cmxliii{Luego, dimos a Moisés la Escritura [Sagrada], completando Nuestras bendiciones sobre él, por ser virtuoso, como una explicación detallada de todo y guía y misericordia, para que, así, crean en el encuentro con su Señor.\qt@no{154}}
\qt@newcmd\qurantrans@es@cmxliv{Esta es una Escritura bendecida que Nosotros hemos hecho descender (para ti). ¡Seguidla, pues y sed temerosos, para que podáis recibir Su misericordia!\qt@no{155}}
\qt@newcmd\qurantrans@es@cmxlv{y para que no podáis decir: «En verdad, la Escritura fue hecha descender para dos comunidades anteriores a nosotros e ignorábamos sus enseñanzas.»\qt@no{156}}
\qt@newcmd\qurantrans@es@cmxlvi{O para que no podáis decir: «Si se hubiese hecho descender para nosotros la Escritura [Sagrada] habríamos seguido la guía mejor que ellos.» Así pues, ha venido a vosotros una prueba clara procedente de vuestro Señor y una guía y una misericordia. ¿Quién es más opresor que quien desmiente las señales de Dios y se aparta de ellas? Pronto retribuiremos a quienes se apartan de Nuestras señales con un terrible castigo por haberse apartado.\qt@no{157}}
\qt@newcmd\qurantrans@es@cmxlvii{¿Acaso esperan algo diferente a que vengan a ellos los ángeles de la muerte o que venga a ellos tu Señor o que vengan algunas de las señales de tu Señor? El día en que vengan algunas señales de tu Señor, la fe no beneficiará a nadie que no haya creído anteriormente o que no haya obtenido algo bueno gracias a su fe. Di: «¡Esperad! ¡Nosotros también seremos de los que esperan!»\qt@no{158}}
\qt@newcmd\qurantrans@es@cmxlviii{En verdad, tú no tienes nada que ver con quienes se escindieron en su creencia y se dividieron en partidos diferentes. Su asunto incumbe solamente a Dios. Él les informará de lo que hacían.\qt@no{159}}
\qt@newcmd\qurantrans@es@cmxlix{Quien traiga una buena acción recibirá diez veces más y quien traiga una mala acción sólo recibirá un castigo equivalente y no serán tratados injustamente.\qt@no{160}}
\qt@newcmd\qurantrans@es@cml{Di: «En verdad, mi Señor me ha guiado a un camino recto, a una creencia auténtica, la creencia de Abraham, el buscador de la Verdad. No fue de los que adoran otros dioses junto a Dios.»\qt@no{161}}
\qt@newcmd\qurantrans@es@cmli{Di: «En verdad, mi oración y toda mi adoración, mi vida y mi muerte, pertenecen a Dios, Señor del Universo.\qt@no{162}}
\qt@newcmd\qurantrans@es@cmlii{Él no tiene socio. Se me ha ordenado estoy soy el primero de los que se someten.»\qt@no{163}}
\qt@newcmd\qurantrans@es@cmliii{Di: «¿Buscaré a otro señor que no sea Dios, cuando Él es el Señor de todas las cosas?» Ningún alma hace nada malo sino contra ella misma y nadie cargará con la carga de otro. Luego, regresaréis hacia vuestro Señor y Él os informará de aquello sobre lo que solíais tener diferencias.\qt@no{164}}
\qt@newcmd\qurantrans@es@cmliv{Él es Quien ha hecho de vosotros Sus representantes en la Tierra y ha elevado la dignidad de unos sobre otros, para poneros a prueba en lo que os ha dado. En verdad, tu Señor es rápido en el castigo, pero también es perdonador, misericordiosísimo con los creyentes.\qt@no{165}}
\qt@newcmd\qurantrans@es@cmlv{\basmalahes Alif, lam, mim, sad.\qt@no{1}}
\qt@newcmd\qurantrans@es@cmlvi{Esta es la Escritura que se hizo descender a ti para que amonestes con ella y sea un recuerdo para los creyentes. Por tanto, que no haya preocupación en tu pecho por causa de ella.\qt@no{2}}
\qt@newcmd\qurantrans@es@cmlvii{¡Seguid, pues o que se hizo descender para vosotros procedente de vuestro Señor y no sigáis, aparte de Él, a ningún otro amigo y protector! ¡Qué poco recapacitáis!\qt@no{3}}
\qt@newcmd\qurantrans@es@cmlviii{¡Cuántas ciudades hemos destruido! ¡Nuestro castigo llegó a ellas en la noche o mientras dormían la siesta!\qt@no{4}}
\qt@newcmd\qurantrans@es@cmlix{Y cuando les llegó Nuestro castigo su súplica fue solamente decir: «En verdad, fuimos opresores.»\qt@no{5}}
\qt@newcmd\qurantrans@es@cmlx{Sin duda, interrogaremos a quienes les fueron enviados profetas y, sin duda, interrogaremos a los profetas mismos.\qt@no{6}}
\qt@newcmd\qurantrans@es@cmlxi{Luego, ciertamente, les explicaremos, con conocimiento, lo que hacían, pues no estábamos ausentes.\qt@no{7}}
\qt@newcmd\qurantrans@es@cmlxii{Ese día, la balanza será la Verdad. Aquellos cuyos actos hayan sido de peso serán los triunfadores\qt@no{8}}
\qt@newcmd\qurantrans@es@cmlxiii{y, aquellos cuyos actos hayan sido ligeros serán quienes se habrán perdido a sí mismos por haber sido injustos con Nuestras señales.\qt@no{9}}
\qt@newcmd\qurantrans@es@cmlxiv{Ciertamente, os dimos poder en la Tierra y pusimos en ella medios de vida para vosotros. ¡Qué poco agradecidos sois!\qt@no{10}}
\qt@newcmd\qurantrans@es@cmlxv{Ciertamente, os hemos creado, luego os hemos dado forma [física], luego dijimos a los ángeles: «¡Postraos ante Adán!» Y todos ellos se postraron excepto Iblís, que no fue de los que se postraron.\qt@no{11}}
\qt@newcmd\qurantrans@es@cmlxvi{Dijo (Dios): «¿Qué te impidió postrarte cuando te lo ordené?» Dijo (Iblís): «Yo soy mejor que él. Me has creado de fuego y a él le has creado de barro.»\qt@no{12}}
\qt@newcmd\qurantrans@es@cmlxvii{Dijo (Dios): «¡Desciende de ella! En ella no se puede uno llenar de soberbia, por lo tanto ¡Sal! ¡Eres de los seres de poca categoría espiritual!»\qt@no{13}}
\qt@newcmd\qurantrans@es@cmlxviii{Dijo (Iblís): «Otórgame de plazo hasta el día en que ellos sean resucitados.»\qt@no{14}}
\qt@newcmd\qurantrans@es@cmlxix{Dijo (Dios): «¡En verdad, tendrás tu plazo de espera!»\qt@no{15}}
\qt@newcmd\qurantrans@es@cmlxx{Dijo (Iblís): «Por haberme Tú extraviado, yo les induciré a apartarse de Tu camino recto.\qt@no{16}}
\qt@newcmd\qurantrans@es@cmlxxi{Llegaré a ellos por delante y por detrás, por su derecha y por su izquierda y encontrarás que la mayoría de ellos no son agradecidos.»\qt@no{17}}
\qt@newcmd\qurantrans@es@cmlxxii{Dijo (Dios): «¡Sal de aquí, deshonrado, desterrado! ¡Con quien te siga de ellos (y contigo), con todos vosotros, llenaré el Infierno!»\qt@no{18}}
\qt@newcmd\qurantrans@es@cmlxxiii{Y «¡Oh, Adán! Tú y tu pareja vivid en el Jardín y comed de lo que queráis, pero no os acerquéis a este árbol, pues seríais de los opresores.»\qt@no{19}}
\qt@newcmd\qurantrans@es@cmlxxiv{Entonces, Satanás les susurró a ambos para mostrarles su desnudez ignorada, diciéndoles: «Vuestro Señor os ha prohibido este árbol para que no lleguéis a ser ángeles o para que no viváis eternamente.»\qt@no{20}}
\qt@newcmd\qurantrans@es@cmlxxv{Y les juró a ambos: «En verdad, soy para vosotros dos un buen consejero.»\qt@no{21}}
\qt@newcmd\qurantrans@es@cmlxxvi{Con mentiras les hizo caer y cuando probaron del árbol se les evidenció a ambos su desnudez y comenzaron a cubrirse mutuamente con hojas del Jardín. Pero su Señor les llamó: «¿No os prohibí ese árbol y os dije que Satanás era para vosotros un enemigo declarado?»\qt@no{22}}
\qt@newcmd\qurantrans@es@cmlxxvii{Ambos dijeron: «¡Señor nuestro! Hemos oprimido a nuestra propia alma y si Tú no nos perdonas y tienes clemencia de nosotros, seremos sin duda de los perdedores.»\qt@no{23}}
\qt@newcmd\qurantrans@es@cmlxxviii{Dijo (Dios): «¡Descended! Seréis enemigos los unos de los otros. La Tierra será durante un tiempo vuestro lugar de estancia y de sustento.»\qt@no{24}}
\qt@newcmd\qurantrans@es@cmlxxix{Dijo: «En ella viviréis y en ella moriréis y de ella seréis sacados.»\qt@no{25}}
\qt@newcmd\qurantrans@es@cmlxxx{¡Oh, hijos de Adán! Ciertamente, hemos creado para vosotros vestidos con los que cubrir vuestra desnudez y como adorno, pero la mejor vestidura es el temor de Dios. Esta es una de las señales de Dios. Quizás así sean agradecidos.\qt@no{26}}
\qt@newcmd\qurantrans@es@cmlxxxi{¡Oh, hijos de Adán! ¡No permitáis que Satanás os engañe, igual que hizo salir a vuestros padres del Paraíso, despojándoles de sus vestiduras para que ambos vieran su propia desnudez! En verdad, él y los suyos os ven desde donde vosotros no les veis. En verdad, Nosotros pusimos a los demonios como tutores de aquellos que no tienen fe.\qt@no{27}}
\qt@newcmd\qurantrans@es@cmlxxxii{Y cuando cometen una indecencia, dicen: «Nuestros antepasados hacían lo mismo. Dios nos ordenó hacerlo» Di: «¡Dios jamás ordena cometer indecencias! ¿Atribuís a Dios lo que no sabéis?»\qt@no{28}}
\qt@newcmd\qurantrans@es@cmlxxxiii{Di: «Mi Señor ha ordenado la justicia y la equidad. Poned toda la atención de vuestro corazón en Él en todos vuestros actos de adoración e invocadle y que vuestra creencia sincera sea para Él.» Y sabed que, igual que Él os creó la primera vez, regresaréis.\qt@no{29}}
\qt@newcmd\qurantrans@es@cmlxxxiv{Un grupo al que Él ha guiado y otro grupo que merecían el extravío. En verdad, ellos tomaron a los demonios como protectores, en lugar de a Dios, y creen que así están bien guiados.\qt@no{30}}
\qt@newcmd\qurantrans@es@cmlxxxv{¡Oh, hijos de Adán! Poneos vuestros adornos cada vez que recéis, y comed y bebed, pero sin excesos, pues a Él no le agradan quienes se extralimitan.\qt@no{31}}
\qt@newcmd\qurantrans@es@cmlxxxvi{Di: «¿Quién prohíbe los adornos y los buenos alimentos que Dios ha creado para Sus criaturas?» Di: «Esto es para quienes creen, mientras dure su vida en este mundo, pero será solamente para ellos el Día del Levantamiento.» Así es como Nosotros explicamos nuestras indicaciones para la gente que tiene conocimiento y entendimiento.\qt@no{32}}
\qt@newcmd\qurantrans@es@cmlxxxvii{Di: «En verdad, mi Señor solamente ha prohibido la indecencia y los malos comportamientos públicos o privados, el pecado, la agresión sin derecho, que adoréis como si fuera Dios aquello a lo que Él no ha concedido ninguna autoridad y poder y que atribuyáis a Dios lo que no sabéis.»\qt@no{33}}
\qt@newcmd\qurantrans@es@cmlxxxviii{Toda comunidad tiene un plazo de vida y cuando venza su plazo no podrán retrasarlo ni una hora ni tampoco adelantarlo.\qt@no{34}}
\qt@newcmd\qurantrans@es@cmlxxxix{¡Oh, hijos de Adán! Si, de entre vosotros mismos, os llegan profetas que os comunican Mis indicaciones, quienes tengan temor de Dios y corrijan sus malos actos no tendrán que temer y no estarán tristes.\qt@no{35}}
\qt@newcmd\qurantrans@es@cmxc{Pero aquellos que desmientan Nuestras indicaciones y se muestren altivos ante ellas serán la gente del Fuego en el cual estarán eternamente.\qt@no{36}}
\qt@newcmd\qurantrans@es@cmxci{¿Quién, pues, es más opresor que quien inventa mentiras sobre Dios o desmiente Sus indicaciones? Esos recibirán la parte que les fue decretada, hasta que lleguen a ellos Nuestros enviados, tomen sus almas y les digan: “¿Dónde están aquellos a quienes invocabais en lugar de Dios?” Dirán: «Se apartaron de nosotros» y testificarán contra ellos mismos que ocultaban la Verdad.\qt@no{37}}
\qt@newcmd\qurantrans@es@cmxcii{Dirá (Dios): «Entrad en el Fuego, con las comunidades de genios y humanos semejantes a vosotros que os precedieron.» Cada vez que una comunidad entre maldecirá a su hermana. Hasta que, cuando todas ellas se encuentren reunidas en él, la última de ellas diga de la primera: «¡Señor nuestro! ¡Ellos fueron quienes nos extraviaron! ¡Dales, pues, doble castigo del Fuego!» Dirá (Dios): «Será el doble para cada una, pero no lo sabéis.»\qt@no{38}}
\qt@newcmd\qurantrans@es@cmxciii{Y el primero de ellos dirá al último: «No nos aventajáis en nada, así que gustad el castigo por lo que habéis hecho.»\qt@no{39}}
\qt@newcmd\qurantrans@es@cmxciv{En verdad, no se abrirán las puertas del Cielo para quienes niegan Nuestros signos o se llenan de soberbia ante ellos y no entrarán en el Jardín mientras no pase el camello por el ojo de la aguja. Así es como recompensamos a quienes hacen el mal.\qt@no{40}}
\qt@newcmd\qurantrans@es@cmxcv{Tendrán el Infierno por lecho y sobre ellos cobertores de fuego. Así es como recompensamos a los opresores.\qt@no{41}}
\qt@newcmd\qurantrans@es@cmxcvi{Pero quienes crean y obren rectamente -Nosotros no exigimos a nadie más allá de sus posibilidades- serán la gente del Jardín, en el cual estarán eternamente.\qt@no{42}}
\qt@newcmd\qurantrans@es@cmxcvii{Extraeremos de sus pechos lo que quede de rencor o envidia y los arroyos fluirán a sus pies. Y dirán: «Alabado sea Dios, Quien nos guió a esto. Nunca habríamos encontrado la dirección si Dios no nos hubiese guiado. Ciertamente, los profetas de nuestro Señor, vinieron con la Verdad.» Se les convocará diciendo: «Este es el Jardín que se os ha dado en herencia por lo que habéis hecho.»\qt@no{43}}
\qt@newcmd\qurantrans@es@cmxcviii{Las gentes del Jardín dirán a las gentes del Fuego: «En verdad, encontramos que aquello que nuestro Señor nos prometió era cierto. ¿Era también cierto lo que os prometió vuestro Señor?» Dirán: «Sí.» Entonces un pregonero anunciará: «¡Que la maldición de Dios sea con los opresores!\qt@no{44}}
\qt@newcmd\qurantrans@es@cmxcix{¡Aquellos que intentan apartar a la gente del camino de Dios, tratando de complicarlo y mostrarlo tortuoso y que no creen en la otra vida!»\qt@no{45}}
\qt@newcmd\qurantrans@es@m{Y entre ambos habrá una barrera y en los lugares elevados habrá hombres que reconocerán a cada uno de ellos por sus señales y que se dirigirán a las gentes del Jardín diciendo: «La paz sea con vosotros», pero no entrarán en él aunque desean ardientemente hacerlo.\qt@no{46}}
\qt@newcmd\qurantrans@es@mi{Y, cuando vuelvan su vista hacia las gentes del Fuego, dirán: «¡Señor nuestro! ¡No nos pongas con la gente opresora!»\qt@no{47}}
\qt@newcmd\qurantrans@es@mii{Y los hombres de los lugares elevados se dirigirán a algunas personas a las que reconocerán por sus señales, diciéndoles: «De nada os ha servido cuanto amasasteis y lo soberbios que erais.»\qt@no{48}}
\qt@newcmd\qurantrans@es@miii{«¿Son éstos aquéllos de quienes jurabais que Dios no tendría misericordia de ellos?» «¡Entrad en el Jardín! ¡No tendréis por qué temer y no estaréis tristes!»\qt@no{49}}
\qt@newcmd\qurantrans@es@miv{Y las gentes del Fuego se dirigirán a las gentes del Jardín diciendo: «¡Facilitadnos algo de agua o algo de lo que os proveyó vuestro Señor!» Ellos dirán: «En verdad, Dios ha prohibido ambas cosas para los que no creen.\qt@no{50}}
\qt@newcmd\qurantrans@es@mv{Aquellos que no dieron importancia a sus creencias y jugaron con ellas, atrapados por la vida mundanal.» Hoy Nosotros nos olvidaremos de ellos, de la misma manera que ellos se olvidaron de la cita que tenían para este Día y negaron Nuestras señales.\qt@no{51}}
\qt@newcmd\qurantrans@es@mvi{Ciertamente, trajimos para ellos una Escritura, que explicamos con conocimiento, como guía y misericordia para una gente que cree.\qt@no{52}}
\qt@newcmd\qurantrans@es@mvii{¿Acaso esperan otra cosa que la aclaración de la realidad a la que aluden sus versículos? El día en que se explique la realidad a la que alude la Escritura, quienes anteriormente la habían olvidado dirán: «Ciertamente, los Mensajeros de nuestro Señor vinieron con la Verdad. ¿Habrá alguien que interceda por nosotros o que nos haga regresar para que podamos actuar de manera diferente a como hemos actuado?» En verdad, habrán echado a perder sus almas y se habrá alejado de ellos aquello que inventaban.\qt@no{53}}
\qt@newcmd\qurantrans@es@mviii{En verdad, vuestro Señor es Dios, Quien creó los cielos y la Tierra en seis días y después se instaló en el Trono. Hace que la noche cubra al día, al cual sigue con premura. Y (creó) el Sol, la Luna y las estrellas, todos ellos obedientes a Su orden. ¿Acaso no pertenecen a Él la Creación y el imperativo creador? ¡Bendito sea Dios, Señor del Universo!\qt@no{54}}
\qt@newcmd\qurantrans@es@mix{Suplicad a vuestro Señor con humildad y en secreto. En verdad, Él no ama a los transgresores.\qt@no{55}}
\qt@newcmd\qurantrans@es@mx{Y no corrompáis en la Tierra después de haber sido restablecidos los valores morales y espirituales, e imploradle con temor y esperanza. En verdad, la misericordia de Dios está cerca de quienes hacen el bien.\qt@no{56}}
\qt@newcmd\qurantrans@es@mxi{Él es Quien envía los vientos como nuncios de Su misericordia. Cuando transportan nubes cargadas de lluvia Nosotros los dirigimos hacia una tierra muerta y hacemos que el agua descienda a ella, haciendo así que surjan toda clase de frutos. De la misma manera haremos salir a los muertos. Quizá así os dejéis amonestar.\qt@no{57}}
\qt@newcmd\qurantrans@es@mxii{La buena tierra da su vegetación con el permiso de su Señor y la que es mala da pero con escasez. Así es como Nosotros explicamos los signos a una gente que es agradecida.\qt@no{58}}
\qt@newcmd\qurantrans@es@mxiii{Ciertamente, enviamos a Noé a su pueblo y dijo: «¡Oh, pueblo mío! ¡Adorad a Dios! No tenéis más dios que Él. En verdad, temo para vosotros el castigo de un día impresionante.»\qt@no{59}}
\qt@newcmd\qurantrans@es@mxiv{Los notables de su pueblo dijeron: «En verdad, te vemos en un extravío evidente.»\qt@no{60}}
\qt@newcmd\qurantrans@es@mxv{Él dijo: «¡Oh, pueblo mío! No estoy extraviado. Soy un Mensajero del Señor del Universo\qt@no{61}}
\qt@newcmd\qurantrans@es@mxvi{para transmitiros los mensajes de mi Señor y aconsejaros, pues sé por mi Señor lo que vosotros no sabéis.»\qt@no{62}}
\qt@newcmd\qurantrans@es@mxvii{«¿Acaso os sorprende que vuestro Señor os haga llegar una llamada al recuerdo por medio de un hombre de los vuestros, para amonestaros y para que seáis temerosos y así, quizás, se tenga misericordia de vosotros?»\qt@no{63}}
\qt@newcmd\qurantrans@es@mxviii{Pero le desmintieron y Nosotros le salvamos, a él y a los que con él estaban, en el Arca y ahogamos a quienes desmentían Nuestras señales. En verdad, eran un pueblo ciego.\qt@no{64}}
\qt@newcmd\qurantrans@es@mxix{Y a los Aditas (enviamos) a su hermano Hud. Dijo: «¡Oh, pueblo mío! ¡Adorad a Dios! ¡No tenéis más dios que Él! ¿Es que no seréis temerosos?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mxx{Los notables de su pueblo que no eran creyentes dijeron: «Ciertamente, vemos que eres un insensato y creemos que eres un mentiroso.»\qt@no{66}}
\qt@newcmd\qurantrans@es@mxxi{Dijo: «¡Oh, pueblo mío! ¡No soy un insensato, sino un Mensajero del Señor del Universo!\qt@no{67}}
\qt@newcmd\qurantrans@es@mxxii{para transmitiros los mensajes de mi Señor. Soy para vosotros un consejero leal.»\qt@no{68}}
\qt@newcmd\qurantrans@es@mxxiii{«¿Acaso os sorprende que vuestro Señor os haga llegar una llamada al recuerdo por medio de un hombre de los vuestros, para amonestaros? Recordad cuando os nombró sucesores, tras el pueblo de Noé y os dio una gran corpulencia.» «Recordad, pues, las bendiciones de Dios, para que, así, tengáis éxito.»\qt@no{69}}
\qt@newcmd\qurantrans@es@mxxiv{Ellos dijeron: «¿Has venido a nosotros para que adoremos solamente a Dios y abandonemos lo que nuestros padres adoraban? ¡Haz, entonces, que venga a nosotros el castigo que nos has prometido, si eres de los que dicen la verdad!»\qt@no{70}}
\qt@newcmd\qurantrans@es@mxxv{Él dijo: «Ciertamente, llegará a vosotros el castigo y la ira de vuestro Señor. ¿Discutís conmigo sobre nombres con los que vosotros y vuestros antepasados les habéis denominado? Dios no les ha enviado poder alguno. ¡Esperad! ¡Yo también esperaré con vosotros!»\qt@no{71}}
\qt@newcmd\qurantrans@es@mxxvi{Entonces, por Nuestra misericordia, les salvamos, a él y a los que con él estaban, y cortamos las raíces de quienes desmentían Nuestras señales y no eran creyentes.\qt@no{72}}
\qt@newcmd\qurantrans@es@mxxvii{Y (enviamos) a los Tamudeos a su hermano Saleh. Él dijo: «¡Oh, pueblo mío! ¡Adorad a Dios! No tenéis más dios que Él. Sin duda, ha llegado a vosotros una prueba clara de vuestro Señor. Está camella de Dios es una señal para vosotros. Permitidla que paste en la tierra de Dios y no le causéis mal alguno, pues sufriríais un castigo doloroso.»\qt@no{73}}
\qt@newcmd\qurantrans@es@mxxviii{«Y recordad cuando os nombró sucesores tras el pueblo de Ad, y os dio poder en la Tierra. Construisteis fortalezas en sus llanuras y excavasteis casas en las montañas.» «Recordad, pues, las bendiciones de Dios y no actuéis en la Tierra como corruptores.»\qt@no{74}}
\qt@newcmd\qurantrans@es@mxxix{Los notables de su pueblo, que eran arrogantes, dijeron a los que habían tratado de debilitar, a los que entre ellos habían tenido fe: «¿Cómo sabéis que Saleh es un Mensajero de su Señor?» Ellos dijeron: «En verdad, creemos en aquello con lo que fue enviado.»\qt@no{75}}
\qt@newcmd\qurantrans@es@mxxx{Los arrogantes dijeron: «Nosotros no creemos en absoluto en aquello en lo que vosotros habéis creído.»\qt@no{76}}
\qt@newcmd\qurantrans@es@mxxxi{Así que desjarretaron a la camella, desafiando la orden de su Señor y dijeron: «¡Eh, Saleh! ¡Ven a nosotros con el castigo que nos prometiste, si eres un profeta!»\qt@no{77}}
\qt@newcmd\qurantrans@es@mxxxii{Entonces, el terremoto les sorprendió y amanecieron muertos en sus casas.\qt@no{78}}
\qt@newcmd\qurantrans@es@mxxxiii{Así que, (Saleh) se alejó de ellos, diciendo: «¡Oh, pueblo mío! ¡En verdad, yo os transmití el mensaje de mi Señor y os aconsejé buenamente, pero vosotros no queríais buenos consejeros!»\qt@no{79}}
\qt@newcmd\qurantrans@es@mxxxiv{Y (recuerda a) Lot cuando dijo a su pueblo: «¿Cometeréis una indecencia que nadie en el Universo ha cometido antes?\qt@no{80}}
\qt@newcmd\qurantrans@es@mxxxv{En verdad, vais con deseo a los hombres en lugar de a las mujeres. Sois, verdaderamente, gente inmoderada.»\qt@no{81}}
\qt@newcmd\qurantrans@es@mxxxvi{Y la respuesta de su pueblo no fue otra que decir: «¡Expulsadles de vuestra ciudad! ¡Son unos puritanos!»\qt@no{82}}
\qt@newcmd\qurantrans@es@mxxxvii{Pero Nosotros les salvamos, a él y a su gente, excepto a su esposa, que fue de los que se quedaron atrás,\qt@no{83}}
\qt@newcmd\qurantrans@es@mxxxviii{e hicimos que lloviera sobre ellos. Observa cuál fue el final de los malhechores.\qt@no{84}}
\qt@newcmd\qurantrans@es@mxxxix{Y (enviamos) a los Madianitas a su hermano Shuaib. Dijo: «¡Oh, pueblo mío! ¡Adorad a Dios! No tenéis más dios que Él. Ciertamente, ha venido a vosotros una prueba clara de vuestro Señor. Dad, pues, la medida y el peso (correctos) y no estaféis a la gente en sus cosas y no corrompáis en la Tierra después de que ha sido reformada. Eso será en beneficio vuestro, si sois creyentes.»\qt@no{85}}
\qt@newcmd\qurantrans@es@mxl{«Y no acechéis a las gentes en cada camino para intimidarlas, ni pongáis obstáculos tratando de hacerlo complicado y tortuoso, para que la gente pueda seguir el camino de Dios si cree en Él.» «Recordad cuando erais pocos y Él aumentó vuestro número y observad cuál fue el final de los corruptores.»\qt@no{86}}
\qt@newcmd\qurantrans@es@mxli{«Y si un grupo de vosotros creyese en aquello con lo que he sido enviado y otro grupo no creyese, sed pacientes hasta que Dios juzgue entre nosotros, pues Él es el mejor de los jueces.»\qt@no{87}}
\qt@newcmd\qurantrans@es@mxlii{Los notables de su pueblo, que eran arrogantes, dijeron: «Shuaib, os expulsaremos de nuestra ciudad, a ti y a los que creen contigo, si no regresáis a nuestras creencias.» (Shuaib) dijo: «¿Aunque eso nos repugne?»\qt@no{88}}
\qt@newcmd\qurantrans@es@mxliii{«Inventaríamos una mentira sobre Dios si regresásemos a vuestras creencias después de habernos Dios salvado de ellas. No nos es posible regresar a ellas a menos que Dios, nuestro Señor, lo quiera. El conocimiento de nuestro Señor abarca todas las cosas. Hemos depositado nuestra confianza en Dios.» «¡Oh, Señor! ¡Juzga con justicia entre nosotros y nuestro pueblo! ¡Tú eres el mejor de los jueces!»\qt@no{89}}
\qt@newcmd\qurantrans@es@mxliv{Los notables de su pueblo que no eran creyentes dijeron: «En verdad, si seguís a Shuaib seréis de los perdedores.»\qt@no{90}}
\qt@newcmd\qurantrans@es@mxlv{Pero les sorprendió el terremoto y amanecieron muertos en sus casas.\qt@no{91}}
\qt@newcmd\qurantrans@es@mxlvi{Fue como si quienes desmintieron a Shuaib no hubiesen habitado jamás en ellas. Quienes desmintieron a Shuaib fueron los perdedores.\qt@no{92}}
\qt@newcmd\qurantrans@es@mxlvii{Así que, se alejó de ellos diciendo: «¡Oh, pueblo mío! ¡En verdad, yo os transmití los mensajes de mi Señor y os aconsejé buenamente, así pues ¿Cómo sentir pena por gente que oculta la Verdad?»\qt@no{93}}
\qt@newcmd\qurantrans@es@mxlviii{No hemos enviado a ciudad alguna un profeta sin hacer que su gente padeciese dificultades y males, para que, quizá así, fuesen humildes.\qt@no{94}}
\qt@newcmd\qurantrans@es@mxlix{Luego transformamos el mal en bien, hasta que de nuevo se excedieron y dijeron: «También nuestros padres soportaron perjuicios y dificultades.» Entonces, les tomamos por sorpresa en su estado de inconsciencia.\qt@no{95}}
\qt@newcmd\qurantrans@es@ml{Si las gentes de las ciudades hubiesen creído y sido temerosos, les habríamos otorgado las bendiciones de los cielos y la Tierra, pero negaron la Verdad y les castigamos por lo que habían cometido.\qt@no{96}}
\qt@newcmd\qurantrans@es@mli{¿Acaso las gentes de las ciudades están seguras de que no les llegará Nuestro castigo en la noche mientras duermen?\qt@no{97}}
\qt@newcmd\qurantrans@es@mlii{¿O están seguros de que no les llegará Nuestro castigo de mañana, mientras están jugando?\qt@no{98}}
\qt@newcmd\qurantrans@es@mliii{¿Están seguros frente a los planes de Dios? Sólo la gente perdida se siente a salvo de los planes de Dios.\qt@no{99}}
\qt@newcmd\qurantrans@es@mliv{¿Acaso, a quienes heredaron la Tierra después de sus antepasados, no les sirve de guía saber que si Nosotros quisiéramos también les castigaríamos a ellos por sus pecados y sellaríamos sus corazones para que no pudiesen oír?\qt@no{100}}
\qt@newcmd\qurantrans@es@mlv{Estas son ciudades de las que te hemos contado algunas cosas. Sus Mensajeros les trajeron pruebas evidentes pero ellos no estuvieron dispuestos a creer en lo que antes habían considerado falso. Así es como sella Dios el corazón de los que no creen.\qt@no{101}}
\qt@newcmd\qurantrans@es@mlvi{Y no encontramos en la mayoría de ellos lealtad a los compromisos contraídos. Lo que encontramos fue que la mayoría de ellos eran transgresores.\qt@no{102}}
\qt@newcmd\qurantrans@es@mlvii{Tras ellos, enviamos a Moisés con Nuestras señales al Faraón y a sus cortesanos, pero no las hicieron justicia. Mira, pues, cuál fue el fin de los corruptores.\qt@no{103}}
\qt@newcmd\qurantrans@es@mlviii{Y dijo Moisés: «¡Oh, Faraón! ¡Ciertamente, soy un Mensajero del Señor del Universo!»\qt@no{104}}
\qt@newcmd\qurantrans@es@mlix{«Lo correcto es que no diga sobre Dios sino la verdad. He venido a vosotros con una prueba clara de vuestro Señor. Deja, por tanto, ir conmigo a los hijos de Israel.»\qt@no{105}}
\qt@newcmd\qurantrans@es@mlx{Dijo (Faraón): «Si has venido con una señal ¡Muéstrala! si eres de los que dicen la verdad.»\qt@no{106}}
\qt@newcmd\qurantrans@es@mlxi{Entonces, arrojó su vara y ésta se transformó en una serpiente verdadera.\qt@no{107}}
\qt@newcmd\qurantrans@es@mlxii{Y descubrió su mano y ésta apareció blanca ante los que miraban.\qt@no{108}}
\qt@newcmd\qurantrans@es@mlxiii{Los principales de la gente del Faraón dijeron: «Verdaderamente, éste es un mago experto.\qt@no{109}}
\qt@newcmd\qurantrans@es@mlxiv{Lo que quieren es echaros de vuestra tierra, por tanto ¿Qué opináis?»\qt@no{110}}
\qt@newcmd\qurantrans@es@mlxv{Dijeron: «Hazles regresar a él y a su hermano y envía a las ciudades encargados\qt@no{111}}
\qt@newcmd\qurantrans@es@mlxvi{que te traigan a todos los magos expertos.»\qt@no{112}}
\qt@newcmd\qurantrans@es@mlxvii{Y llegaron los magos ante el Faraón y dijeron: «Queremos una recompensa si somos los vencedores.»\qt@no{113}}
\qt@newcmd\qurantrans@es@mlxviii{Dijo (Faraón): «Sí. Además, seréis de los próximos a mí.»\qt@no{114}}
\qt@newcmd\qurantrans@es@mlxix{Dijeron (los magos): «¡Oh, Moisés! ¿Lanzas tú o lanzamos nosotros?»\qt@no{115}}
\qt@newcmd\qurantrans@es@mlxx{Dijo: «¡Lanzad!» Y, cuando lanzaron, hechizaron los ojos de la gente, asustándoles y creando una magia impresionante.\qt@no{116}}
\qt@newcmd\qurantrans@es@mlxxi{Nosotros inspiramos a Moisés: «¡Lanza tu vara!». Y ésta capturó sus falsos trucos.\qt@no{117}}
\qt@newcmd\qurantrans@es@mlxxii{La verdad prevaleció y anuló lo que ellos habían hecho.\qt@no{118}}
\qt@newcmd\qurantrans@es@mlxxiii{Así fueron vencidos y quedaron humillados.\qt@no{119}}
\qt@newcmd\qurantrans@es@mlxxiv{Y los magos cayeron postrados.\qt@no{120}}
\qt@newcmd\qurantrans@es@mlxxv{Dijeron: «¡Creemos en el Señor del Universo!\qt@no{121}}
\qt@newcmd\qurantrans@es@mlxxvi{¡El Señor de Moisés y de Aarón!»\qt@no{122}}
\qt@newcmd\qurantrans@es@mlxxvii{Dijo Faraón: «¿Creéis en Él antes de que yo os dé mi permiso? Esto es un plan que habéis tramado en la ciudad para echar de ella a sus habitantes. ¡Vais a saber!\qt@no{123}}
\qt@newcmd\qurantrans@es@mlxxviii{¡Os cortaré las manos y los pies opuestos y luego os crucificaré a todos!»\qt@no{124}}
\qt@newcmd\qurantrans@es@mlxxix{Dijeron: «¡En verdad, regresaremos a nuestro Señor!\qt@no{125}}
\qt@newcmd\qurantrans@es@mlxxx{Solamente te vengas de nosotros por haber creído en las señales de nuestro Señor cuando llegaron a nosotros. ¡Señor nuestro! ¡Danos paciencia y haznos morir sometidos a Ti!»\qt@no{126}}
\qt@newcmd\qurantrans@es@mlxxxi{Los principales de la gente del Faraón dijeron: «¿Dejarás que Moisés y su gente corrompan el país y os abandonen a ti y a tus dioses?» Dijo: «Mataremos a sus hijos y dejaremos con vida a sus mujeres, pues, ciertamente, les tenemos dominados.»\qt@no{127}}
\qt@newcmd\qurantrans@es@mlxxxii{Moisés dijo a su pueblo: «¡Invocad la ayuda de Dios y sed pacientes! ¡Ciertamente, la Tierra pertenece a Dios y Él la da en herencia a quien quiere de Sus siervos! ¡El triunfo final es de los temerosos de Dios!»\qt@no{128}}
\qt@newcmd\qurantrans@es@mlxxxiii{Dijeron: «Fuimos perseguidos antes de que vinieses a nosotros y después de haber llegado.» Dijo: «Puede que vuestro Señor destruya a vuestros enemigos y haga que les sucedáis en la Tierra y vea cómo actuáis entonces.»\qt@no{129}}
\qt@newcmd\qurantrans@es@mlxxxiv{Y, ciertamente, Nosotros castigamos a la gente del Faraón con los años de sequía y escasez de frutos, para que, así, se dejasen amonestar.\qt@no{130}}
\qt@newcmd\qurantrans@es@mlxxxv{Pero cuando les llegaba algo bueno decían: «Esto nos corresponde.» Y cuando les aquejaba un mal lo atribuían al mal agüero de Moisés y de los que estaban con él. ¿Acaso su suerte no dependía de Dios? Pero la mayoría de ellos no sabían\qt@no{131}}
\qt@newcmd\qurantrans@es@mlxxxvi{y dijeron: «Sea cual sea la señal que nos traigas para hacernos magia con ella, no te creeremos.»\qt@no{132}}
\qt@newcmd\qurantrans@es@mlxxxvii{Enviamos contra ellos huracanes, langostas, piojos, ranas y sangre. Señales sucesivas. Pero se llenaron de soberbia y fueron un pueblo de pecadores.\qt@no{133}}
\qt@newcmd\qurantrans@es@mlxxxviii{Cuando caía sobre ellos una plaga, decían: «¡Oh, Moisés! ¡Ruega por nosotros a tu Señor en virtud de la alianza que tiene contigo! ¡Si apartas de nosotros este mal creeremos en ti y dejaremos que los Hijos de Israel se vayan contigo!»\qt@no{134}}
\qt@newcmd\qurantrans@es@mlxxxix{Pero cuando apartábamos de ellos el mal al cumplirse el plazo anunciado, rompían su promesa.\qt@no{135}}
\qt@newcmd\qurantrans@es@mxc{Nos vengamos de ellos y les ahogamos en el mar por haber desmentido Nuestras señales y no haber hecho caso de ellas.\qt@no{136}}
\qt@newcmd\qurantrans@es@mxci{Y dimos en herencia, al pueblo que había estado sometido, los Orientes y los Occidentes de la tierra que Nosotros habíamos bendecido. Y se cumplió la buena palabra de tu Señor a los Hijos de Israel, por haber sido pacientes y destruimos lo que Faraón y su pueblo habían construido y lo que habían erigido.\qt@no{137}}
\qt@newcmd\qurantrans@es@mxcii{E hicimos que los Hijos de Israel cruzasen el mar y llegasen junto a una gente que rendía pleitesía a unos ídolos que poseían. Dijeron: «¡Oh, Moisés! ¡Tráenos un dios semejante a los dioses que ellos tienen!» Dijo (Moisés): «¡En verdad, sois un pueblo ignorante!\qt@no{138}}
\qt@newcmd\qurantrans@es@mxciii{Aquello de lo que se ocupan está llamado a perecer y sus obras no les servirán de nada.»\qt@no{139}}
\qt@newcmd\qurantrans@es@mxciv{Dijo (Moisés): «¿Voy a buscar otro dios diferente de Dios, cuando Él os ha favorecido más que a nadie en el Universo?»\qt@no{140}}
\qt@newcmd\qurantrans@es@mxcv{Y (recordad) cuando os salvamos de la gente del Faraón que os infligía un duro castigo. Mataban a vuestros hijos varones y dejaban con vida a vuestras mujeres. Con ello os sometió vuestro Señor a una dura prueba.\qt@no{141}}
\qt@newcmd\qurantrans@es@mxcvi{Nosotros tuvimos un encuentro con Moisés durante treinta noches, que completamos con otras diez. Siendo, por tanto, de cuarenta noches la cita con su Señor. Y Moisés dijo a su hermano Aarón: «Represéntame ante mi pueblo, pon orden y no sigas la senda de los corruptores.»\qt@no{142}}
\qt@newcmd\qurantrans@es@mxcvii{Y cuando Moisés vino a Nuestra cita y su Señor le hubo hablado, dijo: «¡Señor mío! ¡Muéstrate a mí para que yo pueda verte!» Dijo Él: «¡Jamás me verás! Pero mira la montaña y si ésta permanece firme en su sitio Me verás.» Y cuando su Señor se manifestó a la montaña la desmoronó y Moisés cayó desvanecido. Al volver en sí, dijo: «¡Glorificado seas! ¡Me vuelvo a Ti arrepentido y soy el primero de los creyentes!»\qt@no{143}}
\qt@newcmd\qurantrans@es@mxcviii{Él dijo: «¡Oh, Moisés! ¡Te he elegido entre toda la gente para entregarte Mi mensaje y hablar contigo! ¡Toma, pues, lo que te he dado y sé de los agradecidos!»\qt@no{144}}
\qt@newcmd\qurantrans@es@mxcix{Y escribimos para él en las Tablas consejos y advertencias de todo y explicaciones detalladas sobre todas las cosas. «¡Tómalas, pues, con fuerza y ordena a tu pueblo que tome lo bueno que hay en ellas! Yo pronto os mostraré la morada de los transgresores.»\qt@no{145}}
\qt@newcmd\qurantrans@es@mc{«Apartaré de (la fe en) Mis señales a quienes se llenan de soberbia en la Tierra sin ningún derecho y aunque vean todas las señales no creerán en ellas y aunque vean el camino de la dirección correcta no lo elegirán como su camino y si ven el camino equivocado lo adoptarán como su camino. Eso, por haber desmentido Nuestras señales y haberse desentendido de ellas.»\qt@no{146}}
\qt@newcmd\qurantrans@es@mci{Aquellos que desmintieron Nuestras señales y el encuentro de la otra vida habrán invalidados sus obras. ¿Acaso recibirán otra recompensa que la que corresponde a lo que hicieron?\qt@no{147}}
\qt@newcmd\qurantrans@es@mcii{El pueblo de Moisés, en su ausencia, modeló con sus joyas el cuerpo de un becerro que mugía. ¿Es que no veían que no les hablaba ni les guiaba a ningún camino? Lo tomaron (como objeto de su adoración) y obraron injustamente.\qt@no{148}}
\qt@newcmd\qurantrans@es@mciii{Y, cuando la Verdad se les hizo evidente y vieron que se habían extraviado, dijeron: «Si nuestro Señor no tiene misericordia de nosotros y no nos perdona seremos de los perdedores.»\qt@no{149}}
\qt@newcmd\qurantrans@es@mciv{Y cuando Moisés regresó junto a su pueblo, enfadado y entristecido, dijo: «¡Qué mal me habéis representado en mi ausencia! ¿Queréis adelantar el juicio de vuestro Señor?» Arrojó las Tablas y cogió a su hermano de la cabeza, atrayéndole hacia sí. (Aarón) dijo: «¡Hijo de mi madre! ¡El pueblo me ha hecho de menos y casi me mata! ¡Que los enemigos, pues, no se alegren de mi desgracia y no me sitúes entre la gente opresora!»\qt@no{150}}
\qt@newcmd\qurantrans@es@mcv{Dijo (Moisés): «Señor, perdóname y perdona a mi hermano y haznos entrar en Tu misericordia, pues Tú eres el más misericordioso de los misericordiosos.»\qt@no{151}}
\qt@newcmd\qurantrans@es@mcvi{En verdad, a quienes tomaron al becerro pronto les alcanzará el enfado de su Señor y sufrirán la humillación en esta vida. De esa manera recompensamos a los que inventan (mentiras).\qt@no{152}}
\qt@newcmd\qurantrans@es@mcvii{Y aquellos que obran mal y luego se arrepienten y creen…, en verdad, tu Señor, tras ello, es perdonador, misericordiosísimo con los creyentes.\qt@no{153}}
\qt@newcmd\qurantrans@es@mcviii{Y cuando a Moisés se le pasó el enfado tomó las Tablas. En sus escritos hay guía y misericordia para quienes sontemerosos de su Señor.\qt@no{154}}
\qt@newcmd\qurantrans@es@mcix{Y eligió Moisés a setenta hombres de su pueblo para que se encontraran con Nosotros. Y cuando les alcanzó el terremoto, dijo: «Señor, si hubieras querido, ya antes los habrías aniquilado a ellos y a mí. ¿Vas a aniquilarnos por lo que han hecho los necios de entre nosotros? Esto no es más que una prueba Tuya con la que extravías a quien Tú quieres y guías a quien Tú quieres. Tú eres nuestro amigo y protector ¡Perdónanos, pues, y ten misericordia de nosotros! ¡Tú eres el mejor de los perdonadores!»\qt@no{155}}
\qt@newcmd\qurantrans@es@mcx{«Y dispón para nosotros lo bueno en esta vida y en la otra. Ciertamente, nos hemos vuelto a Ti.» Dijo Él: «Inflijo Mi castigo a quien Yo quiero, pero Mi misericordia alcanza a todas las cosas y la dispondré para quienes sean temerosos y den la limosna obligatoria que purifica sus bienes y para quienes crean en Mis señales.»\qt@no{156}}
\qt@newcmd\qurantrans@es@mcxi{Aquellos que sigan al Mensajero, el profeta iletrado al que encuentran descrito en la Torá y el Evangelio que tienen con ellos, el cual les ordena lo que está bien y les prohíbe lo que está mal y hace lícitas para ellos las cosas buenas e ilícitas para ellos las cosas malas y que les libera de las cargas que les abrumaban y de las cadenas que les oprimían. Así pues, quienes crean en él, le honren y le auxilien y sigan la luz que se hizo descender con él, serán los triunfadores.\qt@no{157}}
\qt@newcmd\qurantrans@es@mcxii{Di: «¡Oh, gentes! Soy, en verdad, el Mensajero de Dios para todos vosotros. De Aquél a Quien pertenecen los cielos y la Tierra. No hay otro dios más que Él. Da la vida y da la muerte.» Así pues, creed en Dios y en Su Mensajero, el profeta iletrado, que cree en Dios y en Sus palabras. Seguidle para que así seáis bien guiados.\qt@no{158}}
\qt@newcmd\qurantrans@es@mcxiii{Y, de la comunidad de Moisés, hay un grupo que guía (a la gente) con la Verdad y con ella hace justicia.\qt@no{159}}
\qt@newcmd\qurantrans@es@mcxiv{Y les dividimos en doce comunidades tribales. Y cuando su pueblo le pidió agua, revelamos a Moisés: «Golpea con tu bastón la roca.» Y brotaron de ella doce fuentes. Cada uno supo de cuál debía beber. Y les dimos sombra con las nubes e hicimos descender para ellos el maná y las codornices. «¡Comed de los buenos alimentos con que os proveemos!» Y no nos oprimieron a Nosotros, sino que se oprimieron a sí mismos.\qt@no{160}}
\qt@newcmd\qurantrans@es@mcxv{Y (recuerda) cuando se les dijo: «Estableceos en esta ciudad y comed cuanto deseéis de lo que hay en ella. Y decid: «Alivia» (la carga de nuestros pecados) y entrad por la puerta en prosternación y os perdonaremos vuestros errores e incrementaremos la recompensa de los que hagan el bien.»\qt@no{161}}
\qt@newcmd\qurantrans@es@mcxvi{Pero los opresores de entre ellos cambiaron la palabra por otra diferente de la que se les había dicho y les enviamos un mal del cielo por haber sido transgresores.\qt@no{162}}
\qt@newcmd\qurantrans@es@mcxvii{Y pregúntales por la ciudad que estaba situada junto al mar, cuando violaron el sábado, al ser el sábado cuando venía a ellos la pesca, que se veía desde la orilla, y no venir a ellos otros días. Así les pusimos a prueba por haber sido transgresores.\qt@no{163}}
\qt@newcmd\qurantrans@es@mcxviii{Y (recuerda) cuando un grupo de ellos dijo (a otro): «¿Para qué amonestar a una gente a la que Dios va a aniquilar o a castigar con un duro castigo?» Dijeron (estos otros): «Es para tener una disculpa ante vuestro Señor y porque quizás así sean temerosos de Dios.»\qt@no{164}}
\qt@newcmd\qurantrans@es@mcxix{Y cuando olvidaron lo que se les había recordado, salvamos a quienes condenaron el mal y castigamos duramente a quienes fueron opresores, por haber transgredido.\qt@no{165}}
\qt@newcmd\qurantrans@es@mcxx{Y cuando desafiaron lo que se les había prohibido, les dijimos: «Sed monos despreciables.»\qt@no{166}}
\qt@newcmd\qurantrans@es@mcxxi{Y (recuerda) cuando tu Señor proclamó que, sin duda, enviaría contra ellos, hasta el Día del Levantamiento, a quienes les infligiesen un terrible castigo. En verdad, tu Señor es rápido en la retribución, pero, ciertamente, es perdonador, misericordiosísimo con los creyentes.\qt@no{167}}
\qt@newcmd\qurantrans@es@mcxxii{Y les separamos por la Tierra en comunidades. Algunas de ellas rectas y virtuosas y otras no. Y les pusimos a prueba con cosas buenas y malas, para que así, quizás, regresasen.\qt@no{168}}
\qt@newcmd\qurantrans@es@mcxxiii{Y, tras ellos vino una generación que heredó la Escritura [Sagrada] y que se aferraba a los bienes superfluos de este bajo mundo diciendo: «Pronto seremos perdonados.» y si llegaban a ellos bienes semejantes, volvían a tomarlos. ¿Acaso no se obtuvo de ellos el juramento que está en la Escritura de que no dirían sobre Dios más que la verdad y no estudiaron lo que hay en ella? La morada de la otra vida es mejor para quienes tienen temor de Dios. ¿Es que no razonáis?\qt@no{169}}
\qt@newcmd\qurantrans@es@mcxxiv{Pero, en verdad, no dejaremos de recompensar a quienes corrigen lo que está mal, se aferran a la Escritura [Sagrada] y hacen la oración.\qt@no{170}}
\qt@newcmd\qurantrans@es@mcxxv{Y (recuerda) cuando colocamos la montaña sobre ellos como si fuera un toldo y pensaron que les caería encima. ¡Tomad con fuerza lo que Nosotros os hemos dado y recordad lo que hay en ella, para que así seáis temerosos de Dios!\qt@no{171}}
\qt@newcmd\qurantrans@es@mcxxvi{Y (recuerda) cuando tu Señor tomó de los riñones de los hijos de Adán a su descendencia e hizo que sus almas dieran testimonio: «¿Acaso no soy Yo vuestro Señor?» Dijeron: «Sí, lo atestiguamos.» Para que no pudierais decir el Día del Levantamiento: «Ciertamente, lo ignorábamos.»\qt@no{172}}
\qt@newcmd\qurantrans@es@mcxxvii{O dijeseis: “Ciertamente, nuestros antepasados adoraban desde antiguo a otros dioses junto a Dios y nosotros somos sus descendientes. ¿Vas a aniquilarnos por las equivocaciones que ellos cometieron?”\qt@no{173}}
\qt@newcmd\qurantrans@es@mcxxviii{Así es como Nosotros explicamos detalladamente las señales. Quizás así ellos regresen.\qt@no{174}}
\qt@newcmd\qurantrans@es@mcxxix{Cuéntales la historia de aquel a quien Nosotros dimos nuestros signos y se despojó de ellos, entonces Satanás le siguió y fue de los que se extravían.\qt@no{175}}
\qt@newcmd\qurantrans@es@mcxxx{Y, si Nosotros hubiésemos querido, le habríamos elevado mediante ellos, pero él se inclinó a lo terrenal y siguió a sus pasiones. Su ejemplo es como el del perro, que si le atacas jadea y si no le haces caso jadea. Así son quienes desmienten Nuestras señales. Cuéntales, pues, la historia, quizás así reflexionen.\qt@no{176}}
\qt@newcmd\qurantrans@es@mcxxxi{¡Qué mal ejemplo el de quienes desmienten la verdad de Nuestras señales y oprimen a sus propias almas!\qt@no{177}}
\qt@newcmd\qurantrans@es@mcxxxii{A quien Dios guía está bien guiado y a quienes Él extravía, esos son los perdedores.\qt@no{178}}
\qt@newcmd\qurantrans@es@mcxxxiii{Ciertamente, hemos creado para el Infierno a muchos genios y humanos. Tienen corazones con los que no reflexionan y ojos con los que no ven y oídos con los que no oyen. Son como el ganado o más perdidos aun. Esos son los que están desatentos.\qt@no{179}}
\qt@newcmd\qurantrans@es@mcxxxiv{A Dios pertenecen los nombres mejores, así pues, invócale con ellos y apártate de quienes hacen mal uso de Sus nombres. Pronto les retribuiremos por lo que han hecho.\qt@no{180}}
\qt@newcmd\qurantrans@es@mcxxxv{Y, entre quienes Nosotros hemos creado, hay una comunidad que guía (a la gente) con la Verdad y con ella hace justicia.\qt@no{181}}
\qt@newcmd\qurantrans@es@mcxxxvi{Y a quienes desmientan Nuestras señales les llevaremos gradualmente (a la perdición) sin que sepan cómo.\qt@no{182}}
\qt@newcmd\qurantrans@es@mcxxxvii{Y les concederemos un plazo determinado. En verdad, Mi plan es sólido.\qt@no{183}}
\qt@newcmd\qurantrans@es@mcxxxviii{¿Es que no reflexionan? Su compañero no está poseído, no es más que alguien que amonesta claramente.\qt@no{184}}
\qt@newcmd\qurantrans@es@mcxxxix{¿Acaso no contemplan el orden de los cielos y la Tierra y todo lo que Dios ha creado y que quizás su plazo esté cercano? ¿En qué otras palabras van a creer después de estas?\qt@no{185}}
\qt@newcmd\qurantrans@es@mcxl{No hay quien guíe a aquel a quien Dios extravía y Él les deja que, en su rebeldía, vaguen ciegamente.\qt@no{186}}
\qt@newcmd\qurantrans@es@mcxli{Te preguntan sobre la Hora, ¿Cuándo tendrá lugar? Di: «En verdad, el conocimiento de eso pertenece a mi Señor. Nadie más que Él hará que se manifieste en su momento. Pesa en los cielos y en la Tierra. No vendrá a vosotros sino por sorpresa.» Te preguntan a ti, como si tú tuvieses conocimiento de ella. Di: «En verdad, el conocimiento de ella pertenece a Dios.» Pero la mayoría de la gente no sabe.\qt@no{187}}
\qt@newcmd\qurantrans@es@mcxlii{Di: «No poseo la capacidad de beneficiarme o perjudicarme aparte de lo que Dios quiera. Si tuviera conocimiento de lo que está oculto a los sentidos incrementaría mi bien y el mal no me tocaría. Yo sólo soy un amonestador y un portador de buenas noticias para unas gentes que son creyentes.»\qt@no{188}}
\qt@newcmd\qurantrans@es@mcxliii{Él es Quien os creó a partir de una sola alma, de la que hizo a su pareja para que viviese tranquilo con ella. Cuando él la cubrió, ella quedó embarazada con un embarazo ligero durante un tiempo. Cuando éste se hizo pesado, ambos rogaron a su Señor: «Si nos das un hijo sano, seremos, ciertamente, de los agradecidos.»\qt@no{189}}
\qt@newcmd\qurantrans@es@mcxliv{Pero, cuando les concedió un hijo sano, lo atribuyeron a otras causas además de a Dios. Pero Dios está muy por encima de cuanto le asocian.\qt@no{190}}
\qt@newcmd\qurantrans@es@mcxlv{¿Asociarán a Dios a quienes nada han creado, sino que ellos mismos han sido creados?\qt@no{191}}
\qt@newcmd\qurantrans@es@mcxlvi{¿Y que ni pueden prestarles ayuda ni ayudarse a sí mismos?\qt@no{192}}
\qt@newcmd\qurantrans@es@mcxlvii{Si les invitáis a la buena guía no os seguirán. Da igual que les invitéis o que os quedéis callados.\qt@no{193}}
\qt@newcmd\qurantrans@es@mcxlviii{En verdad, aquellos a quienes invocáis en lugar de Dios son siervos, como vosotros. Invocadlos y esperad a que os respondan, si es que sois sinceros.\qt@no{194}}
\qt@newcmd\qurantrans@es@mcxlix{¿Acaso poseen pies con los que caminar o manos con las que aferrar u ojos con los que ver u oídos con los que oír? Di: «Invocad a los dioses que adoráis como si fueran Dios y trazad vuestros planes contra mí sin hacerme esperar más.»\qt@no{195}}
\qt@newcmd\qurantrans@es@mcl{«En verdad, mi protector es Dios, que hizo descender la Escritura y que protege a quienes son justos.\qt@no{196}}
\qt@newcmd\qurantrans@es@mcli{Y aquellos a quienes invocáis aparte de Él no pueden ayudaros ni ayudarse a ellos mismos.»\qt@no{197}}
\qt@newcmd\qurantrans@es@mclii{Y si les invitáis a la guía no escuchan. Y les ves que te miran, pero no ven.\qt@no{198}}
\qt@newcmd\qurantrans@es@mcliii{¡Sé indulgente, ordena el bien y apártate de los ignorantes!\qt@no{199}}
\qt@newcmd\qurantrans@es@mcliv{Y cuando llegue a ti el susurro de Satanás, refúgiate en Dios, pues, ciertamente, Él todo lo oye, todo lo sabe.\qt@no{200}}
\qt@newcmd\qurantrans@es@mclv{Quienes son temerosos de Dios, cuando les roza el susurro de un demonio, recuerdan a Dios y, entonces, ven claro.\qt@no{201}}
\qt@newcmd\qurantrans@es@mclvi{Pero sus hermanos les hacen permanecer en el error, sin escatimarles perjuicios.\qt@no{202}}
\qt@newcmd\qurantrans@es@mclvii{Y, cuando no vienes a ellos con una señal, dicen: «¿Por qué no has reunido alguna?» Di: «En verdad, solamente sigo lo que me es revelado procedente de mi Señor.» Esto son visiones claras que proceden de vuestro Señor, guía y misericordia para gentes creyentes.\qt@no{203}}
\qt@newcmd\qurantrans@es@mclviii{Y, cuando el Corán sea recitado, escuchadlo y callad. Quizá así obtengáis la misericordia divina.\qt@no{204}}
\qt@newcmd\qurantrans@es@mclix{Y recuerda a tu Señor en tu corazón con humildad y respeto, y sin levantar la voz, mañana y tarde, y no seas de los que están desatentos,\qt@no{205}}
\qt@newcmd\qurantrans@es@mclx{pues, en verdad, quienes están cerca de tu Señor no se vuelven orgullosos por el hecho de adorarle y Le glorifican y se prosternan ante Él.\qt@no{206}}
\qt@newcmd\qurantrans@es@mclxi{\basmalahes Te preguntan sobre los bienes excedentes. Di: «Los bienes excedentes pertenecen a Dios y a Su Mensajero. Así pues, sed temerosos de Dios y arreglad vuestras diferencias y obedeced a Dios y a Su Mensajero si sois creyentes.»\qt@no{1}}
\qt@newcmd\qurantrans@es@mclxii{En verdad, los creyentes son aquellos que, cuando se menciona a Dios, sus corazones se estremecen y cuando les son recitados Sus versículos éstos les incrementan su fe, y que confían en su Señor.\qt@no{2}}
\qt@newcmd\qurantrans@es@mclxiii{Quienes hacen la oración y reparten de los bienes que Nosotros les proporcionamos.\qt@no{3}}
\qt@newcmd\qurantrans@es@mclxiv{Esos son los verdaderos creyentes. Ellos disfrutarán de mayores grados de cercanía junto a su Señor, de perdón y de provisión generosa.\qt@no{4}}
\qt@newcmd\qurantrans@es@mclxv{De la misma manera que cuando tu Señor, con razón, te sacó de tu casa y un grupo de los creyentes se disgustó,\qt@no{5}}
\qt@newcmd\qurantrans@es@mclxvi{te discuten ahora la Verdad, tras habérsela explicado claramente, como si les arrastrasen a la muerte ante sus propios ojos.\qt@no{6}}
\qt@newcmd\qurantrans@es@mclxvii{Y (recuerda) cuando Dios os prometió (la victoria) sobre uno de los dos grupos, (diciendo): «Serán vuestros.» Y deseasteis que fuera el desarmado. Pero Dios quería que la Verdad quedase claramente establecida con Sus palabras y cortar la raíz de los no creyentes,\qt@no{7}}
\qt@newcmd\qurantrans@es@mclxviii{para que la Verdad se consolide y la falsedad sea aniquilada, por mucho que les disguste a los pecadores.\qt@no{8}}
\qt@newcmd\qurantrans@es@mclxix{Recuerda) Cuando pedisteis ayuda a vuestro Señor y Él os respondió: «Os reforzaré con mil ángeles, uno tras otro.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mclxx{Y Dios no lo hizo sino como una buena nueva y para tranquilizar y aportar seguridad con ello a vuestros corazones. Pues el auxilio proviene solamente de Dios. En verdad, Dios es poderoso, sabio.\qt@no{10}}
\qt@newcmd\qurantrans@es@mclxxi{Recuerda) Cuando os envolvió un sueño ligero como un aporte de tranquilidad procedente de Él y descendió sobre vosotros agua del cielo para purificaros con ella y apartar de vosotros el susurro envenenado de Satanás, fortalecer vuestros corazones y consolidar vuestros pasos.\qt@no{11}}
\qt@newcmd\qurantrans@es@mclxxii{Recuerda) Cuando tu Señor reveló a los ángeles: «Yo estoy con vosotros. ¡Fortaleced, pues, a los que creen! Infundiré el terror en el corazón de los que no creen. ¡Golpeadles en las nucas y golpeadles en todos sus dedos\qt@no{12}}
\qt@newcmd\qurantrans@es@mclxxiii{por haber desafiado a Dios y a Su Mensajero!» Dios castiga severamente a quien desafía a Dios y a Su Mensajero.\qt@no{13}}
\qt@newcmd\qurantrans@es@mclxxiv{¡Así es! ¡Probadlo! Y sabed que el castigo del Fuego es para los que ocultan la Verdad.\qt@no{14}}
\qt@newcmd\qurantrans@es@mclxxv{¡Oh, creyentes! ¡Cuando os encontréis a los que no creen en formación de combate no les deis la espalda!\qt@no{15}}
\qt@newcmd\qurantrans@es@mclxxvi{Quien les dé la espalda ese día, excepto para cambiar su puesto de combate o para incorporarse a otra tropa, sufrirá la ira de Dios y su refugio será el Infierno ¡Qué mal destino!\qt@no{16}}
\qt@newcmd\qurantrans@es@mclxxvii{No erais vosotros quienes les matabais, sino Dios Quien les mató. Ni eras tú quien lanzaba cuando lanzabas, sino Dios Quien lanzaba, para otorgar a los creyentes una recompensa de Su parte. En verdad, Dios todo lo oye, todo lo sabe.\qt@no{17}}
\qt@newcmd\qurantrans@es@mclxxviii{¡Así es! ¡Dios destruye los planes de los que no son creyentes!\qt@no{18}}
\qt@newcmd\qurantrans@es@mclxxix{¡Deseabais la victoria y la victoria ha venido a vosotros! Y si os abstenéis será mejor para vosotros y si regresáis Nosotros también regresaremos y vuestras tropas no os servirán de nada por muchas que sean. Dios está con los creyentes.\qt@no{19}}
\qt@newcmd\qurantrans@es@mclxxx{¡Oh, los que creéis! ¡Obedeced a Dios y a Su Mensajero! ¡Y no le volváis la espalda mientras le escucháis!\qt@no{20}}
\qt@newcmd\qurantrans@es@mclxxxi{No seáis como aquellos que dicen: «¡Escuchamos!» pero no escuchan.\qt@no{21}}
\qt@newcmd\qurantrans@es@mclxxxii{Los peores animales ante Dios son los ciegos y sordos que no razonan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mclxxxiii{Si Dios hubiese encontrado algo bueno en ellos les habría hecho oír, pero aun si les hiciese oír se volverían de espaldas y se apartarían.\qt@no{23}}
\qt@newcmd\qurantrans@es@mclxxxiv{¡Oh, los que creéis! Responded a Dios y al Mensajero cuando os invitan a lo que os da vida y sabed que Dios se sitúa entre el hombre y su corazón y que seréis congregados hacia Él.\qt@no{24}}
\qt@newcmd\qurantrans@es@mclxxxv{Y temed una prueba que no solamente afligirá a quienes son injustos entre vosotros. Y sabed que Dios castiga con severidad.\qt@no{25}}
\qt@newcmd\qurantrans@es@mclxxxvi{Y recordad cuando erais pocos, oprimidos en la Tierra, temiendo que la gente os apresara y Él os refugió y os fortaleció con Su ayuda y os proveyó de cosas buenas para que pudierais estar agradecidos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mclxxxvii{¡Oh, los que creéis! No traicionéis a Dios y al Mensajero y no traicionéis a sabiendas lo que se os ha confiado.\qt@no{27}}
\qt@newcmd\qurantrans@es@mclxxxviii{Y sabed que vuestros bienes y vuestros hijos son una prueba para vosotros y que junto a Dios hay una recompensa inmensa.\qt@no{28}}
\qt@newcmd\qurantrans@es@mclxxxix{¡Oh, los que creéis! Si sois temerosos de Dios, Él os otorgará criterio, ocultará vuestros defectos y os perdonará, pues Dios es el Dueño del Favor Inmenso.\qt@no{29}}
\qt@newcmd\qurantrans@es@mcxc{Y (recuerda) cuando los que no creían planearon hacerte prisionero o matarte o expulsarte. Ellos hacían planes y Dios hacía planes, pero Dios es Quien mejor hace los planes.\qt@no{30}}
\qt@newcmd\qurantrans@es@mcxci{Y, cuando les son recitados Nuestros versículos, dicen: «¡Ya lo hemos oído! ¡Si quisiéramos podríamos decir cosas semejantes! ¡No son más que mitos de los primitivos!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mcxcii{Y (recuerda) cuando dijeron: «¡Oh, Dios! Si esto es la Verdad que viene de Ti ¡Haz que lluevan sobre nosotros piedras del cielo o inflígenos un castigo doloroso!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mcxciii{Pero Dios no les castigará mientras tú estés entre ellos, ni les castigará mientras le pidan perdón.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcxciv{¿Por qué no iba Dios a castigarles si ellos impiden acceder (a los creyentes) a la Mezquita Sagrada sin ser sus protectores? Sus protectores son únicamente los temerosos de Dios, pero la mayoría de ellos no saben.\qt@no{34}}
\qt@newcmd\qurantrans@es@mcxcv{Su oración ante La Casa no es otra cosa que silbidos y palmas. ¡Saboread, pues, el castigo por ocultar la Verdad!\qt@no{35}}
\qt@newcmd\qurantrans@es@mcxcvi{En verdad, los que no son creyentes gastan su riqueza para apartar a la gente del camino de Dios. Pronto la habrán gastado y tendrán que lamentarse de ello y luego serán vencidos. Los que ocultan la Verdad serán congregados en el Infierno\qt@no{36}}
\qt@newcmd\qurantrans@es@mcxcvii{para que Dios separe al impuro del puro y amontone a los impuros unos sobre otros y les ponga a todos juntos en el Infierno. Esos serán los perdedores.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcxcviii{Di a quienes ocultan la Verdad que si abandonan su actitud se les perdonará lo pasado, pero que si reinciden ya saben lo que les sucedió a sus antepasados.\qt@no{38}}
\qt@newcmd\qurantrans@es@mcxcix{Combatidles, pues, hasta que cese la idolatría y se rinda culto solamente a Dios. Pero si cesan, en verdad, Dios ve lo que hacen.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcc{Y si dan la espalda, sabed que Dios es vuestro protector. ¡Un excelente protector y un excelente auxiliador!\qt@no{40}}
\qt@newcmd\qurantrans@es@mcci{Y sabed que, de los bienes excedentes que obtengáis de cualquier cosa, una quinta parte pertenece a Dios, al Mensajero y a su familia, a los huérfanos, a los necesitados y a los viajeros, si creéis en Dios y en lo que Nosotros hicimos descender para Nuestro siervo el Día del Criterio, el día en que se encontraron los dos ejércitos, pues Dios tiene poder sobre todas las cosas.\qt@no{41}}
\qt@newcmd\qurantrans@es@mccii{Cuando vosotros estabais en la posición más cercana y ellos en la más alejada y la caravana más baja que vosotros. Si hubierais acordado previamente encontraros no lo habríais conseguido, pero Dios lo hizo para que sucediese lo que ya estaba decretado y fuera destruido, mediante una prueba clara, quien fue destruido y viviera, mediante una prueba clara, quien vivió, pues, en verdad, Dios todo lo oye, todo lo sabe.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcciii{Cuando Dios hizo que en tu sueño les vieses poco numerosos, pues si les hubieses visto muy numerosos habríais vacilado y disputado sobre la orden, pero Dios os protegió. En verdad, Él conoce bien la esencia de los corazones.\qt@no{43}}
\qt@newcmd\qurantrans@es@mcciv{Y, cuando os encontrasteis con ellos, os hizo que les vieseis poco numerosos y os hizo poco numerosos a los ojos de ellos, de manera que sucediese lo que Dios había decretado, pues hacia Dios remiten todos los asuntos.\qt@no{44}}
\qt@newcmd\qurantrans@es@mccv{¡Oh, los que creéis! Cuando os encontréis con un ejército aguantad con firmeza y recordad mucho a Dios, quizás así triunféis.\qt@no{45}}
\qt@newcmd\qurantrans@es@mccvi{Y obedeced a Dios y a Su Mensajero y no disputéis, pues vacilaríais y perderíais vuestro ímpetu. Y sed pacientes. En verdad, Dios está con los pacientes.\qt@no{46}}
\qt@newcmd\qurantrans@es@mccvii{Y no seáis como aquellos que salieron de sus hogares con altanería y ostentación, apartando a la gente del camino de Dios, pues Dios tiene bajo control cuanto hacen.\qt@no{47}}
\qt@newcmd\qurantrans@es@mccviii{Y (recuerda) cuando Satanás les adornó sus actos y les dijo: “Nadie podrá venceros hoy y yo estaré con vosotros.” Pero cuando los dos ejércitos se avistaron se echó atrás y dijo: «Me aparto de vosotros. En verdad, veo lo que vosotros no veis y, en verdad, temo a Dios, pues Dios es severo castigando.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mccix{Los hipócritas y aquellos cuyos corazones están enfermos dijeron: «A esos les ha engañado su creencia.» Pero quien confía en Dios (sepa) que Dios es poderoso, sabio.\qt@no{49}}
\qt@newcmd\qurantrans@es@mccx{Y, si vieses cuando los ángeles arrebaten las almas de los que no creen, les golpearán los rostros y las espaldas y (les dirán:) «¡Saboread el castigo de Fuego abrasador!\qt@no{50}}
\qt@newcmd\qurantrans@es@mccxi{¡Eso es por lo que hicisteis en vuestra vida anterior, pues Dios no oprime a los siervos!»\qt@no{51}}
\qt@newcmd\qurantrans@es@mccxii{Lo mismo que hacían las gentes del Faraón y los que hubo antes de ellos. Negaron las señales de Dios y Dios le castigó por sus pecados. En verdad, Dios es fuerte, severo en el castigo.\qt@no{52}}
\qt@newcmd\qurantrans@es@mccxiii{Eso es porque Dios no cambia la bendición que ha otorgado a un pueblo mientras ellos no cambien lo que hay en sus almas, pues Dios todo lo oye, todo lo sabe.\qt@no{53}}
\qt@newcmd\qurantrans@es@mccxiv{Lo mismo que hacían las gentes del Faraón y los que hubo antes de ellos. Desmentían las señales de su Señor y les destruimos por sus pecados y ahogamos a la gente del Faraón. Todos ellos eran opresores.\qt@no{54}}
\qt@newcmd\qurantrans@es@mccxv{En verdad, los peores animales ante Dios son los que niegan la Verdad, pues ellos no tienen fe.\qt@no{55}}
\qt@newcmd\qurantrans@es@mccxvi{Aquellos con los que concertaste un pacto y que violan el pacto cada vez y no tienen temor de Dios.\qt@no{56}}
\qt@newcmd\qurantrans@es@mccxvii{Y si te enfrentas a ellos en la guerra, dispérsales de tal manera que sirva de escarmiento a los que están tras ellos. Quizás así recapaciten.\qt@no{57}}
\qt@newcmd\qurantrans@es@mccxviii{Y si temes una traición por parte de una gente, denuncia con equidad el pacto que tienes con ellos. En verdad, Dios no ama a los traidores.\qt@no{58}}
\qt@newcmd\qurantrans@es@mccxix{Y que no crean los que no tienen fe que tienen ventaja. Ellos no vencerán.\qt@no{59}}
\qt@newcmd\qurantrans@es@mccxx{Y preparad contra ellos toda la fuerza que podáis y caballería, para intimidar con ella a los enemigos de Dios y enemigos vuestros y a otros que no son ellos, a los que no conocéis pero a quienes Dios conoce. Y lo que gastéis por la causa de Dios os será devuelto y no seréis oprimidos.\qt@no{60}}
\qt@newcmd\qurantrans@es@mccxxi{Y si se inclinan hacia la paz inclinaos también vosotros y confiad en Dios. En verdad, Él todo lo oye, todo lo sabe.\qt@no{61}}
\qt@newcmd\qurantrans@es@mccxxii{Y si quieren engañarte, en verdad, Dios te basta. Él es Quien te fortaleció con Su ayuda y con los creyentes\qt@no{62}}
\qt@newcmd\qurantrans@es@mccxxiii{y unió sus corazones. Si hubieras gastado todo lo que hay en la Tierra no habrías podido unir sus corazones, pero Dios los unió. En verdad, Él es poderoso, sabio.\qt@no{63}}
\qt@newcmd\qurantrans@es@mccxxiv{¡Oh, Profeta! ¡Dios y los creyentes que te siguen son suficiente para ti!\qt@no{64}}
\qt@newcmd\qurantrans@es@mccxxv{¡Oh, Profeta! ¡Convoca a los creyentes al combate! Si hubiera entre vosotros veinte hombres pacientes y contenidos, vencerán a doscientos y si hubiera entre voso tros cien, vencerán a mil de los que no creen, pues son gente que no posee entendimiento.\qt@no{65}}
\qt@newcmd\qurantrans@es@mccxxvi{Ahora, Dios ha aligerado vuestra carga, pues Él sabe que estáis débiles. Así pues, si entre vosotros hubiera cien hombres pacientes y contenidos vencerán a doscientos y si hubiese entre vosotros mil vencerán a dos mil con el permiso de Dios, pues Dios está con los que son pacientes.\qt@no{66}}
\qt@newcmd\qurantrans@es@mccxxvii{No es apropiado que un profeta haga prisioneros hasta haberles diezmado en la Tierra. Deseáis lo accesorio de este mundo pero Dios desea (para vosotros los beneficios de) la Otra vida. Y Dios es poderoso, sabio.\qt@no{67}}
\qt@newcmd\qurantrans@es@mccxxviii{Si no hubiese sido por un decreto previo de Dios, con seguridad os hubiese alcanzado un castigo inmenso por lo que obtuvisteis.\qt@no{68}}
\qt@newcmd\qurantrans@es@mccxxix{Comed, pues, del botín que habéis obtenido, lo que es lícito y bueno y sed temerosos de Dios. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{69}}
\qt@newcmd\qurantrans@es@mccxxx{¡Oh, Profeta! Di a los cautivos que están en tus manos: «Si Dios encuentra algo bueno en vuestros corazones os concederá algo mejor que aquello que os ha sido quitado y os perdonará, pues Dios es perdonador, misericordiosísimo con los creyentes.»\qt@no{70}}
\qt@newcmd\qurantrans@es@mccxxxi{Y si quieren traicionarte, ya traicionaron anteriormente a Dios y Él te dio poder sobre ellos. Dios todo lo conoce, es sabio.\qt@no{71}}
\qt@newcmd\qurantrans@es@mccxxxii{En verdad, quienes creyeron y emigraron y combatieron con sus bienes y sus personas en la senda de Dios y quienes les dieron refugio y auxilio son amigos y protectores entre sí. Y a quienes creyeron pero no emigraron no tenéis por que protegerles en absoluto hasta que emigren. Y si os piden ayuda por causa de la creencia entonces sí debéis ayudarles, excepto si es contra un pueblo con el que tenéis concertado un tratado. Y Dios ve lo que hacéis.\qt@no{72}}
\qt@newcmd\qurantrans@es@mccxxxiii{Y quienes no creen son protectores y amigos unos de otros. A menos que lo hagáis habrá problemas en la Tierra y una gran corrupción.\qt@no{73}}
\qt@newcmd\qurantrans@es@mccxxxiv{Quienes creyeron y emigraron y combatieron en la senda de Dios y quienes les dieron refugio y auxilio, esos son los verdaderos creyentes. Ellos serán perdonados y provistos con generosidad.\qt@no{74}}
\qt@newcmd\qurantrans@es@mccxxxv{Y quienes creyeron después y emigraron y combatieron con vosotros, esos son de los vuestros. Pero los familiares de sangre tienen más derecho a heredar unos de otros en el Libro de Dios. En verdad, Dios conoce todas las cosas.\qt@no{75}}
\qt@newcmd\qurantrans@es@mccxxxvi{\basmalahes Rechazo de Dios y de Su Mensajero a los politeístas con los que hicisteis un tratado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mccxxxvii{Así pues, viajad por la Tierra (libremente) durante cuatro meses y sabed que no podéis humillar a Dios y que Dios es Quien humillará a los que no creen.\qt@no{2}}
\qt@newcmd\qurantrans@es@mccxxxviii{Anuncio de Dios y de Su Mensajero para la gente en el día de la gran peregrinación: «Dios y Su Mensajero rechazan a los politeístas. Si os arrepentís será mejor para vosotros, pero si dais la espalda, sabed que vosotros no podéis humillar a Dios.» E informa a quienes no creen que tendrán un castigo doloroso,\qt@no{3}}
\qt@newcmd\qurantrans@es@mccxxxix{excepto aquellos de los politeístas con quienes hicisteis un pacto y luego no han violado nada de él ni han apoyado a nadie contra vosotros. Así pues, cumplid con el pacto que tengáis con ellos hasta su término. En verdad, Dios ama a quienes son temerosos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mccxl{Y, cuando los meses sagrados hayan concluido, matad a los politeístas donde quiera que los encontréis. Apresadles, sitiadles, acechadles en cada recodo, pero si se arrepienten y hacen la oración y entregan el impuesto religioso, dejadles paso libre. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mccxli{Y si uno de los politeístas te pide asilo, ofréceselo hasta que oiga la palabra de Dios y luego hazle llegar a un lugar seguro para él. Eso es porque son un pueblo que no sabe.\qt@no{6}}
\qt@newcmd\qurantrans@es@mccxlii{¿Cómo podrían tener los politeístas un pacto con Dios y Su Mensajero, excepto aquellos con los que pactasteis junto a la Mezquita Sagrada? Mientras ellos cumplan con vosotros, nosotros cumplid con ellos. En verdad, Dios ama a quienes son temerosos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mccxliii{¿Cómo? Si cuando os vencen no respetan pacto ni acuerdo alguno. Tratan de complaceros con sus bocas, pero sus corazones os rechazan y la mayoría de ellos son transgresores.\qt@no{8}}
\qt@newcmd\qurantrans@es@mccxliv{Han vendido las señales de Dios por poco precio y apartado a la gente de Su camino. ¡Qué malo es lo que han hecho!\qt@no{9}}
\qt@newcmd\qurantrans@es@mccxlv{No respetan pacto ni acuerdo con un creyente. ¡Ellos son los transgresores!\qt@no{10}}
\qt@newcmd\qurantrans@es@mccxlvi{Pero si se arrepienten y hacen la oración y entregan el impuesto religioso serán vuestros hermanos en la creencia. Nosotros explicamos detalladamente las señales para un pueblo que sabe.\qt@no{11}}
\qt@newcmd\qurantrans@es@mccxlvii{Pero si rompen sus promesas después de haberse comprometido e insultan vuestra creencia, combatid a los dirigentes de la incredulidad. En verdad, para ellos no existen promesas. Quizás así desistan.\qt@no{12}}
\qt@newcmd\qurantrans@es@mccxlviii{¿No combatiréis contra gentes que rompen sus promesas, que pretenden expulsar al Mensajero y que inician las hostilidades contra vosotros? ¿Vais a temerles? Dios tiene más derecho a que le temáis si sois creyentes.\qt@no{13}}
\qt@newcmd\qurantrans@es@mccxlix{¡Combatidles! Dios les castigará con vuestras manos y les avergonzará y a vosotros os auxiliará contra ellos, curará los pechos de la gente creyente\qt@no{14}}
\qt@newcmd\qurantrans@es@mccl{y eliminará la ira de sus corazones. Dios acepta el arrepentimiento de quien Él quiere. Dios todo lo conoce, es sabio.\qt@no{15}}
\qt@newcmd\qurantrans@es@mccli{¿O pensasteis que seríais perdonados antes de que Dios supiera quién de vosotros ha combatido y no ha tomado por confidente a nadie más que a Dios y a Su Mensajero y a los creyentes? Dios está bien informado de lo que hacéis.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcclii{No corresponde a los politeístas la reparación de las mezquitas de Dios, cuando ellos mismos dan testimonio de su propia incredulidad. Ellos mismos han invalidado sus obras y estarán en el Fuego eternamente.\qt@no{17}}
\qt@newcmd\qurantrans@es@mccliii{En verdad, quien debe reparar las mezquitas de Dios es quien cree en Dios y en el Último Día y hace la oración y da el impuesto religioso y sólo teme a Dios. Puede que así ellos sean guiados.\qt@no{18}}
\qt@newcmd\qurantrans@es@mccliv{¿Acaso el que suministréis agua a los peregrinos y la reparación de la Mezquita Sagrada es equiparable a quien cree en Dios y en el Último Día y combate en la senda de Dios? No son iguales ante Dios y Dios no guía a la gente opresora.\qt@no{19}}
\qt@newcmd\qurantrans@es@mcclv{Quienes creyeron y emigraron y combatieron por la causa de Dios con sus bienes y sus personas poseen un grado mayor ante Dios y ellos son los triunfadores.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcclvi{Su Señor les anuncia una misericordia que de Él procede, satisfacción y Jardines en los que disfrutarán de delicias eternas.\qt@no{21}}
\qt@newcmd\qurantrans@es@mcclvii{En ellos estarán para siempre, eternamente. En verdad, Dios dispone junto a Sí de una recompensa inmensa.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcclviii{¡Oh, los que sois creyentes! No toméis a vuestros padres y hermanos por amigos si prefieren la incredulidad a la fe y quienes de vosotros les tomen por amigos, esos serán (también) opresores.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcclix{Di: «Si vuestros padres y vuestros hijos, vuestros hermanos, vuestras esposas, vuestro clan, los bienes que habéis obtenido, los negocios por cuyos beneficios teméis y las casas que os satisfacen, os son más queridos que Dios y Su Mensajero y que el esfuerzo por Su causa, entonces aguardad hasta que Dios emita Su veredicto, pues Dios no guía a la gente transgresora.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mcclx{En verdad, Dios os ha auxiliado en numerosos lugares y (especialmente) el día de Hunayn, cuando vuestro gran número os llenó de alegría. Pero no os benefició en nada y la tierra se os hizo estrecha a pesar de su amplitud y, en ese momento, volvisteis la espalda para huir.\qt@no{25}}
\qt@newcmd\qurantrans@es@mcclxi{Entonces Dios hizo que descendiera Su calma sobre Su Mensajero y los creyentes e hizo descender ejércitos que vosotros no veíais y castigó a los que no creían. Esa es la recompensa de los que no creen.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcclxii{Luego, tras ello, Dios aceptará el arrepentimiento de quien Él quiera. Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{27}}
\qt@newcmd\qurantrans@es@mcclxiii{¡Oh, los que creéis! En verdad, los idólatras son impuros. ¡Que no se acerquen a la Mezquita Sagrada después de este año! Y si teméis la pobreza, Dios os enriquecerá con Su favor si Él quiere. En verdad, Dios todo lo conoce, es sabio.\qt@no{28}}
\qt@newcmd\qurantrans@es@mcclxiv{Combatid a quienes, de aquellos a los que les fue dada la Escritura [Sagrada], no creen en Dios ni en el Último Día y no prohíben lo que Dios y Su Mensajero han prohibido, ni practican la religión de la Verdad, hasta que paguen sus impuestos con su propia mano y con humildad.\qt@no{29}}
\qt@newcmd\qurantrans@es@mcclxv{Los judíos dicen: «Uzair es el hijo de Dios» y los cristianos dicen: «El Mesías es el hijo de Dios.» Eso es lo que dicen con sus bocas. Imitan lo que dijeron anteriormente los que no creían. ¡Que Dios les maldiga por sus mentiras!\qt@no{30}}
\qt@newcmd\qurantrans@es@mcclxvi{Han tomado a sus doctores de la ley y a sus sacerdotes por sus señores en lugar de Dios, así como al Mesías hijo de María, a pesar de que se les ordenó que adoraran solamente al Dios Uno. No hay otro dios excepto Él. ¡Glorificado sea por encima de lo que Le asocian!\qt@no{31}}
\qt@newcmd\qurantrans@es@mcclxvii{Quisieran apagar la luz de Dios con sus bocas, pero Dios no quiere sino que Su luz brille plenamente, aunque moleste a los que no creen.\qt@no{32}}
\qt@newcmd\qurantrans@es@mcclxviii{Él es Quien ha enviado a Su Mensajero con la guía y con la religión de la Verdad para que prevalezca sobre todas las otras creencias religiosas, aunque moleste a los que no creen.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcclxix{¡Oh, los que creéis! En verdad, muchos de los doctores de la ley y de los sacerdotes se comen, sin derecho, los bienes de la gente y les apartan del camino de Dios. Y, a quienes atesoran el oro y la plata y no los gastan por la causa de Dios, anúnciales un castigo doloroso\qt@no{34}}
\qt@newcmd\qurantrans@es@mcclxx{el día en que (esos metales) sean calentados en el fuego del Infierno y se marquen con ellos sus frentes, sus costados y sus espaldas. «¡Esto era lo que atesorabais para vuestras almas! ¡Saboread pues lo que atesorasteis!»\qt@no{35}}
\qt@newcmd\qurantrans@es@mcclxxi{En verdad, el número de meses para Dios es de doce. Es así en la Escritura de Dios desde el día en que creó los cielos y la Tierra. De ellos, cuatro son sagrados. Esa es la religión establecida. Así pues, no os oprimáis durante ellos a vosotros mismos y combatid contra todos los idólatras igual que ellos combaten contra todos vosotros y sabed que Dios está con quienes son temerosos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcclxxii{En verdad, trasladar la inviolabilidad de un mes a otro es un incremento en la idolatría con el que se extravían los politeístas. Lo declaran lícito un año y lo sacralizan otro año, para que coincida con el número de meses que Dios ha declarado sagrados, haciendo lícito lo que Dios ha considerado inviolable. Sus malos actos les parecen bellos, pero Dios no guía a la gente que oculta la Verdad.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcclxxiii{¡Oh, los que creéis! ¡Qué sucede con vosotros! Cuando se os dice: ¡Salid a combatir por la causa de Dios! os quedáis pegados al suelo. ¿Acaso os satisface más la vida mundanal que la otra? Pues el disfrute de la vida mundanal comparado con el de la otra es muy poca cosa.\qt@no{38}}
\qt@newcmd\qurantrans@es@mcclxxiv{Si no salís a combatir Él os castigará con un castigo doloroso y os cambiará por un pueblo diferente sin que e causéis ningún perjuicio. Dios tiene poder sobre todas las cosas.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcclxxv{Si no le auxiliáis ya Dios le auxilió cuando le hicieron salir los que no tenían fe y era el segundo de dos y ambos estaban en la cueva y le dijo a su compañero: «No estés triste, en verdad, Dios está con nosotros.» Y Dios hizo descender Su calma sobre él y le ayudó con ejércitos que vosotros no visteis y puso la palabra de los que no son creyentes en la posición más baja, pues la palabra de Dios es la más elevada y Dios es poderoso, sabio.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcclxxvi{¡Salid a la batalla, ligeros o pesados, y combatid con vuestros bienes y vuestras personas por la causa de Dios. Eso es mejor para vosotros. Si supierais...\qt@no{41}}
\qt@newcmd\qurantrans@es@mcclxxvii{Si hubiera sido una ganancia asequible o un viaje corto seguramente te habrían seguido, pero les pareció una gran distancia. Jurarán por Dios: «Si hubiéramos podido, habríamos ido contigo.» Se destruyen ellos mismos y Dios sabe que son unos mentirosos.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcclxxviii{¡Que Dios te perdone! ¿Por qué les diste permiso antes de que te quedase claro quiénes eran sinceros y supieses quiénes eran los mentirosos?\qt@no{43}}
\qt@newcmd\qurantrans@es@mcclxxix{Quienes creen en Dios y en el Último Día no te pedirán que les excuses de combatir con sus bienes y sus personas y Dios conoce a los que temen disgustarle.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcclxxx{En verdad, te piden que les excuses aquellos que no creen en Dios ni en el Último Día, que tienen dudas en sus corazones y sus dudas les hacen ser reluctantes.\qt@no{45}}
\qt@newcmd\qurantrans@es@mcclxxxi{Si hubiesen querido salir seguramente habrían realizado algunos preparativos para ello, pero a Dios le pareció desaconsejable enviarles y les hizo permanecer y se les dijo: «¡Quedaos sentados con los que se quedan!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mcclxxxii{Si hubieran ido con vosotros sólo os habrían ocasionado más problemas, difundiendo rumores y buscando causar sedición y entre vosotros algunos les habrían escuchado. Dios conoce bien a los opresores.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcclxxxiii{Ya anteriormente quisieron crear problemas y confundir las cosas para ti, hasta que vino la Verdad y se evidenció la orden de Dios, a despecho de ellos.\qt@no{48}}
\qt@newcmd\qurantrans@es@mcclxxxiv{Entre ellos hay quien dice: «Dispénsame y no me hagas pecar.» ¿Acaso no han caído ya en el pecado? En verdad, el Infierno rodea a los que no tienen fe.\qt@no{49}}
\qt@newcmd\qurantrans@es@mcclxxxv{Si te sucede algo bueno se entristecen, pero si te aflige alguna dificultad dicen: «Nosotros ya habíamos tomado nuestras precauciones anteriormente.» y se alejan llenos de alegría.\qt@no{50}}
\qt@newcmd\qurantrans@es@mcclxxxvi{Di: «No nos aflige excepto aquello que Dios tiene escrito para nosotros. Él es nuestro amigo y protector.» Así pues, que los creyentes confíen en Dios.\qt@no{51}}
\qt@newcmd\qurantrans@es@mcclxxxvii{Di: «¿Qué podéis esperar que nos suceda sino una de las dos cosas buenas? Mientras que nosotros esperamos que Dios os aflija con un castigo que venga directamente de Él o a través de nuestras manos. Así pues, ¡Esperad! ¡Que nosotros también esperaremos con vosotros!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mcclxxxviii{Di: «¡Gastad (en limosnas) de grado o a la fuerza! No os será aceptado. En verdad, sois una gente transgresora.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mcclxxxix{No hay nada que impida que lo que gastan sea aceptado, excepto que ellos no creen en Dios ni en Su Mensajero, que no acuden a la oración excepto con pereza y que no gastan en limosnas excepto a disgusto.\qt@no{54}}
\qt@newcmd\qurantrans@es@mccxc{No dejes pues que sus riquezas ni sus hijos te impresionen. En verdad, Dios quiere castigarles por medio de ello en la vida mundanal y que sus almas partan sin que ellos tengan fe.\qt@no{55}}
\qt@newcmd\qurantrans@es@mccxci{Juran por Dios que son de los vuestros, pero no son de los vuestros sino que son gente que os teme.\qt@no{56}}
\qt@newcmd\qurantrans@es@mccxcii{Si pudieran encontrar un refugio o una gruta o un agujero en el que meterse, se arrojarían a él a toda prisa.\qt@no{57}}
\qt@newcmd\qurantrans@es@mccxciii{Algunos de ellos te censuran por las limosnas. Si se les da de ellas están satisfechos, pero si no se les da de ellas se enfadan.\qt@no{58}}
\qt@newcmd\qurantrans@es@mccxciv{Mejor habría sido si hubieran estado satisfechos con lo que Dios y Su Mensajero les dieron y hubieran dicho: «Dios es suficiente para nosotros. Dios nos otorgará Su favor y también Su Mensajero. Nuestros deseos se dirigen a Él.»\qt@no{59}}
\qt@newcmd\qurantrans@es@mccxcv{En verdad, las limosnas son para los pobres y los necesitados, para los encargados de recaudarlas y para aquellos cuyos corazones se quiere atraer, para liberar esclavos, para los endeudados, para la causa de Dios y para el viajero. Es una disposición obligatoria procedente de Dios y Dios todo lo conoce, es sabio.\qt@no{60}}
\qt@newcmd\qurantrans@es@mccxcvi{Entre ellos hay quienes molestan al Profeta diciendo: «Es una oreja.» Di: «Es una buena oreja para vosotros. Tiene fe en Dios y confía en los creyentes y es una misericordia para aquellos de vosotros que tenéis fe.» Y para quienes molestan al Profeta hay un castigo doloroso.\qt@no{61}}
\qt@newcmd\qurantrans@es@mccxcvii{Os juran por Dios para satisfaceros, pero Dios y Su Mensajero tienen más derecho a que ellos les satisfagan, si es que son creyentes.\qt@no{62}}
\qt@newcmd\qurantrans@es@mccxcviii{¿Acaso no saben que el fuego del Infierno en el que estarán eternamente es para quienes se oponen a Dios y a Su Mensajero? ¡Esa es la gran desgracia!\qt@no{63}}
\qt@newcmd\qurantrans@es@mccxcix{Los hipócritas temen que descienda para ellos un capítulo que les informe de lo que hay en sus corazones. Di: «Burlaos, que, en verdad, Dios hará que se manifieste aquello que os atemoriza.»\qt@no{64}}
\qt@newcmd\qurantrans@es@mccc{Y si les preguntas, seguramente que dirán: «Nos divertíamos y jugábamos.» Di: «¿Os burlabais de Dios, de Sus señales y de Su Mensajero?\qt@no{65}}
\qt@newcmd\qurantrans@es@mccci{No os excuséis, pues habéis descreído después de haber creído.» Si perdonamos a un grupo de vosotros castigaremos a otro, porque han sido pecadores.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcccii{Los hipócritas, y las hipócritas son tal para cual, ordenan lo que está mal y prohíben lo que está bien y aprietan sus puños. Se olvidaron de Dios así que Él se olvidó de ellos. En verdad, los hipócritas son los transgresores.\qt@no{67}}
\qt@newcmd\qurantrans@es@mccciii{Dios ha prometido a los hipócritas y a las hipócritas y a los que no creen, el fuego del Infierno, en el que estarán eternamente. Eso es suficiente para ellos y Dios les maldice. Tendrán un castigo permanente.\qt@no{68}}
\qt@newcmd\qurantrans@es@mccciv{Hipócritas) sois como los que os precedieron. Eran más fuertes que vosotros y poseían más bienes e hijos y disfrutaron de su parte. Disfrutad vosotros de la vuestra como disfrutaron los que os precedieron de la suya. Os habéis dado a la frivolidad como ellos se dieron a la frivolidad. Ellos arruinaron sus obras en esta vida y en la otra y ellos son los perdedores.\qt@no{69}}
\qt@newcmd\qurantrans@es@mcccv{¿Acaso no llegó a ellos la noticia de quienes les precedieron: los pueblos de Noé, de Ad, de Tamud, el pueblo de Abraham y la gente de Madyan y de las ciudades que fueron vueltas del revés? Vinieron a ellos sus Mensajeros con las pruebas claras. No fue Dios quien les oprimió sino que fueron ellos mismos quienes se oprimieron.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcccvi{Y los creyentes y las creyentes son amigos y protectores los unos de los otros. Ordenan lo que es bueno y prohíben lo que es malo y hacen la oración, dan el impuesto religioso y obedecen a Dios y a Su Mensajero. Es con ellos con quien Dios será misericordioso. En verdad, Dios es poderoso, sabio.\qt@no{71}}
\qt@newcmd\qurantrans@es@mcccvii{Dios ha prometido a los creyentes y a las creyentes Jardines de cuyas profundidades brotan los ríos, en los que estarán eternamente y moradas agradables en los Jardines del Edén. Pero obtener la satisfacción de Dios es algo más grande. ¡Ése es el triunfo inmenso!\qt@no{72}}
\qt@newcmd\qurantrans@es@mcccviii{¡Oh, Profeta! Combate a los que no creen y a los hipócritas y sé severo con ellos. Su refugio será el Infierno. ¡Qué mal destino!\qt@no{73}}
\qt@newcmd\qurantrans@es@mcccix{Juran por Dios que no dijeron, pero sí que dijeron, palabras propias de no creyentes y dejaron de creer después de haber aceptado el Islam. Ansiaron lo que no pudieron conseguir y su único reproche es que Dios y Su Mensajero les enriquecieron con Su favor. Así pues, si se arrepintiesen sería mejor para ellos. Pero si dan la espalda Dios les castigará con un castigo doloroso en esta vida y en la otra y no tendrán en la Tierra quien les proteja ni quien les auxilie.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcccx{Y, entre ellos, algunos acordaron con Dios: «Si nos otorga Su favor, daremos limosnas y seremos virtuosos.»\qt@no{75}}
\qt@newcmd\qurantrans@es@mcccxi{Pero cuando Él les otorga algo de Su favor son avariciosos de ello y dan la espalda y se desentienden.\qt@no{76}}
\qt@newcmd\qurantrans@es@mcccxii{Eso causará la hipocresía en sus corazones hasta el día en que se encuentren con Él por haber faltado al acuerdo que hicieron con Dios y por haber sido mentirosos.\qt@no{77}}
\qt@newcmd\qurantrans@es@mcccxiii{¿Acaso no sabían que Dios conoce sus secretos y sus conversaciones privadas y que Dios conoce lo que está oculto a los sentidos?\qt@no{78}}
\qt@newcmd\qurantrans@es@mcccxiv{Dios se burlará de quienes critican a los creyentes que dan limosnas voluntariamente y se burlan de quienes apenas encuentran algo que dar. Y tendrán un castigo doloroso.\qt@no{79}}
\qt@newcmd\qurantrans@es@mcccxv{Puedes pedir perdón por ellos o no pedir perdón por ellos, pero aunque pidas perdón por ellos setenta veces Dios no les perdonará. Eso es por no haber creído en Dios ni en Su Mensajero. Y Dios no guía a la gente transgresora.\qt@no{80}}
\qt@newcmd\qurantrans@es@mcccxvi{Quienes se quedaron atrás tras la partida del Mensajero se alegraron de quedarse y de haberse opuesto a él, pues les repugnaba la idea de combatir con sus bienes y sus personas por la causa de Dios y dijeron: «No salgáis con este calor.» Di: «El Fuego del Infierno es más abrasador.» Si entendieran...\qt@no{81}}
\qt@newcmd\qurantrans@es@mcccxvii{Así pues, que rían poco y lloren mucho en recompensa por lo que han hecho y han obtenido.\qt@no{82}}
\qt@newcmd\qurantrans@es@mcccxviii{Y si Dios hace regresar a ti a un grupo de ellos y te piden permiso para salir a luchar contigo, di: «No saldréis conmigo jamás, ni combatiréis conmigo a los enemigos. En verdad, estuvisteis satisfechos de quedaros la primera vez, así que quedaos con los que se quedan.\qt@no{83}}
\qt@newcmd\qurantrans@es@mcccxix{Y no reces jamás por ninguno de ellos cuando mueran, ni visites sus tumbas, ya que ellos no creyeron en Dios ni en Su Mensajero y murieron siendo transgresores.\qt@no{84}}
\qt@newcmd\qurantrans@es@mcccxx{Y que no te impresionen sus riquezas y sus hijos, porque, en verdad, Dios quiere con ello castigarles en esta vida y que sus almas les abandonen mientras aun son de los que no creen.\qt@no{85}}
\qt@newcmd\qurantrans@es@mcccxxi{Y cuando desciende un capítulo (diciendo): «¡Creed en Dios y combatid junto a Su Mensajero!» los poderosos de entre ellos te piden permiso y dicen: «Deja que seamos de los que se quedan.»\qt@no{86}}
\qt@newcmd\qurantrans@es@mcccxxii{Están satisfechos de quedarse con los que se quedan atrás. Sus corazones están sellados y no entienden.\qt@no{87}}
\qt@newcmd\qurantrans@es@mcccxxiii{Pero el Mensajero y los que creyeron con él combaten con sus bienes y con sus personas y para ellos serán las cosas buenas y ellos serán los triunfadores.\qt@no{88}}
\qt@newcmd\qurantrans@es@mcccxxiv{Dios ha preparado para ellos Jardines de cuyas profundidades brotan los arroyos, en los que estarán eternamente. Ese es el triunfo inmenso.\qt@no{89}}
\qt@newcmd\qurantrans@es@mcccxxv{Y algunos beduinos que se excusan vienen a que se les de permiso, pero los que mintieron a Dios y a Su Mensajero se quedan sentados. Los que de ellos no creen pronto padecerán un castigo doloroso.\qt@no{90}}
\qt@newcmd\qurantrans@es@mcccxxvi{No hay razón para ir contra los débiles, ni los enfermos, ni quienes no disponen de medios, ni contra los que obran bien, siempre que alberguen buenos deseos para Dios y Su Mensajero. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{91}}
\qt@newcmd\qurantrans@es@mcccxxvii{Ni tampoco contra aquellos a quienes, cuando vinieron a ti para que les proporcionases monturas, les dijiste: «No encuentro monturas para vosotros» y se dieron la vuelta con los ojos llenos de lagrimas de la tristeza por no encontrar medios,\qt@no{92}}
\qt@newcmd\qurantrans@es@mcccxxviii{pero sí contra aquellos que te piden permiso siendo ricos. Están satisfechos de estar con los que se quedan atrás. Dios selló sus corazones, así que ellos no saben.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcccxxix{Os ofrecerán sus excusas cuando regreséis a ellos. Di: «No os excuséis. Nunca os creeremos, pues Dios nos ha informado sobre vosotros. Y Dios y Su Mensajero ven vuestros actos. Luego, seréis devueltos al Conocedor de lo oculto y lo manifiesto y Él os informará de lo que hacíais.»\qt@no{94}}
\qt@newcmd\qurantrans@es@mcccxxx{Pronto os jurarán por Dios, cuando volváis a ellos, para que cambiéis de opinión sobre ellos. ¡Apartaos de ellos! Verdaderamente, son malvados y pecadores y su morada será el Infierno, recompensa por lo que obtuvieron con su comportamiento.\qt@no{95}}
\qt@newcmd\qurantrans@es@mcccxxxi{Os jurarán para que estéis a bien con ellos, pero, aunque les aceptéis, en verdad, Dios no acepta a la gente transgresora.\qt@no{96}}
\qt@newcmd\qurantrans@es@mcccxxxii{Los beduinos son los que menos creen, los más hipócritas y los más propensos a ignorar las leyes que Dios hizo descender sobre Su Mensajero. Y Dios todo lo conoce, es sabio.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcccxxxiii{Y, entre los beduinos, hay quienes consideran un perjuicio económico lo que gastan y desean que os suceda algo malo. ¡Que algo malo les suceda a ellos! Y Dios todo lo oye, todo lo sabe.\qt@no{98}}
\qt@newcmd\qurantrans@es@mcccxxxiv{Y, entre los beduinos, hay quienes creen en Dios y en el Último Día y consideran lo que gastan y las bendiciones que piden para el Mensajero medios para obtener mayor cercanía a Dios. ¿Acaso no son para ellos un medio de obtener cercanía? Dios les hará entrar en Su misericordia. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{99}}
\qt@newcmd\qurantrans@es@mcccxxxv{De la vanguardia de los primeros emigrantes y auxiliares y de quienes les siguieron en hacer el bien Dios está satisfecho y ellos están satisfechos de Él. Y Él les ha preparado Jardines de cuyas profundidades brotan los ríos, en los que estarán eternamente. ¡Ése es el triunfo grandioso!\qt@no{100}}
\qt@newcmd\qurantrans@es@mcccxxxvi{Y entre los beduinos que están alrededor vuestro y también entre la gente de Medina hay hipócritas que practican la hipocresía con asiduidad. Tú no les conoces pero Nosotros es conocemos. Pronto les castigaremos dos veces. Luego serán destinados a un castigo inmenso.\qt@no{101}}
\qt@newcmd\qurantrans@es@mcccxxxvii{Y otros, que reconocen sus pecados, han mezclado actos buenos y otros malos. Puede que Dios acepte su arrepentimiento. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{102}}
\qt@newcmd\qurantrans@es@mcccxxxviii{Toma de sus riquezas una limosna para limpiarles y purificarles por medio de ella y reza por ellos. En verdad, tu oración es una tranquilidad para ellos. Y Dios todo lo oye, todo lo sabe.\qt@no{103}}
\qt@newcmd\qurantrans@es@mcccxxxix{¿Acaso no saben que Dios es Quien acepta el arrepentimiento de Sus siervos y Quien toma la limosna y que Dios es el Perdonador, el Misericordiosísimo con los creyentes?\qt@no{104}}
\qt@newcmd\qurantrans@es@mcccxl{Y di: «Haced lo que queráis, que Dios verá vuestras obras, y también Su Mensajero y los creyentes. Y pronto seréis llevados hacia el Conocedor de lo oculto y lo manifiesto y Él os informará de lo que hacíais.»\qt@no{105}}
\qt@newcmd\qurantrans@es@mcccxli{Otros estarán a la espera de lo que Dios ordene: que les castigue o que les perdone. Y Dios todo lo conoce, es sabio.\qt@no{106}}
\qt@newcmd\qurantrans@es@mcccxlii{Y quienes hicieron una mezquita para hacer daño y para ocultar la verdad, para crear división entre los creyentes y servir de refugio a quienes combatieron anteriormente a Dios y a Su Mensajero, con seguridad, jurarán: «Sólo queríamos el bien» pero Dios es testigo de que ellos mienten.\qt@no{107}}
\qt@newcmd\qurantrans@es@mcccxliii{¡No asistas a ella jamás! Una mezquita fundada sobre el temor de Dios desde el primer día tiene más derecho a que asistas a ella. En ella hay hombres que aman purificarse y Dios ama a los que se purifican.\qt@no{108}}
\qt@newcmd\qurantrans@es@mcccxliv{¿Quién es mejor? ¿Quien ha fundado su edificio sobre el temor de Dios y Su satisfacción o quien ha fundado su edificio al borde de un precipicio a punto de desmoronarse y que le arrastrará al fuego del Infierno? Y Dios no guía a la gente opresora.\qt@no{109}}
\qt@newcmd\qurantrans@es@mcccxlv{El edificio que han construido no cesará de inquietar sus corazones hasta que sus corazones se despedacen. Y Dios todo lo conoce, es sabio.\qt@no{110}}
\qt@newcmd\qurantrans@es@mcccxlvi{En verdad, Dios ha comprado a los creyentes sus personas y sus bienes porque para ellos es el Jardín. Combaten por la causa de Dios y matan y son matados. Es un compromiso cierto que Él ha asumido en la Torá, el Evangelio y el Corán. Y ¿Quién es más leal a sus pactos que Dios? ¡Alegraos de la beneficiosa transacción que habéis realizado! ¡Eso sí que es el triunfo grandioso!\qt@no{111}}
\qt@newcmd\qurantrans@es@mcccxlvii{[Los creyentes son] Los que se arrepienten, los que adoran a Dios, los que Le alaban, los que viajan a las mezquitas, los que se inclinan ante Dios, los que se prosternan ante Él, los que ordenan el bien y prohíben el mal y los que protegen las leyes de Dios. ¡Anuncia la buena nueva a los creyentes!\qt@no{112}}
\qt@newcmd\qurantrans@es@mcccxlviii{No es apropiado que el Profeta y los creyentes pidan el perdón para los idólatras, aunque sean sus parientes cercanos, después de habérseles explicado claramente que ellos son gente destinada al Infierno.\qt@no{113}}
\qt@newcmd\qurantrans@es@mcccxlix{El perdón que Abraham pidió para su padre no fue sino en cumplimiento de una promesa que le había hecho, pero cuando le quedó claro que él era enemigo de Dios se apartó de él. En verdad, Abraham era piadoso, tolerante.\qt@no{114}}
\qt@newcmd\qurantrans@es@mcccl{Y Dios no extravía a un pueblo después de haberle guiado sin antes explicarle claramente aquello que debe temer y evitar. En verdad, Dios conoce todas las cosas.\qt@no{115}}
\qt@newcmd\qurantrans@es@mcccli{En verdad, a Dios pertenece el gobierno de los cielos y la Tierra. Él da la vida y la muerte y no tenéis aparte de Dios ni amigo ni protector ni quien pueda auxiliaros.\qt@no{116}}
\qt@newcmd\qurantrans@es@mccclii{Ciertamente, Dios se ha vuelto con misericordia hacia el Mensajero y los emigrantes y los auxiliares que le siguieron a la hora de la dificultad, después de que los corazones de un grupo de ellos estuviesen a punto de desviarse, y les ha perdonado. En verdad, Él es para ellos compasivo, misericordiosísimo.\qt@no{117}}
\qt@newcmd\qurantrans@es@mcccliii{Y hacia los tres que se quedaron, hasta que la Tierra, con toda su amplitud, se les hizo estrecha y sus propias almas se angustiaron y supieron que no podrían refugiarse de Dios excepto en Él mismo. Luego, Él se volvió a ellos con misericordia para que pudiesen arrepentirse. En verdad, Dios es Quien acepta el arrepentimiento, el Misericordiosísimo con los creyentes.\qt@no{118}}
\qt@newcmd\qurantrans@es@mcccliv{¡Oh, los que creéis! ¡Sed temerosos de Dios y estad con los sinceros!\qt@no{119}}
\qt@newcmd\qurantrans@es@mccclv{No es adecuado para la gente de Medina y para los beduinos que hay alrededor de ellos que se queden atrás del Mensajero de Dios, ni preferirse a ellos mismos antes que a él, ya que no sufrirán sed ni cansancio ni hambre en la senda de Dios. Ni darán ningún paso que irrite a los que no son creyentes, ni soportarán golpe alguno de sus enemigos sin que sea consignado para ellos como una buena obra. En verdad, Dios no deja que se pierda la recompensa de los que hacen el bien.\qt@no{120}}
\qt@newcmd\qurantrans@es@mccclvi{Y no realizarán gasto alguno, sea poco o mucho, ni cruzarán valle alguno sin que quede escrito para ellos y Dios les recompense por ello como lo mejor que han hecho.\qt@no{121}}
\qt@newcmd\qurantrans@es@mccclvii{No es adecuado que todos los creyentes salgan de expedición. ¿Por qué no viajan algunos de cada grupo para ser instruidos en la religión y que amonesten a los suyos cuando regresen a ellos y así, quizás, sean temerosos?\qt@no{122}}
\qt@newcmd\qurantrans@es@mccclviii{¡Oh, los que creéis! Combatid a los incrédulos que tenéis en vuestra vecindad. Y que os encuentren firmes y duros y sabed que Dios está con quienes son temerosos.\qt@no{123}}
\qt@newcmd\qurantrans@es@mccclix{Y, cuando se hace descender un capítulo, hay entre ellos alguno que dice: «¿A quién de vosotros le ha incrementado la fe con él?» Pero a quienes son creyentes ello les incrementa la fe y les hace felices.\qt@no{124}}
\qt@newcmd\qurantrans@es@mccclx{Y a quienes tienen sus corazones enfermos les añade mal a su mal y mueren sin tener fe.\qt@no{125}}
\qt@newcmd\qurantrans@es@mccclxi{¿Acaso no ven que son puestos a prueba cada año una o dos veces? Pero ellos ni se arrepienten ni recapacitan.\qt@no{126}}
\qt@newcmd\qurantrans@es@mccclxii{Y, cuando se hace descender un capítulo, se miran unos a otros: “¿Os ha visto alguien? y se dan la vuelta. Dios dará la vuelta a sus corazones porque son una gente que no comprende.\qt@no{127}}
\qt@newcmd\qurantrans@es@mccclxiii{Ciertamente, ha venido a vosotros un Mensajero de entre vosotros mismos al que le abruma vuestro sufrimiento, se preocupa por vosotros y con los creyentes es compasivo, misericordioso.\qt@no{128}}
\qt@newcmd\qurantrans@es@mccclxiv{Y si (a pesar de todo ello) te vuelven la espalda, di: «Dios es suficiente para mí. No hay más dios que Él. En Él confío y Él es el Señor del Trono inmenso.»\qt@no{129}}
\qt@newcmd\qurantrans@es@mccclxv{\basmalahes Alif, lam, ra. Esos son los versículos de la Escritura sabia.\qt@no{1}}
\qt@newcmd\qurantrans@es@mccclxvi{¿Acaso sorprende a las personas que Nosotros hayamos revelado a un hombre de entre ellos: «Amonesta a las gentes y anuncia a los creyentes la buena nueva de que hay para ellos una posición de Verdad junto a Su Señor»? Quienes no creen dicen: «En verdad, éste es un mago evidente.»\qt@no{2}}
\qt@newcmd\qurantrans@es@mccclxvii{En verdad, vuestro Señor es Dios, Quien creó los cielos y la Tierra en seis días. Luego se situó sobre Su trono, dirigiendo el asunto. No hay nadie que pueda interceder sino después de haber obtenido Su permiso. Ése es Dios ¡Adoradle, pues! ¿Es que no os dejaréis amonestar?\qt@no{3}}
\qt@newcmd\qurantrans@es@mccclxviii{A Él regresaréis todos. La promesa de Dios es verdadera. Él inicia la Creación y luego la hace regresar (a Él) para recompensar con equidad a quienes creyeron y obraron rectamente. Y aquellos que no creyeron tendrán una bebida de agua hirviente y un castigo doloroso por haber ocultado la Verdad.\qt@no{4}}
\qt@newcmd\qurantrans@es@mccclxix{Él es Quien hizo al Sol resplandecer y a la Luna iluminar y estableció en ella fases para que conozcáis el número de los años y la cuenta. Dios no ha creado esto sino con la Verdad. Él explica detalladamente las señales para un pueblo que posee conocimiento.\qt@no{5}}
\qt@newcmd\qurantrans@es@mccclxx{En verdad, en la diferencia de la noche y el día y en lo que Dios creó en los cielos y en la Tierra hay señales para una gente que es temerosa.\qt@no{6}}
\qt@newcmd\qurantrans@es@mccclxxi{En verdad, quienes no esperan encontrarse con Nosotros y están satisfechos de la vida mundanal y seguros de ella y quienes no prestan atención a Nuestras señales\qt@no{7}}
\qt@newcmd\qurantrans@es@mccclxxii{tendrán de morada el Fuego por lo que obtenían con sus actos.\qt@no{8}}
\qt@newcmd\qurantrans@es@mccclxxiii{En verdad, a quienes creen y obran rectamente, Dios les guía por medio de su fe. Correrán a sus pies los ríos en los Jardines de las Delicias.\qt@no{9}}
\qt@newcmd\qurantrans@es@mccclxxiv{La invocación de ellos allí será: «¡Glorificado seas, Oh Dios!» y entre ellos se saludarán: «¡Paz!» y al final de su invocación: «¡Alabado sea Dios, Señor de los mundos!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mccclxxv{Si Dios apresurase la llegada del mal para los hombres de la misma manera que estos desean que se apresure la llegada de lo bueno, su plazo ya se habría cumplido, pero dejamos que quienes no esperan encontrarse con Nosotros vaguen errantes en su rebeldía.\qt@no{11}}
\qt@newcmd\qurantrans@es@mccclxxvi{Cuando alguien sufre un perjuicio Nos invoca acostado, sentado o de pie, pero cuando eliminamos el mal que le aquejaba pasa como si no Nos hubiera suplicado por el mal que le aquejaba. Así es como les son adornados sus actos a los despilfarradores.\qt@no{12}}
\qt@newcmd\qurantrans@es@mccclxxvii{Ciertamente, destruimos a otras generaciones anteriores a vosotros cuando fueron opresores y vinieron a ellos sus Mensajeros con las pruebas claras pero no creyeron. Así recompensamos a la gente pecadora.\qt@no{13}}
\qt@newcmd\qurantrans@es@mccclxxviii{Luego, tras ellos, os pusimos como herederos en la Tierra para observar como actuabais.\qt@no{14}}
\qt@newcmd\qurantrans@es@mccclxxix{Y, cuando se les recitan Nuestros claros versículos, quienes no esperan encontrarse con Nosotros dicen: «Tráenos otro Corán o altéralo.» Di: «Yo no puedo alterarlo por iniciativa propia. Yo sólo sigo lo que se me ha revelado. En verdad, temo, si desobedezco a mi Señor, el castigo de un día inmenso.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mccclxxx{Di: «Si Dios hubiera querido yo no os lo habría recitado ni Él os lo habría dado a conocer. Antes de ello he permanecido entre vosotros una vida. Es que no razonaréis.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mccclxxxi{¿Quién es más opresor que quien inventa mentiras sobre Dios o desmiente Sus señales? En verdad, los pecadores no triunfarán.\qt@no{17}}
\qt@newcmd\qurantrans@es@mccclxxxii{Y adoran, aparte de Dios, lo que no les perjudica ni les beneficia y dicen: «¡Éstos son nuestros intercesores ante Dios!» Di: «¿Vais a informar a Dios de algo que Él no sepa de los cielos o de la Tierra? Glorificado y Ensalzado sea por encima de lo que asocian a Él.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mccclxxxiii{Los humanos eran una sola comunidad pero disintieron entre ellos y si no hubiera sido por una disposición previa de tu Señor ya se habría juzgado entre ellos sobre aquello en lo que disentían.\qt@no{19}}
\qt@newcmd\qurantrans@es@mccclxxxiv{Y dicen: «¿Por qué no se ha hecho que descienda sobre él una señal procedente de Su señor?» Di: «En verdad, lo oculto pertenece a Dios, así pues, esperad, que yo también esperaré con vosotros.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mccclxxxv{Y cuando hacemos probar a la gente una misericordia después de haberles tocado una desgracia, ellos traman contra Nuestras señales. Di: «Dios es más rápido tramando.» En verdad, Nuestros enviados escriben lo que tramáis.\qt@no{21}}
\qt@newcmd\qurantrans@es@mccclxxxvi{Y Él es Quien os lleva de viaje por la tierra y el mar. Cuando estáis en el barco navegando con viento favorable y disfrutando de ello y llega un viento tempestuoso y las olas llegan a ellos por todos lados y se sienten rodeados (por la muerte), invocan a Dios con una creencia sincera: «Si nos salvas de ésta seremos, ciertamente, de los agradecidos.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mccclxxxvii{Pero cuando Él les salva, vuelven a comportarse injustamente en la Tierra, sin derecho. ¡Oh, gentes! En verdad, vuestra injusticia caerá sobre vosotros. Disfrutaréis de la vida mundanal, luego regresaréis a Nosotros y os informaremos de lo que hacíais.\qt@no{23}}
\qt@newcmd\qurantrans@es@mccclxxxviii{En verdad, la vida de este mundo es como el agua que Nosotros hacemos descender del cielo. Se nutre con ella la vegetación de la Tierra, de la cual comen las personas y el ganado. Hasta que, cuando la Tierra se ha embellecido y adornado y sus gentes creen que tienen poder sobre ella, llega a ella Nuestra orden, por la noche o por el día, y la dejamos como si hubiera sido cosechada, como si no hubiera estado florecida el día anterior. Así explicamos detalladamente las señales para gente que reflexiona.\qt@no{24}}
\qt@newcmd\qurantrans@es@mccclxxxix{Y Dios invita a la morada de la paz y dirige hacia el camino recto a quien Él quiere.\qt@no{25}}
\qt@newcmd\qurantrans@es@mcccxc{Quienes hacen el bien recibirán el mismo bien y más en recompensa y ni el polvo ni la humillación cubrirán sus rostros. Esos son los habitantes del Paraíso, en el que vivirán eternamente.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcccxci{Y quienes hagan el mal tendrán de recompensa el mismo mal y les cubrirá la humillación. No tendrán nadie que les proteja de Dios. Como si sus rostros fueran cubiertos por un fragmento de la noche tenebrosa. Esos son los habitantes del Fuego, en el que estarán eternamente.\qt@no{27}}
\qt@newcmd\qurantrans@es@mcccxcii{Y, el día en que les reunamos a todos ellos, diremos a quienes equipararon a otros dioses a Dios: «Quedaos en vuestro sitio, vosotros y aquellos a quienes adorabais.» Y les separaremos a unos de otros y dirán sus asociados: «No era a nosotros a quienes adorabais\qt@no{28}}
\qt@newcmd\qurantrans@es@mcccxciii{y Dios basta como testigo entre nosotros y vosotros de que nosotros desconocíamos vuestra adoración.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mcccxciv{Allí, cada alma examinará lo que hizo anteriormente y serán devueltos a Dios, su verdadero Señor, y se alejarán de ellos aquellos que inventaron.\qt@no{30}}
\qt@newcmd\qurantrans@es@mcccxcv{Di: «¿Quién os procura el sustento del cielo y de la Tierra? ¿Quién posee el oído y la vista? ¿Quién hace salir la vida de la muerte y la muerte de la vida? y ¿Quién dirige todo?» Dirán: «Dios» Di, pues: «¿Es que no seréis temerosos (de Él)?»\qt@no{31}}
\qt@newcmd\qurantrans@es@mcccxcvi{Ese es Dios, vuestro verdadero Señor. Y ¿Qué hay después de la Verdad excepto el extravío? Así pues ¿Por qué os apartáis?\qt@no{32}}
\qt@newcmd\qurantrans@es@mcccxcvii{Así se ha verificado la palabra de tu Señor sobre los transgresores, de que ellos no creerán.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcccxcviii{Di: «¿Existe entre aquellos que adoráis alguno que origine la Creación y luego la haga regresar a él?» Di: «¡Dios es Quién origina la Creación y luego la hace regresar a Él! Entonces ¿Por qué os apartáis (de la Verdad)?»\qt@no{34}}
\qt@newcmd\qurantrans@es@mcccxcix{Di: «¿Existe, entre aquellos que adoráis, alguno que guíe hacia la Verdad?» Di: «¡Dios es Quien guía hacia la Verdad! ¿Quién tiene más derecho a ser seguido, quien guía hacia la Verdad o quien no guía a no ser que él mismo sea guiado? ¿Qué pasa entonces con vosotros, que juzgáis de esa manera?»\qt@no{35}}
\qt@newcmd\qurantrans@es@mcd{La mayoría de ellos no siguen sino suposiciones, y las suposiciones no tienen valor frente a la Verdad. Ciertamente, Dios conoce bien lo que hacéis.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcdi{Nadie más que Dios ha podido crear este Corán que, además, confirma lo que ellos ya tenían en sus manos y explica detalladamente la Escritura que, sin duda alguna, procede del Señor del Universo.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcdii{O dicen: «Lo ha creado él.» Di: «Entonces, traed un capítulo semejante o llamad a quien podáis aparte de Dios, si es que decís la verdad.»\qt@no{38}}
\qt@newcmd\qurantrans@es@mcdiii{Pero ellos desmienten aquello que su conocimiento no abarca y cuyo significado trascendente no ha llegado a ellos. Así mismo desmintieron quienes les precedieron, pero observa cuál fue el final de los opresores.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcdiv{De ellos, hay quien cree en él y hay quien no cree en él, pero tu Señor es quien mejor conoce a los corruptores.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcdv{Y si te desmienten, di: «Para mí mis actos y para vosotros vuestros actos. Vosotros no sois responsables de lo que yo hago ni yo soy responsable de los vosotros hacéis.»\qt@no{41}}
\qt@newcmd\qurantrans@es@mcdvi{Y, entre ellos, algunos te escuchan, pero ¿Cómo podrás hacerte oír de quien es sordo y no razona?\qt@no{42}}
\qt@newcmd\qurantrans@es@mcdvii{Y, entre ellos, alguno te mira, pero ¿vas a guiar al ciego aunque no puede ver?\qt@no{43}}
\qt@newcmd\qurantrans@es@mcdviii{En verdad, Dios no oprime a las personas en absoluto, sino que son las personas quienes se oprimen ellas mismas.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcdix{Y, (recuérdales) el día en que Él les reúna como si sólo hubiesen permanecido una hora del día. Se reconocerán entre ellos. Sin duda, habrán perdido quienes negaron el encuentro con Dios y no estaban bien guiados.\qt@no{45}}
\qt@newcmd\qurantrans@es@mcdx{Y, tanto si te hacemos ver algo de lo que les prometimos como si te hacemos morir, ellos habrán de volver a Nosotros y Dios es testigo de lo que hacen.\qt@no{46}}
\qt@newcmd\qurantrans@es@mcdxi{Y para cada comunidad hay un Mensajero. Cuando llega a ellos su Mensajero, juzga entre ellos con equidad y ellos no son oprimidos.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcdxii{Y dicen: «¿Cuándo llegará lo prometido, si decís la verdad?»\qt@no{48}}
\qt@newcmd\qurantrans@es@mcdxiii{Di: «Yo no tengo poder para perjudicarme o para beneficiarme, excepto lo que Dios quiera. Cada comunidad tiene un plazo. Cuando llega su plazo no pueden atrasarlo o adelantarlo ni una hora.»\qt@no{49}}
\qt@newcmd\qurantrans@es@mcdxiv{Di: «Decidme, si Su castigo llega a vosotros de noche o de día ¿Por qué quieren apresurarlo los pecadores?\qt@no{50}}
\qt@newcmd\qurantrans@es@mcdxv{¿Creeréis en él cuando ya haya ocurrido?» «¿Ahora? Y vosotros queríais precipitar su llegada.»\qt@no{51}}
\qt@newcmd\qurantrans@es@mcdxvi{Entonces se dirá a los opresores: «¡Probad el castigo eterno! ¿Se os ha recompensado con algo distinto a lo que obtuvisteis?»\qt@no{52}}
\qt@newcmd\qurantrans@es@mcdxvii{Querrán que les informes: «¿Es eso cierto?» Di: «Sí. Juro por mi Señor que es la Verdad y no podréis evitarlo.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mcdxviii{Si todo aquel que ha oprimido poseyera cuanto hay en la Tierra, lo daría a cambio de su rescate. Cuando vean el castigo disimularán su remordimiento, pero serán juzgados con equidad y no serán oprimidos.\qt@no{54}}
\qt@newcmd\qurantrans@es@mcdxix{¿Acaso no pertenece a Dios lo que hay en los cielos y en la Tierra? ¿Acaso no es cierta la promesa de Dios? Pero la mayoría de ellos no saben.\qt@no{55}}
\qt@newcmd\qurantrans@es@mcdxx{Él da la vida y la muerte y hacia Él regresaréis.\qt@no{56}}
\qt@newcmd\qurantrans@es@mcdxxi{¡Oh, gentes! ¡Ciertamente, ha llegado a vosotros una amonestación de vuestro Señor, cura para lo que hay en vuestros pechos y guía y misericordia para los creyentes!\qt@no{57}}
\qt@newcmd\qurantrans@es@mcdxxii{Di: «¡Que se alegren del favor de Dios y de Su misericordia!» ¡Eso es mejor que todo lo que ellos atesoran!\qt@no{58}}
\qt@newcmd\qurantrans@es@mcdxxiii{Di: «Decidme ¿Cómo es que, de la provisión que Dios hace descender para vosotros, vosotros habéis declarado alguna lícita y otra ilícita?» Di: «¿Os ha dado Dios permiso o inventáis cosas sobre Dios?»\qt@no{59}}
\qt@newcmd\qurantrans@es@mcdxxiv{Y, ¿Qué pensarán, quienes inventaron mentiras sobre Dios, el Día del Levantamiento? En verdad, Dios favorece a las personas, pero la mayoría de ellas no agradecen.\qt@no{60}}
\qt@newcmd\qurantrans@es@mcdxxv{Y no hay estado en que te encuentres, ni nada de lo que del Corán recitas, ni nada de lo que hacéis, de lo que Nosotros no seamos testigos desde que lo iniciáis. Y no escapa a tu Señor ni el peso de un átomo en la Tierra o en el cielo. Y no hay nada menor o mayor que eso que no esté consignado en una Escritura clara.\qt@no{61}}
\qt@newcmd\qurantrans@es@mcdxxvi{Presta atención: Los amigos de Dios no tendrán que temer ni estarán tristes.\qt@no{62}}
\qt@newcmd\qurantrans@es@mcdxxvii{Son aquellos que creyeron y fueron temerosos.\qt@no{63}}
\qt@newcmd\qurantrans@es@mcdxxviii{Para ellos hay buenas nuevas en esta vida y en la Otra. La palabra de Dios no cambia. Ese es el triunfo inmenso.\qt@no{64}}
\qt@newcmd\qurantrans@es@mcdxxix{¡Que no te entristezcan lo que ellos digan! En verdad, todo el poder pertenece a Dios. Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{65}}
\qt@newcmd\qurantrans@es@mcdxxx{Presta atención: En verdad, a Dios pertenecen quienes están en los cielos y quienes están en la Tierra. ¿Qué es lo que siguen quienes invocan a otros que equiparan a Dios? En verdad, no siguen más que suposiciones y sólo son gente que especula y fabrica mentiras.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcdxxxi{Él es Quien ha puesto la noche para que reposéis en ella y el día para que veáis con claridad. En verdad, en ello hay señales para gente que escucha.\qt@no{67}}
\qt@newcmd\qurantrans@es@mcdxxxii{Dicen: «Dios ha tomado un hijo.» ¡Glorificado sea! Él se basta a Sí mismo. A Él pertenece cuanto hay en los cielos y en la Tierra. No tenéis autoridad alguna para decir eso. ¿Decís sobre Dios lo que no sabéis?\qt@no{68}}
\qt@newcmd\qurantrans@es@mcdxxxiii{Di: «En verdad, quienes inventan mentiras sobre Dios no triunfarán.»\qt@no{69}}
\qt@newcmd\qurantrans@es@mcdxxxiv{Un disfrute en este bajo mundo y luego regresarán a Nosotros. Entonces les haremos probar el castigo severo por haber estado ocultando la Verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcdxxxv{Y relátales la historia de Noé, cuando dijo a su gente: «¡Oh, pueblo mío! Si os resulta difícil de soportar mi misión espiritual y el que os recuerde las señales de Dios, yo pongo mi confianza en Dios. Decidid junto con vuestros dioses y que no os preocupe llevar a cabo lo que decidáis y ejecutad vuestra sentencia contra mí sin hacerme esperar más.»\qt@no{71}}
\qt@newcmd\qurantrans@es@mcdxxxvi{«Y si me dais la espalda, yo no os he pedido recompensa alguna. Mi recompensa sólo incumbe a Dios. Se me ha ordenado que sea de los musulmanes.»\qt@no{72}}
\qt@newcmd\qurantrans@es@mcdxxxvii{Pero ellos le tacharon de mentiroso y Nosotros le salvamos, junto a los que estaban con él, en el Arca y les hicimos herederos y ahogamos a quienes desmintieron Nuestras señales. Mira cual fue el fin de los que habían sido amonestados.\qt@no{73}}
\qt@newcmd\qurantrans@es@mcdxxxviii{Luego, tras él, enviamos a otros Mensajeros a sus pueblos y fueron a ellos con las pruebas claras, pero no creyeron en aquello que ya antes habían desmentido. Así es como sellamos los corazones de los transgresores.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcdxxxix{Luego, tras ellos, enviamos a Moisés y a Aarón al Faraón y a sus notables con Nuestras señales, pero se ensoberbecieron y fueron una gente pecadora.\qt@no{75}}
\qt@newcmd\qurantrans@es@mcdxl{Y cuando vino a ellos la Verdad procedente de Nosotros, dijeron: «En verdad, esto es magia evidente.»\qt@no{76}}
\qt@newcmd\qurantrans@es@mcdxli{Moisés dijo: «¿Eso decís de la Verdad cuando llega a vosotros? ¿Es esto magia? Los magos no triunfarán.»\qt@no{77}}
\qt@newcmd\qurantrans@es@mcdxlii{Dijeron: «¿Habéis venido a nosotros para apartarnos de aquello que vimos hacer a nuestros padres, para conseguir vosotros dos la supremacía en el país? No os creeremos.»\qt@no{78}}
\qt@newcmd\qurantrans@es@mcdxliii{Y el Faraón dijo: «¡Traedme a todos los magos expertos!»\qt@no{79}}
\qt@newcmd\qurantrans@es@mcdxliv{Y, cuando los magos llegaron, Moisés les dijo: «Lanzad lo que debáis lanzar.»\qt@no{80}}
\qt@newcmd\qurantrans@es@mcdxlv{Y cuando lo lanzaron, dijo Moisés: «Lo que habéis hecho es magia. En verdad, Dios la anulará. Dios no aprueba la conducta de los corruptores.\qt@no{81}}
\qt@newcmd\qurantrans@es@mcdxlvi{Y Dios, con Sus palabras, hace que triunfe la Verdad, aunque eso disguste a los pecadores.»\qt@no{82}}
\qt@newcmd\qurantrans@es@mcdxlvii{Y nadie tuvo fe en Moisés excepto algunos jóvenes de su pueblo, pues temían que el Faraón y sus notables les creasen problemas, ya que el Faraón poseía un gran poder en su país y era un déspota.\qt@no{83}}
\qt@newcmd\qurantrans@es@mcdxlviii{Y Moisés dijo: «¡Oh, pueblo mío! Si creéis en Dios y estáis sometidos a Él, poned vuestra confianza en Él.»\qt@no{84}}
\qt@newcmd\qurantrans@es@mcdxlix{Ellos dijeron: «Confiamos en Dios.» «¡Señor nuestro! ¡No hagas de nosotros un medio para poner a prueba al pueblo de los opresores\qt@no{85}}
\qt@newcmd\qurantrans@es@mcdl{y sálvanos, por Tu misericordia, del pueblo de los que no tiene fe!»\qt@no{86}}
\qt@newcmd\qurantrans@es@mcdli{Y Nosotros revelamos a Moisés y a su hermano: «Proveed de casas a vuestra gente en Egipto y construid vuestras casas unas frente a otras y haced la oración y dad la buena nueva a los creyentes.»\qt@no{87}}
\qt@newcmd\qurantrans@es@mcdlii{Y Moisés dijo: «¡Señor nuestro, en verdad, Tú has dado a Faraón y a sus notables adornos y riquezas en esta vida para que se extravíen ¡Señor nuestro! de Tu camino!» «¡Señor nuestro! Elimina sus riquezas y endurece sus corazones para que no crean hasta que vean el castigo doloroso.»\qt@no{88}}
\qt@newcmd\qurantrans@es@mcdliii{Dijo Él: «Vuestra súplica ha sido aceptada. Seguid ambos el camino recto y no sigáis la senda de aquellos que no saben.»\qt@no{89}}
\qt@newcmd\qurantrans@es@mcdliv{Permitimos que los Hijos de Israel cruzasen el mar. Faraón y sus soldados les siguieron con ánimo hostil y violento, hasta que, al comprender que se ahogaba, dijo: «Creo en que no hay más dios que ese en el que creen los Hijos de Israel y soy de los que se someten (a Él).»\qt@no{90}}
\qt@newcmd\qurantrans@es@mcdlv{«¿Ahora? ¿Cuando antes desobedeciste y fuiste de los corruptores?»\qt@no{91}}
\qt@newcmd\qurantrans@es@mcdlvi{«Hoy salvaremos tu cuerpo a fin de que seas un signo para los que vengan después de ti, a pesar de que la mayoría de las personas no prestan atención a Nuestros signos.»\qt@no{92}}
\qt@newcmd\qurantrans@es@mcdlvii{Y establecimos a los Hijos de Israel en un buen sitio y les proveímos de buenas cosas. Y no discreparon entre ellos hasta que les llegó el conocimiento. En verdad, tu Señor juzgará entre ellos el Día del Levantamiento sobre aquello en lo que discrepaban.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcdlviii{Y si tienes dudas sobre aquello que hicimos descender para ti, pregunta a quienes leen la Escritura desde antes que tú. Ciertamente, ha venido a ti la Verdad procedente de tu Señor, no seas, pues, de los escépticos.\qt@no{94}}
\qt@newcmd\qurantrans@es@mcdlix{Y no seas de esos que desmienten las señales de Dios, pues serías de los perdedores.\qt@no{95}}
\qt@newcmd\qurantrans@es@mcdlx{En verdad, aquellos sobre los que el juicio de Dios ha sido tajante no creerán,\qt@no{96}}
\qt@newcmd\qurantrans@es@mcdlxi{aunque vengan a ellos toda clase de señales, hasta que vean el castigo doloroso.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcdlxii{¿Por qué no hubo ciudad que creyera y se beneficiara de su fe, excepto la gente de Jonás? En cuanto creyeron apartamos de ellos el castigo degradante de esta vida y les permitimos disfrutar de ella durante un tiempo.\qt@no{98}}
\qt@newcmd\qurantrans@es@mcdlxiii{Y si tu Señor hubiera querido, todos los que habitan la Tierra habrían tenido fe. ¿Acaso quisieras obligar a las personas a que fueran creyentes?\qt@no{99}}
\qt@newcmd\qurantrans@es@mcdlxiv{No es posible que ningún alma crea si no es con permiso de Dios y Él hace dudar a quien no razona.\qt@no{100}}
\qt@newcmd\qurantrans@es@mcdlxv{Di: «Observad lo que hay en los cielos y en la Tierra.» Pero las señales y las amonestaciones no benefician a la gente que no tiene fe.\qt@no{101}}
\qt@newcmd\qurantrans@es@mcdlxvi{¿Qué esperan entonces, sino días semejantes a los de quienes pasaron antes que ellos? Di: «¡Esperad pues! Que yo también esperaré con vosotros.»\qt@no{102}}
\qt@newcmd\qurantrans@es@mcdlxvii{Entonces, salvaremos a Nuestros Mensajeros y a quienes hayan tenido fe. Ese es Nuestro deber: Salvar a los creyentes.\qt@no{103}}
\qt@newcmd\qurantrans@es@mcdlxviii{Di: «¡Oh, gentes! Si tenéis dudas sobre mis creencias, (sabed que) yo no adoro a quienes vosotros adoráis en lugar de Dios, sino que adoro a Dios, Aquel que os hará morir. Se me ha ordenado que sea de los creyentes.»\qt@no{104}}
\qt@newcmd\qurantrans@es@mcdlxix{Y dirige tu rostro hacia la creencia pura y verdadera y no seas jamás de los que adoran falsos dioses, equiparándolos a Dios.\qt@no{105}}
\qt@newcmd\qurantrans@es@mcdlxx{Y no invoques, en lugar de Dios, a lo que no tiene poder para beneficiarte ni perjudicarte. Y, si lo hicieras, serías de los opresores.\qt@no{106}}
\qt@newcmd\qurantrans@es@mcdlxxi{Y si Dios te aflige con una desgracia, nadie podrá librarte de ella excepto Él. Y si Él desea un bien para ti, nadie puede impedir Su Favor. Él se lo concede a quien quiere de Sus siervos y Él es el Perdonador, el Misericordiosísimo con los creyentes.\qt@no{107}}
\qt@newcmd\qurantrans@es@mcdlxxii{Di: «¡Oh, gente! Ha venido a vosotros la Verdad procedente de vuestro Señor, así pues, quien se guíe, en verdad, se guía en beneficio propio y quien se extravíe, en verdad, se extravía para su propio perjuicio, y yo no soy vuestro tutor.»\qt@no{108}}
\qt@newcmd\qurantrans@es@mcdlxxiii{¡Sigue lo que te ha sido revelado y se paciente hasta que Dios juzgue! ¡Y Él es el mejor de los jueces!\qt@no{109}}
\qt@newcmd\qurantrans@es@mcdlxxiv{\basmalahes Alif, lam, ra. (Este Corán es una) Escritura cuyos versículos han sido establecidos y luego han sido explicados detalladamente por un Sabio bien informado:\qt@no{1}}
\qt@newcmd\qurantrans@es@mcdlxxv{¡Que no adoréis nada ni nadie excepto a Dios! En verdad, yo soy para vosotros un amonestador y un portador de buenas nuevas de Su parte.\qt@no{2}}
\qt@newcmd\qurantrans@es@mcdlxxvi{¡Y que pidáis perdón a vuestro Señor y luego os volváis a Él arrepentidos! Él os permitirá disfrutar de buenas cosas durante un plazo ya establecido y otorgará Su favor a todo el que merezca ser favorecido. Pero si dan la espalda, (diles:) «¡Temo que caiga sobre vosotros el castigo de un día grande!\qt@no{3}}
\qt@newcmd\qurantrans@es@mcdlxxvii{Regresaréis hacia Dios y Él tiene poder sobre todas las cosas.»\qt@no{4}}
\qt@newcmd\qurantrans@es@mcdlxxviii{¡Ved cómo se repliegan en sus pechos queriendo ocultarse de él! ¡Ved cómo cubren sus cabezas con sus ropas! Él conoce lo que ocultan en secreto y lo que manifiestan. En verdad, Él es Quien mejor conoce lo que hay en el fondo de los pechos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mcdlxxix{No existe animal en la Tierra cuya provisión no corra a cargo de Dios y Él conoce su guarida y el lugar al que se desplaza. Todo ello está en una Escritura clara.\qt@no{6}}
\qt@newcmd\qurantrans@es@mcdlxxx{Y Él es Quien creó los cielos y la Tierra en seis días y puso Su trono sobre el agua, para poneros a prueba y ver quién de vosotros obra mejor. Juro que si dices: «En verdad, seréis resucitados después de la muerte», los que no creen seguro que dirán: «Eso no es más que magia evidente.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mcdlxxxi{Y juro que si retrasamos su castigo hasta un momento determinado, seguro que dirán: «¿Cuál es el impedimento?» Sabed que el día que venga a ellos nada podrá cambiarlo y se verán asediados por aquello de lo que se burlaban.\qt@no{8}}
\qt@newcmd\qurantrans@es@mcdlxxxii{Si hacemos que la persona disfrute una misericordia procedente de Nosotros y luego la apartamos de él, caerá en una profunda desesperación y desagradecimiento.\qt@no{9}}
\qt@newcmd\qurantrans@es@mcdlxxxiii{Y, si le hacemos disfrutar de una merced después de haber sufrido una dificultad, con seguridad dirá: «Se han ido de mí los males.» y se llenará de alegría y orgullo.\qt@no{10}}
\qt@newcmd\qurantrans@es@mcdlxxxiv{Excepto quienes son pacientes y obran rectamente. Ellos son quienes obtendrán perdón y una gran recompensa.\qt@no{11}}
\qt@newcmd\qurantrans@es@mcdlxxxv{Puede que tú dejases parte de lo que te ha sido revelado y que se angustie tu pecho porque dicen: «¿Por qué no se ha hecho descender para él un tesoro o ha venido con él un ángel?» En verdad, tú eres (solamente) un amonestador y Dios es responsable de todo.\qt@no{12}}
\qt@newcmd\qurantrans@es@mcdlxxxvi{O dicen: «Él lo ha inventado». Di: «Si es verdad lo que decís ¡Traed entonces diez capítulos semejantes a éste, inventados con ayuda de quien podáis, (y decid que son revelados) de parte de Dios!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mcdlxxxvii{Y si no pueden daros respuesta, sabed que (este Corán) ha descendido gracias al conocimiento de Dios y que no hay más dios que Él ¿Seréis entonces musulmanes?\qt@no{14}}
\qt@newcmd\qurantrans@es@mcdlxxxviii{A quienes deseen la vida mundanal y sus encantos, Nosotros les entregaremos en ella el resultado todo de sus obras, sin merma alguna.\qt@no{15}}
\qt@newcmd\qurantrans@es@mcdlxxxix{Esos son quienes no tendrán en la otra vida excepto el fuego. Habrán arruinado cuanto construyeron en ella e invalidado cuanto hicieron.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcdxc{¿Acaso quien posee una prueba clara que procede de su Señor y quienes, de su gente, le siguen y dan testimonio de Él y, antes de él de la Escritura de Moisés, que fue un dirigente y una misericordia (son como quienes no creen)? Esos creen en él y, quienes, de entre los distintos grupos, no creen en él, tienen el Fuego como lugar de cita. Por tanto ¡No seas de los que dudan de ello! En verdad, ello es la Verdad procedente de tu Señor, pero la mayoría de la gente no cree.\qt@no{17}}
\qt@newcmd\qurantrans@es@mcdxci{¿Y, quién es más opresor que quien inventa mentiras sobre Dios? Esos serán llevados ante su Señor y los testigos dirán: “¡Esos son quienes dijeron mentiras sobre su Señor!” Has de saber que la maldición de Dios es para los opresores.\qt@no{18}}
\qt@newcmd\qurantrans@es@mcdxcii{Aquellos que ponen trabas en la senda de Dios y quisieran hacerla tortuosa y que no creen en la otra vida.\qt@no{19}}
\qt@newcmd\qurantrans@es@mcdxciii{Ellos no podrán escapar en la Tierra ni tendrán aparte de Dios amigos ni protectores. Se les doblará el castigo. No podían oír ni ver.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcdxciv{Esos son quienes se han perdido a sí mismos y se apartará de ellos lo que inventaban.\qt@no{21}}
\qt@newcmd\qurantrans@es@mcdxcv{No hay duda de que ellos serán los que más pierdan en la otra vida.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcdxcvi{En verdad, quienes creen y obran rectamente y son humildes ante su Señor serán quienes habiten el Paraíso. En él estarán eternamente.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcdxcvii{Estos dos grupos son como el que es ciego y sordo y el que ve y oye ¿Acaso son iguales ambos ejemplos? ¿Por qué, entonces, no recapacitáis?\qt@no{24}}
\qt@newcmd\qurantrans@es@mcdxcviii{Y es cierto que Nosotros enviamos a Noé a su pueblo: «En verdad, soy para vosotros un amonestador que os habla claramente.\qt@no{25}}
\qt@newcmd\qurantrans@es@mcdxcix{Excepto a Dios, nada adoréis. Temo para vosotros el castigo de un día doloroso.»\qt@no{26}}
\qt@newcmd\qurantrans@es@md{Pero los notables de su pueblo, aquellos que no creyeron, dijeron: «No vemos en ti otra cosa que un hombre como nosotros, ni vemos que te sigan más que los pobres de entre nosotros, que carecen de criterio, ni vemos en vosotros nada que os haga superiores a nosotros, más bien creemos que sois unos mentirosos.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mdi{Dijo: «¡Oh, pueblo mío! Decidme ¿Si me basase en una prueba clara procedente de mi Señor y Él me hubiera otorgado una misericordia venida de Él aunque sea invisible para vosotros, podríamos obligaros a aceptarla cuando vosotros la rechazáis?»\qt@no{28}}
\qt@newcmd\qurantrans@es@mdii{Y «¡Oh, pueblo mío! No os pido a cambio bienes materiales. En verdad, mi recompensa sólo incumbe a Dios. Ni voy a rechazar a quienes tienen fe. Ellos se encontrarán con su Señor. Pero veo que vosotros sois una gente ignorante.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mdiii{«¡Oh, pueblo mío! ¿Quién podría protegerme de Dios si yo les rechazase? ¿Es que no reflexionáis?»\qt@no{30}}
\qt@newcmd\qurantrans@es@mdiv{«Y no os digo que yo posea los tesoros de Dios, ni que tenga conocimiento del mundo oculto a los sentidos. Ni os digo: ‘Verdaderamente, yo soy un ángel.’ Ni diré a quienes ante vuestros ojos son despreciables que Dios no les otorgará bien alguno. Dios es Quien mejor conoce lo que hay en sus almas. Entonces, sería, verdaderamente, uno de los opresores.»\qt@no{31}}
\qt@newcmd\qurantrans@es@mdv{Ellos dijeron: «¡Oh, Noé! Nos has refutado y has discutido con nosotros en demasía, así que, tráenos aquello con lo que nos amenazas, si eres de los que dicen la verdad.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mdvi{Dijo: «En verdad, Dios os lo traerá, si Él quiere, y vosotros no podréis evitarlo.»\qt@no{33}}
\qt@newcmd\qurantrans@es@mdvii{«Ni os beneficiaría en absoluto mi consejo, aún cuando yo desease aconsejaros, si Dios quisiera extraviaros. Él es vuestro Señor y a Él regresaréis.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mdviii{O dicen: «¡Él lo ha inventado!» Di: «Si yo lo hubiese inventado mi pecado recaería sobre mí, pero yo estoy absuelto de los pecados que vosotros cometáis.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mdix{Y Nosotros revelamos a Noé: «No creerán de tu pueblo más que los que ya han creído, así pues, no te disgustes por lo que hagan.\qt@no{36}}
\qt@newcmd\qurantrans@es@mdx{Y construye el Arca ante Nuestros ojos y conforme a lo que Nosotros te hemos revelado y no Me hables más de quienes han sido opresores. En verdad, ellos serán ahogados.»\qt@no{37}}
\qt@newcmd\qurantrans@es@mdxi{Y se puso a construir el Arca. Y cada vez que pasaban ante él los ricos de su pueblo, se burlaban de él. Él dijo: «Si os burláis de nosotros, nosotros nos burlaremos de vosotros como vosotros os burláis.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdxii{Pronto sabréis a quién le llegará un castigo que le destruirá y sufrirá un castigo permanente.»\qt@no{39}}
\qt@newcmd\qurantrans@es@mdxiii{Hasta que, cuando llegó Nuestra orden y el horno comenzó a hervir, le dijimos: «Carga en ella dos de cada especie, a tu familia, excepto quien fue sentenciado previamente, y a los que creyeron.» Y no habían creído con él excepto unos pocos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdxiv{Y dijo: «¡Embarcad en ella! ¡Que navegue y llegue a puerto mediante el nombre de Dios! ¡En verdad, mi Señor es perdonador, misericordiosísimo con los creyentes!»\qt@no{41}}
\qt@newcmd\qurantrans@es@mdxv{Y navegó con ellos sobre olas como montañas. Y Noé llamó a su hijo que estaba a un lado: «¡Oh, hijito mío! ¡Embarca con nosotros y no te quedes con los que no creen!»\qt@no{42}}
\qt@newcmd\qurantrans@es@mdxvi{El dijo: «Me refugiaré ahora mismo en una montaña que me proteja del agua.» (Noé) dijo: «Hoy no hay quien esté protegido de la orden de Dios, excepto aquel de quien Él tenga misericordia.» Y surgieron las olas entre ambos y fue de los que se ahogaron.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdxvii{Y fue dicho: «¡Oh Tierra, absorbe tu agua!» y «¡Oh cielo, escampa!» y el agua decreció y la orden fue ejecutada y se posó sobre el (monte) Yudi. Y fue dicho: «¡Qué la gente opresora sea alejada!»\qt@no{44}}
\qt@newcmd\qurantrans@es@mdxviii{E invocó Noé a su Señor y dijo: «¡Oh Señor mío! En verdad, mi hijo es de mi familia y, en verdad, Tu promesa es la Verdad y Tú eres el más justo de los jueces.»\qt@no{45}}
\qt@newcmd\qurantrans@es@mdxix{Dijo (Dios): «¡Oh, Noé! En verdad, él no es de tu familia. Es un acto incorrecto. Por tanto, no me pidas sobre lo que no tienes conocimiento. Te prevengo para que no seas de los ignorantes.»\qt@no{46}}
\qt@newcmd\qurantrans@es@mdxx{Dijo: «¡Señor mío! Me refugio en Ti de pedirte algo sobre lo que no tengo conocimiento. Y si no me perdonas y tienes misericordia de mí seré de los perdedores.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mdxxi{Se le dijo: «¡Oh, Noé! ¡Desembarca con Mi paz y Mis bendiciones para ti y para algunas comunidades de quienes están contigo! Y otras comunidades disfrutarán un tiempo y luego Nosotros haremos que les toque un castigo doloroso.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mdxxii{Esto es parte de las noticias del mundo oculto a los sentidos que Nosotros hemos revelado para ti. Ni tú ni tu pueblo las conocíais antes de esto. Así pues ¡Se paciente! En verdad, el final es para quienes son temerosos.\qt@no{49}}
\qt@newcmd\qurantrans@es@mdxxiii{Y (enviamos) a Ad a su hermano Hud. Dijo: «¡Oh, pueblo mío! Adorad a Dios. No tenéis otro dios más que Él. En verdad, vosotros sólo inventáis.»\qt@no{50}}
\qt@newcmd\qurantrans@es@mdxxiv{«¡Oh, pueblo mío! No os pido recompensa. En verdad, mi recompensa incumbe únicamente a Quien me creó. ¿Es que no razonáis?»\qt@no{51}}
\qt@newcmd\qurantrans@es@mdxxv{Y «¡Oh, pueblo mío! Pedid perdón a vuestro Señor y volveos arrepentidos a Él. Él enviará el cielo sobre vosotros con una lluvia abundante y añadirá fuerza a vuestra fuerza. Y no deis la espalda como pecadores.»\qt@no{52}}
\qt@newcmd\qurantrans@es@mdxxvi{Dijeron: «¡Oh, Hud! No has venido a nosotros con pruebas claras y no abandonaremos a nuestros dioses por lo que tú dices, pues no creemos en tus palabras.\qt@no{53}}
\qt@newcmd\qurantrans@es@mdxxvii{Sólo decimos que alguno de nuestros dioses te ha visitado con un mal.» Él dijo: «Pongo a Dios por testigo y sed testigos vosotros de que yo repudio lo que vosotros adoráis\qt@no{54}}
\qt@newcmd\qurantrans@es@mdxxviii{como si fuera Él. Así pues, reuníos todos y planead contra mí. Luego, no me hagáis esperar.»\qt@no{55}}
\qt@newcmd\qurantrans@es@mdxxix{«En verdad, confío en Dios, mi Señor y vuestro Señor. No existe criatura que Él no lleve agarrada por su flequillo. Verdaderamente, mi Señor está sobre un camino recto.»\qt@no{56}}
\qt@newcmd\qurantrans@es@mdxxx{«Así pues, si volvéis la espalda, yo ya os he transmitido aquello con lo que fui enviado a vosotros y mi Señor os sustituirá por otro pueblo distinto y no Le perjudicaréis en absoluto. En verdad, mi Señor es Quien se ocupa de proteger y cuidarlo todo.»\qt@no{57}}
\qt@newcmd\qurantrans@es@mdxxxi{Y, cuando llegó Nuestra orden, salvamos a Hud y a quienes con él habían creído mediante una misericordia procedente de Nosotros. Y les salvamos de un duro castigo.\qt@no{58}}
\qt@newcmd\qurantrans@es@mdxxxii{Esos fueron los Ad. Negaron las señales procedentes de su Señor y desobedecieron a Sus Mensajeros y siguieron (en cambio) las órdenes de cualquier tirano implacable.\qt@no{59}}
\qt@newcmd\qurantrans@es@mdxxxiii{Por ello serán perseguidos por una maldición en este bajo mundo y el Día del Levantamiento. ¡Ved como los Ad no creyeron en su Señor! ¡Alejados sean los Ad, el pueblo de Hud!\qt@no{60}}
\qt@newcmd\qurantrans@es@mdxxxiv{Y (enviamos) al pueblo de Tamud a su hermano Salih. Dijo: «¡Oh pueblo mío! Adorad a Dios. No tenéis otro dios aparte de Él. Él os hizo surgir de la tierra y os ha establecido en ella, por tanto, pedidle perdón. Luego, volveos a Él arrepentidos. En verdad, mi Señor está cercano y responde.»\qt@no{61}}
\qt@newcmd\qurantrans@es@mdxxxv{Ellos dijeron: «¡Oh, Salih! Antes de esto eras una esperanza entre nosotros.» «¿Vas a prohibirnos que adoremos lo que nuestros antepasados adoraban?» «En verdad, nosotros dudamos seriamente de aquello a lo que nos invitas.»\qt@no{62}}
\qt@newcmd\qurantrans@es@mdxxxvi{Dijo: «¡Oh, pueblo mío! Decidme, si me basase en una prueba clara procedente de mi Señor y Él me hubiera otorgado una misericordia venida de Él ¿Quién me protegería de Dios si yo le desobedeciese? Eso sólo me perjudicaría más aun.»\qt@no{63}}
\qt@newcmd\qurantrans@es@mdxxxvii{Y: «¡Oh, pueblo mío! Esta camella de Dios es una señal para vosotros. Dejadla, pues, comer libremente en la tierra de Dios y no le hagáis daño, pues os alcanzaría pronto un castigo.»\qt@no{64}}
\qt@newcmd\qurantrans@es@mdxxxviii{Pero la desjarretaron y dijo: «¡Disfrutad de tres días en vuestros hogares! ¡Esta no es una falsa promesa!»\qt@no{65}}
\qt@newcmd\qurantrans@es@mdxxxix{Y, cuando llegó Nuestra orden, salvamos a Salih y a los que con él habían creído, mediante una misericordia venida de Nosotros, (del castigo) y de la desgracia de ese día. En verdad, tu Señor es El fuerte, el Poderoso.\qt@no{66}}
\qt@newcmd\qurantrans@es@mdxl{Y a quienes fueron opresores les alcanzó el grito y amanecieron en sus casas caídos de bruces sobre el suelo\qt@no{67}}
\qt@newcmd\qurantrans@es@mdxli{como si nunca hubiesen vivido en ellas. ¡Ved como los Tamud no creyeron en su Señor! ¡Alejados sean los Tamud!\qt@no{68}}
\qt@newcmd\qurantrans@es@mdxlii{Y, ciertamente, Nuestros Mensajeros vinieron a Abraham con la buena nueva. Dijeron: «Paz.» Dijo él: «Paz» y no tardó en traer un ternero asado.\qt@no{69}}
\qt@newcmd\qurantrans@es@mdxliii{Y cuando vio que las manos de ellos no lo tocaban, pensó que eran enemigos y sintió miedo. Ellos dijeron: «No temas. Hemos sido enviados al pueblo de Lot.»\qt@no{70}}
\qt@newcmd\qurantrans@es@mdxliv{A su esposa, que estaba en pie, le bajó la menstruación, y le anunciamos a Isaac y, tras Isaac, a Jacob.\qt@no{71}}
\qt@newcmd\qurantrans@es@mdxlv{Ella dijo: «¡Ay de mí! ¿Acaso tendré un hijo siendo yo anciana y este marido mío anciano? ¡Verdaderamente, esto es una cosa sorprendente!»\qt@no{72}}
\qt@newcmd\qurantrans@es@mdxlvi{Ellos dijeron: «¿Te sorprende la orden de Dios con la misericordia de Dios y Sus bendiciones para vosotros, gente de la Casa? En verdad, Él es digno de alabanza, generoso.»\qt@no{73}}
\qt@newcmd\qurantrans@es@mdxlvii{Cuando el sentimiento de temor se hubo ido de Abraham y le llegó la buena noticia, discutió con Nosotros sobre el pueblo de Lot.\qt@no{74}}
\qt@newcmd\qurantrans@es@mdxlviii{En verdad, Abraham era poco inclinado a la venganza, sensible y volcado a Dios.\qt@no{75}}
\qt@newcmd\qurantrans@es@mdxlix{«¡Oh, Abraham! ¡Deja eso! ¡Ha llegado la orden de tu Señor y, con certeza, vendrá a ellos un castigo irrevocable!»\qt@no{76}}
\qt@newcmd\qurantrans@es@mdl{Y cuando Nuestros enviados vinieron a Lot él se disgustó por causa de ellos y se sintió impotente para protegerles y dijo: “Este es un día difícil.”\qt@no{77}}
\qt@newcmd\qurantrans@es@mdli{Y vino a él su pueblo apremiándole y ya desde antes eran gente que cometía indecencias. Dijo: «¡Oh, pueblo mío! Esas son mis hijas. ¡Ellas son una opción más pura para vosotros! ¡Temed a Dios y no me avergoncéis con mis invitados! ¿No hay entre vosotros un hombre recto?»\qt@no{78}}
\qt@newcmd\qurantrans@es@mdlii{Ellos dijeron: «Tú bien sabes que no tenemos interés en tus hijas y tú bien sabes lo que queremos.»\qt@no{79}}
\qt@newcmd\qurantrans@es@mdliii{Él dijo: «Ojalá tuviese fuerza frente a vosotros o pudiese apoyarme en un soporte fuerte.»\qt@no{80}}
\qt@newcmd\qurantrans@es@mdliv{Los ángeles) dijeron: «¡Oh, Lot! ¡Verdaderamente, somos enviados de tu Señor! ¡Ellos no podrán llegar a ti!» «Parte en secreto con tu familia en un momento de la noche y que nadie de vosotros se dé la vuelta.» «Exceptuando a tu esposa, que sufrirá la misma suerte que ellos.» «En verdad, la cita es al amanecer. ¿Acaso el amanecer no está cercano?»\qt@no{81}}
\qt@newcmd\qurantrans@es@mdlv{Y, cuando llegó Nuestra orden, la volvimos de arriba abajo e hicimos llover sobre ella piedras de arcilla con orden y continuidad,\qt@no{82}}
\qt@newcmd\qurantrans@es@mdlvi{marcadas por tu Señor. Y este (castigo) no está lejos de los opresores.\qt@no{83}}
\qt@newcmd\qurantrans@es@mdlvii{Y (enviamos) a Madyan a su hermano Shuayb. Dijo: «¡Oh, pueblo mío! ¡Adorad a Dios! ¡No tenéis otro dios aparte de Él!» «Y no deis de menos en la medida ni en el peso. En verdad, os veo en buena posición y, en verdad, temo para vosotros el castigo de un día que todo lo abarcará.»\qt@no{84}}
\qt@newcmd\qurantrans@es@mdlviii{Y: «¡Oh, pueblo mío! ¡Dad con equidad la medida y el peso y no defraudéis a la gente en sus cosas y no corrompáis en la Tierra!\qt@no{85}}
\qt@newcmd\qurantrans@es@mdlix{Lo que queda de Dios es mejor para vosotros, si sois creyentes. Y yo no soy vuestro protector.»\qt@no{86}}
\qt@newcmd\qurantrans@es@mdlx{Dijeron: «¡Oh, Shuayb! ¿Acaso tu oración te ordena que abandonemos lo que nuestros antepasados adoraban o que no podamos hacer con nuestros bienes lo que queramos? Precisamente tú que, en verdad, eres el razonable, el que obra con máxima rectitud.»\qt@no{87}}
\qt@newcmd\qurantrans@es@mdlxi{Él dijo: «¡Oh, pueblo mío! ¿Acaso habéis considerado si yo me baso en una prueba evidente venida de mi Señor y que Él me ha provisto de un buen sustento?» «Yo no quiero contrariaros con aquello que os prohíbo. No quiero más que corregir lo que estaba mal en la medida de mis posibilidades, pues mi éxito depende exclusivamente de Dios. En Él pongo mi confianza y hacia Él me vuelvo.»\qt@no{88}}
\qt@newcmd\qurantrans@es@mdlxii{Y: «¡Oh, pueblo mío! ¡Que vuestra enemistad y oposición a mí no sea causa de que os aflijan los mismos males que afligieron al pueblo de Noé o al pueblo de Hud o al pueblo de Salih!» «Y lo que le sucedió al pueblo de Lot no está muy distante de vosotros.»\qt@no{89}}
\qt@newcmd\qurantrans@es@mdlxiii{«Pedid perdón a vuestro Señor. Luego, volveos a Él arrepentidos. En verdad, mi Señor es misericordiosísimo con los creyentes, constante en Su amor.»\qt@no{90}}
\qt@newcmd\qurantrans@es@mdlxiv{Ellos dijeron: «¡Oh, Shuayb! No comprendemos mucho de lo que dices y, la verdad, vemos que entre nosotros eres débil. Si no fuera por tu pequeña tribu te habríamos apedreado. Tú no tienes poder sobre nosotros.»\qt@no{91}}
\qt@newcmd\qurantrans@es@mdlxv{Él dijo: «¡Oh, pueblo mío! ¿Acaso mi pequeña tribu tiene más poder sobre vosotros que Dios y por eso Le habéis dado la espalda, olvidándoos de Él? ¡En verdad, mi Señor abarca cuanto hacéis!»\qt@no{92}}
\qt@newcmd\qurantrans@es@mdlxvi{«Haced lo que podáis hacer que yo también actuaré. Pronto sabréis a quién le ha de llegar un castigo que le avergüence y humille y quién es mentiroso. Y esperad vigilantes, que yo también estaré a la espera con vosotros»\qt@no{93}}
\qt@newcmd\qurantrans@es@mdlxvii{Y, cuando llegó Nuestra orden, salvamos a Shuayb y a quienes con él habían tenido fe, mediante una misericordia venida de Nosotros y a quienes habían sido opresores les alcanzó el Grito y amanecieron en sus casas caídos de bruces, muertos.\qt@no{94}}
\qt@newcmd\qurantrans@es@mdlxviii{Como si nunca hubieran vivido en ellas. ¡Alejados sean los Madyan igual que fueron alejados los Tamud!\qt@no{95}}
\qt@newcmd\qurantrans@es@mdlxix{Y es cierto que enviamos a Moisés con Nuestras señales y con un poder evidente\qt@no{96}}
\qt@newcmd\qurantrans@es@mdlxx{al Faraón y a sus cortesanos. Pero ellos siguieron la orden del Faraón y la orden del Faraón no era correcta.\qt@no{97}}
\qt@newcmd\qurantrans@es@mdlxxi{Irá delante de su pueblo el Día del Levantamiento y les llevará a beber al borde del Fuego. ¡Qué mala bebida para beber!\qt@no{98}}
\qt@newcmd\qurantrans@es@mdlxxii{Serán perseguidos por una maldición (divina) en esta (vida) y en el Día del Levantamiento. ¡Qué mal regalo recibirán!\qt@no{99}}
\qt@newcmd\qurantrans@es@mdlxxiii{Estas que te hemos relatado son noticias de algunas ciudades. Alguna de ellas aun están en pie y otras han sido arrasadas.\qt@no{100}}
\qt@newcmd\qurantrans@es@mdlxxiv{Y no fuimos Nosotros quienes les oprimimos sino que ellos se oprimieron a sí mismos. Y los dioses que invocaban aparte de Dios no les beneficiaron en nada cuando llegó la orden de tu Señor. Sólo incrementaron su ruina.\qt@no{101}}
\qt@newcmd\qurantrans@es@mdlxxv{Así es el castigo de tu Señor cuando castiga a una ciudad que ha sido opresora. En verdad, Su castigo es doloroso, severo.\qt@no{102}}
\qt@newcmd\qurantrans@es@mdlxxvi{En verdad, en ello hay señales para quien tema el castigo de la otra vida. Ese día será congregada toda la humanidad y será un día del que todos serán testigos.\qt@no{103}}
\qt@newcmd\qurantrans@es@mdlxxvii{Y no lo retrasaremos más que hasta un plazo establecido.\qt@no{104}}
\qt@newcmd\qurantrans@es@mdlxxviii{Viene un día en el que nadie hablará sino con Su permiso. Unos serán desgraciados y otros afortunados.\qt@no{105}}
\qt@newcmd\qurantrans@es@mdlxxix{Los desgraciados estarán en el Fuego. Allí sólo tendrán gemidos y lamentos.\qt@no{106}}
\qt@newcmd\qurantrans@es@mdlxxx{Estarán eternamente allí mientras duren los cielos y la Tierra, a no ser que tu Señor quiera otra cosa. En verdad, tu Señor hace lo que quiere.\qt@no{107}}
\qt@newcmd\qurantrans@es@mdlxxxi{Y los afortunados estarán en el Paraíso eternamente, mientras duren los cielos y la Tierra, a no ser que tu Señor quiera otra cosa. Un regalo que no se interrumpirá.\qt@no{108}}
\qt@newcmd\qurantrans@es@mdlxxxii{No tengas dudas, pues, de lo que ellos adoran. No adoran sino lo que adoraban sus padres desde antes. En verdad, que les daremos lo que les corresponde sin merma alguna.\qt@no{109}}
\qt@newcmd\qurantrans@es@mdlxxxiii{En verdad, dimos a Moisés la Escritura [Sagrada] y se discrepó sobre ella y si no hubiese sido por una decisión previa de tu Señor habríamos juzgado entre ellos. Y, en verdad, aún tienen dudas sobre ella, dudas mal intencionadas.\qt@no{110}}
\qt@newcmd\qurantrans@es@mdlxxxiv{En verdad, tu Señor recompensará plenamente a cada cual por sus obras. En verdad, Él está bien informado de lo que ellos hacen.\qt@no{111}}
\qt@newcmd\qurantrans@es@mdlxxxv{Por tanto ¡Mantente firme como te ha sido ordenado y también los que se han vuelto hacia Dios contigo y no os endioséis! En verdad, Él observa lo que hacéis.\qt@no{112}}
\qt@newcmd\qurantrans@es@mdlxxxvi{Y no os inclinéis hacia los opresores pues os alcanzaría el Fuego y, como no tenéis aparte de Dios quien os proteja, no seríais auxiliados.\qt@no{113}}
\qt@newcmd\qurantrans@es@mdlxxxvii{¡Haced la oración de los dos extremos del día y en las horas de la noche cercanas al día! En verdad, las buenas obras borran las malas. Esto es una amonestación para la gente que recuerda (a Dios)\qt@no{114}}
\qt@newcmd\qurantrans@es@mdlxxxviii{Y se paciente, pues, en verdad, Dios no permite que se pierda la recompensa de los que realizan buenas acciones.\qt@no{115}}
\qt@newcmd\qurantrans@es@mdlxxxix{¿Por qué no hubo en las generaciones anteriores a vosotros gente sabia que se opusiese a la corrupción en la Tierra, excepto unos pocos a los cuales Nosotros pusimos a salvo, y los opresores siguieron en la lujuria y la opulencia y fueron pecadores?\qt@no{116}}
\qt@newcmd\qurantrans@es@mdxc{Y tu Señor no destruye una ciudad injustamente cuando sus gentes corrigen lo que está mal.\qt@no{117}}
\qt@newcmd\qurantrans@es@mdxci{Y, si tu Señor hubiera querido, habría hecho de las gentes una sola comunidad. Y no dejarán de discrepar entre ellos\qt@no{118}}
\qt@newcmd\qurantrans@es@mdxcii{excepto aquellos de quienes Dios ha tenido misericordia. Y por eso les ha creado. Y la palabra de tu Señor es terminante: «He de llenar el Infierno de hombres y genios, todos juntos.»\qt@no{119}}
\qt@newcmd\qurantrans@es@mdxciii{Todas estas noticias que te contamos de los profetas son para fortalecer con ello tu corazón y con ellas llega a ti la Verdad y una amonestación y un recordatorio para los creyentes.\qt@no{120}}
\qt@newcmd\qurantrans@es@mdxciv{Y di a quienes no son creyentes: «¡Haced aquello que tengáis poder para hacer que yo también actuaré\qt@no{121}}
\qt@newcmd\qurantrans@es@mdxcv{y esperad vigilantes que yo también esperaré!»\qt@no{122}}
\qt@newcmd\qurantrans@es@mdxcvi{Y a Dios pertenece lo que en los cielos y en la Tierra no se puede percibir con los sentidos y hacía Él regresan todos los asuntos. Así pues, adoradle y depositad vuestra confianza en Él, pues vuestro Señor no está desatento a lo que hacéis.\qt@no{123}}
\qt@newcmd\qurantrans@es@mdxcvii{\basmalahes Alif, lam, ra. Estos son los versículos de la Escritura clara.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdxcviii{En verdad, la hemos hecho descender como una recitación en árabe, quizás así razonéis.\qt@no{2}}
\qt@newcmd\qurantrans@es@mdxcix{Con este Corán que te revelamos, Nosotros te vamos a relatar la mejor de las historias y, antes de ello, la desconocías.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdc{Cuando José dijo a su padre: «¡Oh, padre mío querido! He visto en un sueño once estrellas y el Sol y la Luna. ¡Los he visto postrándose ante mí!»\qt@no{4}}
\qt@newcmd\qurantrans@es@mdci{Dijo: «¡Oh, hijito! No cuentes tu visión a tus hermanos, pues tramarán algo contra ti. En verdad, Satanás es un enemigo declarado de las personas.»\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcii{«Y así es como tu Señor te escogerá y te enseñará a interpretar el significado verdadero de los acontecimientos y confirmará Su bendición sobre ti y sobre la familia de Jacob, igual que anteriormente la confirmó sobre tus antepasados Abraham e Isaac.» «En verdad, tu Señor todo lo conoce, es sabio.»\qt@no{6}}
\qt@newcmd\qurantrans@es@mdciii{Ciertamente, en José y sus hermanos hay señales para quienes [se] preguntan.\qt@no{7}}
\qt@newcmd\qurantrans@es@mdciv{Cuando ellos dijeron: «José y su hermano son más queridos por nuestro padre que nosotros, siendo nosotros un grupo (mayor). ¡Verdaderamente, nuestro padre está en un extravió evidente!»\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcv{«¡Matad a José o abandonadlo en una tierra alejada para que, así, vuestro padre sólo os preste atención a vosotros! Y, después de eso, sed gente recta.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcvi{Uno de ellos dijo: «¡No matéis a José! Dejadlo en el fondo del aljibe para que lo encuentre algún viajero, si es que hacéis algo.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcvii{Dijeron: «¡Oh, padre nuestro! ¿Por qué no nos confías a José? Nosotros somos buenos consejeros para él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcviii{Envíale con nosotros mañana. Que pasee y juegue y nosotros le cuidaremos.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcix{Dijo: «Me preocupa que os lo llevéis y temo que se lo coma el lobo en un descuido vuestro.»\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcx{Ellos dijeron: «Si el lobo se lo comiese, siendo nosotros un grupo grande, entonces sí que seríamos unos desgraciados.»\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcxi{Y, cuando se lo llevaron con ellos y se pusieron de acuerdo en ponerle en el fondo del aljibe, Nosotros le revelamos: «Ciertamente, tú les informarás de este asunto y ellos no se darán cuenta.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcxii{Y ellos regresaron a su padre al anochecer llorando.\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcxiii{Dijeron: «¡Oh, padre nuestro! Nos fuimos a hacer carreras y dejamos a José junto a nuestras cosas y se lo comió el lobo. No nos creerás, pero decimos la verdad.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcxiv{Y trajeron su camisa manchada de sangre falsa. Él dijo: «[No es así] Sino que vuestras almas os han susurrado algún asunto. Así pues, ¡Paciencia hermosa! Y en Dios busco ayuda ante lo que decís.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcxv{Y llegó una caravana y enviaron a su aguador que sumergió su cubo. Dijo: «¡Buena noticia! Es un joven.» Y lo ocultaron como una mercancía. Y Dios sabía bien lo que hacían.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcxvi{Y lo vendieron barato, por unas pocas monedas, sin prestarle mucha atención.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcxvii{Y el egipcio que le compró dijo a su esposa: «Facilítale un buen alojamiento, puede que nos beneficie o que lo adoptemos como hijo.» Así fue como establecimos a José en aquella tierra y para enseñarle a interpretar el verdadero significado de los acontecimientos. Y Dios siempre obtienen la victoria sobre lo que ordena, pero la mayoría de la gente no sabe.\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcxviii{Y cuando llegó a la pubertad le dimos sabiduría y conocimiento. Así es como recompensamos a los que hacen el bien.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcxix{Y la señora de la casa en la que él estaba le acosó. Cerró las puertas y dijo: «¡Ven!» Él dijo: «¡Dios me proteja! En verdad, Él es mi Señor y me ha dado un buen alojamiento. ¡En verdad, los opresores no triunfarán!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcxx{Ciertamente, ella le deseaba y él la hubiese deseado sino hubiera visto en ello una prueba de su Señor. Así hicimos para apartar de él el mal y la indecencia. En verdad, él era de Nuestros siervos puros.\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcxxi{Y corrieron ambos hacia la puerta y ella rasgó la camisa de él por detrás y junto a la puerta encontraron al esposo de ella. Ella dijo: «¿Qué recompensa merece quien quería un mal para tu familia, excepto que sea encarcelado o que se le aplique un castigo doloroso?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcxxii{Él dijo: «Ella me acosó.» Y un miembro de la familia de ella dijo: «Si la camisa de él está desgarrada por delante, ella dice la verdad y él es un mentiroso\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcxxiii{y si su camisa está desgarrada por detrás, ella miente y él dice la verdad.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcxxiv{Y cuando vio su camisa rasgada por detrás dijo: «En verdad, esto es una treta propia de vosotras. En verdad, vuestras tretas son enormes.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcxxv{«José ¡No des importancia a esto! Y tú, mujer ¡Pide perdón por tu pecado! ¡En verdad, has cometido un error!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcxxvi{Un grupo de mujeres de la ciudad dijo: «La mujer del poderoso acosó a su mancebo. Está apasionadamente enamorada. En verdad, la vemos en un extravío evidente.»\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcxxvii{Y cuando ella oyó sus cotilleos las hizo llamar y preparó para ellas un lugar en el que sentarse cómodamente y dio a cada una de ellas un cuchillo y le dijo: «Sal donde ellas están.» Y cuando ellas le vieron se quedaron absortas y se cortaron en las manos y dijeron: «¡Santo Dios! ¡Esto no es un hombre, sino un ángel precioso!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcxxviii{Ella dijo: «Pues éste es aquél por el cual me criticabais.» «Yo le acosé, pero él se contuvo. Pero si no hace lo que yo le ordeno, será, ciertamente, encarcelado y humillado.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcxxix{Él dijo: «¡Dios mío! ¡Más quiero la cárcel que aquello a lo que ellas me invitan! Si Tu no cambias los planes que tienen para mí, cederé ante ellas y seré de los ignorantes.»\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcxxx{Su Señor respondió a su súplica y le protegió de los planes de ellas. En verdad, Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcxxxi{Luego, les pareció, a pesar de haber visto las señales, que debían encarcelarle por un tiempo.\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcxxxii{Y con él entraron en la prisión dos jóvenes. Uno de ellos dijo: «En verdad, me he visto en un sueño prensando uvas para hacer vino.» Y dijo el otro: «En verdad, me he visto en un sueño llevando pan sobre mi cabeza y los pájaros comían de él.» «¡Infórmanos que significan! En verdad, vemos que tú eres una persona virtuosa.»\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcxxxiii{El dijo: «Antes de que os llegue la comida que está preparada para vosotros os habré informado a ambos de lo que significan. Esto forma parte de las cosas que mi Señor me ha enseñado. En verdad, yo he dejado de lado las creencias de una gente que no tiene fe en Dios ni en la Otra vida\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcxxxiv{y he seguido las creencias de mis padres, Abraham e Isaac y Jacob.» «Nosotros no hemos asociado nada a Dios. Eso es por un favor de Dios para nosotros y para la gente, pero la mayoría de la gente no es agradecida.»\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcxxxv{«¡Oh, compañeros de prisión! ¿Son mejor diferentes dioses o Dios, El Único, el Victorioso?»\qt@no{39}}
\qt@newcmd\qurantrans@es@mdcxxxvi{«Aparte de Él no adoráis más que nombres que vosotros mismos y vuestros padres habéis creado y para los que Dios no ha hecho descender ningún poder.» «En verdad, el juicio sólo pertenece a Dios. Él ha ordenado que no adoréis nada excepto a Él.» «Esa es la creencia establecida, pero la mayoría de la gente no tiene conocimiento.»\qt@no{40}}
\qt@newcmd\qurantrans@es@mdcxxxvii{«¡Oh, compañeros de prisión! Uno de vosotros escanciará vino a su señor pero el otro será crucificado y los pájaros comerán de su cabeza.» «Aquello sobre lo que ambos me pedíais opinión es un asunto que ya ha sido decretado.»\qt@no{41}}
\qt@newcmd\qurantrans@es@mdcxxxviii{Y dijo al que pensaba que se salvaría de los dos: «¡Recuérdame ante tu señor!» Pero Satanás le hizo olvidarse de recordárselo a su señor y (José) permaneció en prisión varios años.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdcxxxix{Y el rey dijo: «En verdad, he visto en un sueño siete vacas gordas que eran comidas por siete flacas y siete espigas verdes y otras tantas secas.» «¡Oh, cortesanos! ¡Dadme vuestra opinión sobre mi sueño, si es que sabéis interpretar los sueños!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mdcxl{Dijeron: «Son un puñado de pesadillas y nosotros no sabemos interpretar las pesadillas.»\qt@no{44}}
\qt@newcmd\qurantrans@es@mdcxli{Y el que se salvó de los dos, que recordó después de un tiempo, dijo: «Yo os informaré lo que significa. ¡Dejadme ir!»\qt@no{45}}
\qt@newcmd\qurantrans@es@mdcxlii{«José ¡Oh, el verídico! Danos tu opinión sobre siete vacas gordas que son comidas por siete flacas y siete espigas verdes y otras tantas secas, para que yo pueda volver a la gente y que ellos sepan.»\qt@no{46}}
\qt@newcmd\qurantrans@es@mdcxliii{Dijo: «Sembraréis siete años seguidos. Cuando cosechéis, dejadlo en la espiga excepto un poco de lo que comeréis.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mdcxliv{«Después de eso, vendrán siete años duros en los que comeréis lo que habíais guardado previamente para ellos, excepto un poco que preservaréis.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mdcxlv{«Después, vendrá tras eso un año en el que la gente será favorecida, lloverá en abundancia y podrá prensar.»\qt@no{49}}
\qt@newcmd\qurantrans@es@mdcxlvi{El rey dijo: «¡Traedlo a mí!» Y cuando llegó el mensajero, él dijo: «Regresa a tu señor y pregúntale sobre las mujeres que se cortaron las manos. En verdad, mi Señor conoce bien lo que ellas planearon.»\qt@no{50}}
\qt@newcmd\qurantrans@es@mdcxlvii{Dijo: «¿Qué os proponíais vosotras cuando acosasteis a José?» Ellas dijeron: «¡Santo Dios! ¡No conocemos nada malo de él!» Y la mujer del poderoso dijo: «¡Ahora se ha aclarado la verdad! ¡Yo le acosé y él dice la verdad!»\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcxlviii{«Esto es para que él sepa que yo no le traicioné en su ausencia y que Dios no guía los planes de los traidores.»\qt@no{52}}
\qt@newcmd\qurantrans@es@mdcxlix{«Yo no disculpo a mi alma. En verdad, el alma ordena insistentemente el mal, excepto en lo que mi Señor tiene misericordia. En verdad, mi Señor es perdonador, misericordiosísimo con los creyentes.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mdcl{Y dijo el rey. «¡Traedlo a mí! ¡Le haré mi favorito!» y cuando habló con él, dijo: «En verdad, hoy (has encontrado) entre nosotros un puesto de honor y de confianza.»\qt@no{54}}
\qt@newcmd\qurantrans@es@mdcli{Él dijo: «Ponme al frente de los almacenes del país. En verdad, soy un buen guardián y tengo conocimiento.»\qt@no{55}}
\qt@newcmd\qurantrans@es@mdclii{Así es como dimos a José una posición en la Tierra que le permitía establecerse donde quisiera. Nosotros otorgamos Nuestra misericordia a quien queremos y no dejamos que se pierda la recompensa de quienes hacen el bien.\qt@no{56}}
\qt@newcmd\qurantrans@es@mdcliii{Y, sin duda, para quienes han creído y han sido temerosos la recompensa de la otra vida es mejor aún.\qt@no{57}}
\qt@newcmd\qurantrans@es@mdcliv{Y vinieron los hermanos de José y se presentaron ante él y él les reconoció pero ellos no le reconocieron.\qt@no{58}}
\qt@newcmd\qurantrans@es@mdclv{Y cuando les hubo suministrado sus provisiones, dijo: «Traedme a vuestro hermano de padre. ¿No veis como os doy la medida justa y soy el mejor de los anfitriones?\qt@no{59}}
\qt@newcmd\qurantrans@es@mdclvi{Y si no venís a mí con él, no obtendréis de mi más medidas ni os acercaréis a mí.»\qt@no{60}}
\qt@newcmd\qurantrans@es@mdclvii{Ellos dijeron: «Se lo pediremos a su padre con insistencia y, en verdad, lo haremos.»\qt@no{61}}
\qt@newcmd\qurantrans@es@mdclviii{Él dijo a sus mancebos: «Ponedles los objetos con los que han pagado en sus sacos, puede que los reconozcan cuando regresen a su familia, quizás así regresen.»\qt@no{62}}
\qt@newcmd\qurantrans@es@mdclix{Y, cuando regresaron a su padre, dijeron: «¡Oh, padre nuestro! ¡Nos han negado la medida! Envía, pues, con nosotros a nuestro hermano para que podamos obtener las medidas y nosotros, ciertamente, le protegeremos.»\qt@no{63}}
\qt@newcmd\qurantrans@es@mdclx{Él dijo: «¿He de confiárosle como os confié a su hermano anteriormente? Pero Dios es mejor protector y el más misericordioso de los misericordiosos.»\qt@no{64}}
\qt@newcmd\qurantrans@es@mdclxi{Y cuando abrieron su cargamento encontraron que les habían devuelto los objetos con los que habían pagado. Dijeron: «¡Oh, padre nuestro! ¿Qué más podemos desear? Estos son los objetos con los que habíamos pagado, que nos han sido devueltos. Obtendremos provisiones para nuestra familia y protegeremos a nuestro hermano y obtendremos una carga mayor, pues ésta es una carga pequeña.»\qt@no{65}}
\qt@newcmd\qurantrans@es@mdclxii{Dijo: «No le enviaré con vosotros hasta que me aseguréis solemnemente ante Dios que me lo traeréis, excepto que vuestra vida esté en peligro.» Y cuando se lo aseguraron, dijo: «Dios es testigo de lo que decimos.»\qt@no{66}}
\qt@newcmd\qurantrans@es@mdclxiii{Y dijo: «¡Oh, hijos míos! No entréis por una misma puerta. Entrad por diferentes puertas. Y no puedo favoreceros en nada frente a Dios. En verdad, el juicio pertenece solamente a Dios. En Él confió. Que quienes confían confíen en Él.»\qt@no{67}}
\qt@newcmd\qurantrans@es@mdclxiv{Y aunque entraron como su padre les había ordenado eso no les sirvió de nada frente a Dios, pero se cumplió el deseo del alma de Jacob. Y, en verdad, él poseía un conocimiento que Nosotros le habíamos enseñado, que la mayoría de la gente no conoce.\qt@no{68}}
\qt@newcmd\qurantrans@es@mdclxv{Y cuando entraron ante José, acercó a sí a su hermano (y le) dijo: «En verdad, yo soy tu hermano. No estés triste ni enfadado por lo que hicieron.»\qt@no{69}}
\qt@newcmd\qurantrans@es@mdclxvi{Y, cuando les suministraba sus provisiones, puso la copa en la carga de su hermano. Luego, un pregonero voceó: «¡Eh vosotros, los de la caravana! ¡Sois unos ladrones!»\qt@no{70}}
\qt@newcmd\qurantrans@es@mdclxvii{Volviéndose hacia ellos, dijeron: «¿Qué echáis a faltar?»\qt@no{71}}
\qt@newcmd\qurantrans@es@mdclxviii{Ellos dijeron: «Echamos a faltar la copa del rey y a quien la traiga le daremos la carga de un camello. Yo lo garantizo.»\qt@no{72}}
\qt@newcmd\qurantrans@es@mdclxix{Dijeron: «¡Lo juramos por Dios! Vosotros sabéis con certeza que nosotros no hemos venido a corromper en esta tierra y que no somos ladrones.»\qt@no{73}}
\qt@newcmd\qurantrans@es@mdclxx{Ellos dijeron: «¿Cuál será el castigo si estáis mintiendo?»\qt@no{74}}
\qt@newcmd\qurantrans@es@mdclxxi{Dijeron: «El pago de quien lo tenga en sus alforjas será él mismo. Así castigamos a los opresores.»\qt@no{75}}
\qt@newcmd\qurantrans@es@mdclxxii{Y comenzó por las alforjas de ellos antes que por la alforja de su hermano, luego lo sacó de la alforja de su hermano. Eso fue lo que Nosotros le sugerimos a José. No podía retener a su hermano, conforme a la ley del rey, excepto si Dios quería. Nosotros elevamos el rango de quien queremos. Por encima de todo el que posee conocimiento hay otro que sabe más.\qt@no{76}}
\qt@newcmd\qurantrans@es@mdclxxiii{Ellos dijeron: «Si ha robado, ya robó un hermano suyo antes.» Pero José lo guardó en secreto para sí mismo y no se lo reveló a ellos. Dijo: «¡Vosotros os encontráis en peor situación y Dios es Quien mejor conoce lo que alegáis!»\qt@no{77}}
\qt@newcmd\qurantrans@es@mdclxxiv{Ellos dijeron: «¡Oh, poderoso! Él tiene un padre muy anciano, toma a uno de nosotros en su lugar. En verdad, nosotros vemos que tú eres de los que hacen el bien.»\qt@no{78}}
\qt@newcmd\qurantrans@es@mdclxxv{Él dijo: «Dios no permita que apresemos a nadie excepto a aquél a quien hemos encontrado nuestro objeto pues, entonces, seríamos injustos.»\qt@no{79}}
\qt@newcmd\qurantrans@es@mdclxxvi{Y cuando perdieron la esperanza sobre él se retiraron a deliberar en voz baja. El mayor de ellos dijo: «¿Acaso no sabéis que vuestro padre os tomó un solemne juramento por Dios y, anteriormente, faltasteis a vuestras obligaciones con José? Yo no abandonaré esta tierra hasta que mi padre no me dé permiso o Dios disponga algo para mí, pues Él es el mejor de los jueces.\qt@no{80}}
\qt@newcmd\qurantrans@es@mdclxxvii{Regresad a vuestro padre y decid: ‘¡Oh, padre nuestro! ¡Tu hijo ha robado! No damos testimonio sino de lo que sabemos. No estamos informados de lo que está oculto a los sentidos.»\qt@no{81}}
\qt@newcmd\qurantrans@es@mdclxxviii{«Pregunta en la ciudad en la que estuvimos y en la caravana con la que vinimos. En verdad, somos sinceros.»\qt@no{82}}
\qt@newcmd\qurantrans@es@mdclxxix{Él dijo: «[No es así] Sino que vuestras almas os han susurrado algún asunto. Así pues, ¡Paciencia hermosa! Puede que Dios me los devuelva a todos. En verdad, Él es Quien todo lo conoce, el Sabio.»\qt@no{83}}
\qt@newcmd\qurantrans@es@mdclxxx{Y apartándose de ellos dijo: «¡Oh, qué tristeza por José!» Y sus ojos se volvieron blancos de la tristeza, pero reprimió su exasperación.\qt@no{84}}
\qt@newcmd\qurantrans@es@mdclxxxi{Ellos dijeron: «¡Por Dios! Tanto recuerdas a José que enfermarás gravemente o morirás.»\qt@no{85}}
\qt@newcmd\qurantrans@es@mdclxxxii{Él dijo: «Sólo me quejo de mi dolor y mi tristeza ante Dios. Y sé, procedente de Dios, lo que vosotros no sabéis.\qt@no{86}}
\qt@newcmd\qurantrans@es@mdclxxxiii{¡Hijos míos! Id y buscar información acerca de José y de su hermano y no desesperéis de la misericordia de Dios, que de la misericordia de Dios solamente desespera la gente que no tiene fe.»\qt@no{87}}
\qt@newcmd\qurantrans@es@mdclxxxiv{Y cuando entraron ante él dijeron: «¡Oh, poderoso! A nosotros y a nuestra familia nos ha tocado la desgracia y hemos traído una mercancía poco valiosa. ¡Danos la medida completa y se generoso con nosotros En verdad, Dios recompensa a quienes son generosos!»\qt@no{88}}
\qt@newcmd\qurantrans@es@mdclxxxv{Él dijo: «¿Sabéis lo que hicisteis a José y a su hermano, en vuestra ignorancia?»\qt@no{89}}
\qt@newcmd\qurantrans@es@mdclxxxvi{Ellos dijeron: «¿Eres tú realmente José?» Él dijo: «¡Yo soy José y éste es mi hermano! Dios nos ha favorecido. En verdad, si uno es temeroso y paciente, Dios no permite que se pierda la recompensa de quienes hacen el bien.»\qt@no{90}}
\qt@newcmd\qurantrans@es@mdclxxxvii{Ellos dijeron: «¡Por Dios! ¡En verdad, Dios te ha preferido a nosotros y nosotros estuvimos equivocados!»\qt@no{91}}
\qt@newcmd\qurantrans@es@mdclxxxviii{Él dijo: «¡Hoy nada se os reprochará! ¡Dios os ha perdonado! Él es el más misericordioso de los misericordiosos.»\qt@no{92}}
\qt@newcmd\qurantrans@es@mdclxxxix{«Llevad está camisa mía y ponedla sobre el rostro de mi padre, recuperará la vista. Y traedme a toda vuestra familia.»\qt@no{93}}
\qt@newcmd\qurantrans@es@mdcxc{Y, cuando la caravana se alejo, dijo el padre de ellos: «Percibo el olor de José, si no creéis que chocheo.»\qt@no{94}}
\qt@newcmd\qurantrans@es@mdcxci{Ellos dijeron: «¡Por Dios! ¡Vuelves a tu antiguo extravío!»\qt@no{95}}
\qt@newcmd\qurantrans@es@mdcxcii{Cuando el portador de la buena nueva llegó, la puso sobre su rostro y él recuperó la vista. Él dijo: «¿No os dije que yo conozco, procedente de Dios, lo que vosotros no conocéis?»\qt@no{96}}
\qt@newcmd\qurantrans@es@mdcxciii{Ellos dijeron: «¡Oh, padre nuestro! Perdona nuestros pecados. ¡Verdaderamente, estábamos equivocados!»\qt@no{97}}
\qt@newcmd\qurantrans@es@mdcxciv{Él dijo: «Pediré a mi Señor que os perdone. En verdad, Él es el Perdonador, el Misericordiosísimo con los creyentes.»\qt@no{98}}
\qt@newcmd\qurantrans@es@mdcxcv{Y cuando entraron ante José acercó a él a sus padres y les dijo: «¡Entrad en Egipto que, si Dios quiere, estaréis a salvo\qt@no{99}}
\qt@newcmd\qurantrans@es@mdcxcvi{Y subió a sus padres al trono y [todos] cayeron prosternados ante él y él dijo: «¡Oh, padre mío! Éste es el significado del sueño que vi anteriormente. Mi Señor ha hecho que se verifique y me favoreció cuando me sacó de la prisión y os trajo del desierto, después de haber destruido Satanás la relación entre yo y mis hermanos.» «En verdad, mi Señor es sutil en lo que desea. En verdad, Él es Quien todo lo conoce, el Sabio.»\qt@no{100}}
\qt@newcmd\qurantrans@es@mdcxcvii{«¡Señor mío! ¡Tú me has dado parte del gobierno y me enseñaste la interpretación de los acontecimientos! ¡Creador de los cielos y de la Tierra! Tú eres mi protector en esta vida y en la otra. ¡Hazme morir sometido a Ti y ponme junto a los justos!»\qt@no{101}}
\qt@newcmd\qurantrans@es@mdcxcviii{Estas son algunas noticias del mundo oculto a los sentidos que Nosotros te hemos revelado, pues Tú no estabas junto a ellos cuando se reunieron y planearon lo que harían.\qt@no{102}}
\qt@newcmd\qurantrans@es@mdcxcix{Y la mayoría de las personas, por mucho que lo intentes, no creerán.\qt@no{103}}
\qt@newcmd\qurantrans@es@mdcc{Y tú no les pides una recompensa por ello. En verdad, él no es más que un recuerdo para todo el mundo.\qt@no{104}}
\qt@newcmd\qurantrans@es@mdcci{¡Cuántas señales hay en los cielos y en la Tierra ante las que pasan y se apartan de ellas!\qt@no{105}}
\qt@newcmd\qurantrans@es@mdccii{¡La mayoría de ellos no creen en Dios excepto para asociar a Él falsos dioses!\qt@no{106}}
\qt@newcmd\qurantrans@es@mdcciii{¿Acaso están a salvo de que llegue a ellos una sombra del castigo de Dios cubriéndoles o que les llegue la hora de manera imprevista y repentina?\qt@no{107}}
\qt@newcmd\qurantrans@es@mdcciv{Di: «Éste es mi camino. Llamo hacia Dios, con una profunda visión de las cosas, a todo el mundo. Yo y quienes me siguen.» «Y ¡Glorificado sea Dios! no soy de los que adoran falsos dioses junto a Dios.»\qt@no{108}}
\qt@newcmd\qurantrans@es@mdccv{Y antes de ti no enviamos sino a hombres de las mismas ciudades, a los cuales dimos la revelación. ¿Por qué no viajan por la Tierra y observan cual fue el final de quienes les precedieron? Y para quienes son temerosos de Dios la morada de la otra vida es mejor. ¿Acaso no razonáis?\qt@no{109}}
\qt@newcmd\qurantrans@es@mdccvi{Hasta que, cuando los Mensajeros perdieron la esperanza y pensaron que habían sido engañados, llegó a ellos Nuestra ayuda y salvamos a quien Nosotros quisimos. Y Nuestro castigo no abandonará a la gente pecadora.\qt@no{110}}
\qt@newcmd\qurantrans@es@mdccvii{En sus historias hay una enseñanza para quienes están dotados de intelecto. No son hechos inventados sino que confirma lo que ellos ya tenían en sus manos y explica detalladamente todas las cosas y es una guía y una misericordia para las personas creyentes.\qt@no{111}}
\qt@newcmd\qurantrans@es@mdccviii{\basmalahes Alif, lam, mim, ra. Esos son los versículos de la Escritura [Sagrada]. Lo que ha sido hecho descender a ti, procedente de tu Señor, es la Verdad, pero la mayoría de la gente no tiene fe.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdccix{Dios es quien elevó los cielos sin columnas que podáis ver, después se instaló en el Trono. Y sometió al Sol y a la Luna. Cada uno se desplaza durante un tiempo establecido. Él dirige los asuntos y explica detalladamente las señales, quizás así tengáis certeza de que os encontraréis con vuestro Señor.\qt@no{2}}
\qt@newcmd\qurantrans@es@mdccx{Y Él es quien extendió la Tierra y puso en ella firmes montañas y ríos y puso en ella, de todas las frutas, una pareja. Cubre el día con la noche. En verdad, en ello hay señales para una gente que reflexiona.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdccxi{Y en la tierra hay parcelas colindantes y viñedos y plantaciones de cereales y palmeras de un tronco o de varios, regado (todo) con una misma agua, pero favorecemos unos alimentos sobre otros. En verdad, en ello hay señales para la gente que razona.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdccxii{Y si te sorprendes, sorprendente es lo que ellos dicen: «¿Acaso cuando seamos polvo seremos creados de nuevo?» Esos son los que no creen en su Señor y quienes llevan sus cuellos encadenados y son la gente del Fuego. En él permanecerán eternamente.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdccxiii{Te piden que apresures lo malo antes que lo bueno aunque, antes de ellos, han tenido lugar castigos ejemplares y, en verdad, tu Señor puede perdonar a los hombres a pesar de sus injusticias. Y, en verdad, tu Señor es duro castigando.\qt@no{6}}
\qt@newcmd\qurantrans@es@mdccxiv{Y, aquellos que no creen dicen: «¿Por qué no se hace descender sobre él una señal de su Señor?» En verdad, tú eres un amonestador y para todo pueblo hay un guía.\qt@no{7}}
\qt@newcmd\qurantrans@es@mdccxv{Dios sabe lo que porta toda hembra y lo que merma en los senos maternos y lo que incrementa. Y todo junto a Él tiene una medida.\qt@no{8}}
\qt@newcmd\qurantrans@es@mdccxvi{Él es Quien conoce lo oculto y lo manifiesto, el Grande, Quien está por encima de todo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mdccxvii{Da igual que alguno de vosotros hable en secreto o en público o que se esconda en la noche o se muestre en el día,\qt@no{10}}
\qt@newcmd\qurantrans@es@mdccxviii{tiene guardianes por delante y por detrás que le protegen por orden de Dios. En verdad, Dios no cambia la situación de un pueblo mientras ellos no cambien lo que hay en sus almas. Y cuando Dios quiere el mal para un pueblo nadie puede impedirlo y no tendrán amigo o protector, aparte de Él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdccxix{Él es Quien os hace ver el relámpago con miedo y admiración y Quien hace surgir las nubes cargadas [de agua].\qt@no{12}}
\qt@newcmd\qurantrans@es@mdccxx{El trueno con sus alabanzas y los ángeles con su temor Le glorifican y Él envía los rayos con los que alcanza a quien quiere. Ellos discuten sobre la existencia de Dios y Él posee un poder ilimitado.\qt@no{13}}
\qt@newcmd\qurantrans@es@mdccxxi{La súplica verdadera es la que se dirige a Él y aquellos a quienes invocan en lugar de Él no les responderán nada. Como el que extiende las palmas de sus manos hacia el agua para llevarla a su boca y no lo consigue. La súplica de los que no creen no es más que extravío.\qt@no{14}}
\qt@newcmd\qurantrans@es@mdccxxii{Ante Dios se postran quienes están en los cielos y en la Tierra, así como sus sombras, de buen grado o a disgusto, al comienzo y al final del día.\qt@no{15}}
\qt@newcmd\qurantrans@es@mdccxxiii{Di: «¿Quién es el Señor de los cielos y la Tierra?» Di: «Dios.» Di: «¿Por qué, entonces, habéis tomado, aparte de Él, amigos y protectores que no tienen capacidad de beneficiarse o perjudicarse a sí mismos?» Di: «¿Son semejantes el ciego y el que ve o se asemejan las tinieblas y la luz?» ¿Acaso han puesto junto a Dios socios que hayan creado como crea Él y lo que estos crean les parece semejante a lo que Él ha creado? Di: «Dios es el Creador de todo y Él es el Único, el Dominante.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mdccxxiv{«Él hace descender de los cielos agua que fluye por los valles según la capacidad que poseen y la corriente lleva espuma flotando; semejante a la espuma que sale de lo que se pone sobre el fuego para fabricar adornos o instrumentos.» Así compara Dios la Verdad con la falsedad. La espuma desaparece, pero lo que es beneficioso para la gente permanece en la Tierra. Así es como pone Dios los ejemplos.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdccxxv{Quienes han respondido a (la llamada de) su Señor obtendrán el bien y quienes no Le han respondido, aunque poseyeran todo lo que hay en la Tierra y otro tanto, no les serviría de rescate. Su cuenta les saldrá mal y su morada será el Infierno ¡Que mal lugar de reposo!\qt@no{18}}
\qt@newcmd\qurantrans@es@mdccxxvi{¿Acaso quien sabe que lo que ha descendido a ti procedente de tu Señor es la Verdad es igual que el que está ciego? En verdad, sólo se dejan amonestar los dotados de inteligencia,\qt@no{19}}
\qt@newcmd\qurantrans@es@mdccxxvii{aquellos que cumplen con el pacto de Dios y que no rompen la promesa\qt@no{20}}
\qt@newcmd\qurantrans@es@mdccxxviii{y aquellos que mantienen unido lo que Dios ha ordenado mantener unido y temen a su Señor y temen que su cuenta salga mal.\qt@no{21}}
\qt@newcmd\qurantrans@es@mdccxxix{Y aquellos que son pacientes, buscando contemplar el rostro de su Señor y que hacen la oración y que reparten, secreta o públicamente, de aquello que les proveemos y que, con el bien, rechazan el mal. Para ellos es la última morada:\qt@no{22}}
\qt@newcmd\qurantrans@es@mdccxxx{Los Jardines del Edén, en los que entrarán con aquellos de sus antepasados y esposas y descendientes que fueron rectos y los ángeles vendrán a ellos entrando por todas las puertas:\qt@no{23}}
\qt@newcmd\qurantrans@es@mdccxxxi{«¡Paz sobre vosotros por haber sido pacientes! ¡Qué excelente es la última morada!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mdccxxxii{Y para aquellos que violan en contrato de Dios después de haberlo pactado y cortan lo que Dios ordenó que se mantuviera unido y corrompen la Tierra, la maldición, y para ellos la mala morada.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdccxxxiii{Dios concede la provisión a quien Él quiere y la quita a quien Él quiere. Y ellos se regocijaron de esta vida, cuando esta vida no es más que un breve disfrute.\qt@no{26}}
\qt@newcmd\qurantrans@es@mdccxxxiv{Y aquellos que no creen dicen: «¿Por qué no se ha hecho descender sobre él una señal procedente de su Señor?» Di: «En verdad, Dios extravía a quien quiere y guía hacia Él a quien se arrepiente,\qt@no{27}}
\qt@newcmd\qurantrans@es@mdccxxxv{aquellos que creen y tienen sus corazones tranquilos.» ¿Acaso no es con el recuerdo de Dios como se tranquilizan los corazones?\qt@no{28}}
\qt@newcmd\qurantrans@es@mdccxxxvi{Quienes creen y obran rectamente tendrán la mejor vida y el mejor final.\qt@no{29}}
\qt@newcmd\qurantrans@es@mdccxxxvii{Así mismo, te hemos enviado a una comunidad antes de la cual pasaron otras comunidades, para que les recites lo que Nosotros te hemos revelado, pero ellos no creen en el Misericordioso. Di: «Él es mi Señor. No hay dios sino Él. En Él confío y a Él me vuelvo arrepentido.»\qt@no{30}}
\qt@newcmd\qurantrans@es@mdccxxxviii{Y [no creerían] aunque con este Corán caminaran las montañas o se partiera en pedazos la Tierra o hablasen los muertos. Pero a Dios pertenecen todos los asuntos. ¿Acaso los que creen no saben que si Dios hubiera querido habría guiado a todos los seres humanos? Y la desgracia no cesará de afligir a quienes no creen, o cerca de sus hogares, por lo que han hecho, hasta que llegue el castigo acordado por Dios. En verdad, Dios no incumple lo prometido.\qt@no{31}}
\qt@newcmd\qurantrans@es@mdccxxxix{Y, ciertamente, se burlaron de los Mensajeros anteriores a ti, así pues, di un plazo a los que no creían y luego les atrapé y ¡Cómo fue Mi castigo!\qt@no{32}}
\qt@newcmd\qurantrans@es@mdccxl{¿Acaso Quien vigila los actos de cada alma (es como quien no posee ese poder)? Pero ellos atribuyen socios a Dios. Di: «Decid sus nombres o informadle de lo que Él no sepa sobre la Tierra. ¿O es que habláis por hablar?» Quienes no creen se adornan con sus intrigas y han sido apartados del camino (de Dios). Y a quien Dios extravía no habrá quien le guíe.\qt@no{33}}
\qt@newcmd\qurantrans@es@mdccxli{Tendrán un castigo en esta vida y el castigo de la otra será más duro aún. Y no tendrán quien les proteja de Dios.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdccxlii{El Jardín que les ha sido prometido a los temerosos de Dios es así: De sus profundidades brotan los ríos, siempre tiene frutos y sombra. Ese será el destino final de los temerosos, pero el destino final de los que no creen es el Fuego.\qt@no{35}}
\qt@newcmd\qurantrans@es@mdccxliii{Aquellos a quienes dimos la Escritura [Sagrada] se alegran de lo que fue hecho descender para ti, pero, en los partidos, hay quienes niegan parte de ello. Di: «En verdad, me fue ordenado que adore a Dios y que no Le asocie nada ni nadie. A Él convoco y a Él regreso.»\qt@no{36}}
\qt@newcmd\qurantrans@es@mdccxliv{Así mismo, lo hicimos descender como una ley en lengua árabe. Pero si sigues sus deseos, después del conocimiento que ha llegado a ti, no tendrás ante Dios amigo ni protector.\qt@no{37}}
\qt@newcmd\qurantrans@es@mdccxlv{Ciertamente, enviamos Mensajeros antes de ti y les dimos esposas y descendencia. Y no es propio de un Mensajero realizar milagros si no es con el permiso de Dios. Para cada época hay una Escritura Sagrada.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdccxlvi{Dios anula y confirma lo que quiere. Junto a Él está la Escritura Madre.\qt@no{39}}
\qt@newcmd\qurantrans@es@mdccxlvii{Si te hacemos ver algo del castigo que les hemos prometido o si te hacemos morir (antes), a ti sólo te corresponde transmitir (el Mensaje divino) y a Nosotros el ajuste de cuentas.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdccxlviii{¿Acaso no ven como reducimos los bordes de la Tierra? Dios juzga y nadie puede aplazar Su juicio y Él es rápido en ajustar las cuentas.\qt@no{41}}
\qt@newcmd\qurantrans@es@mdccxlix{Ya planearon los que vinieron antes de ellos, pero Dios es el dueño de todos los planes. Él conoce lo que obtiene cada ser con sus actos y los que no creen sabrán pronto para quién es la última morada.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdccl{Y quienes no creen dicen: «Tú no eres un Mensajero.» Di: «Es suficiente Dios y los que tienen el conocimiento de la Escritura Sagrada como testigos entre vosotros y yo.»\qt@no{43}}
\qt@newcmd\qurantrans@es@mdccli{\basmalahes Alif, lam, ra. Una Escritura [Sagrada] que hemos hecho descender a ti para que saques a la gente de las tinieblas hacia la Luz con el permiso de su Señor, hacia el camino del Poderoso, el Alabado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdcclii{Dios, a Quien pertenece lo que hay en los cielos y en la Tierra. ¡Ay! ¡Qué duro castigo para los que ocultan la Verdad y no tienen fe!\qt@no{2}}
\qt@newcmd\qurantrans@es@mdccliii{Aquellos que prefieren la vida de este mundo a la del Otro y ponen dificultades en el camino de Dios, tratando de desviar a la gente. ¡Esos están muy extraviados!\qt@no{3}}
\qt@newcmd\qurantrans@es@mdccliv{No enviamos Mensajero alguno que no hablase la lengua de su pueblo, para que pudiera explicarles con claridad. Dios extravía a quien Él quiere y guía a quien Él quiere. Él es el Poderoso, el Sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdcclv{Y, ciertamente, enviamos a Moisés con Nuestros milagros: «¡Saca a tu pueblo de las tinieblas a la Luz y recuérdales los Días de Dios!» En verdad, en ello hay señales para todo el que sea muy paciente, muy agradecido.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcclvi{Y (recuerda) cuando dijo Moisés a su pueblo: «Recordad la merced de Dios con vosotros cuando os salvó de la gente del Faraón, que os sometían a un terrible castigo y degollaban a vuestros hijos y dejaban vivas a vuestras mujeres. Y en ello había una prueba inmensa para vosotros, procedente de vuestro Señor.»\qt@no{6}}
\qt@newcmd\qurantrans@es@mdcclvii{Y (recuerda) cuando anunció vuestro Señor: «Si sois agradecidos os daremos más y si no creéis... En verdad, Mi castigo es duro.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mdcclviii{Y dijo Moisés: «Aunque no creáis, vosotros y todos los que están sobre la Tierra, en verdad, Dios se basta a Sí mismo, es Digno de Alabanza.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcclix{¿Acaso no han llegado a vosotros noticias de quienes os precedieron? ¿Los pueblos de Noé, de Ad y de Tamud y los que vinieron tras ellos, que nadie conoce excepto Dios? Vinieron a ellos sus Mensajeros con las pruebas claras, pero ellos llevaron sus manos a sus bocas y dijeron: «En verdad, no creemos en aquello con lo que habéis sido enviados y, en verdad, dudamos de aquello a lo que nos invitáis.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcclx{Sus Mensajeros dijeron: «¿Dudáis de Dios, el Creador de los cielos y la Tierra?» «Él os llama para perdonaros vuestros pecados y os da tiempo hasta un plazo establecido.» Ellos dijeron: «No sois más que seres humanos como nosotros. Deseáis desviarnos de lo que adoraban nuestros antepasados. Dadnos una prueba clara de vuestra autoridad.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcclxi{Sus Mensajeros les dijeron: «Sólo somos seres humanos como vosotros, pero Dios favorece de entre sus siervos a quien Él quiere y nosotros no podemos venir a vosotros con una prueba de nuestra autoridad, excepto con el permiso de Dios. Y es en Dios en Quien deben confiar los creyentes.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcclxii{«¿Por qué no íbamos a confiar en Dios si Él es Quien nos ha guiado en nuestros caminos?» «Tendremos paciencia ante lo que nos molestáis. Quienes confían, deben confiar en Dios.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcclxiii{Y aquellos que no creían dijeron a sus Mensajeros: «O volvéis a nuestras creencias o, ciertamente, os expulsaremos de nuestra tierra.» Entonces su Señor les reveló: «¡Destruiremos a los opresores\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcclxiv{y, tras ellos, os estableceremos a vosotros en la Tierra! Así será para quien tema Mi posición y tema Mi amenaza.»\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcclxv{Pidieron a Dios que les diese la victoria y todo tirano obstinado fue destruido.\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcclxvi{El Infierno anda tras él y le darán de beber un agua fétida.\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcclxvii{La beberá a sorbos con dificultad, casi sin poder tragarla y la muerte le vendrá por todos lados pero no morirá. Un castigo abrumador anda tras él.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcclxviii{Las obras de aquellos que no creen en su Señor son como cenizas esparcidas por el viento en un día de tormenta. No tendrán poder sobre nada de lo que obtuvieron. Éste será el extravío lejano y prolongado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcclxix{¿Acaso no ves que Dios ha creado los cielos y la Tierra con la Verdad. Si Él quisiera os destruiría y haría una Creación nueva.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcclxx{Eso no le supone a Dios ningún esfuerzo.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcclxxi{Comparecerán todos ante Dios y los débiles dirán a los prepotentes: «En verdad, fuimos seguidores vuestros ¿Podéis prestarnos ahora alguna ayuda frente al castigo de Dios?» Ellos dirán: «Si Dios nos hubiera guiado, nosotros os habríamos guiado. [Pero ahora]Da igual que nos impacientemos o que tengamos paciencia, no tenemos escapatoria.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcclxxii{Y dirá el Demonio cuando el caso esté ya concluido: «Ciertamente, Dios os prometió la Verdad y yo también os prometí, pero no cumplí.» «Yo no tenía poder sobre vosotros excepto para convocaros y vosotros me respondisteis. No me censuréis a mí, censuraos a vosotros mismos.» «Ni yo puedo acudir a vuestras llamadas de socorro ni vosotros podéis acudir a las mías. Verdaderamente, reniego de la condición divina que antes me otorgasteis.» En verdad, los opresores sufrirán un castigo doloroso.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcclxxiii{Y quienes creyeron y obraron rectamente serán introducidos en Jardines de cuyas profundidades brotan los ríos, en los que estarán eternamente con permiso de su Señor. En ellos se saludaran entre sí diciendo: «¡Paz!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcclxxiv{¿No has visto cómo Dios compara una buena palabra con un árbol bueno? Su base está firme y sus ramas están en el cielo.\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcclxxv{Da su fruto en toda época, con permiso de su Señor. Dios pone ejemplos a las gentes para que, quizás así, reflexionen.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcclxxvi{Y una mala palabra es semejante a un árbol malo, arrancado de la tierra, sin estabilidad.\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcclxxvii{Dios fortalece a quienes creen mediante la palabra firme en esta vida y en la otra y Dios extravía a los opresores. Dios hace lo que quiere.\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcclxxviii{¿No has visto a quienes cambiaron la merced de Dios por la incredulidad y llevan a su gente a la morada de la destrucción,\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcclxxix{el Infierno en el que arderán? ¡Qué mal lugar de descanso!\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcclxxx{Pusieron semejantes a Dios, para desviar a otros de Su camino. Di: «¡Disfrutad! Pues, en verdad, vuestro camino os lleva hacia el Fuego.»\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcclxxxi{Di a Mis siervos, aquellos que creen: «Haced la oración y repartid, en secreto o abiertamente de lo que Nosotros os hemos provisto antes de que llegue un día en el que no hay comercio ni amistad.»\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcclxxxii{Dios es quien creó los cielos y la Tierra y hace descender de los cielos agua mediante la cual hace surgir frutos para vuestro sustento y ha puesto a vuestro servicio los barcos para que surquen los mares por orden Suya y ha puesto a vuestro servicio los ríos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcclxxxiii{Y ha puesto a vuestro servicio el Sol y la Luna, que siguen un curso establecido y ha puesto a vuestro servicio la noche y el día\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcclxxxiv{y os ha dado de todo lo que pedisteis. Y si tratáis de contar las mercedes de vuestro Señor no podréis calcularlas. En verdad, el hombre es muy opresor y muy desagradecido.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcclxxxv{Y (recuerda) cuando Abraham dijo: «¡Señor mío! Haz esta tierra segura e impide que yo y mis hijos adoremos a los ídolos.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcclxxxvi{«¡Señor mío! En verdad, ellos han extraviado a muchos hombres.» «Quién me siga será de los míos y quien me desobedezca... En verdad, Tú eres perdonador, misericordiosísimo con los creyentes.»\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcclxxxvii{«¡Señor nuestro! En verdad, he asentado a parte de mi descendencia en un valle desierto, junto a Tu Casa Sagrada ¡Señor nuestro! para que hagan la oración. ¡Haz, pues, que los corazones de la gente se vuelvan hacia ellos y provéeles de frutos para que sean agradecidos!»\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcclxxxviii{«¡Señor nuestro! En verdad Tú sabes lo que ocultamos y lo que manifestamos. Y no se oculta de Dios nada de lo que hay en la Tierra ni en los cielos.»\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcclxxxix{«Alabado sea Dios, Quien me otorgó, a pesar de mi mucha edad, a Ismael e Isaac. En verdad, mi Señor escucha la súplica.»\qt@no{39}}
\qt@newcmd\qurantrans@es@mdccxc{«¡Señor mío! ¡Haz que yo y mis descendientes seamos de los que hacen la oración! ¡Señor nuestro! ¡Acepta mi súplica!»\qt@no{40}}
\qt@newcmd\qurantrans@es@mdccxci{«¡Señor nuestro! ¡Perdónanos a mí y a mis padres y a los creyentes el Día del Ajuste de Cuentas!»\qt@no{41}}
\qt@newcmd\qurantrans@es@mdccxcii{¡Y no penséis que Dios se despreocupa de los actos de los opresores! ¡Sino que se lo pospone para un día en que las miradas quedarán paralizadas!\qt@no{42}}
\qt@newcmd\qurantrans@es@mdccxciii{¡Sus cuellos estirados, sus cabezas erguidas, sus pupilas inmóviles, un vacío en sus entrañas!\qt@no{43}}
\qt@newcmd\qurantrans@es@mdccxciv{Advierte a la gente de un día en que vendrá a ellos el castigo y en el que los opresores dirán: «¡Señor nuestro! ¡Retrásanoslo un pequeño plazo para que podamos responder a Tu convocatoria y seguir a los Mensajeros!» ¿Acaso no jurabais anteriormente que no llegaría el fin para vosotros\qt@no{44}}
\qt@newcmd\qurantrans@es@mdccxcv{y habitasteis en los mismos lugares que quienes se oprimieron a sí mismos y os informamos claramente de lo que hicimos con ellos y os pusimos ejemplos?\qt@no{45}}
\qt@newcmd\qurantrans@es@mdccxcvi{Y, ciertamente, tramaron sus planes, pero Dios conocía sus planes, aunque sus planes eran como para aplastar las montañas.\qt@no{46}}
\qt@newcmd\qurantrans@es@mdccxcvii{No contéis, pues, con que Dios incumpla la promesa que Él hizo a Sus Mensajeros -en verdad, Dios es poderoso, dueño de la venganza-\qt@no{47}}
\qt@newcmd\qurantrans@es@mdccxcviii{el día en que la Tierra se transforme en otra Tierra y los cielos [también] y ellos comparezcan ante Dios, el Uno, el Dominador.\qt@no{48}}
\qt@newcmd\qurantrans@es@mdccxcix{Y verás ese día a los pecadores unidos por cadenas,\qt@no{49}}
\qt@newcmd\qurantrans@es@mdccc{sus ropas de alquitrán y el Fuego cubriendo sus rostros,\qt@no{50}}
\qt@newcmd\qurantrans@es@mdccci{para que Dios recompense a cada alma por lo que realizó. En verdad, Dios es rápido en ajustar las cuentas.\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcccii{Este es un aviso para la gente. Para que se den por advertidos y para que sepan que Él es un Dios Único y para que reflexiones los dotados de discernimiento.\qt@no{52}}
\qt@newcmd\qurantrans@es@mdccciii{\basmalahes Alif, lam, ra. Esos son los versículos de la Escritura [Sagrada] y de un Corán claro.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdccciv{¡Cuánto desearán los que no creen haber sido musulmanes!\qt@no{2}}
\qt@newcmd\qurantrans@es@mdcccv{Déjales que coman y disfruten y les engañe la esperanza! ¡Pronto sabrán!\qt@no{3}}
\qt@newcmd\qurantrans@es@mdcccvi{No hemos destruido a ningún pueblo sin haberle dado un plazo determinado.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdcccvii{Ninguna comunidad puede adelantar su plazo ni retrasarlo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcccviii{Y dijeron: “¡Eh tú! ¡Ese para quien fue hecho descender el recuerdo! ¡Verdaderamente, estás loco!\qt@no{6}}
\qt@newcmd\qurantrans@es@mdcccix{¿Por qué no nos traes a los ángeles, si es verdad lo que dices?”\qt@no{7}}
\qt@newcmd\qurantrans@es@mdcccx{¡No hacemos descender a los ángeles excepto con la Verdad y entonces no tendrán que esperar.\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcccxi{En verdad, Nosotros hacemos descender el Recuerdo y, en verdad, Nosotros somos sus protectores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcccxii{Y, ciertamente, enviamos antes de ti otros Mensajeros a los primeros pueblos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcccxiii{Y no enviamos un solo Mensajero sin que se burlasen de él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcccxiv{Así es como lo introducimos en el corazón de los pecadores.\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcccxv{No creen en él y esa misma fue la costumbre de los pueblos anteriores.\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcccxvi{Aunque hubiéramos abierto para ellos una puerta en el cielo por la que pudieran ascender a él,\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcccxvii{habrían dicho: «¡Nos han hipnotizado! ¡Nos han hechizado!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcccxviii{Ciertamente, hemos puesto en el cielo constelaciones y lo hemos adornado para los observadores\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcccxix{y lo hemos protegido de cualquier demonio maldito\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcccxx{y quien se acerca a escondidas para escuchar, es perseguido por una estrella fugaz brillante.\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcccxxi{Y expandimos la Tierra y pusimos en ella firmes montañas e hicimos surgir de todo de manera equilibrada\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcccxxii{y pusimos en ella los medios necesarios para vivir, vosotros y otros que no dependen de que vosotros les sustentéis.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcccxxiii{No existe nada de lo que Nosotros no hayamos dispuesto grandes cantidades, pero no lo hacemos descender sino en una proporción determinada.\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcccxxiv{Y hemos enviado los vientos fecundadores y hacemos descender agua de los cielos con la que os damos de beber y no sois vosotros quienes la almacenáis.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcccxxv{Y, en verdad, somos Nosotros quienes damos la vida y la muerte y Nosotros somos los herederos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcccxxvi{Y conocemos, en verdad, a quienes os precedieron y a quienes vendrán después.\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcccxxvii{Y, en verdad, tu Señor es Quien les congregará. En verdad, Él es sabio, todo lo conoce.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcccxxviii{Y, ciertamente, creamos al ser humano de un barro seco procedente de un lodo negro y maloliente.\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcccxxix{Y creamos a los genios anteriormente de fuego ardiente.\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcccxxx{Y (recuerda) cuando tu Señor dijo a los ángeles: «En verdad, crearé a un ser humano de barro seco procedente de un lodo negro y maloliente.\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcccxxxi{Cuando lo haya terminado y sople en él de Mi Espíritu, caed prosternados ante él.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcccxxxii{Todos los ángeles se prosternaron\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcccxxxiii{excepto Iblís, que rehusó ser de los que se prosternan.\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcccxxxiv{Dijo (Dios): «¿Qué te sucede que no eres de los que se prosternan?»\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcccxxxv{Dijo (Iblís): «¡No estoy para prosternarme ante un ser humano al cual Tú has creado de barro seco procedente de un lodo negro y maloliente!»\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcccxxxvi{Dijo (Dios): «¡Sal, entonces, de ella! Se, pues, de los excluidos.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcccxxxvii{Y, en verdad, sea sobre ti la maldición hasta el Día de la Recompensa.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcccxxxviii{Dijo (Iblís): «¡Señor mío! ¡Dame de plazo hasta el día en que sean resucitados!»\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcccxxxix{Dijo (Dios): «Se, pues, de aquellos a quienes se ha dado un plazo\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcccxl{hasta un Día cuyo tiempo es sabido.»\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcccxli{Dijo (Iblís): «¡Señor mío! Puesto que me has desviado, les adornaré en la Tierra y les desviaré a todos,\qt@no{39}}
\qt@newcmd\qurantrans@es@mdcccxlii{excepto a quienes de entre ellos sean Tus siervos puros.»\qt@no{40}}
\qt@newcmd\qurantrans@es@mdcccxliii{Dijo (Dios): «Éste es Mi camino recto.\qt@no{41}}
\qt@newcmd\qurantrans@es@mdcccxliv{En verdad, no tendrás poder sobre Mis siervos, excepto sobre los extraviados que te sigan.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdcccxlv{Y, en verdad, todos ellos están citados en el Infierno.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdcccxlvi{Tiene siete puertas y a cada puerta le corresponde un grupo concreto de ellos.»\qt@no{44}}
\qt@newcmd\qurantrans@es@mdcccxlvii{En verdad, los temerosos estarán en Jardines y Fuentes.\qt@no{45}}
\qt@newcmd\qurantrans@es@mdcccxlviii{«¡Entrad en ellos en paz y seguridad!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mdcccxlix{Eliminaremos el rencor que quede en sus pechos. Hermanos sobre lechos unos frente a otros.\qt@no{47}}
\qt@newcmd\qurantrans@es@mdcccl{Allí no les alcanzará la desgracia ni serán de allí sacados.\qt@no{48}}
\qt@newcmd\qurantrans@es@mdcccli{Informa a Mis siervos que, en verdad, Yo soy el Perdonador, el Misericordiosísimo con los creyentes\qt@no{49}}
\qt@newcmd\qurantrans@es@mdccclii{y que Mi castigo es el castigo doloroso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mdcccliii{E informales de los huéspedes de Abraham.\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcccliv{Cuando entraron donde él se hallaba y dijeron: «¡Paz!». Él dijo: «La verdad, nos atemorizáis.»\qt@no{52}}
\qt@newcmd\qurantrans@es@mdccclv{Ellos dijeron: «No temas. En verdad, te anunciamos la buena noticia de un joven muy sabio.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mdccclvi{Él dijo: «¿Me anunciáis la buena noticia a pesar de lo mayor que soy? ¿Qué es lo que me estáis anunciando?»\qt@no{54}}
\qt@newcmd\qurantrans@es@mdccclvii{Ellos dijeron: «Te anunciamos la Verdad. ¡No seas de los que pierden la esperanza!»\qt@no{55}}
\qt@newcmd\qurantrans@es@mdccclviii{Él dijo: «¿Quién desespera de la misericordia divina excepto los extraviados?»\qt@no{56}}
\qt@newcmd\qurantrans@es@mdccclix{Dijo: «¿Qué asunto importante os ha traído ¡Oh Mensajeros!?»\qt@no{57}}
\qt@newcmd\qurantrans@es@mdccclx{Ellos dijeron: «En verdad, hemos sido enviados a un pueblo en el que todos son pecadores\qt@no{58}}
\qt@newcmd\qurantrans@es@mdccclxi{excepto la familia de Lot. En verdad, les salvaremos a todos ellos\qt@no{59}}
\qt@newcmd\qurantrans@es@mdccclxii{excepto a su mujer. Hemos decretado que sea de los que se quedan.»\qt@no{60}}
\qt@newcmd\qurantrans@es@mdccclxiii{Y, cuando los Mensajeros, llegaron a la familia de Lot,\qt@no{61}}
\qt@newcmd\qurantrans@es@mdccclxiv{éste) dijo: «Verdaderamente, sois gente desconocida.»\qt@no{62}}
\qt@newcmd\qurantrans@es@mdccclxv{Ellos dijeron: «Hemos venido a ti con aquello de lo que ellos dudaban.\qt@no{63}}
\qt@newcmd\qurantrans@es@mdccclxvi{Hemos venido a ti con la Verdad. En verdad, somos sinceros.\qt@no{64}}
\qt@newcmd\qurantrans@es@mdccclxvii{Ellos dijeron: «Hemos venido a ti con aquello de lo que ellos dudaban. Parte, pues, con tu familia durante la noche y tú sígueles por detrás y que ninguno de vosotros se vuelva a mirar, e id a donde se os ha ordenado.»\qt@no{65}}
\qt@newcmd\qurantrans@es@mdccclxviii{Y le revelamos este asunto: «¡Todos ellos serán destruidos al amanecer!»\qt@no{66}}
\qt@newcmd\qurantrans@es@mdccclxix{Las gentes de la ciudad se informaron unos a otros y vinieron.\qt@no{67}}
\qt@newcmd\qurantrans@es@mdccclxx{Dijo (Lot): «Estos son mis invitados. ¡No me deshonréis!\qt@no{68}}
\qt@newcmd\qurantrans@es@mdccclxxi{¡Temed a Dios y no me humilléis!»\qt@no{69}}
\qt@newcmd\qurantrans@es@mdccclxxii{Ellos dijeron: «¿Acaso no te habíamos prohibido a todo el mundo?»\qt@no{70}}
\qt@newcmd\qurantrans@es@mdccclxxiii{Dijo: «Aquí están mis hijas, si es que queréis actuar [rectamente].»\qt@no{71}}
\qt@newcmd\qurantrans@es@mdccclxxiv{Juro por tu vida que, en su embriaguez, no sabían lo que hacían\qt@no{72}}
\qt@newcmd\qurantrans@es@mdccclxxv{Y el Grito les sorprendió a la salida del Sol.\qt@no{73}}
\qt@newcmd\qurantrans@es@mdccclxxvi{Y pusimos lo de arriba de ella abajo e hicimos llover sobre ellos piedras de arcilla.\qt@no{74}}
\qt@newcmd\qurantrans@es@mdccclxxvii{Verdaderamente, en ello hay signos para quienes prestan atención.\qt@no{75}}
\qt@newcmd\qurantrans@es@mdccclxxviii{En verdad, ella está en un camino que todavía existe\qt@no{76}}
\qt@newcmd\qurantrans@es@mdccclxxix{y en ello hay un signo para los creyentes.\qt@no{77}}
\qt@newcmd\qurantrans@es@mdccclxxx{En verdad, los habitantes de Al-Aika fueron opresores.\qt@no{78}}
\qt@newcmd\qurantrans@es@mdccclxxxi{Así que Nos vengamos de ellos. Y ambas están a la vista en el camino.\qt@no{79}}
\qt@newcmd\qurantrans@es@mdccclxxxii{Ciertamente, los habitantes de Al-Hichr desmintieron a los Mensajeros.\qt@no{80}}
\qt@newcmd\qurantrans@es@mdccclxxxiii{Les habíamos enviado Nuestras señales pero se apartaron de ellas.\qt@no{81}}
\qt@newcmd\qurantrans@es@mdccclxxxiv{Habían excavado en la montaña casas seguras,\qt@no{82}}
\qt@newcmd\qurantrans@es@mdccclxxxv{pero el Grito les sorprendió en la mañana\qt@no{83}}
\qt@newcmd\qurantrans@es@mdccclxxxvi{y todo lo que habían obtenido no les sirvió de nada.\qt@no{84}}
\qt@newcmd\qurantrans@es@mdccclxxxvii{No hemos creado los cielos y la Tierra y lo que hay entre ambos sino con la Verdad. En verdad, la Hora ha de llegar, así pues, perdona con un hermoso perdón.\qt@no{85}}
\qt@newcmd\qurantrans@es@mdccclxxxviii{Verdaderamente, tu Señor es el Creador de todo, el Conocedor de todo.\qt@no{86}}
\qt@newcmd\qurantrans@es@mdccclxxxix{En verdad, te hemos dado siete de las que se repiten y el Corán Inmenso.\qt@no{87}}
\qt@newcmd\qurantrans@es@mdcccxc{No alargues tu mirada hacia lo que Nosotros hemos otorgado a algunos de ellos para que disfruten y no te entristezcas por ello y protege con tus alas a los creyentes\qt@no{88}}
\qt@newcmd\qurantrans@es@mdcccxci{y di: «En verdad, yo soy un amonestador claro.\qt@no{89}}
\qt@newcmd\qurantrans@es@mdcccxcii{Les enviaremos un castigo) como lo enviamos a los troceadores.\qt@no{90}}
\qt@newcmd\qurantrans@es@mdcccxciii{Aquellos que trocearon el Corán.\qt@no{91}}
\qt@newcmd\qurantrans@es@mdcccxciv{Así que, juro por tu Señor que hemos de interrogarles a todos\qt@no{92}}
\qt@newcmd\qurantrans@es@mdcccxcv{por lo que estuvieron haciendo.\qt@no{93}}
\qt@newcmd\qurantrans@es@mdcccxcvi{Comunica, pues, claramente aquello que se te ha ordenado y apártate de los idólatras.\qt@no{94}}
\qt@newcmd\qurantrans@es@mdcccxcvii{En verdad, Nosotros te bastamos frente a quienes se burlan,\qt@no{95}}
\qt@newcmd\qurantrans@es@mdcccxcviii{aquellos que ponen otros dioses junto a Dios. ¡Pronto van a saber!\qt@no{96}}
\qt@newcmd\qurantrans@es@mdcccxcix{En verdad, Nosotros sabemos que tu pecho se encoge por lo que ellos dicen,\qt@no{97}}
\qt@newcmd\qurantrans@es@mcm{pero glorifica con alabanzas a tu Señor y se de los que se prosternan.\qt@no{98}}
\qt@newcmd\qurantrans@es@mcmi{Y adora a tu Señor hasta que te llegue la certeza.\qt@no{99}}
\qt@newcmd\qurantrans@es@mcmii{\basmalahes Viene la orden de Dios, no queráis pues apresurarla. ¡Glorificado y ensalzado sea por encima de aquello que asocian a Él!\qt@no{1}}
\qt@newcmd\qurantrans@es@mcmiii{Él hace descender a los ángeles con el Espíritu procedente de Su orden sobre quien Él quiere de Sus siervos: «¡Advertid que no existe otro dios que Yo, así pues, temedme a Mí!»\qt@no{2}}
\qt@newcmd\qurantrans@es@mcmiv{Él creó los cielos y la Tierra por medio de la Verdad. Él está muy por encima de aquello que asocian a Él.\qt@no{3}}
\qt@newcmd\qurantrans@es@mcmv{Él creó al ser humano de semen y ¡helo aquí! un discutidor obstinado.\qt@no{4}}
\qt@newcmd\qurantrans@es@mcmvi{Y también creó a los animales. En ellos hay para vosotros calor y beneficio y de algunos de ellos os alimentáis\qt@no{5}}
\qt@newcmd\qurantrans@es@mcmvii{y, para vosotros, hay una belleza en ellos cuando los recogéis al atardecer y cuando les lleváis por la mañana a los pastos\qt@no{6}}
\qt@newcmd\qurantrans@es@mcmviii{Y transportan vuestras pesadas cargas a países que no podríais alcanzar excepto con gran dificultad y esfuerzo para vosotros. En verdad, vuestro Señor es piadoso, misericordiosísimo con los creyentes.\qt@no{7}}
\qt@newcmd\qurantrans@es@mcmix{Y (Él ha creado) los caballos, los mulos y los asnos para que montéis en ellos y para (vuestro) realce y embellecimiento. Y Él crea cosas que no conocéis.\qt@no{8}}
\qt@newcmd\qurantrans@es@mcmx{A Dios corresponde la responsabilidad de mostrar el camino recto, pues algunos de ellos están desviados. Si Él quisiera os guiaría a todos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mcmxi{Él es Quien hace descender agua del cielo. De ella obtenéis bebida y de ella beben las plantas con las que alimentáis al ganado.\qt@no{10}}
\qt@newcmd\qurantrans@es@mcmxii{Con ella hace Él crecer para vosotros las cosechas, los olivos, las palmeras, las viñas y de todos los frutos. En verdad, en ello hay una señal para gente que reflexiona.\qt@no{11}}
\qt@newcmd\qurantrans@es@mcmxiii{Y ha puesto a vuestra disposición la noche y el día. El Sol, la Luna y las estrellas están sometidas a Su mandato. En verdad, en ello hay señales para gente que usa su intelecto.\qt@no{12}}
\qt@newcmd\qurantrans@es@mcmxiv{Y en lo que ha creado para vosotros en la Tierra hay variados colores. En verdad, en ello hay una señal para gente que se deja amonestar.\qt@no{13}}
\qt@newcmd\qurantrans@es@mcmxv{Y Él es Quien ha puesto el mar a vuestro servicio para que comáis de él carne fresca y para que extraigáis de él adornos para vuestra indumentaria. Y ves la nave surcándolo para que disfrutéis de Su favor. Y, quizás así, seáis agradecidos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mcmxvi{Y ha fijado en la Tierra firmes montañas para que no tiemble con vosotros y ríos y caminos, para que así, quizás, vayáis bien dirigidos.\qt@no{15}}
\qt@newcmd\qurantrans@es@mcmxvii{Y (ha colocado) señales. Y ellos se guían con las estrellas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcmxviii{¿Acaso Quien crea es como quien no crea? ¿Es que no os dejaréis amonestar?\qt@no{17}}
\qt@newcmd\qurantrans@es@mcmxix{Si trataseis de enumerar las mercedes de Dios no podríais contabilizarlas. En verdad, Dios es perdonador, misericordiosísimo con los creyentes\qt@no{18}}
\qt@newcmd\qurantrans@es@mcmxx{y Dios conoce los que ocultáis y lo que manifestáis.\qt@no{19}}
\qt@newcmd\qurantrans@es@mcmxxi{Y aquellos a quienes ellos ruegan aparte de Dios no han creado nada sino que han sido creados.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcmxxii{Están muertos, no vivos, y no se darán cuenta en qué momento serán resucitados.\qt@no{21}}
\qt@newcmd\qurantrans@es@mcmxxiii{Vuestro dios es un dios Único. Pero los corazones de quienes no creen en la otra vida niegan y ellos son arrogantes.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcmxxiv{No hay duda que Dios conoce lo que ocultan y lo que manifiestan. En verdad, Él no ama a los arrogantes.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcmxxv{Y si se les dice: «¿Qué ha hecho descender vuestro Señor?», dicen: «¡Fábulas de los primitivos!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mcmxxvi{Portarán su pesada carga completa el Día del Levantamiento y la carga de aquellos a quienes, por su falta de conocimiento, ellos desviaron. ¡Observad que mala carga portarán!\qt@no{25}}
\qt@newcmd\qurantrans@es@mcmxxvii{Quienes vivieron antes que ellos maquinaron, pero Dios debilitó su edificio desde los cimientos y el techo cayó sobre ellos desde lo alto y el castigo les vino sin que se dieran cuenta de cómo ni de dónde.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcmxxviii{Luego, el Día del levantamiento, Él les avergonzará y les dirá: «¿Dónde están Mis socios sobre los que no os poníais de acuerdo?» Aquellos a quienes les fue dado el conocimiento dirán: «En verdad, hoy la vergüenza y la desgracia son para los que no tienen fe.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mcmxxix{Aquellos que cuando los ángeles vienen a tomar sus almas mientras ellos están oprimiéndose a sí mismos se muestran humildes y sumisos: «¡No hacíamos nada!» ¡Claro que sí! ¡Dios sabe muy bien lo que hacíais!\qt@no{28}}
\qt@newcmd\qurantrans@es@mcmxxx{¡Entrad por las puertas del Infierno en el que estaréis eternamente! ¡Qué mala es la morada final de los arrogantes!\qt@no{29}}
\qt@newcmd\qurantrans@es@mcmxxxi{Y a quienes fueron temerosos se les dirá: «¿Qué fue lo que hizo descender vuestro Señor?» Ellos dirán: «El bien.» Quienes hayan hecho el bien en esta vida obtendrán bien, pero, sin duda, la morada de la Otra es mejor aún. ¡Qué bendición la morada de los temerosos!\qt@no{30}}
\qt@newcmd\qurantrans@es@mcmxxxii{Entrarán en los Jardines del Edén, de cuyas profundidades brotan los ríos. Allí hay para ellos todo lo que deseen. Así es como Dios recompensa a quienes son temerosos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mcmxxxiii{Aquellos a quienes los ángeles vienen a tomar sus almas y, encontrándoles de conducta pura, les dicen: «La Paz sobre vosotros. Entrad en el Jardín por lo que hacíais.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mcmxxxiv{¿Qué esperan sino que vengan a ellos los ángeles o que llegue a ellos la orden de tu Señor? Lo mismo hicieron quienes vinieron antes de ellos. Y Dios no les oprimió sino que ellos mismos fueron quienes se oprimieron.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcmxxxv{Sufrieron las consecuencias de sus malas acciones y les alcanzó el castigo del que se burlaban.\qt@no{34}}
\qt@newcmd\qurantrans@es@mcmxxxvi{Y los idólatras dicen: «Si Dios hubiera querido no habríamos adorado nada aparte de Él, ni nosotros ni nuestros padres, ni habríamos declarado nada prohibido sin Su permiso.» Eso mismo hicieron quienes les precedieron. ¿Acaso la responsabilidad de los Mensajeros es otra que transmitir el mensaje claro?\qt@no{35}}
\qt@newcmd\qurantrans@es@mcmxxxvii{Ciertamente, Nosotros enviamos a cada comunidad un Mensajero: «¡Adorad a Dios y abandonad los ídolos!» Hubo algunos de ellos a quienes Dios guió y otros que merecieron el extravío. ¡Viajad, pues, por la Tierra y ved cuál fue el final de los desmentidores!\qt@no{36}}
\qt@newcmd\qurantrans@es@mcmxxxviii{Te gustaría guiarles, pero, en verdad, Dios no guía a quienes ha desviado. Y no tendrán quien les auxilie.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcmxxxix{Y juran por Dios con solemnes juramentos que Dios no resucitará a quien esté muerto. ¡Pues sí! Es una promesa que Él se ha impuesto, aunque la mayoría de las personas no saben,\qt@no{38}}
\qt@newcmd\qurantrans@es@mcmxl{para mostrarles claramente aquello sobre lo que tenían diferentes opiniones y para que quienes no creen sepan que eran unos mentirosos.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcmxli{En verdad, cuando Nosotros deseamos que algo exista, simplemente le decimos: «¡Sé!» y es.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcmxlii{Y a quienes emigraron por Dios después de haber sido oprimidos les proporcionaremos una buena situación en esta vida y la recompensa de la Otra será mayor. ¡Si ellos supieran!\qt@no{41}}
\qt@newcmd\qurantrans@es@mcmxliii{Esos que fueron pacientes y confiaron en su Señor.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcmxliv{Y, antes de ti, solamente hemos enviado hombres a los cuales Nosotros revelamos -preguntad a la gente del recuerdo si no sabéis-\qt@no{43}}
\qt@newcmd\qurantrans@es@mcmxlv{las pruebas claras y las Escrituras Sagradas. E hicimos descender para ti el Recuerdo para que puedas aclarar a la gente lo que fue hecho descender para ellos (anteriormente) y para que, quizás así, reflexionen.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcmxlvi{¿Acaso quienes planearon el mal están a salvo de que Dios haga que la tierra les trague o que les llegue el castigo sin que se den cuenta por dónde?\qt@no{45}}
\qt@newcmd\qurantrans@es@mcmxlvii{¿O que les alcance en plena actividad sin que puedan evitarlo?\qt@no{46}}
\qt@newcmd\qurantrans@es@mcmxlviii{¿O que les alcance de manera que les vaya atemorizando cada vez más? En verdad, tu Señor es piadoso, misericordiosísimo con los creyentes.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcmxlix{¿Acaso no ven que todas las cosas que Dios ha creado desplazan sus sombras a derecha e izquierda en prosternación ante Dios y son humildes?\qt@no{48}}
\qt@newcmd\qurantrans@es@mcml{Y para Dios se prosterna cuanto animal y ángel hay en los cielos y en la Tierra y no son arrogantes\qt@no{49}}
\qt@newcmd\qurantrans@es@mcmli{Temen a su Señor, que está por encima de ellos y hacen lo que se les ha ordenado.\qt@no{50}}
\qt@newcmd\qurantrans@es@mcmlii{Dice Dios: «¡No toméis dos dioses! ¡En verdad, Él es un dios Único! Así pues ¡Temedme sólo a Mí!»\qt@no{51}}
\qt@newcmd\qurantrans@es@mcmliii{A Él pertenece lo que hay en los cielos y en la Tierra y Suya es la creencia inmutable ¿Vais, pues, a temer a otro que a Dios?\qt@no{52}}
\qt@newcmd\qurantrans@es@mcmliv{No poseéis don alguno que no proceda de Dios, por ello, cuando os aqueja un mal os refugiáis en Él.\qt@no{53}}
\qt@newcmd\qurantrans@es@mcmlv{Luego, cuando Él elimina el mal que os aquejaba, algunos de los vuestros asocian falsos dioses a su Señor.\qt@no{54}}
\qt@newcmd\qurantrans@es@mcmlvi{Ocultando lo que Nosotros les hemos otorgado. ¡Disfrutad, pues! ¡Pronto vais a saber!\qt@no{55}}
\qt@newcmd\qurantrans@es@mcmlvii{Atribuyen a lo que no conocen parte de aquello que Nosotros les hemos proveído. ¡Por Dios, que seréis interrogados sobre lo que inventabais!\qt@no{56}}
\qt@newcmd\qurantrans@es@mcmlviii{Y atribuyen a Dios las hijas ¡Glorificado sea! y a ellos mismos lo que desean.\qt@no{57}}
\qt@newcmd\qurantrans@es@mcmlix{Y cuando a alguno de ellos se le anuncia la buena nueva de una hembra su rostro se ensombrece y se llena de pesar.\qt@no{58}}
\qt@newcmd\qurantrans@es@mcmlx{Se aparta de la gente por el mal que se le ha comunicado ¿Se quedará con ella a pesar de la humillación o la ocultará bajo tierra? ¡Observad qué mal juzgan!\qt@no{59}}
\qt@newcmd\qurantrans@es@mcmlxi{Quienes no creen en la otra vida poseen malos atributos y a Dios pertenecen los atributos más elevados y Él es el Poderoso, el Sabio.\qt@no{60}}
\qt@newcmd\qurantrans@es@mcmlxii{Si Dios diese a las gentes lo que se merecen por sus injusticias no dejaría un ser vivo sobre ella, pero se lo pospone hasta una fecha señalada y cuando llegue su plazo no podrán retrasarlo ni una hora, ni tampoco adelantarlo.\qt@no{61}}
\qt@newcmd\qurantrans@es@mcmlxiii{Atribuyen a Dios lo que ellos aborrecen y proclaman con sus lenguas la mentira de que ellos obtendrán el bien. No hay duda de que para ellos será el Fuego y que serán los primeros en ser enviados a él.\qt@no{62}}
\qt@newcmd\qurantrans@es@mcmlxiv{Juro por Dios que enviamos [Mensajeros] a las comunidades anteriores a ti, pero Satanás les embelleció su [mal] comportamiento y hoy él es su amigo y protector. Y les aguarda un castigo doloroso.\qt@no{63}}
\qt@newcmd\qurantrans@es@mcmlxv{Y Nosotros no te enviamos la Escritura sino para que les expliques claramente aquello sobre lo que tienen diferencias y como una guía y una misericordia para la gente que es creyente.\qt@no{64}}
\qt@newcmd\qurantrans@es@mcmlxvi{Y Dios hace descender agua del cielo y con ella da vida a la tierra después de haber estado muerta. En verdad, en ello hay un signo para la gente que escucha.\qt@no{65}}
\qt@newcmd\qurantrans@es@mcmlxvii{Y, en verdad, en el ganado hay una enseñanza. Os damos de beber, de lo que llevan en su interior entre heces y sangre, leche pura, grata para los bebedores.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcmlxviii{Y (os damos) de los frutos de las palmeras y de la vides, de los cuales obtenéis embriagante y una buena provisión. En verdad, en ello hay una señal para gente que razona.\qt@no{67}}
\qt@newcmd\qurantrans@es@mcmlxix{Y tu Señor reveló a la abeja: «Pon tu casa en las montañas y en los árboles y en lo que construyen.\qt@no{68}}
\qt@newcmd\qurantrans@es@mcmlxx{Luego, come de todos los frutos y transita sumisa los caminos de tu Señor.» De su vientre sale una bebida de diferentes colores en la que hay una cura para la gente. En verdad, en ello hay una señal para gente que piensa.\qt@no{69}}
\qt@newcmd\qurantrans@es@mcmlxxi{Y Dios os crea y luego se lleva vuestra alma y a algunos de vosotros les hace llegar a una edad tan avanzada que después de haber sabido no saben nada. En verdad, Dios es Quien todo lo sabe, poderoso.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcmlxxii{Y Dios favorece a algunos de vosotros con más provisión que a otros, pero quienes fueron favorecidos no están dispuestos a dar de su provisión a sus siervos de manera que se igualen en ello. ¿Rechazan, pues, las bendiciones de Dios?\qt@no{71}}
\qt@newcmd\qurantrans@es@mcmlxxiii{Y Dios os ha dado esposas de vuestra misma especie y os ha dado, de vuestra esposas, hijos y nietos y os ha provisto de cosas buenas y puras. ¿Creerán en lo falso y no creerán en las bendiciones de Dios?\qt@no{72}}
\qt@newcmd\qurantrans@es@mcmlxxiv{Y adoran, aparte de Dios, lo que no posee provisión para ellos de nada de lo que hay en los cielos o en la Tierra y no pueden.\qt@no{73}}
\qt@newcmd\qurantrans@es@mcmlxxv{Así pues, no comparéis a Dios con nada. En verdad, Dios sabe y vosotros no sabéis.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcmlxxvi{Pone Dios el ejemplo de un siervo esclavo que no tiene poder sobre nada y otro a quien Nosotros hemos provisto de un buen sustento y que reparte de ello secreta y abiertamente. ¿Son iguales? ¡Alabado sea Dios! Pero la mayoría de ellos no saben.\qt@no{75}}
\qt@newcmd\qurantrans@es@mcmlxxvii{Y pone Dios el ejemplo de dos hombres, uno de ellos es mudo de nacimiento y no tiene poder sobre nada y es una carga para su amo. A cualquier asunto al que le envía no le trae nada bien ¿Serán iguales él y quien ordena la justicia y está sobre un camino recto?\qt@no{76}}
\qt@newcmd\qurantrans@es@mcmlxxviii{Y a Dios pertenece lo que está oculto a los sentidos en los cielos y en la Tierra y la orden de la Hora es como un parpadeo o más próxima aún. En verdad, Dios tiene poder sobre todas las cosas.\qt@no{77}}
\qt@newcmd\qurantrans@es@mcmlxxix{Y Dios os ha hecho salir del interior de vuestras madres sin tener conocimiento de nada y os ha dado el oído, la vista y el intelecto, puede que, así, seáis agradecidos.\qt@no{78}}
\qt@newcmd\qurantrans@es@mcmlxxx{¿Acaso no han visto a las aves suspendidas en el aire del cielo? Nadie las sostiene excepto Dios. En verdad, en ello hay señales para gente que tiene fe.\qt@no{79}}
\qt@newcmd\qurantrans@es@mcmlxxxi{Y Dios ha dispuesto para vosotros vuestras casas para el reposo y la tranquilidad y ha dispuesto, de las pieles del ganado, casas que os resulten ligeras el día en que tengáis que partir y el día que tengáis que acampar, y de su lana, su pelo y su crin, enseres domésticos y vestidos para disfrute durante un tiempo.\qt@no{80}}
\qt@newcmd\qurantrans@es@mcmlxxxii{Y Dios dispuso para vosotros, de aquello que Él ha creado, sombra, refugios en las montañas y vestimentas que os protejan del calor (y del frío) y vestimentas que os protejan de vuestra violencia. De esa manera, Él completa Su bendición sobre vosotros para que así, quizás, os sometáis.\qt@no{81}}
\qt@newcmd\qurantrans@es@mcmlxxxiii{Pero, si te dan la espalda, en verdad, tu responsabilidad es únicamente transmitir el mensaje claro.\qt@no{82}}
\qt@newcmd\qurantrans@es@mcmlxxxiv{Ellos conocen la bendición de Dios pero la niegan. La mayoría de ellos no tienen fe.\qt@no{83}}
\qt@newcmd\qurantrans@es@mcmlxxxv{Y [recordad] el día en que designaremos un testigo de cada comunidad y no se dará permiso a quienes no hayan tenido fe y no podrán buscar el perdón de Dios.\qt@no{84}}
\qt@newcmd\qurantrans@es@mcmlxxxvi{Y cuando, quienes fueron opresores, vean el castigo, no se les atenuará ni se les hará esperar.\qt@no{85}}
\qt@newcmd\qurantrans@es@mcmlxxxvii{Y cuando, quienes fueron idólatras, vean a sus ídolos, dirán: «¡Dios nuestro! ¡Esos son los que asociábamos a Ti! ¡Aquellos a los que adorábamos en lugar de adorarte a Ti!» Entonces sus ídolos les dirán: «¡En verdad, vosotros sois unos mentirosos!»\qt@no{86}}
\qt@newcmd\qurantrans@es@mcmlxxxviii{Ese día, ellos se someterán a Dios y se alejará de ellos lo que inventaron.\qt@no{87}}
\qt@newcmd\qurantrans@es@mcmlxxxix{A quienes no creen y ponen dificultades en el camino de Dios les añadiremos castigo sobre castigo por haber corrompido.\qt@no{88}}
\qt@newcmd\qurantrans@es@mcmxc{Y el día que designemos un testigo de cada comunidad, escogido de entre ellos mismos y que de testimonio sobre ellos, te traeremos a ti como testigo sobre éstos. Hicimos descender sobre ti la Escritura que explica claramente todas las cosas y que es guía, misericordia y buena nueva para los sometidos.\qt@no{89}}
\qt@newcmd\qurantrans@es@mcmxci{En verdad, Dios ordena la justicia, el bien y la generosidad con los familiares y prohíbe la indecencia, los malos actos y la opresión. Él os amonesta para que, quizás así, reflexionéis.\qt@no{90}}
\qt@newcmd\qurantrans@es@mcmxcii{Y, cuando concertéis un pacto con Dios, sed fieles al pacto y no rompáis vuestros juramentos después de haberlos ratificado y haber puesto a Dios por garante vuestro. En verdad, Dios sabe lo que hacéis.\qt@no{91}}
\qt@newcmd\qurantrans@es@mcmxciii{Y no seáis como aquella que destruía lo que había hilado después de haberlo tejido fuertemente, usando vuestros juramentos para defraudaros, pretextando que una comunidad es mayor y más fuerte que la otra. Verdaderamente, con ello Dios os pone a prueba y, sin duda, el Día del Levantamiento Él os aclarará aquello sobre lo que manteníais diferencias.\qt@no{92}}
\qt@newcmd\qurantrans@es@mcmxciv{Si Dios hubiera querido habría hecho de vosotros una sola comunidad, pero extravía a quien Él quiere y guía a quien Él quiere y seréis interrogados sobre lo que hacíais.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcmxcv{Y no uséis vuestros juramentos para defraudaros entre vosotros de manera que vacile vuestro paso después de haber sido firme y probéis la desgracia por apartaros del camino de Dios y sufráis un castigo inmenso.\qt@no{94}}
\qt@newcmd\qurantrans@es@mcmxcvi{Y no vendáis el pacto de Dios por poco precio. En verdad, lo que hay junto a Dios es mejor para vosotros. Que lo sepáis.\qt@no{95}}
\qt@newcmd\qurantrans@es@mcmxcvii{Lo que vosotros poseéis perece y lo que hay junto a Dios permanece. Y a quienes sean pacientes les recompensaremos conforme a lo mejor que hacían.\qt@no{96}}
\qt@newcmd\qurantrans@es@mcmxcviii{A quien obre rectamente, sea hombre o mujer, y sea creyente, le haremos vivir una vida buena. Y les recompensaremos conforme a lo mejor que hacían.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcmxcix{Y cuando recitéis el Corán buscad la protección de Dios de Satanás el expulsado.\qt@no{98}}
\qt@newcmd\qurantrans@es@mm{En verdad, él no tiene autoridad sobre quienes son creyentes y confían en su Señor.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmi{En verdad, él tiene poder sobre quienes le toman por amigo y sobre quienes le adoran como si fuese Dios.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmii{Y cuando cambiamos un versículo por otro -y Dios es Quien mejor sabe lo que hace descender- ellos dicen: “¡En verdad, tú lo has inventado!” Pero la mayoría de ellos no saben.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmiii{Di: «Lo ha bajado el Espíritu Santo, procedente de tu Señor, por medio de la Verdad, para consolidar a los que creen y como guía y buena nueva para los musulmanes.»\qt@no{102}}
\qt@newcmd\qurantrans@es@mmiv{Nosotros bien sabemos que ellos dicen: «En verdad, es un ser humano quien le instruye.» La lengua de aquel a quien ellos se refieren no es árabe y ésta es una lengua árabe clara.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmv{En verdad, Dios no guía a quienes no creen en las señales de Dios y sufrirán un castigo doloroso.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmvi{Los que inventan esta mentira son quienes no creen en las señales de Dios y ellos son los mentirosos.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmvii{Quienes renieguen de Dios después de haber creído -no quien se ve obligado a ello pero su corazón permanece seguro en la fe- sino quienes abran su pecho a la incredulidad, sufrirán la ira de Dios y tendrán un castigo inmenso.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmviii{Eso será por haber preferido esta vida a la Otra y porque Dios no guía a la gente que no tiene fe.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmix{Aquellos a quienes Dios ha cerrado sus corazones, sus oídos y su vista. Ellos son los negligentes.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmx{No hay duda de que en la otra vida serán los perdedores.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmxi{Luego, tu Señor, con quienes emigraron después de haber sido perseguidos y combatieron y fueron pacientes, después de todo ello, será perdonador, misericordiosísimo\qt@no{110}}
\qt@newcmd\qurantrans@es@mmxii{el Día en que cada alma esté ocupada en defenderse a sí misma y en que cada ser reciba la recompensa por lo que hizo. Y no serán tratados injustamente.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmxiii{Dios pone el ejemplo de una ciudad que vivía segura y tranquila y a la que llegaba abundante provisión de todos los lugares, pero no creyeron en las bendiciones de Dios y Dios les hizo probar el vestido del hambre y el temor por lo que hacían.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmxiv{Y, ciertamente, vino a ellos un Mensajero de entre ellos mismos y le desmintieron y el castigo les alcanzó, pues eran opresores.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmxv{Comed, pues, de lo lícito y puro que Dios os ha proveído y agradeced la bendición de Dios si es sólo a Él a Quien adoráis.\qt@no{114}}
\qt@newcmd\qurantrans@es@mmxvi{En verdad, Él os ha prohibido la carroña y la sangre, la carne del cerdo y la de aquello que se ha sacrificado a otro distinto de Dios. Pero con quien se vea obligado, no por extravagancia o por transgredir, Dios será, en verdad, perdonador, misericordiosísimo.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmxvii{Y no digáis, calificando falsamente con vuestras lenguas: «Esto es lícito y esto es ilícito», atribuyendo a Dios cosas que son mentira. En verdad, quienes atribuyan a Dios cosas que son mentira no tendrán éxito.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmxviii{Obtendrán un disfrute pequeño y un castigo doloroso.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmxix{Y a los judíos les hicimos ilícito lo que ya te hemos relatado antes y Nosotros no fuimos injustos con ellos, sino que ellos mismos oprimieron sus propias almas.\qt@no{118}}
\qt@newcmd\qurantrans@es@mmxx{Con quienes hicieron el mal por ignorancia, luego, tras ello, se arrepintieron y rectificaron, tu Señor, en verdad, será perdonador, misericordiosísimo.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmxxi{Verdaderamente, Abraham era una nación, obediente a Dios, buscador de la Verdad y nunca fue uno de los idólatras.\qt@no{120}}
\qt@newcmd\qurantrans@es@mmxxii{[Por ser] Agradecido a Sus mercedes, Dios le escogió y le guió a un camino recto\qt@no{121}}
\qt@newcmd\qurantrans@es@mmxxiii{Y Yo le di lo bueno en esta vida y, en verdad, en la otra será de los Rectos.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmxxiv{Luego, te revelamos: «Sigue las creencias de Abraham, el buscador de la Verdad, que no nunca fue uno de los idólatras.»\qt@no{123}}
\qt@newcmd\qurantrans@es@mmxxv{En verdad, el Sabat fue establecido solamente para aquellos que discrepaban sobre ello y, en verdad, tu Señor juzgará entre ellos, el Día del Levantamiento, sobre aquello en lo que discrepaban.\qt@no{124}}
\qt@newcmd\qurantrans@es@mmxxvi{Invita al camino de tu Señor con sabiduría y buenas palabras y discute con ellos de la mejor manera. En verdad, tu Señor es Quien mejor conoce quién se extravía de Su camino y Él es Quien mejor conoce o los bien guiados.\qt@no{125}}
\qt@newcmd\qurantrans@es@mmxxvii{Y si castigáis, castigad en la misma medida en que fuisteis castigados, pero si sois pacientes, eso es mejor para quien sea paciente.\qt@no{126}}
\qt@newcmd\qurantrans@es@mmxxviii{Se paciente, pero no podrás ser paciente si no es por Dios. Y no te entristezcas por ellos ni te preocupes por sus intrigas.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmxxix{En verdad, Dios está con quienes son temerosos y con quienes hacen el bien.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmxxx{\basmalahes Glorificado sea Quien hizo viajar una noche a Su siervo, para hacerle ver algunas de Nuestras señales, desde la Mezquita Sagrada a la Mezquita Mas Lejana, cuyo entorno Nosotros bendijimos. En verdad, Él es Quien todo lo oye, Quien todo lo ve.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmxxxi{Y dimos a Moisés la Escritura y la pusimos como una guía para los Hijos de Israel: «No toméis protector aparte de Mí,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmxxxii{descendientes de quienes Nosotros transportamos con Noé. En verdad, él era un siervo agradecido.»\qt@no{3}}
\qt@newcmd\qurantrans@es@mmxxxiii{Y anunciamos a los hijos de Israel en la Escritura: «Ciertamente, corromperéis la tierra dos veces y ejerceréis una gran tiranía.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmxxxiv{Y cuando la primera promesa se cumpla, enviaremos contra vosotros a Nuestros siervos dotados de un gran poder que os buscarán en el interior de las casas. Es una promesa terminante.»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmxxxv{Luego os dimos el turno (de imponeros) sobre ellos e incrementamos vuestra riqueza e hijos e hicimos de vosotros un grupo más numeroso.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmxxxvi{En verdad, si hacéis el bien lo haréis en vuestro propio beneficio y si hacéis el mal lo haréis en vuestro propio perjuicio. Y, cuando se cumpla la otra promesa, vuestros rostros reflejarán la tristeza y el miedo y entrarán en la Mezquita como entraron la primera vez y destruirán todo lo que caiga en su poder.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmxxxvii{Puede que vuestro Señor tenga misericordia de vosotros, pero si reincidís Nosotros reincidiremos y hemos puesto el Infierno como prisión para los que niegan la Verdad.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmxxxviii{En verdad, este Corán guía a lo que es más auténtico y anuncia a los creyentes que obran rectamente que hay para ellos una gran recompensa\qt@no{9}}
\qt@newcmd\qurantrans@es@mmxxxix{y que hemos preparado para quienes no creen en la Otra Vida un castigo doloroso.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmxl{El hombre busca el mal lo mismo que busca el bien. El hombre es precipitado.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmxli{Y hemos puesto la noche y el día como dos señales. Ocultamos la señal de la noche y hacemos visible la señal del día para que busquéis el favor de vuestro Señor y para que conozcáis el número de los años y para el cómputo. Hemos explicado todas las cosas de manera detallada.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmxlii{Hemos colocado los actos de cada persona en su cuello y el Día del Levantamiento haremos salir para él un libro que encontrará abierto.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmxliii{«¡Lee tu libro! ¡Hoy, tú mismo eres suficiente para ajustarte la cuenta!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmxliv{Quien se guíe, en verdad, se guía en beneficio propio y quien se extravíe, en verdad, se extravía en su propio perjuicio. Nadie portará la carga de otro y no castigamos sin haber enviado previamente un Mensajero.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmxlv{Cuando queremos destruir una ciudad, damos órdenes a los favorecidos de ella y entonces ellos transgreden. Se cumple así la palabra decretada y la destruimos completamente.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmxlvi{¡Cuántos pueblos hemos destruido después de Noé! Tu Señor se basta para estar informado y ver los pecados de Sus siervos.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmxlvii{A quien desee esta vida efímera, Nos apresuraremos a darle de ella lo que queramos, a él y a quien queramos. Luego, le pondremos en el Infierno en el que arderá maldecido, despreciado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmxlviii{Y quien desee la otra vida y se esfuerce por obtenerla y tenga fe será recompensado por su esfuerzo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmxlix{Damos a todos con largueza de los dones de tu Señor. Los dones de tu Señor no se le niegan a nadie.\qt@no{20}}
\qt@newcmd\qurantrans@es@mml{Observa como favorecemos a unos sobre otros! ¡Y en la otra vida obtendrán mayor posición y mayores favores!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmli{¡No coloques junto a Dios a otro dios, pues quedarás maldecido, abandonado!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmlii{Tu Señor ha decretado que no adoréis nada excepto a Él y que tengáis el mejor comportamiento con vuestros padres. Si se hace mayor junto a ti uno de ellos o ambos, no les digas «¡Uf!» ni les grites, sino que, más bien, háblales con palabras dulces y tiernas.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmliii{Y baja para ellos con misericordia las alas de la humildad y di: «¡Señor mío! ¡Ten misericordia de ellos igual que ellos me cuidaron cuando yo era pequeño!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmliv{Vuestro Señor es Quien mejor conoce lo que hay en vuestras almas. Si os comportáis rectamente, Él perdona a quienes se vuelven a Él arrepentidos.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmlv{Y da a tus familiares sus derechos y a los necesitados y al viajero y no seas derrochador.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmlvi{En verdad, los derrochadores son hermanos de los demonios y el Demonio es desagradecido con su Señor.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmlvii{Y si has de alejarte de ellos buscando la misericordia de tu Señor, háblales con amabilidad.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmlviii{Y no lleves tu mano cerrada a tu cuello ni la extiendas completamente, pues serás censurado y quedarás debilitado.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmlix{En verdad, tu Señor proporciona con largueza la provisión o la restringe a quien Él quiere. En verdad, Él está bien informado de Sus siervos, les observa.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmlx{Y no matéis a vuestros hijos por miedo a la pobreza. Nosotros les proveeremos y también a vosotros. Verdaderamente, matarlos es un gran pecado.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmlxi{Y no os acerquéis a la fornicación ni al adulterio. En verdad, eso es una indecencia y un mal camino.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmlxii{Y no matéis a quien Dios ha prohibido matar, excepto con derecho. Y si alguien es matado injustamente, daremos poder a su representante, pero que éste no se exceda al matar. En verdad, él ha sido auxiliado.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmlxiii{Y no os acerquéis a las propiedades del huérfano excepto para beneficiarle, hasta que llegue a la mayoría de edad. Y cumplid los contratos, pues se os pedirán cuentas por ello.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmlxiv{Y cuando midáis dad la medida justa y pesad con equidad y exactitud. Eso es lo que está bien y tiene las mejores consecuencias.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmlxv{Y no vayas tras aquello de lo que no tienes conocimiento. En verdad, del oído, de la vista, del intelecto, de todo ello se os pedirán cuentas.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmlxvi{Y no vayas por la Tierra con arrogancia. En verdad, tú no puedes atravesar la Tierra ni alcanzar la altura de las montañas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmlxvii{El mal que hay en todo ello es detestable para tu Señor.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmlxviii{Esto es parte de la sabiduría que te ha revelado tu Señor. No pongas, entonces, otro dios junto a Dios, pues caerías en el Infierno, censurado, derrotado.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmlxix{¿Acaso vuestro Señor os ha dado preferencia, otorgándoos hijos varones y tomando para Sí hijas de entre los ángeles? Verdaderamente, lo que decís son palabras mayores.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmlxx{Ciertamente, hemos diversificado la forma de exponer las cosas en este Corán de manera que reflexionen, pero sólo incrementa su rechazo.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmlxxi{Di: «Si hubiese junto a Él otros dioses, como dicen, entonces buscarían un camino hacia el Dueño del Trono.»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmlxxii{¡Glorificado y ensalzado está Él, muy por encima de lo que dicen!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmlxxiii{Los siete cielos y la Tierra y quienes en ellos están Le glorifican y no hay cosa alguna que no le glorifique con su forma de glorificar, pero vosotros no comprendéis sus glorificaciones. En verdad Él es indulgente, perdonador.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmlxxiv{Y, cuando lees el Corán, ponemos un velo invisible entre tú y quienes no creen en la otra vida.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmlxxv{Y hemos puesto sobres sus corazones velos a su entendimiento y endurecido sus oídos y, cuando recuerdas a tu Señor el Único en el Corán, se vuelven de espaldas con rechazo.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmlxxvi{Nosotros somos quienes mejor conocemos lo que escuchan cuando te escuchan y cuando deliberan en secreto. Cuando los opresores dicen: «Solamente seguís a un hombre embrujado.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmlxxvii{¡Mira a lo que te comparan! Se equivocan y no pueden encontrar el camino.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmlxxviii{Y dicen: «¿Acaso cuando seamos sólo huesos y polvo, vamos a ser creados nuevamente?»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmlxxix{Di: «¡Sed piedras o hierro\qt@no{50}}
\qt@newcmd\qurantrans@es@mmlxxx{o cualquier criatura que os parezca difícil!» Dicen: «¿Quién nos hará regresar?» Di: «El mismo que os creó la primera vez.» Y moviendo hacia ti sus cabezas con altanería dirán: «¿Cuándo será eso?» Di: «Puede que sea pronto.»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmlxxxi{El día que Él os llame, responderéis alabándole y creeréis que no habéis permanecido más que un poco.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmlxxxii{Y di a Mis siervos que hablen de la mejor manera. En verdad, Satanás incita los malos sentimientos entre ellos. Satanás es para la gente un enemigo evidente.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmlxxxiii{Vuestro Señor es quien mejor os conoce. Si Él quiere tendrá misericordia de vosotros y si quiere os castigará y no te hemos enviado a ellos para que seas su guardián.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmlxxxiv{Tu Señor es Quien mejor conoce a quienes están en los cielos y en la Tierra. Y, ciertamente, hemos favorecido a unos profetas sobre otros y otorgamos a David los Salmos.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmlxxxv{Di: «¡Invocad a quien vosotros suponéis en lugar de Él! Ellos no tienen poder para eliminar vuestras dificultades ni para cambiar vuestra situación.»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmlxxxvi{Esos mismos a quienes invocan buscan un medio para ver quién de ellos se aproxima más a su Señor y tienen esperanza en Su misericordia y temen Su castigo. En verdad, el castigo de tu Señor es digno de ser temido.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmlxxxvii{No hay pueblo que Nosotros no destruyamos antes del Día del Levantamiento o que no castiguemos con un duro castigo. Esto ha sido consignado en la Escritura.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmlxxxviii{Nada nos impidió enviar milagros, excepto el que los antiguos los desmintieran. Enviamos a Tamud la camella para que abrieran los ojos, pero la trataron injustamente. Y no enviamos los milagros sino para atemorizar.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmlxxxix{Y recuerda cuando te dijimos: «En verdad, tu Señor tiene bajo control a toda la humanidad.» No pusimos esa visión que te hicimos ver sino como una prueba para la gente, así como el árbol maldito en el Corán. Nosotros les atemorizamos, pero eso sólo incrementa en ellos su rebeldía.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmxc{Y recuerda cuando dijimos a los ángeles: «¡Prosternaos ante Adán!» y todos se prosternaron excepto Iblís. Dijo: «¿Acaso voy a prosternarme ante quien has creado de barro?»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmxci{Dijo: «¿Has visto a quién has dado preferencia sobre mí? Si me das de plazo hasta el Día del Levantamiento, destruiré, sin duda, a toda su descendencia, excepto a unos pocos.»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmxcii{Él dijo: «¡Ve tú y quien de ellos te siga! El Infierno será vuestra recompensa. Una recompensa abundante.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmxciii{Y tienta con tu voz a quien puedas de ellos y dirige contra ellos tu caballería e infantería. Y asóciate a ellos en los bienes y los hijos y hazles promesas.» Pero Satanás sólo promete mentiras.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmxciv{«En verdad, sobre Mis siervos no posees ningún poder y tu Señor es suficiente para protegerles.»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmxcv{Vuestro Señor es Quien dirige para vosotros las naves en el mar, para que podáis buscar Su favor. En verdad, Él es misericordiosísimo con vosotros.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmxcvi{Y, cuando sufrís un percance en el mar, todos aquellos a los que invocáis desaparecen excepto Él, pero cuando os pone a salvo en tierra firme os apartáis de Él. La gente carece de fe y es desagradecida.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmxcvii{¿Estáis seguros de que Él no hará que la tierra os trague o de que envíe contra vosotros una tormenta de arena? Entonces, no encontraríais nadie que os protegiera.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmxcviii{O ¿Acaso estáis seguros de que no os devolverá a él otra vez y enviará sobre vosotros un tifón huracanado que os ahogue por no haber tenido fe y ser desagradecidos? Entonces, no encontraríais nadie que reclamase por ello ante Nosotros.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmxcix{Y, ciertamente, hemos sido generosos con los seres humanos y les hemos llevado por la tierra y el mar y les hemos proveído de cosas buenas y les hemos otorgado una preferencia absoluta sobre muchas cosas de las que hemos creado.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmc{[Recuerda]el día en que convoquemos a cada grupo de gentes con su dirigente. A quienes les sea entregado su libro en su mano derecha lo leerán y no serán oprimidos en lo más mínimo.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmci{Y quien estuvo ciego en esta vida estará ciego en la Otra y aún más alejado del camino.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcii{Cerca estuvieron de apartarte de lo que te hemos revelado para que inventases sobre Nosotros algo diferente. Entonces te habrían tomado como amigo.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmciii{Si no te hubiésemos fortalecido habrías podido inclinarte algo hacia ellos.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmciv{Entonces te habríamos hecho probar el doble en la vida y el doble en la muerte, luego no habrías encontrado quien te auxiliara frente a Nosotros.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcv{Cerca han estado de persuadirte a salir de la tierra para expulsarte de ella y, entonces, no habrían permanecido en ella sino poco tiempo.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcvi{Es la costumbre de Nuestros Mensajeros, aquellos a quienes enviamos antes de ti. Y no encontrarás cambios en Nuestras costumbres.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcvii{Haz la oración desde el declinar del sol hasta entrada la noche, así como la recitación del amanecer. En verdad, la recitación del amanecer es observada.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcviii{Y levántate parte de la noche e incrementa. Puede que tu Señor te otorgue una posición bendecida.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcix{Y di: «¡Señor mío! ¡Hazme entrar con sinceridad y salir con sinceridad y otórgame un poder que me ayude!»\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcx{Y di: «¡Ha venido la Verdad y ha desaparecido la falsedad! ¡En verdad, la falsedad estaba llamada a desaparecer!»\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcxi{E hicimos descender en el Corán lo que es una cura y una misericordia para los creyentes y que a los opresores sólo les incrementa los perjuicios.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcxii{Cuando favorecemos al ser humano es desagradecido y se aleja y cuando sufre un mal se desespera.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcxiii{Di: «Cada cual actúa conforme a su forma de ser y vuestro Señor es Quien mejor conoce quién va mejor guiado en el camino.»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcxiv{Te preguntan sobre el Espíritu, di: «El Espíritu es una de las ordenes de mi Señor y no se os ha dado del conocimiento más que un poco.»\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcxv{Y si Nosotros quisiéramos nos llevaríamos lo que te hemos revelado. Entonces no encontrarías quien te protegiera de Nosotros en ello.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcxvi{Excepto por una misericordia procedente de tu Señor. En verdad, Su favor sobre ti ha sido grande.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcxvii{Di: «Si los hombres y los genios se juntasen para traer un Corán como éste no podrían traerlo aun que se ayudasen unos a otros.»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcxviii{Hemos expuesto todo tipo de ejemplos en este Corán para la gente, pero la mayoría de la gente insiste en ocultar la Verdad.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcxix{Y dicen: «No te creeremos hasta que hagas brotar de la tierra, para nosotros, una fuente que nunca se seque,\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcxx{tengas un jardín con palmeras y viñas y hagas que broten en medio de él manantiales abundantes,\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcxxi{o hagas que caiga el cielo en pedazos sobre nosotros, como pretendes que sucederá, o hasta que traigas a Dios y a los ángeles ante nosotros,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcxxii{o hasta que tengas una casa de oro o te eleves en el cielo.» «Y no creeremos en tu ascensión hasta que no hagas descender para nosotros un libro que podamos leer.» Di: «¡Glorificado sea mi Señor! ¿Acaso soy otra cosa que un ser humano, un Mensajero?»\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcxxiii{Y lo único que impide a la gente creer cuando les llega la Guía es decir: «¿Ha designado Dios mensajero a un hombre?»\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcxxiv{Di: «Si hubiera en la Tierra ángeles caminando y residiendo, Nosotros habríamos hecho descender del cielo para ellos de Mensajero a un ángel.»\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcxxv{Di: «Dios es suficiente como testigo entre yo y vosotros. En verdad, Él está bien informado de Sus siervos, les ve.»\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcxxvi{Y a quien Dios guía ese está bien guiado y a quienes extravíe, no encontrarás, aparte de Él, quienes les protejan y sean sus amigos y el Día del Levantamiento les reuniremos boca abajo, ciegos, mudos y sordos. Su refugio será el Infierno. Cada vez que sus llamas decrezcan las avivaremos.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcxxvii{Esa será su recompensa por no haber creído en Nuestras señales y porque dijeron: «¿Acaso cuando seamos huesos y polvo se nos otorgará una nueva Creación?»\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcxxviii{¿Acaso no ven que Dios, que ha creado los cielos y la Tierra, tiene poder para crear otros como ellos, y que les ha dado un plazo sobre el que no hay duda? Los opresores perseveran en ocultar la Verdad.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmcxxix{Di: «Incluso si poseyeseis los tesoros de la misericordia de mi Señor, los retendríais con avaricia por miedo a gastarlos.» El hombre es muy tacaño.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmcxxx{Ciertamente, dimos a Moisés nueve señales claras. Pregunta a los Hijos de Israel cuando fue a ellos y el Faraón le dijo: «En verdad, creo ¡Oh, Moisés! que estás embrujado.»\qt@no{101}}
\qt@newcmd\qurantrans@es@mmcxxxi{[Moisés] Dijo: «Tu sabes que estas señales no las ha hecho descender sino el Señor de los cielos y la Tierra para abrir los ojos de las gentes. Y creo ¡Oh Faraón! que serás destruido.»\qt@no{102}}
\qt@newcmd\qurantrans@es@mmcxxxii{Él quiso expulsar a la gente del país y Nosotros le ahogamos, a él y a todos los que estaban con él.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmcxxxiii{Y, tras ello, dijimos a los Hijos de Israel: «Habitad la tierra y cuando venga a vosotros la promesa final os traeremos a todos juntos.»\qt@no{104}}
\qt@newcmd\qurantrans@es@mmcxxxiv{Con la Verdad lo hicimos descender y con la Verdad descendió y no te enviamos sino como un portador de buenas noticias y un amonestador.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmcxxxv{Es un Corán que hemos dividido en pequeñas partes para que lo recites a la gente poco a poco y que hicimos descender gradualmente.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmcxxxvi{Di: «Creáis en él o no creáis, en verdad, aquellos a quienes les fue dado el conocimiento antes de él, cuando se les recita, caen al suelo con la frente en prosternación\qt@no{107}}
\qt@newcmd\qurantrans@es@mmcxxxvii{y dicen: “¡Glorificado sea nuestro Señor! ¡La promesa de nuestro Señor se cumple!»\qt@no{108}}
\qt@newcmd\qurantrans@es@mmcxxxviii{Ponen la frente en el suelo llorando y su humildad aumenta.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmcxxxix{Di: «¡Invocad a Dios o invocad al Misericordiosísimo! De cualquier manera que Le invoquéis, a Él pertenecen los mejores nombres.» Y no levantes la voz excesivamente en tus oraciones ni tampoco la conviertas en un murmullo, más bien busca un camino intermedio.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmcxl{Y di: «Glorificado sea Dios que no ha tomado hijos y que no tiene socio en el reinado y que no necesita que nadie Le proteja ante la debilidad y ensálzale proclamando Su grandeza.»\qt@no{111}}
\qt@newcmd\qurantrans@es@mmcxli{\basmalahes Alabado sea Dios que hizo descender sobre Su siervo la Escritura y no ha puesto en ella nada desviado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcxlii{Hecha para advertir de un duro castigo de Su parte y para dar la buena noticia a los creyentes, aquellos que obran rectamente, de que para ellos hay una buena recompensa.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcxliii{En él estarán eternamente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcxliv{Y advierte a quienes dijeron: «Dios ha tomado un hijo.»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcxlv{Ellos no poseen ningún conocimiento sobre eso, ni tampoco sus padres. Eso que sale de sus bocas son palabras mayores. No dicen más que mentiras.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcxlvi{Puede que quieras morir de tristeza tras sus huellas si no creen en este relato.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcxlvii{En verdad, hemos puesto lo que hay en la Tierra como un adorno para probarles y ver quién de ellos actúa mejor.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcxlviii{Y, en verdad, haremos que todo lo que hay en ella desaparezca y quede pelada.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcxlix{¿Has pensado que los compañeros de la cueva y Al-Raqim son parte de Nuestras sorprendentes señales?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcl{Cuando los jóvenes puros se refugiaron en la cueva y dijeron: «¡Señor nuestro! ¡Otórganos una misericordia venida de Ti y facilítanos una guía en nuestro asunto!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcli{Y les hicimos dormir en la cueva durante muchos años.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmclii{Luego, les hicimos despertar para saber cuál de los dos grupos podría calcular mejor cuánto permanecieron.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcliii{Nosotros vamos a relatarte la historia verdadera. En verdad, ellos eran unos jóvenes buenos que creían en su Señor y Nosotros incrementamos su guía\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcliv{y fortificamos sus corazones cuando se pusieron en pie y dijeron: «Nuestro Señor es el Señor de los cielos y de la Tierra. No invocaremos, aparte de a Él, a otro dios. En ese caso estaríamos faltando a la Verdad.»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmclv{«Este pueblo nuestro ha tomado otros dioses aparte de Él. ¿Por qué no aportan pruebas evidentes de su poder?» ¿Quién es más opresor que quien inventa mentiras acerca de Dios?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmclvi{Y cuando os alejéis de ellos y de lo que adoran aparte de Dios, refugiaos en la cueva. Vuestro Señor extenderá de Su misericordia para vosotros y os ayudará a resolver vuestro asunto favorablemente.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmclvii{Habrías visto que el Sol, cuando salía, entraba por el lado derecho de la cueva y cuando se ponía se marchaba por su lado izquierdo mientras ellos estaban en un espacio amplio de ella. Eso es parte de las señales de Dios. A quien Dios guía está bien guiado y para quien Él extravía no encontrarás protector ni guía.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmclviii{Pensarías que estaban despiertos pero dormían y Nosotros les volvíamos del lado derecho y del lado izquierdo y su perro permanecía con sus patas delanteras extendidas en la boca de la cueva. Si les hubieses visto habrías huido de ellos y te habrías llenado de terror.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmclix{Entonces, les levantamos del sueño para que se preguntasen entre ellos. Uno de ellos dijo: «¿Cuánto habéis permanecido?» Dijeron: «Hemos permanecido un día o parte de un día.» Dijeron: «Vuestro Señor es quien mejor sabe lo que habéis permanecido.» «Enviad a uno de vosotros con este dinero que tenéis a la ciudad para que mire quien posee el alimento más puro y os traiga una provisión de él. Pero que sea sutil y no llame en absoluto la atención de nadie sobre vosotros.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmclx{En verdad, si ellos os descubrieran os lapidarían u os harían aceptar sus creencias y entonces nunca triunfaríais.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmclxi{Así fue como Nosotros permitimos que se descubriera su existencia, para que la gente supiese que la promesa de Dios es verdadera y que no hay duda de que la Hora llegará. Cuando discutieron entre ellos sobre su asunto, dijeron: «Construid un edificio sobre ellos. Dios es quien mejor sabe lo que fue de ellos.» Los que vencieron en su asunto dijeron: «Haremos sobre ellos un lugar de adoración.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmclxii{Dirán: «Eran tres y su perro el cuarto.» Dirán: «Eran cinco y su perro el sexto», especulando sobre lo que desconocen. Y dirán: «Eran siete y su perro el octavo.» Di: «Mi Señor es Quien mejor sabe su número. Excepto unos pocos, nadie sabe de ellos.» No discutas, por tanto, sobre ellos, excepto con pruebas y no preguntes por ellos a ninguno de ellos.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmclxiii{Y no digas jamás sobre nada: «En verdad, lo haré mañana»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmclxiv{sin añadir «Si Dios quiere.» Y recuerda a tu Señor si olvidas y di: «Puede que mi Señor me guíe a algo más correcto que esto.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmclxv{Ellos permanecieron en su cueva trescientos años y nueve más.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmclxvi{Di: «Dios es Quien mejor sabe cuánto permanecieron. A Él pertenece lo que está oculto a los sentidos en los cielos y en la Tierra. Es Quien mejor oye. Es Quien mejor ve. Aparte de Él no tienen protector o amigo y nadie comparte con Él el gobierno.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmclxvii{Y recita lo que te ha sido revelado de la Escritura de tu Señor. En Su palabra no hay cambios y no encontrarás refugio aparte de Él.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmclxviii{Y se paciente con quienes invocan a su Señor mañana y tarde deseando Su rostro y no apartes tus ojos de ellos por deseo de los adornos de esta vida mundana y no obedezcas a quien Nosotros hemos hecho que esté desatento de Nuestro recuerdo, que sólo sigue sus pasiones y actúa de manera inmoderada.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmclxix{Y di: «La Verdad procede de vuestro Señor, por tanto, quien quiera que crea y quien quiera que no crea.» En verdad, Nosotros hemos preparado para los opresores un Fuego cuyas paredes les cercarán. Y si imploran ayuda se les auxiliará con un agua como cobre fundido que les abrasará el rostro. ¡Qué mala bebida y qué mal lugar de reposo!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmclxx{En verdad, quienes creen y obran rectamente... No dejaremos que se pierda la recompensa de quien hace el bien.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmclxxi{Para ellos son los Jardines del Edén de cuyas profundidades brotan los ríos. En él serán adornados con brazaletes de oro y vestirán con ropas verdes de seda y brocado y se recostarán en lechos. ¡Qué buena recompensa y qué buen lugar de reposo!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmclxxii{Y ponles el ejemplo de dos hombres a uno de los cuales le dimos dos jardines de viñedos que rodeamos de palmeras datileras y pusimos en medio de ellos cultivos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmclxxiii{Ambos jardines daban sus frutos sin que nada se malograse e hicimos que entre ambos brotase un río.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmclxxiv{Poseía abundantes frutos y dijo a su amigo cuando conversaba con él: «Poseo más riqueza que tú y más poder en gentes.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmclxxv{Y entró en su jardín, opresor de sí mismo, diciendo: «No creo que esto pueda destruirse jamás\qt@no{35}}
\qt@newcmd\qurantrans@es@mmclxxvi{y no creo que la Hora tenga lugar y si soy devuelto a mi Señor seguro que a cambio encontraré junto a Él algo mejor que esto.»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmclxxvii{Y su amigo le dijo al conversar con él: «¿Acaso has dejado de creer en Quien te creó de barro, luego de semen y luego te dio forma de hombre?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmclxxviii{Pero Él es Dios, mi Señor y yo no asocio a nadie a mi Señor.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmclxxix{Si no, cuando entrabas en tu jardín habrías dicho: ‘¡Que sea lo que Dios quiera! ¡No hay más poder que el que viene de Dios!’ Y si ves que tengo menos bienes e hijos que tú\qt@no{39}}
\qt@newcmd\qurantrans@es@mmclxxx{puede que mi Señor me otorgue algo mejor que tu jardín y envíe contra él rayos que lo dejen arrasado\qt@no{40}}
\qt@newcmd\qurantrans@es@mmclxxxi{o haga que su agua se sumerja y no puedas encontrarla.»\qt@no{41}}
\qt@newcmd\qurantrans@es@mmclxxxii{Y se arruinó su cosecha y se retorcía las manos por todo lo que había gastado en él y ahora se había destruido, diciendo: «¡Ojalá no hubiera asociado a nadie con mi Señor!»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmclxxxiii{Y no hubo ningún grupo que le auxiliase aparte de Dios y él mismo no pudo ayudarse.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmclxxxiv{En esa situación sólo puede auxiliar Dios, la Verdad. Él es Quien mejor recompensa y Quien mejor fin otorga.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmclxxxv{Y compárales la vida de este mundo con el agua que hacemos descender del cielo y con la que se mezclan las plantas de la Tierra. Luego se secan y el viento las dispersa. Y Dios tiene poder sobre todas las cosas.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmclxxxvi{La riqueza y los hijos son el adorno de la vida de este mundo, pero los buenos actos perduran, obtendrán una mayor recompensa junto a tu Señor y son una esperanza mejor fundada.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmclxxxvii{Y [recuérdales] el día que hagamos desplazarse a las montañas y veas la Tierra desnuda, y los reunamos a todos, sin dejar fuera ni uno de ellos\qt@no{47}}
\qt@newcmd\qurantrans@es@mmclxxxviii{y sean presentados ante tu Señor en una misma fila: «Ciertamente, venís a Nosotros igual que os creamos la primera vez, a pesar de que creíais que no estableceríamos una cita para vosotros.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmclxxxix{Y sea expuesto el libro y veas a los pecadores temerosos de lo que hay en él y digan: «¡Ay de nosotros! ¿Qué libro es éste que no deja nada, pequeño o grande, sin enumerar?» Y encontrarán ante ellos lo que hicieron. Y tu Señor no oprime a nadie.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcxc{Y [recuerda]cuando dijimos a los ángeles: «Prosternaos ante Adán» y todos se prosternaron excepto Iblís que era uno de los genios y desobedeció la orden de su Señor. ¿Vais a tomarle, a él y a su descendencia, que son vuestros enemigos, como protectores en Mi lugar? ¡Qué mal cambio hacen los opresores!\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcxci{No les hice testigos de la Creación de los cielos y la Tierra ni tampoco de su propia Creación, ni tomé como ayudantes a quienes extravían a los demás.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcxcii{Y el día que Él diga: «¡Llamad a quienes pretendíais que eran Mis socios!» Les llamarán pero ellos no les responderán. Pondremos un abismo entre ellos.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcxciii{Los pecadores verán el Fuego y sabrán que caerán en él, pero no encontrarán manera de escapar.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcxciv{Ciertamente, hemos expuesto para la gente en este Corán toda clase de ejemplos, pero el ser humano es el mayor porfiador.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcxcv{¿Por qué los humanos no tienen fe cuando llega a ellos la guía y piden perdón a su Señor sino cuándo llega a ellos lo que les ocurrió a los primeros o ven el castigo ante sus ojos?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcxcvi{Y no enviamos a los Mensajeros sino como portadores de buenas noticias y amonestadores. Y quienes no creen porfían con falacias para refutar con ello la Verdad y toman a burla Mis señales y las amonestaciones.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcxcvii{Y ¿Quién es más opresor que quien, habiéndosele recordado las señales de su Señor, se aparta de ellas y olvida lo que ha enviado por delante con sus propias manos? En verdad, hemos puesto en sus corazones velos a su entendimiento y endurecido sus oídos y aunque les invites a la guía jamás se guiarán.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcxcviii{Y tu Señor es el Perdonador, Dueño de la Misericordia. Si les diese lo que han obtenido con sus actos, sin duda apresuraría su castigo, pero tienen un plazo establecido. No encontrarán refugio fuera de Él.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcxcix{Estas son las ciudades que Nosotros destruimos cuando fueron opresoras y pusimos un plazo para su destrucción.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcc{Y (recuerda) cuando Moisés le dijo a su discípulo: «No descansaré hasta que alcance la unión de los dos mares, aunque tenga que caminar durante mucho tiempo.»\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcci{Y, cuando alcanzaron la unión de los mares, olvidaron el pez de ambos y éste cogió su camino hacia el mar.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmccii{Y cuando hubieron pasado dijo a su discípulo: «Trae nuestra comida pues, ciertamente, nos encontramos fatigados de este viaje.»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcciii{Dijo: «¿Has visto? Cuando nos cobijamos en la roca me olvide del pez y nada sino Satanás hizo que me olvidara de mencionártelo, pues tomó su camino al mar de manera sorprendente.»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcciv{Dijo (Moisés): «Eso es lo que buscábamos.» Y volvieron atrás sobre sus pasos\qt@no{64}}
\qt@newcmd\qurantrans@es@mmccv{e inmediatamente encontraron a uno de Nuestros siervos al que habíamos otorgado una misericordia y habíamos instruido en una ciencia procedente de Nosotros.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmccvi{Moisés le dijo: «¿Puedo seguirte para que me enseñes de lo que se te ha enseñado de la guía?»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmccvii{Dijo: «En verdad, no podrás tener paciencia conmigo.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmccviii{¿Cómo podrías ser paciente con aquello cuyo conocimiento no abarcas?»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmccix{Dijo: «Me encontrarás, si Dios quiere, paciente y no te desobedeceré en ningún asunto.»\qt@no{69}}
\qt@newcmd\qurantrans@es@mmccx{Dijo: «Si me sigues no me preguntes sobre nada hasta que yo te diga algo sobre ello.»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmccxi{Así pues, partieron. Hasta que, cuando montaron en una barca, él hizo un agujero en ella. Dijo (Moisés): «¿La has agujereado para que se ahogue la gente que va en ella? ¡Has hecho, ciertamente, algo terrible!»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmccxii{Dijo: «¿No te dije que, en verdad, no podrías tener paciencia conmigo?»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmccxiii{Dijo: «No me tomes en cuenta el haberlo olvidado y no me impongas una tarea difícil.»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmccxiv{Y partieron. Hasta que se encontraron con un joven y él le mató. Dijo (Moisés): «¿Mataste a un ser inocente que no había matado a nadie? ¡Has cometido algo reprobable!»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmccxv{Dijo: «¿No te dije que, en verdad, no podrías tener paciencia conmigo?»\qt@no{75}}
\qt@newcmd\qurantrans@es@mmccxvi{Dijo [Moisés]: «Si te interrogo sobre algo después de esto, no me permitas seguir en tu compañía. Me disculpo ante ti.»\qt@no{76}}
\qt@newcmd\qurantrans@es@mmccxvii{Así que partieron, hasta que, al llegar a una ciudad pidieron comida a su gente pero ellos rehusaron darles hospitalidad. Entonces, encontraron un muro a punto de caerse y él lo levantó. Dijo (Moisés): «Si hubieses querido podrías haber obtenido una paga por ello.»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmccxviii{Dijo: «Ha llegado el momento de que tú y yo nos separemos. Voy a informarte del verdadero significado de aquello con lo que no has podido tener paciencia.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmccxix{En cuanto a la barca, era de una pobre gente que trabajaba en el mar. Quise inutilizarla pues venía tras ellos un rey que se apropiaba de todos los barcos por la fuerza.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmccxx{Y en cuanto al joven, sus padres eran creyentes y temimos que él les forzara a la idolatría y la pérdida de la fe\qt@no{80}}
\qt@newcmd\qurantrans@es@mmccxxi{y quisimos que su Señor les otorgase a cambio otro más puro y más misericordioso.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmccxxii{Y en cuanto al muro, era de dos jóvenes huérfanos de la ciudad y bajo él había un tesoro que les pertenecía a ambos y su padre había sido un hombre recto. Así pues, quiso tu Señor que llegasen a la pubertad y su tesoro saliese a la luz. Una misericordia de tu Señor. No lo hice por propia iniciativa. Esa es la interpretación de aquello sobre lo que no pudiste tener paciencia.»\qt@no{82}}
\qt@newcmd\qurantrans@es@mmccxxiii{Y te preguntan sobre Du l-Qarnayn. Di: «Os contaré algo sobre él.»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmccxxiv{En verdad, le dimos poder en la Tierra y los medios para todo\qt@no{84}}
\qt@newcmd\qurantrans@es@mmccxxv{y utilizó esos medios para viajar\qt@no{85}}
\qt@newcmd\qurantrans@es@mmccxxvi{hasta que, cuando alcanzó el lugar en el que el Sol se ponía, encontró que éste se ocultaba en una fuente cenagosa y allí halló a un pueblo. Dijimos: «¡Oh Du l-Qarnayn! O les castigas o les tratas con amabilidad.»\qt@no{86}}
\qt@newcmd\qurantrans@es@mmccxxvii{Dijo: «A quien oprima pronto le castigaremos. Luego se le hará regresar a su Señor y Él le castigará con un castigo sin precedentes.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmccxxviii{Pero quien tenga fe y obre rectamente obtendrá la mejor recompensa y le daremos órdenes fáciles de cumplir.»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmccxxix{Luego usó esos medios de viaje\qt@no{89}}
\qt@newcmd\qurantrans@es@mmccxxx{hasta que alcanzó el lugar en el que surgía el Sol y lo encontró ascendiendo sobre un pueblo al que no habíamos dado nada con que cubrirse de él.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmccxxxi{Así fue. Y Nosotros conocíamos bien los medios de que disponía.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmccxxxii{Luego utilizó esos medios\qt@no{92}}
\qt@newcmd\qurantrans@es@mmccxxxiii{hasta que se encontró entre dos montañas y halló cerca de ellas a un pueblo distinto de los otros dos y que no entendían ninguna habla.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmccxxxiv{Dijeron: «¡Oh, Du l-Qarnayn! Ciertamente, Yayuy y Mayuy [Gog y Magog] corrompen la Tierra. ¿Podemos entregarte un tributo para que pongas entre nosotros y ellos una barrera?»\qt@no{94}}
\qt@newcmd\qurantrans@es@mmccxxxv{Dijo: «El poder que Dios me ha dado es mejor. Ayudadme con gente y medios y pondré entre vosotros y ellos una barrera.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmccxxxvi{Traedme trozos grandes de hierro.» Cuando igualó la altura de ambas montañas, dijo: «Soplad» y cuando se puso ardiendo dijo: «Traedme cobre fundido para verterlo encima y sellar los huecos.»\qt@no{96}}
\qt@newcmd\qurantrans@es@mmccxxxvii{Y no pudieron escalarlo ni pudieron agujerearlo.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmccxxxviii{Dijo: «Esto es una misericordia procedente de mi Señor. Y cuando llegue la promesa de mi Señor la destruirá totalmente. La promesa de mi Señor es verdadera.»\qt@no{98}}
\qt@newcmd\qurantrans@es@mmccxxxix{Y dejaremos que ese día se mezclen unos con otros como olas y será tocada la trompeta y les reuniremos a todos.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmccxl{Ese día mostraremos totalmente el Infierno a los que no creían.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmccxli{Aquellos cuyos ojos estaban velados a Mi recuerdo y que no podían oír.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmccxlii{¿Acaso quienes no creen calculan que podrán tomar a Mis siervos como protectores fuera de Mí? En verdad, hemos preparado el Infierno como alojamiento para los que no creen.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmccxliii{Di: «¿Queréis que os informe de quienes son los que peor obran?\qt@no{103}}
\qt@newcmd\qurantrans@es@mmccxliv{Aquellos que malgastan sus esfuerzos persiguiendo la vida mundanal y creyendo que actúan bien.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmccxlv{Son quienes no creen en las señales de su Señor y en el encuentro con Él. Sus obras no obtendrán recompensa y el Día del Levantamiento no pondremos una balanza para ellos.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmccxlvi{Su recompensa será el Infierno por no haber creído y por haber tomado Mis señales y a Mis mensajeros a broma.»\qt@no{106}}
\qt@newcmd\qurantrans@es@mmccxlvii{En verdad, quienes creen y obran rectamente tendrán por alojamiento los jardines del Paraíso.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmccxlviii{En ellos estarán eternamente, sin desear cambio alguno.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmccxlix{Di: «Si el mar fuera tinta para las palabras de mi Señor, antes se agotaría el mar que las palabras de mi Señor, aunque trajéramos otro mar de tinta semejante.»\qt@no{109}}
\qt@newcmd\qurantrans@es@mmccl{Di: «En verdad, yo soy un ser humano igual a vosotros. Me ha sido revelado que vuestro Dios es un Dios Único. Por tanto, quien tenga esperanza de encontrarse con su Señor que obre rectamente y que no asocie a nadie en la adoración a su Señor.»\qt@no{110}}
\qt@newcmd\qurantrans@es@mmccli{\basmalahes Kaf, Ha, Ya, ‘Ain, Sad.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcclii{Recuerdo de la misericordia de tu Señor con Su siervo Zacarías,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmccliii{cuando invocó a su Señor con una súplica desde un lugar solitario,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmccliv{diciendo: «¡Señor mío! Mis huesos se han debilitado y mi cabeza ha encanecido y no tengo queja, Señor, de cuando te he suplicado.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcclv{Y, en verdad, temo por mis familiares después de mí, pues mi esposa es estéril. Otórgame, pues, un hijo\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcclvi{que herede de mí y de la familia de Jacob. Y hazlo, Señor, complacido.»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcclvii{«¡Oh, Zacarías! En verdad, te anunciamos un hijo de nombre Juan. No habíamos dado ese nombre a nadie antes de él.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcclviii{Dijo: «¡Señor mío! ¿Cómo podré tener un hijo siendo mi mujer estéril y habiendo llegado yo, por la mucha edad, a la decrepitud?»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcclix{Dijo: «Así ha hablado tu Señor: Eso es sencillo para Mí. Yo te creé anteriormente, cuando no eras nada.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcclx{Dijo: «¡Señor mío! Dame una señal.» Dijo: «Tu señal será que no hablarás con nadie durante tres noches, aun estando sano.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcclxi{Así pues, salió ante su pueblo desde el lugar en el que rezaba y les indicó que glorificasen mañana y tarde.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcclxii{«¡Oh, Juan! ¡Toma la Escritura Sagrada con fuerza!» Y le otorgamos la sabiduría desde niño\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcclxiii{y le concedimos de Nuestra compasión y pureza y fue temeroso de Dios\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcclxiv{y bueno con sus padres y no arrogante ni desobediente.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcclxv{¡La paz sobre él el día en que nació, el día en que muera y el día en que sea devuelto a la vida!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcclxvi{Y recuerda en la Escritura a María cuando se apartó de su familia hacia un lugar oriental\qt@no{16}}
\qt@newcmd\qurantrans@es@mmcclxvii{puso un velo que la apartase de ellos. Nosotros enviamos para ella a Nuestro Espíritu, que se presentó ante ella con la forma de un ser humano completo.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmcclxviii{Ella dijo: «En verdad, me refugio en el Clementísimo de ti, si eres temeroso de Dios.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmcclxix{Él dijo: «En verdad, yo soy un Mensajero de tu Señor para otorgarte un muchacho puro.»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmcclxx{Ella dijo: «¿Cómo tendré un hijo si no me ha tocado ningún ser humano y no he perdido mi castidad?»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmcclxxi{Él dijo: «Así ha dicho tu Señor: ¡Eso es fácil para Mí! Haremos de él una señal para la gente y una misericordia procedente de Nosotros. Es un asunto decidido.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmcclxxii{Así que ella le concibió y se retiró con él a un lugar apartado.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmcclxxiii{Los dolores del parto la llevaron junto al tronco seco de una palmera. Ella dijo: «¡Ojalá hubiese muerto antes de pasar por esto y hubiese sido totalmente olvidada!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmcclxxiv{Entonces, él la llamó desde debajo de ella: «No estés triste por mi causa. Tu Señor ha puesto a tus pies un arroyo.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmcclxxv{Mueve hacia ti el tronco de la palmera y caerán sobre ti dátiles maduros recién cortados.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmcclxxvi{«Así que come y bebe y alegra tus ojos. Y si ves a algún ser humano dile: En verdad, he hecho voto al Clementísimo de ayunar, por tanto hoy no hablaré con nadie.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmcclxxvii{Y volvió con él a su gente llevándole en brazos. Ellos dijeron: «¡Oh, María! ¡Ciertamente, has venido con un grave asunto!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmcclxxviii{¡Oh, hermana de Aarón! ¡Tu padre no era un hombre malo, ni tu madre era una transgresora!»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmcclxxix{Entonces, ella señaló hacia él. Ellos dijeron: «¿Cómo vamos a hablar con un niño que está en la cuna?»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmcclxxx{Él dijo: «En verdad, yo soy un siervo de Dios. Él me ha dado la Escritura y me designó profeta\qt@no{30}}
\qt@newcmd\qurantrans@es@mmcclxxxi{y me ha bendecido dondequiera que yo esté y me ha encomendado la oración y el pago del impuesto religioso mientras viva\qt@no{31}}
\qt@newcmd\qurantrans@es@mmcclxxxii{y que sea bueno con mi madre. Y no me ha hecho arrogante ni orgulloso.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmcclxxxiii{Y la paz ha estado conmigo el día en que nací y estará el día en que muera y el día en que vuelva a la vida.»\qt@no{33}}
\qt@newcmd\qurantrans@es@mmcclxxxiv{Éste es Jesús el hijo de María, el que proclama la Verdad acerca de la cual dudan.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmcclxxxv{No es propio de Dios tener un hijo. ¡Glorificado sea! Cuando Él decide un asunto, en verdad, le dice: «¡Sé! y es».\qt@no{35}}
\qt@newcmd\qurantrans@es@mmcclxxxvi{Y, en verdad, Dios es mi Señor y vuestro Señor. Así pues, ¡Adoradle! ¡Ese es el camino recto!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmcclxxxvii{Pero los grupos discreparon entre ellos. ¡Ay de quienes no creen cuando sean testigos de un Día Inmenso!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmcclxxxviii{¡Qué bien oirán y verán el día en que vengan a Nosotros! Pero los tiranos se encuentran hoy en un extravío evidente.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmcclxxxix{Y adviérteles del Día del Remordimiento, cuando se decida el asunto. Pero ellos están descuidados y no creen.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmccxc{En verdad, Nosotros heredaremos la Tierra y a quienes están en ella y a Nosotros retornarán.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmccxci{Y recuerda en la Escritura a Abraham -Ciertamente, él era amante de la Verdad, profeta-\qt@no{41}}
\qt@newcmd\qurantrans@es@mmccxcii{cuando dijo a su padre: «¡Oh, padre! ¿Por qué adoras a lo que no oye ni ve y no puede beneficiarte en nada?»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmccxciii{«¡Oh, padre! En verdad, ha llegado a mí un conocimiento que no ha llegado a ti, así que, sígueme y te guiaré a un camino recto.»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmccxciv{«¡Oh, padre! ¡No adores al Demonio! En verdad, el Demonio es rebelde con el Clementísimo.»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmccxcv{«¡Oh, padre! En verdad, temo que te alcance un castigo del Clementísimo y te conviertas en amigo del Demonio.»\qt@no{45}}
\qt@newcmd\qurantrans@es@mmccxcvi{Él dijo: «¿Acaso ¡Oh, Abraham! te disgustan mis dioses? ¡Si no desistes te lapidaré! ¡Aléjate de mí por un tiempo prolongado!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmccxcvii{[Abraham] dijo: «La paz sea contigo. ¡Pediré a mi Señor que te perdone! En verdad, Él es complaciente conmigo.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmccxcviii{«Me apartaré de vosotros y de lo que adoráis aparte de Dios y suplicaré a mi Señor. Quizás no quede defraudado de mi ruego a mi Señor.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmccxcix{Así que, cuando se apartó de ellos y de lo que ellos adoraban en lugar de Dios, le otorgamos a Isaac y a Jacob e hicimos a ambos profetas.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmccc{Y les otorgamos de Nuestra misericordia y les dimos una altísima reputación.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmccci{Y recuerda en la Escritura a Moisés. En verdad, él era un ser puro, Mensajero y profeta.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcccii{Y le llamamos desde el lado derecho del monte y le acercamos a Nosotros para hablar con él confidencialmente.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmccciii{Y le otorgamos, por Nuestra misericordia, a su hermano Aarón como profeta.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmccciv{Y recuerda en la Escritura a Ismael. En verdad, fue cumplidor de la promesa y fue Mensajero y profeta.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcccv{Solía invitar a su familia a la oración y al impuesto religioso purificador de la riqueza y su Señor estaba satisfecho de él.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcccvi{Y recuerda en la Escritura a Idrís. Ciertamente él era veraz, profeta,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcccvii{y le elevamos a una altísima posición espiritual.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcccviii{Esos son los que Dios ha agraciado de entre los profetas de la descendencia de Adán y de entre los que llevamos con Noé y de la descendencia de Abraham e Israel y de los que Nosotros guiamos y escogimos, quienes, cuando les eran recitados los versículos del Clementísimo, caían prosternados y llorando.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcccix{Tras ellos, sus descendientes se desviaron, abandonaron la oración y siguieron sus pasiones y pronto encontrarán su extravío.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcccx{Excepto quienes se arrepientan, tengan fe y obren rectamente, pues ellos entrarán en el Jardín y no serán oprimidos en absoluto.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcccxi{Jardines del Edén que el Clementísimo ha prometido a Sus siervos, aunque aún no los hayan visto. La promesa de Dios se cumplirá.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcccxii{Allí no escucharán palabras vanas, sino solamente ¡Paz! y en ellos tendrán su provisión mañana y tarde.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcccxiii{Ese es el Jardín que Nosotros daremos en herencia a aquellos de Nuestros siervos que sean temerosos.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcccxiv{Y no lo hacemos descender sino por orden de tu Señor. A Él pertenece lo que tenemos entre nuestras manos y lo que tenemos a nuestras espaldas y lo que hay entre ello. Tu Señor no es olvidadizo.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcccxv{Señor de los cielos y de la Tierra y de lo que entre ellos hay. Así pues ¡Adoradle y perseverad en vuestra adoración a Él! ¿Conoces a alguien así denominado?\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcccxvi{El ser humano dice: «¿Acaso cuando muera seré sacado a la vida?»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcccxvii{¿Acaso no recuerda el ser humano que Nosotros le creamos anteriormente, cuando no era nada?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcccxviii{Juro por tu Señor que les reuniremos a ellos y a los demonios y les haremos comparecer en el Infierno de rodillas.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcccxix{Luego, sacaremos de cada grupo a los que hayan sido más desobedientes al Clementísimo.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcccxx{Pues, ciertamente, Nosotros somos Quienes mejor sabemos quiénes son los que más merecen abrasarse en él.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcccxxi{Y todos vosotros entraréis en él. Es una decisión terminante de tu Señor.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcccxxii{Luego, salvaremos a los que son temerosos de Dios y dejaremos allí de rodillas a los opresores.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcccxxiii{Y cuando les son recitados Nuestros claros versículos, aquellos que no tienen fe dicen a los creyentes. «¿Cuál de los dos grupos disfruta de mejor posición y compañía?»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcccxxiv{¡Cuántas generaciones hemos destruido antes de ellos que poseían mejores propiedades y apariencia!\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcccxxv{Di: «A quienes estén en el extravío, el Clementísimo se lo prolongará hasta que, cuando vean lo que les fue prometido, bien sea el castigo o bien la Hora, sepan quién tiene peor posición y un ejército más débil.»\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcccxxvi{Y Dios incrementa la guía de quienes van por el buen camino y los buenos actos perdurables obtienen mejor recompensa junto a tu Señor y mejor lugar de regreso.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcccxxvii{¿Acaso no has visto a quien niega Nuestras señales y dice: «Me serán dados riqueza e hijos abundantes.»?\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcccxxviii{¿Es que está informado de lo que está oculto a los sentidos o ha obtenido una promesa del Clementísimo?\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcccxxix{¡Nada de eso! ¡Tomaremos nota de lo que dice y le prolongaremos el castigo!\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcccxxx{Y heredaremos de él lo que dice y vendrá a Nosotros él solo.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcccxxxi{En lugar de Dios toman otros dioses para que les den poder.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcccxxxii{¡Pero no! ¡Rechazarán la adoración que ellos les profesan y se pondrán contra ellos!\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcccxxxiii{¿No ves que Nosotros enviamos a los demonios sobre aquellos que no creen para que les inciten con insistencia al mal?\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcccxxxiv{No tengas prisa respecto a ellos, que Nosotros llevamos su cuenta con precisión.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcccxxxv{El día en que reunamos a los temerosos de Dios como invitados del Clementísimo\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcccxxxvi{y conduzcamos a los pecadores sedientos hacia el Infierno,\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcccxxxvii{nadie tendrá poder para interceder excepto quien haya realizado un compromiso con el Clementísimo.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcccxxxviii{Y dicen: «El Clementísimo ha tomado un hijo.»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcccxxxix{Ciertamente, venís con algo odioso.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcccxl{A punto están los cielos de rasgarse, de abrirse la Tierra y de desmoronarse las montañas\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcccxli{por haber ellos atribuido un hijo al Clementísimo.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcccxlii{No tiene sentido que el Clementísimo tome un hijo.\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcccxliii{No hay nadie en los cielos y la Tierra que no venga como siervo ante el Clementísimo.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcccxliv{Ciertamente, Él los ha enumerado a todos y los ha contado con precisión\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcccxlv{y todos ellos vendrán a Él en solitario El Día Del Levantamiento\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcccxlvi{En verdad, el Clementísimo ha puesto el amor para aquellos que creen y obran rectamente.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcccxlvii{Y, en verdad, lo hemos hecho fácil para tu lengua, de manera que, por medio de él, anuncies la buena nueva a los temerosos de Dios y amonestes a la gente hostil.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcccxlviii{¡Cuántas generaciones hemos aniquilado antes de ellos! ¿Acaso percibes a alguno de ellos o les escuchas murmurar?\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcccxlix{\basmalahes Ta Ha.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcccl{No hicimos descender el Corán sobre ti para crearte molestias\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcccli{sino para invitar al recuerdo a quienes son temerosos.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmccclii{Hecho descender por Quien creó la Tierra y los altos cielos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcccliii{El Clementísimo está sobre el Trono.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcccliv{A Él pertenece lo que hay en los cielos y en la Tierra y lo que hay entre ambos y lo que hay bajo ella.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmccclv{Y, aunque hables en voz baja, en verdad, Él conoce lo secreto y lo más oculto.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmccclvi{Al.lah, no hay más dios que Él. A Él pertenecen los nombres mejores.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmccclvii{¿Te ha llegado el relato de Moisés?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmccclviii{Cuando vio un fuego y dijo a su familia: «¡Esperad! En verdad, he creído divisar un fuego. Puede que traiga unas brasas para vosotros o que encuentre el camino con él.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmccclix{Y cuando llegó a él, fue llamado: «¡Oh, Moisés!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmccclx{¡En verdad, Yo soy tu Señor! Así pues, quítate tus sandalias. Estás, en verdad, en el valle sagrado de Tuwa.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmccclxi{Y Yo te he elegido, así que escucha lo que te ha sido revelado.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmccclxii{En verdad, Yo soy Dios. No hay más dios que Yo. Así pues ¡Adoradme y haced la oración en recuerdo Mío!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmccclxiii{En verdad, la Hora viene. He querido mantenerla oculta para que cada alma sea recompensada conforme a su esfuerzo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmccclxiv{Que no te aparten de ella quienes no creen en ella y siguen sus pasiones y seas aniquilado.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmccclxv{¿Y qué es eso ¡Oh, Moisés! que tienes en tu mano derecha?»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmccclxvi{Él dijo: «Es mi bastón. En él me apoyo y con él vareo los árboles para alimentar a mi ganado y también le doy otros usos.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmccclxvii{Dijo [Dios]: «¡Lánzalo! ¡Oh, Moisés!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmccclxviii{Y lo arrojó y fue una serpiente reptando veloz.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmccclxix{Dijo [Dios]: «¡Tómalo y no tengas miedo! Lo devolveremos a su condición primera.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmccclxx{Y guarda tu mano bajo tu axila. Saldrá blanca, sin defecto alguno. Es otra señal,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmccclxxi{para hacerte ver algunas de Nuestras grandes señales.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmccclxxii{«Y ve al Faraón. En verdad, él se ha endiosado.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmccclxxiii{Dijo [Moisés]: «¡Señor mío! Ensancha mi pecho\qt@no{25}}
\qt@newcmd\qurantrans@es@mmccclxxiv{y facilita mi misión\qt@no{26}}
\qt@newcmd\qurantrans@es@mmccclxxv{y desata el nudo de mi lengua\qt@no{27}}
\qt@newcmd\qurantrans@es@mmccclxxvi{para que entiendan mis palabras.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmccclxxvii{Y ponme un ayudante de mi familia.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmccclxxviii{A Aarón, mi hermano.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmccclxxix{Fortalece con él mi poder\qt@no{31}}
\qt@newcmd\qurantrans@es@mmccclxxx{y asóciale a mi misión\qt@no{32}}
\qt@newcmd\qurantrans@es@mmccclxxxi{para que Te glorifiquemos mucho\qt@no{33}}
\qt@newcmd\qurantrans@es@mmccclxxxii{y Te recordemos mucho.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmccclxxxiii{En verdad, Tú siempre has estado informado de nuestra situación.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmccclxxxiv{Dijo: «El poder que Dios me ha dado es mejor. Y dejaremos que ese día se mezclen unos con otros como olas y será tocada la trompeta y les reuniremos a todos. Dijo [Dios]: «Ciertamente te he concedido tus peticiones ¡Oh, Moisés!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmccclxxxv{Y, ciertamente, ya te habíamos agraciado otra vez\qt@no{37}}
\qt@newcmd\qurantrans@es@mmccclxxxvi{cuando Nosotros revelamos a tu madre lo que le fue revelado:\qt@no{38}}
\qt@newcmd\qurantrans@es@mmccclxxxvii{Ponle en la cesta y pon ésta en el río y el río la depositará en la costa. Le recogerá un enemigo Mío y enemigo suyo.» Y deposité sobre ti Mi amor, para que fueras criado bajo Mi mirada\qt@no{39}}
\qt@newcmd\qurantrans@es@mmccclxxxviii{cuando tu hermana fue y dijo: «¿Queréis que os indique a quien se ocupe de él?» y te hicimos regresar a tu madre para que se alegraran sus ojos y no estuviera triste. Y mataste a un hombre y Nosotros te salvamos de la angustia y te pusimos a prueba en la dificultad. Y permaneciste durante años con la gente de Madyan. Luego, viniste cuando estaba decretado ¡Oh, Moisés!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmccclxxxix{Te he escogido y purificado para Mí.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmcccxc{¡Id, tú y tu hermano con Mis señales y no os debilitéis en el recuerdo de Mí!\qt@no{42}}
\qt@newcmd\qurantrans@es@mmcccxci{¡Id ambos al Faraón! ¡En verdad, se ha endiosado!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmcccxcii{Y habladle con amabilidad. Quizás así se deje llamar al recuerdo o tema.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcccxciii{Ellos dijeron: «¡Señor nuestro! ¡En verdad, tememos que se precipite sobre nosotros o que se extralimite en su opresión!»\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcccxciv{Dijo: «¡No temáis! En verdad, Yo estaré con vosotros dos. Oiré y veré.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcccxcv{Así que id a él y decidle: En verdad, somos Mensajeros de tu Señor. Deja, por tanto, ir con nosotros a los Hijos de Israel y no les castigues. Ciertamente, hemos venido a ti con una señal procedente de tu Señor. La paz sea con quien sigue la Guía.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcccxcvi{En verdad, nos ha sido revelado que quien desmienta y de la espalda será castigado.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcccxcvii{Dijo [Faraón]: «¿Quién es entonces ¡Oh, Moisés! vuestro Señor?»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcccxcviii{Dijo: «Nuestro señor es Quien ha creado toda cosa y luego la ha guiado.»\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcccxcix{Dijo: «¿Y qué fue de las generaciones primeras?»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcd{Dijo: «El conocimiento de ellos está junto a mi Señor en una Escritura. Mi Señor no se equivoca ni se olvida.»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcdi{Él es Quien ha puesto para vosotros la Tierra como un lecho y ha trazado en ella, para vosotros, caminos e hizo descender del cielo agua, por medio de la cual hacemos surgir diversas clases de plantas por parejas.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcdii{¡Comed y pastoread vuestro ganado! En verdad, en ello hay señales para quien posee inteligencia.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcdiii{De ella os hemos creado y a ella os hacemos regresar y de ella os haremos salir otra vez.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcdiv{Ciertamente, le hicimos ver todas Nuestras señales, pero él las negó y rechazó.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcdv{Dijo: «¡Oh Moisés! ¿Has venido a nosotros para sacarnos de nuestra tierra con tu magia?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcdvi{Pues vendremos a ti con una magia semejante. Fija una cita entre nosotros y tú en un terreno neutral, a la que ni nosotros ni tú faltaremos.»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcdvii{Dijo: «Vuestra cita será el Día del Adorno y que la gente se reúna al medio día.»\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcdviii{El Faraón se retiró. Preparó su plan y acudió.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcdix{Moisés les dijo: «¡Ay de vosotros! ¡No inventéis mentiras sobre Dios, pues os aniquilará con un castigo! ¡Ciertamente, quien invente mentiras fracasará!»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcdx{Así que discutieron la cuestión entre ellos y mantuvieron en secreto sus deliberaciones.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcdxi{Dijeron. «En verdad, esos dos son magos que quieren expulsaros de vuestra tierra con su magia y destruir vuestras tradiciones.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcdxii{Así que, reunid vuestros artificios y venid en una fila cerrada. Quien gane hoy será el triunfador.»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcdxiii{Ellos dijeron: «¡Oh Moisés! ¡Lanza tú o seremos nosotros los primeros en lanzar!»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcdxiv{Dijo: «¡Lanzad pues!» Entonces le pareció, por efecto de su magia, que sus cuerdas y bastones caminaban\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcdxv{y Moisés sintió miedo en su interior.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcdxvi{Dijimos: «¡No temas! ¡En verdad, tú eres superior!»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcdxvii{«¡Lanza lo que tienes en tu mano derecha y se tragará lo que han creado!» «En verdad, lo que han creado son trucos de mago y el mago no triunfará donde quiera que vaya.»\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcdxviii{Y los magos cayeron prosternados. Dijeron: «¡Creemos en el Señor de Aarón y Moisés!»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcdxix{Dijo [Faraón]: «¿Habéis creído en Él antes de que yo os diera permiso?» «Él es vuestro maestro y el que os ha enseñado a vosotros la magia. Os cortaré las manos y los pies opuestos y os crucificaré en el tronco de una palmera y sabréis quién de nosotros castiga de manera más dura y permanente.»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcdxx{Ellos dijeron: «Nunca te preferiremos a ti por encima de las pruebas claras que nos han llegado y de Aquel que nos ha creado.» «Decidas lo que decidas, tú decides sobre la vida de este mundo»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcdxxi{«En verdad, hemos creído en nuestro Señor para que nos perdone por nuestros errores y por la magia que nos has obligado a realizar. Dios es mejor y más duradero.»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcdxxii{En verdad, quien venga a su Señor como un pecador obtendrá el Infierno, en el cual no morirá ni vivirá.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcdxxiii{Y quienes vengan a Él como creyentes que han obrado rectamente obtendrán los grados más elevados.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcdxxiv{Los Jardines del Edén, de cuyas profundidades brotan los ríos y en los que estarán eternamente. Y esa será la recompensa de quien se haya purificado.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcdxxv{Y, ciertamente, revelamos a Moisés: «Saca a Mis siervos en el secreto de la noche y abre para ellos un camino seco en el mar. No temas que os persigan y no tengas miedo.»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcdxxvi{Y les persiguió el Faraón con su ejército y el mar les cubrió totalmente con sus olas.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcdxxvii{El Faraón extravió a su pueblo y no le guió.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcdxxviii{«¡Oh, Hijos de Israel! Os salvamos de vuestros enemigos y os citamos junto a la ladera derecha del monte e hicimos descender para vosotros el maná y las codornices.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcdxxix{Comed de lo bueno y puro que os hemos proporcionado y no os endioséis en ello, pues provocaríais Mi ira sobre vosotros y quien provoque Mi ira sobre él, ciertamente, se hundirá.»\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcdxxx{Y, en verdad, Yo soy muy perdonador con quien se arrepiente y tiene fe y actúa rectamente y, por tanto, sigue la buena guía.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcdxxxi{«¡Oh, Moisés! ¿Por qué te has adelantado tan apresuradamente a tu pueblo?»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcdxxxii{Dijo: «Ellos vienen siguiendo mis pasos y yo me apresuré en venir a Ti, Señor mío, para complacerte.»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcdxxxiii{Dijo (Dios): «En verdad, pusimos a prueba a tu pueblo después de que tú les dejases y el samaritano les extravió.»\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcdxxxiv{Moisés regresó a su pueblo enfadado y muy preocupado. Dijo: «¡Oh, pueblo mío! ¿Acaso vuestro Señor no os hizo una buena promesa? ¿Acaso os pareció demasiado larga la espera en mi ausencia o quisisteis provocar sobre vosotros la ira de vuestro Señor y por eso faltasteis a la promesa que me hicisteis?»\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcdxxxv{Dijeron: «No faltamos a la promesa que te hicimos por deseo propio, sino que cargábamos las joyas del pueblo y las arrojamos al fuego y el samaritano hizo esto con ellas.»\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcdxxxvi{Y fabricó para ellos la estatua de un ternero que mugía. Y dijeron: «Éste es vuestro dios y el dios de Moisés, y se olvidó.»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcdxxxvii{¿Acaso no vieron que no les respondía y que no tenía poder para perjudicarles ni beneficiarles?\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcdxxxviii{Ciertamente, Aarón les había dicho anteriormente: «¡Oh, pueblo mío! ¡En verdad, se os está poniendo a prueba con ello y, en verdad, vuestro Señor es el Clementísimo! ¡Seguidme pues y obedeced mis órdenes!»\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcdxxxix{Ellos dijeron: «¡No dejaremos de adorarle hasta que Moisés regrese a nosotros!»\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcdxl{Moisés) dijo: «¡Oh, Aarón! ¿Qué te impidió, cuando les vistes que se extraviaban,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcdxli{seguirme? ¿Acaso desobedeciste mis órdenes?»\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcdxlii{Él dijo: «¡Oh, hijo de mi madre! ¡No me tires de la barba ni me tomes de la cabeza! En verdad, temí que me dijeras: ‘Has dividido a los Hijos de Israel y no tuviste en cuenta mis palabras.’»\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcdxliii{Moisés) dijo: «Y tú, Samaritano ¿Qué tienes que decir?»\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcdxliv{Él dijo: «Yo observé lo que ellos no observaron y tomé un puñado de la huella del Mensajero y lo arrojé. Eso fue lo que mi ego me sugirió.»\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcdxlv{Moisés) dijo: «¡Vete! En verdad, durante toda tu vida tendrás que decir: ‘¡No me toques!’ Y, en verdad, tienes una cita a la que no podrás faltar. Y mira a tu dios, al cual seguiste con devoción. Lo quemaremos y dispersaremos totalmente sus restos en el mar.»\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcdxlvi{En verdad, tu dios es Dios. No hay otro dios más que Él. Su conocimiento abarca todas las cosas.\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcdxlvii{Así es como te hemos relatado algunas noticias de lo que sucedió en el pasado. Ciertamente, te hemos dado un Recuerdo procedente de Nosotros.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmcdxlviii{Quien se aparte de él cargará el Día del Levantamiento con un pesado fardo\qt@no{100}}
\qt@newcmd\qurantrans@es@mmcdxlix{que portará eternamente. ¡Qué mala carga para ellos el Día del Levantamiento!\qt@no{101}}
\qt@newcmd\qurantrans@es@mmcdl{El día en que sea tocada la trompeta. Y juntaremos ese día a los pecadores con los ojos morados,\qt@no{102}}
\qt@newcmd\qurantrans@es@mmcdli{que susurrarán entre ellos: “Sólo hemos permanecido diez días [muertos].»\qt@no{103}}
\qt@newcmd\qurantrans@es@mmcdlii{Nosotros somos quienes mejor sabemos de lo que hablan cuando el mejor de ellos dice: «Sólo permanecisteis un día.»\qt@no{104}}
\qt@newcmd\qurantrans@es@mmcdliii{Y te preguntan sobre las montañas. Di: «Mi Señor las pulverizará y aventará\qt@no{105}}
\qt@newcmd\qurantrans@es@mmcdliv{y las dejará como una llanura desértica.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmcdlv{No verás en ella valles ni colinas.»\qt@no{107}}
\qt@newcmd\qurantrans@es@mmcdlvi{Ese día seguirán a quien les convocará sin cometer un solo error y se apagarán las voces ante el Clementísimo y no escucharás más que un susurro.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmcdlvii{Ese día no servirá la intercesión excepto de aquel a quien el Clementísimo de permiso y de cuya palabra Él esté satisfecho.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmcdlviii{Él conoce lo que ellos tienen entre sus manos y lo que hay a sus espaldas, pero ellos no abarcan el conocimiento que Él posee.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmcdlix{Sus rostros se humillarán ante Quien es la Vida y el Sustentador de la vida y, ciertamente, habrá fallado quien cargue con injusticias.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmcdlx{Y quien haya realizado buenas obras y sea creyente no temerá ser oprimido ni ser tratado injustamente.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmcdlxi{Así es como lo hemos hecho descender, como un Corán árabe, y hemos expuesto en él amonestaciones de distintas maneras para que, quizás así, sean temerosos o les sirva de recuerdo.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmcdlxii{Ensalzado sea Dios, el Soberano verdadero. Y no te apresures con la recitación del Corán antes de que se complete su revelación y di: “¡Señor mío! ¡Incrementa mi conocimiento!\qt@no{114}}
\qt@newcmd\qurantrans@es@mmcdlxiii{Anteriormente, habíamos aceptado una promesa de Adán pero él la olvidó y no encontramos en él firmeza.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmcdlxiv{Cuando dijimos a los ángeles: «Prosternaos ante Adán.» y se prosternaron todos menos Iblís que se negó.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmcdlxv{Dijimos: «¡Oh, Adán! En verdad, éste es un enemigo para ti y para tu pareja, así que no le permitáis que os saque del Jardín pues sufriríais.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmcdlxvi{En verdad, en él no sufrirás hambre ni desnudez\qt@no{118}}
\qt@newcmd\qurantrans@es@mmcdlxvii{y en él no pasarás sed ni calor.»\qt@no{119}}
\qt@newcmd\qurantrans@es@mmcdlxviii{Pero le tentó Satanás. Dijo: «¡Oh, Adán! ¿Puedo mostrarte el árbol de la inmortalidad y del gobierno imperecedero?»\qt@no{120}}
\qt@newcmd\qurantrans@es@mmcdlxix{Entonces, ambos comieron de él y se les hizo evidente su desnudez y comenzaron a cubrirse mutuamente con hojas del Jardín. Adán desobedeció a su Señor y se extravió.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmcdlxx{Luego, su Señor le escogió, aceptó su arrepentimiento y le guió.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmcdlxxi{Dijo: «Descended ambos de él, todos juntos. Seréis enemigos unos de otros.» Y si viene a vosotros una guía procedente de Mí, quien siga Mi guía no se extraviará ni se sentirá desgraciado.\qt@no{123}}
\qt@newcmd\qurantrans@es@mmcdlxxii{Pero quien se aparte de Mi recuerdo tendrá una vida difícil y el Día del Levantamiento le resucitaremos ciego.\qt@no{124}}
\qt@newcmd\qurantrans@es@mmcdlxxiii{Dirá: «¡Dios mío! ¿Por qué me resucitas ciego, si yo veía?»\qt@no{125}}
\qt@newcmd\qurantrans@es@mmcdlxxiv{Dirá: «Así como te di Nuestras señales y tú las olvidaste, de la misma manera hoy tú eres olvidado.»\qt@no{126}}
\qt@newcmd\qurantrans@es@mmcdlxxv{Y a quien se propase y no crea en las señales de su Señor Nosotros le recompensaremos de la misma manera. Y el castigo de la otra vida es peor y más duradero.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmcdlxxvi{¿Es que no les sirve de guía ver cuántas generaciones, por cuyas moradas caminan, hemos destruido antes de ellos? En verdad, en ello hay señales para quienes poseen inteligencia.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmcdlxxvii{Y si no hubiese sido por una palabra previa de tu Señor y por un plazo determinado previamente ellos también lo habrían sido.\qt@no{129}}
\qt@newcmd\qurantrans@es@mmcdlxxviii{Por tanto, se paciente con lo que dicen y glorifica con alabanzas a tu Señor antes de la salida del Sol y antes de que se oculte. Y glorifícale parte de la noche y en los extremos del día. Quizás así estés satisfecho y feliz.\qt@no{130}}
\qt@newcmd\qurantrans@es@mmcdlxxix{Y no alargues tus ojos hacia lo que Nosotros hemos proporcionado a algunos de ellos, flor de esta vida mundanal, para ponerles a prueba con ello, pues la provisión de tu Señor es mejor y más duradera.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmcdlxxx{Y ordena a tu gente la oración y persevera en ella. No te pedimos que nos proveas. Nosotros te proveemos a ti. Y el buen final es para el temor de Dios.\qt@no{132}}
\qt@newcmd\qurantrans@es@mmcdlxxxi{Y dicen: “¿Por qué no nos trae una señal procedente de su Señor?” ¿Acaso no ha venido a ellos la prueba clara de lo que contenían las Escrituras primeras?\qt@no{133}}
\qt@newcmd\qurantrans@es@mmcdlxxxii{Si Yo les hubiera destruido con un castigo antes de ello, habrían dicho: «¡Señor nuestro! ¿Por qué no nos envías un Mensajero para que sigamos Tus señales antes de que nos alcance la humillación y la desgracia?»\qt@no{134}}
\qt@newcmd\qurantrans@es@mmcdlxxxiii{Di: «Todos estamos a la espera. Así pues, esperad y pronto sabréis quiénes son la gente del camino llano y quiénes son los guiados.»\qt@no{135}}
\qt@newcmd\qurantrans@es@mmcdlxxxiv{\basmalahes Se acerca para los seres humanos el momento de rendir cuentas, pero ellos están descuidados y le dan la espalda.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcdlxxxv{No llega a ellos ningún nuevo recuerdo de su Señor sin que ellos lo escuchen como si fuera un juego,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcdlxxxvi{vacíos sus corazones. Los opresores secretean entre sí diciendo: «¿Acaso no es éste un ser humano igual que vosotros? ¿Vais, pues, a caer en la magia cuando la estáis viendo?»\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcdlxxxvii{Él dijo: «Mi Señor sabe lo que se dice en los cielos y en la Tierra, pues Él es Quien todo lo oye, Quien todo lo sabe.»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcdlxxxviii{Pero ellos dijeron: «¡Son un montón de delirios!» o «¡Se lo ha inventado!» o “¡Es un poeta!» «¡Qué nos traiga una señal como las que les fueron enviadas a los primeros!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcdlxxxix{No creyó, antes de ellos, ninguna ciudad de las que Nosotros destruimos ¿Van ellos a creer?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcdxc{Y no hemos enviado antes de ti sino a hombres a los que Nosotros inspiramos. ¡Preguntad a la gente del recuerdo, si es que vosotros no sabéis!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcdxci{No les dimos un cuerpo que no necesitase comer alimentos y no eran inmortales.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcdxcii{Fuimos leales a la promesa que les hicimos y les salvamos a ellos y a quienes Nosotros quisimos y destruimos a los transgresores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcdxciii{Ciertamente, hicimos descender a ti una Escritura en la que hay una amonestación para vosotros. ¿Acaso no razonáis?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcdxciv{¡Cuántas ciudades habremos destruido que eran opresoras y, tras ellas, hicimos surgir a otros pueblos!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcdxcv{Y cuando sintieron Nuestro castigo huyeron rápidamente de ellas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcdxcvi{«¡No huyáis y regresad a vuestras distracciones y mansiones! ¡Puede que seáis preguntados!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcdxcvii{Ellos dijeron: «¡Ay de nosotros! ¡En verdad, fuimos opresores!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcdxcviii{Y no cesó ese lamento hasta que les segamos la vida de raíz y quedaron silenciados.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcdxcix{No creamos el cielo, la Tierra y lo que hay entre ambos por juego.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmd{De haber querido entretenernos lo hubiéramos hecho por Nosotros mismos, de haberlo hecho.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdi{Pero no. Lanzamos la Verdad sobre lo falso para destruirlo, hasta que desaparece. ¡Ay de vosotros por vuestras conjeturas!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdii{A Él pertenecen quienes están en los cielos y la Tierra. Y quienes están junto a Él no se vuelven arrogantes por adorarle y no se agotan.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdiii{Glorifican noche y día y no se cansan.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdiv{¿Acaso los dioses que tomaron en la Tierra pueden resucitar a los muertos?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdv{Si hubiera en ellos dos otros dioses aparte de Dios, ambos se corromperían. Así pues ¡Glorificado sea Dios, Señor del Trono, por encima de aquello que Le atribuyen!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdvi{Él no será interrogado por lo que hace, pero ellos sí serán interrogados.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdvii{¿Han tomado otros dioses aparte de Él? Di: «¡Aportad vuestras pruebas!» «Este es el Recuerdo de quienes están conmigo y el Recuerdo de los que estaban antes de mí. Pero la mayoría de ellos no conocen la Verdad y se apartan.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdviii{Y no hemos enviado antes de ti a ningún Mensajero sin haberle revelado: «No hay más dios que Yo, así pues, ¡Adoradme!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdix{Y ellos dicen: «El Clementísimo ha tomado un hijo.» ¡Glorificado sea! No son sino siervos favorecidos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdx{No se adelantan a Él al hablar y actúan conforme a Sus órdenes.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdxi{Él conoce lo que tienen entre sus manos y lo que tienen a sus espaldas y no interceden por la salvación de nadie excepto de quien Él esté satisfecho y sólo por temor a Él se angustian.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdxii{Y si alguno de ellos dijese: «En verdad, yo soy un dios aparte de Él», le recompensaríamos con el Infierno. Así es como recompensamos a los opresores.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdxiii{¿Acaso quienes no creen no ven que los cielos y la Tierra formaban un todo único y Nosotros los separamos e hicimos del agua toda cosa viva? ¿No creerán, pues?\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdxiv{Y pusimos en la Tierra firmes montañas para que se moviera con ellos y dispusimos en ellas amplios caminos para que, quizás así, ellos puedan guiarse.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdxv{Y pusimos el cielo como un techo protegido. Pero ellos dan la espalda a Sus señales.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdxvi{Y Él es Quien creó la noche y el día y el Sol y la Luna. Cada uno navegando en su órbita.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdxvii{Y antes de ti no hemos hecho a ningún ser humano inmortal. ¿Acaso si tú mueres ellos vivirán eternamente?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdxviii{Todo ser humano probará la muerte y os ponemos a prueba con lo malo y con lo bueno. Y a Mí regresaréis.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdxix{Y cuando los que no creen te ven no te toman sino a broma: «¿Es éste el que habla mal de vuestros dioses?» Mientras, ellos niegan el recuerdo del Misericordioso.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdxx{De la prisa fue creado el ser humano. Pronto os haré ver Mis señales, así que no me metáis prisa.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdxxi{Y dicen: «¿Cuándo se cumplirá esa promesa, si es que decís la verdad?»\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdxxii{Si los que no creen supieran que llegará un momento en el que no podrán apartar el Fuego de sus rostros ni de sus espaldas y que no serán auxiliados...\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdxxiii{Llegará a ellos por sorpresa y les dejará anonadados y no podrán eludirlo ni les será aplazado.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdxxiv{Ciertamente, también se burlaron de los profetas anteriores a ti, pero quienes les ridiculizaban fueron cercados por aquello de lo que se burlaban.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdxxv{Di: «¿Quién os protegerá del Misericordioso por la noche y por el día?» Pero no sirve de nada. No prestan atención al Recuerdo de su Señor.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdxxvi{¿Acaso poseen aparte de Mi otros dioses que les protejan? No pueden protegerse a sí mismos ni Nosotros les hemos otorgado poder para auxiliar.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdxxvii{Dejamos que ellos y sus antepasados disfrutasen hasta una edad avanzada. ¿Acaso no ven cómo reducimos los bordes de la Tierra? ¿Acaso son ellos los vencedores?\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdxxviii{Di: «En verdad, aquello con lo que os amonesto es la revelación divina.» Pero los sordos no oyen la invitación cuando son amonestados.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdxxix{Pero si les roza un soplo del castigo de tu Señor, con seguridad dirán: «¡Ay de nosotros! ¡En verdad, fuimos injustos!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdxxx{Y colocaremos las balanzas equilibradas con precisión para el Día del Levantamiento y nadie será tratado injustamente en lo más mínimo. Y aunque sus actos tengan el peso de un grano de mostaza, les recompensaremos por ellos. Y Nosotros somos suficientes para llevar las cuentas.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdxxxi{Y, ciertamente, dimos a Moisés y a Aarón el Criterio y una luz y un recuerdo para los temerosos de Dios.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdxxxii{Aquellos que temen a su Señor en la intimidad y sienten temor de la Hora.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdxxxiii{Y éste es un recuerdo bendecido que Nosotros hemos hecho descender. ¿Acaso lo rechazaréis?\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdxxxiv{Y, ciertamente, dimos a Abraham su guía anteriormente, pues le conocíamos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdxxxv{Cuando dijo a su padre y a su pueblo: «¿Qué son esas imágenes sin alma que vosotros adoráis?»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdxxxvi{Ellos dijeron: «Vimos que nuestros padres las adoraban.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdxxxvii{Él dijo: «Ciertamente, vosotros y vuestros padres estabais en un extravío evidente.»\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdxxxviii{Ellos dijeron: «¿Vienes a nosotros con la Verdad o eres de los que bromean?»\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdxxxix{Él dijo: «No bromeo. Vuestro Señor es el Señor de los cielos y la Tierra y Quien los ha creado. Y yo soy uno de los que dan testimonio de ello.»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdxl{«Y juro por Dios que planearé algo contra vuestros ídolos en cuanto os deis la vuelta.»\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdxli{Así que los hizo pedazos, excepto a uno de ellos más grande, para que se volvieran hacia él.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdxlii{Ellos dijeron: «¿Quién hizo esto con nuestros dioses? ¡En verdad, él es de los opresores!»\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdxliii{Dijeron: «Oímos a un joven hablar mal de ellos. Le llaman Abraham.»\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdxliv{Dijeron: «¡Pues traedle ante la vista de la gente! Quizás así ellos testifiquen.»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdxlv{Dijeron: «¿Has sido tú ¡Oh, Abraham! quien hizo esto a nuestros dioses?»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdxlvi{Él dijo: «No. Lo hizo ese grande. ¡Preguntadles! si es que pueden hablar.»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdxlvii{Así que se ensimismaron y dijeron: «Verdaderamente, vosotros sois los opresores.»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdxlviii{Luego dieron vuelta a sus cabezas: «¿Acaso no sabes que ellos no pueden hablar?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdxlix{Él dijo: «¿Adoráis pues, en lugar de Dios, a quien no puede beneficiaros ni perjudicaros en nada?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdl{¡Uf! ¡Vosotros y lo que vosotros adoráis en lugar de Dios! ¿Es que no reflexionáis?»\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdli{Dijeron: «¡Quemadle y salid en defensa de vuestros dioses si es que sois gente de acción!»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdlii{Dijimos: «¡Oh, fuego! ¡Se frío e inofensivo para Abraham!»\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdliii{Quisieron con ello perjudicarle, pero hicimos que ellos fueran quienes más perdieran.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdliv{Y salvamos a él y a Lot en la tierra que nosotros habíamos bendecido para toda la humanidad.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdlv{le otorgamos a Isaac y a Jacob como una bendición e hicimos que ambos fueran de los justos.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdlvi{Y les pusimos como dirigentes para que guiasen conforme a Nuestro mandato y les revelamos que hicieran el bien, que realizaran la oración y entregaran el impuesto religioso purificador de la riqueza. Y fueron siervos obedientes a Nosotros.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdlvii{Y a Lot le dimos juicio y conocimiento y le pusimos a salvo de la ciudad en la que se cometían actos viciosos. En verdad, era un pueblo malvado y trasgresor.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdlviii{Y le hicimos entrar en Nuestra misericordia. En verdad, él era de los rectos.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdlix{Y, anteriormente, a Noé, cuando invocó y Nosotros le respondimos y le salvamos, a él y a su familia, de la gran tragedia.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdlx{Y le auxiliamos ante la gente que desmentía Nuestras señales. En verdad, eran una mala gente y Nosotros les hicimos ahogarse a todos juntos.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdlxi{Y (recuerda a) David y Salomón cuando ambos juzgaron sobre el huerto en el que entró de noche a pastar el ganado de una gente y Nosotros fuimos testigos de su juicio.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdlxii{Nosotros se lo hicimos comprender a Salomón. Y dimos a ambos juicio y conocimiento. Y sometimos las montañas y las aves para que glorificasen con David. Nosotros fuimos Quienes lo hicimos.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmdlxiii{Y le enseñamos a fabricar cotas de malla para vosotros, para que os protegieran de la violencia. ¿Seréis agradecidos?\qt@no{80}}
\qt@newcmd\qurantrans@es@mmdlxiv{Y (sometimos) a Salomón los vientos huracanados, para que soplasen, cuando él lo ordenase, hacia la tierra que Nosotros habíamos bendecido. Y Nosotros poseemos el conocimiento de todas las cosas.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmdlxv{Y, entre los demonios, algunos buceaban para él y realizaban otras tareas diferentes. Y Nosotros les vigilábamos.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmdlxvi{Y (recuerda) a Job, cuando invocó en voz alta a su Señor: «¡En verdad, me ha alcanzado la aflicción y Tú eres el Más Misericordioso de los misericordiosos!»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmdlxvii{Así que le respondimos y eliminamos el mal que le aquejaba. Y le dimos su familia y otro tanto con ellos. Una misericordia de Nuestra parte y un recordatorio para los siervos creyentes.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmdlxviii{Y [recuerda a] Ismael e Idrís y Du l-Kifl. Todos ellos eran de los pacientes\qt@no{85}}
\qt@newcmd\qurantrans@es@mmdlxix{y les hicimos entrar en Nuestra misericordia. En verdad, ellos eran de los rectos.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmdlxx{Y [recuerda a] Du l-Nun cuando se fue indignado pensando que no le pondríamos en dificultades. Y gritó en la oscuridad: «¡No hay más Dios que Tú! ¡Gloria a Ti! ¡En verdad, he sido de los opresores!»\qt@no{87}}
\qt@newcmd\qurantrans@es@mmdlxxi{Y le respondimos y le salvamos de la angustia. Así es como salvamos a los creyentes.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmdlxxii{Y [recuerda a] Zacarías, cuando invocó a su Señor: «¡Señor mío! ¡No me dejes sin descendencia! ¡Tú eres el mejor dando herederos!»\qt@no{89}}
\qt@newcmd\qurantrans@es@mmdlxxiii{Y le respondimos y le otorgamos a Juan y sanamos a su esposa para él. En verdad, ellos competían en buenas acciones y nos invocaban por anhelo y temor y eran humildes ante Nosotros.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmdlxxiv{Y [recuerda] a aquella que protegió su castidad y en la que Nosotros insuflamos de Nuestro Espíritu. Y pusimos a ella y a su hijo como una señal para toda la humanidad.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmdlxxv{En verdad, esta comunidad vuestra es una comunidad única y Yo soy vuestro Señor. Así pues ¡Adoradme!\qt@no{92}}
\qt@newcmd\qurantrans@es@mmdlxxvi{Ellos se han dividido en lo relativo a su asunto. Todos regresarán hacia Nosotros.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmdlxxvii{Y no se ignorará el esfuerzo de quien realice buenas acciones y sea creyente. En verdad, Nosotros seremos sus escribanos.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmdlxxviii{Queda prohibido para una ciudad que Nosotros hayamos destruido (por sus pecados, el que vuelvan a ella) Ellos jamás volverán\qt@no{95}}
\qt@newcmd\qurantrans@es@mmdlxxix{hasta que sean liberados Yayuy y Mayuy y se precipiten desde todas las alturas.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmdlxxx{Se aproxima la promesa verdadera y, cuando llegue, las miradas de los que no creyeron se quedarán inmovilizadas: «¡Ay de nosotros! ¡Nos desentendimos de esto y fuimos opresores!»\qt@no{97}}
\qt@newcmd\qurantrans@es@mmdlxxxi{«En verdad, vosotros y lo que vosotros adorabais en lugar de Dios, seréis combustible para el Infierno. Entraréis en él.»\qt@no{98}}
\qt@newcmd\qurantrans@es@mmdlxxxii{Si ellos fueran dioses no entrarían en él. Pero todos ellos estarán en él eternamente.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmdlxxxiii{Aullarán de dolor en él y no oirán nada.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmdlxxxiv{En verdad, aquellos para quienes Nosotros habíamos decretado previamente el bien estarán muy alejados de él.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmdlxxxv{No escucharán su crepitar y estarán eternamente en lo que sus almas deseen.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmdlxxxvi{No les afligirá el gran terror y saldrán a su encuentro los ángeles: «¡Éste es el día que se os había prometido!»\qt@no{103}}
\qt@newcmd\qurantrans@es@mmdlxxxvii{El día en que Nosotros enrollemos los cielos como se enrolla un pergamino de escritos. Igual que iniciamos la primera creación la repetiremos. Es una promesa que hicimos y, en verdad, lo haremos.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmdlxxxviii{Y, en verdad, escribimos en los Salmos, después del Recuerdo, que la Tierra la heredarían Mis siervos rectos.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmdlxxxix{En verdad, en esto hay un comunicado elocuente para la gente dedicada a la adoración.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmdxc{Y no te hemos enviado sino como una misericordia para toda la humanidad.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmdxci{Di: «En verdad, lo que me ha sido revelado es que vuestro Dios es un Dios Único, por tanto ¿Os someteréis?»\qt@no{108}}
\qt@newcmd\qurantrans@es@mmdxcii{Pero si dan la espalda di: «Os prevengo a todos por igual. Pero no sé si lo que se os ha prometido está cercano o lejano.»\qt@no{109}}
\qt@newcmd\qurantrans@es@mmdxciii{«En verdad, Él conoce lo que habláis en voz alta y conoce lo que ocultáis.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmdxciv{No sé. Puede que sea una prueba para vosotros y os permita disfrutar por un tiempo.»\qt@no{111}}
\qt@newcmd\qurantrans@es@mmdxcv{Dice: «¡Señor mío! ¡Juzga con justicia! ¡Nuestro Señor es el Misericordiosísimo! Nuestra mejor ayuda contra lo que vosotros decís.»\qt@no{112}}
\qt@newcmd\qurantrans@es@mmdxcvi{\basmalahes ¡Oh, gentes! ¡Temed a vuestro Señor! En verdad, el terremoto de la Hora será una cosa terrible.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdxcvii{El día en que lo veáis, olvidará toda nodriza a su lactante y toda embarazada abortará y verás a las gentes ebrias, pero no estarán ebrias sino que el castigo de Dios será severo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdxcviii{Entre las gentes, hay quienes disputan sobre Dios sin conocimiento y siguen a cualquier demonio rebelde,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdxcix{para el cual se ha decretado que extraviará a cualquiera que le tome por amigo y le conducirá hacia el castigo del Fuego flamígero.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdc{¡Oh, gentes! Si tenéis dudas sobre la resurrección, [sabed que] en verdad, Nosotros os creamos de barro, después de una gota, después de algo suspendido, después de una masa de carne, en parte formada, en parte sin formar, para dejároslo claro. Y depositamos en los senos maternos a quien Nosotros queremos hasta que se cumple un plazo establecido. Luego os sacamos pequeños, luego alcanzáis la madurez y la fuerza. Y de vosotros hay quienes mueren [jóvenes] y a otros se les hace alcanzar una edad tan avanzada que después de haber poseído algún conocimiento no conocen nada. Y ves la tierra árida, pero cuando hacemos que descienda sobre ella el agua, se agita, se esponja y fructifican por parejas todo tipo de plantas coloridas.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdci{Esto es porque Dios es la Verdad y porque Él da vida a lo que estaba muerto y porque Él tiene poder sobre todas las cosas\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdcii{y porque la Hora viene, no hay duda en ello y porque Dios resucitará a quienes están en las tumbas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdciii{Entre la gente hay quien disputa sobre Dios sin conocimiento y sin guía y sin una Escritura luminosa,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdciv{apartándose con arrogancia para desviar [a la gente] del camino de Dios. Será humillado en esta vida y el Día del Levantamiento le haremos probar el castigo abrasador.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdcv{«Eso, por lo que vuestras manos han enviado por delante y porque Dios no oprime a Sus siervos.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdcvi{Y entre la gente hay quien adora a Dios en un solo sentido: Si le sucede algo bueno lo disfruta pero si le viene una prueba cambia su rostro, perdiendo esta vida y la otra. Ésa es la pérdida auténtica.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdcvii{Invoca, en vez de a Dios, lo que no le puede perjudicar ni beneficiar. Ése es el extravío profundo.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdcviii{Invoca a quien más que beneficiar perjudica. ¡Qué mal protector y qué mala compañía!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdcix{En verdad, Dios introduce a quienes son creyentes y obran rectamente en Jardines de cuyas profundidades brotan los ríos. En verdad, Dios hace lo que quiere.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdcx{Quien piense que Dios no le ayudará en esta vida y en la otra, que extienda una cuerda hacia el cielo y corte y vea si su plan elimina aquello que le irritaba.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdcxi{Y así, Nosotros lo hemos hecho descender como una señal clara. Y Dios guía a quien Él quiere.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcxii{En verdad, Dios establecerá las diferencias entre los creyentes, los judíos, los sabeos, los cristianos y los magos y los politeístas el Día del Levantamiento. En verdad, Dios es testigo de todas las cosas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcxiii{¿Acaso no habéis visto que para Dios se prosternan quienes están en los cielos y en la Tierra y el Sol y la Luna y las estrellas y las montañas y los árboles y los animales y muchos de los seres humanos? Pero muchos otros merecen el castigo. Quien es humillado por Dios no encontrará quien le honre. En verdad, Dios hace lo que quiere.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcxiv{Esos dos contendientes se enfrentan por su Señor. Pero a los que no creen les serán cortados vestidos de fuego y desde lo alto de sus cabezas les será arrojada agua hirviente\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcxv{que fundirá sus entrañas y sus pieles.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcxvi{Y hay para ellos martillos de hierro.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcxvii{Cada vez que quieran salir de ello, presos de angustia, se les hará regresar: «Saboread el castigo abrasador.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcxviii{En verdad, Dios hará entrar a quienes creen y realizan buenas acciones en Jardines de cuyas profundidades brotan los ríos. Serán adornados con brazaletes de oro y perlas y sus vestidos serán allí de seda.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcxix{Y serán guiados a la buena palabra y serán guiados a la senda del Alabado.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcxx{En verdad, a quienes no creen y ponen barreras para dificultar el acceso a la senda de Dios y a la Mezquita Sagrada, la cual dispusimos para toda la gente, tanto para los residentes como para los de fuera, y a quienes pretendan cometer en ella injusticia y opresión, les haremos probar del castigo doloroso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcxxi{Y [recuerda] cuando dispusimos para Abraham el emplazamiento de La Casa: «No asocies nada a Mí y purifica Mi Casa para los que dan vueltas alrededor de ella, para los que permanecen en pie [rezando] y para los que se inclinan y prosternan.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcxxii{«Y llama a la gente a la peregrinación. Vendrán a ti a pie o en flacos camellos desde todo camino alejado\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcxxiii{para atestiguar los beneficios que para ellos hay y para recordar el nombre de Dios en los días sabidos, sobre las cabezas del ganado que Él les ha proporcionado.» «¡Comed pues de ellas y alimentad al indigente, al necesitado!»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdcxxiv{«Luego, que limpien su suciedad, que completen sus votos y que circunvalen la Casa Antigua.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcxxv{Esto es lo ordenado. Y quien respete las prohibiciones establecidas por Dios hará lo mejor para él ante su Señor. «Y es lícito para vosotros todo el ganado, excepto lo que se os ha mencionado. Y absteneos de lo abominable que proviene de los ídolos y absteneos de la palabra vana,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcxxvi{buscando sólo a Dios, sin asociar nada a Él.» Y quien adora otros dioses junto a Dios es como lo que cae del cielo y las aves lo devoran o lo arrastra el viento a un lugar lejanísimo.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdcxxvii{Así es. Y quien sea reverente con los ritos establecidos por Dios, en verdad, su comportamiento procederá del temor a Dios de los corazones.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdcxxviii{Hay en ello, para vosotros, un beneficio hasta un plazo determinado, hasta que llegue su momento en la Casa Antigua.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdcxxix{Y hemos establecido ritos para todas las comunidades, para que recuerden el nombre de Dios sobre aquellas cabezas de ganado que Él les ha proveído. Vuestro Dios es un Dios Único, por tanto ¡Someteos a Él! Y transmite la buena nueva a los humildes.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcxxx{Aquellos a quienes, si se les recuerda a Dios, sus corazones tiemblan, son pacientes ante las desgracias, hacen la oración y, de lo que les proveemos, reparten.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcxxxi{Hemos establecido para vosotros el sacrificio de los camellos como uno de los ritos de Dios. En ello hay un bien para vosotros. Mencionad, pues, el nombre de Dios cuando estén en fila. Y cuando hayan caído sobre sus flancos comed de ellos y alimentad a los necesitados y a los mendigos. Esto es lo que Nosotros hemos dispuesto para vuestro beneficio. Quizás así seáis agradecidos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcxxxii{Ni su carne ni su sangre llegan a Dios, lo que llega a Él es vuestra piedad. Eso es lo que Dios ha dispuesto para vosotros, para que ensalcéis a Dios por la guía que os ha proporcionado. Y anuncia la buena nueva a los que hacen el bien.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcxxxiii{En verdad, Dios defiende a quienes tienen fe. En verdad, Dios no ama a ningún traidor ingrato.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcxxxiv{Se ha dado permiso a quienes son atacados, por haber sido oprimidos. Y, en verdad, Dios tiene poder para auxiliarles.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcxxxv{Aquellos que han sido expulsados de sus hogares sin derecho, sólo por haber dicho «Dios es nuestro Señor.» Y si Dios no hubiera defendido a unas personas por medio de otras, habrían sido destruidos monasterios, iglesias, sinagogas y mezquitas, en las que se menciona mucho el nombre de Dios. Ciertamente, Dios auxilia a quienes Le auxilian. En verdad, Dios es fuerte, poderoso.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcxxxvi{Aquellos que, si les damos poder en la Tierra, hacen la oración, dan el impuesto religioso purificador de la riqueza, ordenan lo que está bien y prohíben lo que está mal. Y la conclusión de todos los asuntos está en manos de Dios.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcxxxvii{Y si te desmienten, también antes de ellos desmintieron el pueblo de Noé y el de Ad y el de Zamud\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcxxxviii{y el pueblo de Abraham y el pueblo de Lot\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcxxxix{y los habitantes de Madyan y fue desmentido Moisés. Di un plazo a los que no creían y luego me apoderé de ellos. ¡Cómo fue Mi castigo!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdcxl{¡Cuántas ciudades hemos destruido por haber sido opresoras y quedaron totalmente en ruinas! ¡Cuántos pozos abandonados! ¡Cuántos palacios derrumbados!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdcxli{¿No han viajado jamás por la Tierra con corazones capaces de entender y oídos capaces de escuchar? No es su vista la que está cegada sino los corazones que hay en sus pechos los que no ven.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdcxlii{Te piden que apresures el castigo, pero Dios no falta a Su promesa. Y, en verdad, un día junto a tu Señor es como mil años de los que vosotros contáis.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdcxliii{¡A cuántas ciudades he dado Yo un respiro siendo opresoras y después me apoderé de ellas! El retorno es hacia Mí.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdcxliv{Di: «¡Oh, gentes! ¡Yo soy para vosotros un amonestador claro!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdcxlv{Y quienes tengan fe y obren rectamente obtendrán perdón y una provisión generosa,\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdcxlvi{pero quienes se esfuercen en despreciar Mis señales serán los moradores del Infierno.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdcxlvii{Y no hemos enviado antes de ti a ningún Mensajero ni profeta que no tuviera un deseo, sin que Satanás se interpusiera en su deseo. Pero Dios anula los obstáculos puestos por Satanás y hace Dios que se cumplan Sus señales, pues Dios todo lo conoce, es sabio,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdcxlviii{haciendo de los obstáculos de Satanás una prueba para quienes tienen una enfermedad en sus corazones y para los duros de corazón -En verdad, los opresores mantienen un comportamiento profundamente inadecuado-\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdcxlix{y para que sepan quienes obtuvieron conocimiento, que ello es la Verdad que proviene de tu Señor y crean en ella y humillen ante Él sus corazones. En verdad, Dios guía a quienes tienen fe hacia un camino recto.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdcl{Pero quienes no tienen fe no cesarán de dudar de él hasta que llegue a ellos la Hora repentinamente o llegue a ellos el castigo del día del que no nacerá otro.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdcli{Ese día la soberanía pertenecerá a Dios y Él juzgará entre ellos. Y quienes hayan tenido fe y actuado rectamente estarán en los Jardines de las Delicias.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdclii{Y quienes no hayan tenido fe y hayan desmentido Nuestras señales, obtendrán un castigo humillante.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdcliii{Y a quienes emigraron por la causa de Dios y fueron matados o mueran Dios les otorgará, con certeza, una buena provisión. Y, en verdad, Dios es Quien mejor provee.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdcliv{Les hará entrar en un lugar que les satisfará. En verdad, Dios todo lo conoce, es indulgente.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdclv{Así es. A Quien devuelva un agravio semejante al que se le hizo sufrir y posteriormente vuelva a ser agredido, con certeza, Dios le auxiliará. En verdad, Dios es muy indulgente, perdonador.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdclvi{Eso es así porque Dios hace entrar la noche en el día y hace entrar el día en la noche y porque Dios todo lo oye, todo lo ve.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdclvii{Eso es así porque Dios es la Verdad y lo que ellos invocan aparte de Él es falso y porque Dios es el Altísimo, el Grande.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdclviii{¿Acaso no veis que Dios hace descender del cielo agua y la Tierra se vuelve verde? En verdad, Dios es sutil, bien informado.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdclix{A Él pertenece lo que hay en los cielos y lo que hay en la Tierra y, en verdad, Dios es el Rico en Sí mismo, el digno de Alabanza.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdclx{¿Acaso no has visto que Dios ha dispuesto para vosotros lo que hay en la Tierra y los barcos que surcan el mar a una orden Suya y mantiene el cielo para que no caiga sobre la Tierra, excepto con Su permiso. En verdad, Dios es con los seres humanos el más amable, Misericordiosísimo.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdclxi{Él es Quien os da la vida, luego os hace morir, luego os devuelve a la vida. En verdad, el ser humano es muy desagradecido.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdclxii{Para cada comunidad hemos establecido un ritual con el que ellos adoran. Por tanto, que no discutan contigo sobre este tema. Invita a la gente hacia tu Señor. En verdad, estás sobre un camino recto.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdclxiii{Y si discuten contigo, di: «Dios es quien mejor sabe lo que hacéis.»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdclxiv{Dios juzgará entre vosotros el Día del Levantamiento sobre aquello en lo que no os poníais de acuerdo.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdclxv{¿Es que no sabéis que Dios conoce los que hay en los cielos y la Tierra? En verdad, todo eso está en una Escritura. En verdad, eso es fácil para Dios.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdclxvi{Y adoran, en lugar de Dios, algo a lo que Él no ha concedido poder y sobre lo que no poseen ningún conocimiento. Los opresores no tendrán quien les auxilie.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdclxvii{Y, cuando les son recitados Nuestros versículos claros, reconocerás el rechazo en los rostros de quienes no son creyentes. Poco les falta para lanzarse sobre quienes les recitan Nuestros versículos. Di: «¿Queréis que os informe de algo peor que eso?: Dios ha prometido el Fuego a quienes no son creyentes y ¡Que mal destino!»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdclxviii{¡Oh, gentes! Se os pone un ejemplo ¡Escuchadle!: «En verdad, aquellos que invocáis en lugar de Dios no crearían ni una mosca aunque se reuniesen todos para ello y si una mosca se llevara algo de ellos no podrían recuperarlo.» ¡Qué débiles el pretendiente y el pretendido!\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdclxix{No valoran a Dios como Él merece ser valorado. En verdad, Dios es fuerte, poderoso.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdclxx{Dios elige Mensajeros entre los ángeles y entre los hombres. En verdad, Dios todo lo oye, todo lo ve.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdclxxi{Él conoce lo que tienen entre sus manos y lo que tienen tras ellos y a Dios regresan todos los asuntos.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdclxxii{¡Oh, los que sois creyentes! ¡Inclinaos y prosternaos y adorad a vuestro Señor y haced el bien! ¡Quizás así triunféis!\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdclxxiii{Y esforzaos por Dios con un esfuerzo verdadero por Él! Él os ha elegido y no ha puesto en la religión, la creencia de vuestro padre Abraham, ninguna dificultad para vosotros. Él os ha llamado musulmanes anteriormente y en éste, para que sea el Mensajero testigo sobre vosotros y seáis vosotros testigos sobre la gente. Por tanto, haced la oración, dad el impuesto purificador de la riqueza y aferraos a Dios. Él es vuestro Señor y Protector. Un excelente Protector y un excelente Defensor.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdclxxiv{\basmalahes Ciertamente, los creyentes han triunfado y se han salvado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdclxxv{Aquellos que en su oración están atentos y sumisos.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdclxxvi{Aquellos que se apartan de lo superficial.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdclxxvii{Aquellos que dan de sus bienes.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdclxxviii{Aquellos que protegen sus partes privadas\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdclxxix{excepto de sus esposas o de sus esclavas, pues entonces no son censurables.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdclxxx{Quienes busquen más allá de esto serán los transgresores.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdclxxxi{Y aquellos que respetan lo que se les confía, cumplen sus promesas\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdclxxxii{y protegen sus oraciones.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdclxxxiii{Esos serán los herederos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdclxxxiv{Ellos heredarán el Paraíso en el que estarán eternamente.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdclxxxv{Y, ciertamente, hemos creado al ser humano de un trozo de barro.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdclxxxvi{Luego, le hemos creado de una gota en un lugar protegido.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdclxxxvii{Después, de la gota creamos algo suspendido y, de eso suspendido, una masa parecida a carne picada y de eso, huesos y cubrimos los huesos con carne y entonces creamos otra criatura. Por tanto ¡Bendito sea Dios, el mejor de los creadores!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdclxxxviii{Después de eso habréis de morir.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdclxxxix{Luego, el Día del Levantamiento, seréis devueltos a la vida.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcxc{Y, ciertamente, hemos creado sobre vosotros siete caminos y no estamos descuidados de la creación.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcxci{Hacemos descender de cielo agua en una determinada cantidad y la almacenamos en la Tierra. Y, en verdad, podríamos hacerla desaparecer.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcxcii{Y por medio de ella producimos para vosotros jardines de palmeras datileras y viñedos en los que tenéis frutos abundantes de los cuales coméis\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcxciii{y un árbol que sale en el monte Sinaí que da un fruto en el que hay aceite y condimento para los que comen.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcxciv{Y, en verdad, hay en el ganado, para vosotros, un motivo de reflexión. Os damos de beber de lo que hay en sus entrañas y obtenéis de él múltiples beneficios y coméis de él\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcxcv{y montáis en él y en los barcos.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcxcvi{Y, ciertamente, enviamos a Noé a su pueblo y dijo: «¡Oh, pueblo mío! ¡Adorad a Dios! ¡No tenéis otro Dios que Él! ¿Seréis, pues, temerosos?»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcxcvii{Pero los notables de su pueblo, que no eran creyentes, dijeron: «No es más que un ser humano como vosotros que quiere obtener una posición de favor entre vosotros y, si Dios hubiese querido, habría hecho descender ángeles». «No hemos escuchado nada de esto de nuestros primeros padres.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcxcviii{No es más que un hombre poseído. Dadle, pues, un plazo de espera.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcxcix{Él dijo: «¡Señor mío! ¡Ellos me desmienten, auxíliame Tú!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcc{Así que le revelamos: «¡Construye un barco, que Nosotros te observaremos y te inspiraremos!» «Y cuando llegue Nuestra orden y el horno comience a hervir, introduce en él una pareja de todo y a tu familia, excepto aquellos que fueron sentenciados previamente.» «Y no me hables de quienes son opresores. En verdad, ellos serán ahogados.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcci{«Y cuando tú y quienes están contigo os encontréis instalados en el barco, di: ¡Alabado sea Dios que nos ha salvado del pueblo de los opresores!»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdccii{Y di: «¡Señor mío! ¡Hazme descender en un lugar bendecido, pues Tú eres el mejor haciendo llegar a buen puerto.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcciii{En verdad, en ello hay señales y en verdad, somos Nosotros quienes ponemos a prueba.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcciv{Tras ellos hicimos surgir otras generaciones\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdccv{y les enviamos profetas de entre ellos: «¡Adorad a Dios! ¡No tenéis otro Dios que Él! ¿Seréis, pues, temerosos?»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdccvi{Los notables de su pueblo, que no eran creyentes y desmentían el encuentro de la otra vida y a quienes Nosotros habíamos favorecido en esta vida, dijeron: «No es más que un ser humano como vosotros. Come de lo mismo que vosotros coméis y bebe de lo que vosotros bebéis\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdccvii{y si obedecéis a un ser humano como vosotros, entonces, seréis de los perdedores.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdccviii{«¿Os promete que después de que muráis y seáis polvo y huesos seréis sacados?»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdccix{«¡Qué lejos está de la verdad lo que se os promete!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdccx{No existe más que esta vida. Morimos y nacemos y no seremos resucitados.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdccxi{No es más que un hombre que ha inventado una mentira sobre Dios, pero nosotros no creemos en él.»\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdccxii{Él dijo: «¡Señor mío! ¡Ellos me desmienten, auxíliame Tú!»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdccxiii{Dijo (Dios): «¡Muy pronto se arrepentirán!»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdccxiv{Y les sorprendió el Grito con la Verdad y les dejamos como pasto seco. ¡Maldito sea el pueblo opresor!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdccxv{Tras ellos hicimos surgir otras generaciones.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdccxvi{Ninguna comunidad puede adelantar su plazo ni diferirlo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdccxvii{Luego fuimos enviando a Nuestros Mensajeros uno tras otro. Cada vez que llegaba a una comunidad su Mensajero le desmentían. Así que las destruimos una tras otra e hicimos que fueran solamente una leyenda. ¡Alejado sea el pueblo que no cree!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdccxviii{Luego, enviamos a Moisés y a su hermano Aarón con Nuestras señales y un poder evidente\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdccxix{al Faraón y a sus notables, pero se llenaron de soberbia y fueron un pueblo altivo.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdccxx{Así pues, dijeron: «¿Vamos a creer en un ser humano como nosotros y cuyo pueblo es esclavo nuestro?»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdccxxi{Les desmintieron a ambos y fueron de los destruidos.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdccxxii{Y, ciertamente, dimos a Moisés la Escritura, para que así quizás se guiasen.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdccxxiii{E hicimos del hijo de María y de su madre una señal y les alojamos en una colina fértil y segura provista de manantiales.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdccxxiv{«¡Oh Profetas! ¡Comed de los alimentos puros y obrad rectamente! En verdad, Yo conozco bien lo que hacéis.»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdccxxv{«Y, en verdad, vuestra comunidad es una comunidad única y Yo soy vuestro Señor. Así pues ¡Sed temerosos de Mí!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdccxxvi{Pero ellos se dividieron, cada uno con su Escritura y cada grupo contento con lo que tiene.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdccxxvii{Déjales en su extravío por un tiempo.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdccxxviii{¡Acaso piensan que los bienes y los hijos que les hemos concedido\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdccxxix{es porque nos apresuramos a complacerles? ¡No! Pero no se dan cuenta.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdccxxx{En verdad, quienes por temor a su Señor se estremecen\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdccxxxi{y quienes creen en las señales de su Señor\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdccxxxii{y quienes no adoran nada junto a su Señor\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdccxxxiii{y dan de lo que Yo les doy y sus corazones temen porque regresan hacia su Señor,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdccxxxiv{esos son quienes se apresuran a realizar buenas obras y van en ello por delante.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdccxxxv{Nosotros no exigimos de nadie más allá de su capacidad. Y junto a Nosotros hay una escritura que dice la verdad y ellos no serán oprimidos.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdccxxxvi{Pero sus corazones ignoran totalmente esto y por ello actúan de manera diferente, sin tenerlo en cuenta.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdccxxxvii{Cuando Nos apoderemos de los que entre ellos vivían en la opulencia y les castiguemos, entonces ellos suplicarán.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdccxxxviii{“¡No supliquéis hoy! ¡No recibiréis Nuestro auxilio!\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdccxxxix{Se os recitaban Mis versículos y vosotros os dabais media vuelta.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdccxl{Llenos de soberbia ante ellos, pasabais las noches en charlas delirantes.”\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdccxli{¿Es que no reflexionaban en el Discurso o es que llegó a ellos algo que no les fue dado a sus primeros padres?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdccxlii{¿O no reconocen a su Mensajero y por eso le niegan?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdccxliii{O dicen: «¡Está poseído!» Pero no es así. Ha venido a ellos con la Verdad y a la mayoría de ellos les repugna la Verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdccxliv{Si la Verdad hubiese seguido sus deseos, se habrían corrompido los cielos y la Tierra y todo lo que hay en ellos. En cambio les dimos su Recuerdo, pero ellos se apartan de su Recuerdo.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdccxlv{¿Acaso les pides alguna remuneración? La remuneración de tu Señor es mejor y Él es Quien mejor provee\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdccxlvi{y tú, en verdad, les llamas a un camino recto\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdccxlvii{pero, verdaderamente, quienes no creen en la otra vida se desvían del camino.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdccxlviii{Y si tuviésemos misericordia de ellos y eliminásemos sus dificultades, seguramente, persistirían extraviados en su endiosamiento.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdccxlix{Les castigamos, pero no se someten a su Señor ni le imploran con humildad\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdccl{hasta que abrimos sobre ellos la puerta de un duro castigo. Entonces se desesperan.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdccli{Él es Quien ha creado para vosotros el oído, la vista y el intelecto. ¡Qué poco agradecidos sois!\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdcclii{Y es Él Quien os creó y diseminó por la Tierra y hacia Quien habréis de regresar.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmdccliii{Y es Él Quien da la vida y la muerte y Quien establece la variación de la noche y el día. ¿Es que no razonáis?\qt@no{80}}
\qt@newcmd\qurantrans@es@mmdccliv{Pero dicen lo mismo que dijeron los primeros.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmdcclv{Dicen: “¿Acaso cuando hayamos muerto y seamos polvo y huesos seremos devueltos a la vida?”\qt@no{82}}
\qt@newcmd\qurantrans@es@mmdcclvi{“Ya se nos había prometido lo mismo anteriormente, a nosotros y a nuestros padres. No son más que fábulas de los primitivos.”\qt@no{83}}
\qt@newcmd\qurantrans@es@mmdcclvii{Di: «¿A quién pertenece la Tierra y lo que hay en ella, si es que lo sabéis?»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmdcclviii{Dirán: «A Dios» Di: «¿Entonces, por qué no reflexionáis?»\qt@no{85}}
\qt@newcmd\qurantrans@es@mmdcclix{Di: «¿Quién es el Señor de los siete cielos y el Señor del Trono Inmenso?»\qt@no{86}}
\qt@newcmd\qurantrans@es@mmdcclx{Dirán: «Dios». Di: «¿No seréis, pues, temerosos?»\qt@no{87}}
\qt@newcmd\qurantrans@es@mmdcclxi{Di: «¿Quién tiene el gobierno de todas las cosas en Su mano y otorga protección pero nadie puede protegerse de Él, si es que lo sabéis?»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmdcclxii{Dirán: «Dios» Di: «¿Qué es, entonces, lo que os alucina?»\qt@no{89}}
\qt@newcmd\qurantrans@es@mmdcclxiii{Hemos venido a ellos con la Verdad y ellos la desmienten.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmdcclxiv{Ni Dios ha tenido un hijo ni existe otro dios junto con Él. Pues, en ese caso, cada dios se llevaría lo que hubiese creado y unos se impondrían sobre otros. ¡Glorificado sea Dios sobre aquello que Le atribuyen!\qt@no{91}}
\qt@newcmd\qurantrans@es@mmdcclxv{Él es el Conocedor de lo oculto y lo manifiesto y está muy por encima de lo que Le asocian.\qt@no{92}}
\qt@newcmd\qurantrans@es@mmdcclxvi{Di: «¡Señor mío! Si me haces ver lo que se les ha prometido\qt@no{93}}
\qt@newcmd\qurantrans@es@mmdcclxvii{¡Señor mío! no me pongas con el pueblo de los opresores.»\qt@no{94}}
\qt@newcmd\qurantrans@es@mmdcclxviii{Y, en verdad, Nosotros tenemos poder para hacerte ver lo que les hemos prometido.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmdcclxix{Rechaza el mal con lo que es mejor. Nosotros somos Quienes mejor sabemos lo que ellos profieren.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmdcclxx{Y di: «¡Señor mío! Me refugio en Ti del susurro de los demonios\qt@no{97}}
\qt@newcmd\qurantrans@es@mmdcclxxi{y me refugio en Ti ¡Señor mío! de su presencia cerca de mí.»\qt@no{98}}
\qt@newcmd\qurantrans@es@mmdcclxxii{Cuando a alguno de ellos le llega la muerte, dice: «¡Señor mío! ¡Hazme regresar\qt@no{99}}
\qt@newcmd\qurantrans@es@mmdcclxxiii{para que pueda actuar rectamente en aquello que dejé descuidado!» ¡Pero no! Eso no son más que palabras que ellos dicen. Y les está aguardando el mundo intermedio, en el cual estarán hasta que sean devueltos a la vida.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmdcclxxiv{Y, cuando sea soplada la trompeta, ese día no habrá entre ellos lazos de parentesco y no se preguntarán unos por otros.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmdcclxxv{Y aquellos cuyas obras tengan peso en la balanza serán los triunfadores.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmdcclxxvi{Y aquellos cuyas obras no tengan peso en la balanza habrán echado a perder sus almas. Estarán en el Infierno eternamente.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmdcclxxvii{El fuego cortará sus rostros y les desfigurará.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmdcclxxviii{«¿Acaso no se os recitaban Mis versículos y vosotros los desmentíais?»\qt@no{105}}
\qt@newcmd\qurantrans@es@mmdcclxxix{Dirán: «¡Señor nuestro! Nos vencieron nuestras pasiones y fuimos gente extraviada.»\qt@no{106}}
\qt@newcmd\qurantrans@es@mmdcclxxx{«¡Señor nuestro! ¡Sácanos de él! Y si reincidimos, seremos entonces opresores.»\qt@no{107}}
\qt@newcmd\qurantrans@es@mmdcclxxxi{Él dirá: «¡Id a él y no me habléis!»\qt@no{108}}
\qt@newcmd\qurantrans@es@mmdcclxxxii{«En verdad, había un grupo de Mis siervos que decía: ¡Señor nuestro! ¡Hemos creído! Perdónanos pues y ten misericordia de nosotros ya que Tú eres el mejor de los misericordiosos.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmdcclxxxiii{Pero vosotros les tomabais a broma y os reíais de ellos hasta hacer que os olvidarais de Mí.»\qt@no{110}}
\qt@newcmd\qurantrans@es@mmdcclxxxiv{«En verdad, hoy les he recompensado por lo pacientes que fueron, pues ellos son los triunfadores.»\qt@no{111}}
\qt@newcmd\qurantrans@es@mmdcclxxxv{Él dirá: «¿Cuántos años permanecisteis en la Tierra?»\qt@no{112}}
\qt@newcmd\qurantrans@es@mmdcclxxxvi{Ellos dirán: «Permanecimos un día o parte de un día. Pregunta a quienes llevan la cuenta.»\qt@no{113}}
\qt@newcmd\qurantrans@es@mmdcclxxxvii{Él dirá: «En verdad, no permanecisteis más que un poco. ¡Si vosotros lo hubieseis sabido!\qt@no{114}}
\qt@newcmd\qurantrans@es@mmdcclxxxviii{¿Acaso creísteis que os habíamos creado gratuitamente y que no se os haría regresar a Nosotros?»\qt@no{115}}
\qt@newcmd\qurantrans@es@mmdcclxxxix{Ensalzado sea Dios, el Soberano, la Verdad. No hay más dios que Él. Señor del Noble Trono.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmdccxc{Quien invoca a otro dios junto a Dios no tiene razones para ello y, en verdad, la cuenta de sus actos está junto a su Señor. En verdad, Él no da el éxito a quienes no son creyentes.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmdccxci{Y di: «¡Señor mío! ¡Perdona y ten misericordia! ¡Tú eres el mejor de los misericordiosos!»\qt@no{118}}
\qt@newcmd\qurantrans@es@mmdccxcii{\basmalahes Una sura que hemos hecho descender y hemos hecho obligatoria. E hicimos descender en ella señales claras para que quizás así reflexionéis.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdccxciii{A la fornicadora y al fornicador castigadles con cien azotes a cada uno. Y si creéis en Dios y en el Último Día no dejéis que la compasión por ellos dos os impida aplicar la pena establecida por Dios. Y que su castigo sea presenciado por un grupo de los creyentes.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdccxciv{Que el fornicador no se case sino con una fornicadora o con una idólatra y que la fornicadora no se case sino con un fornicador o un idólatra. Tal cosa está prohibida para los creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdccxcv{Y a quienes acusen a mujeres casadas y luego no aporten cuatro testigos, castigadles con ochenta azotes y no aceptéis jamás su testimonio. Esos son los transgresores.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdccxcvi{Excepto quienes, después de ello, se arrepienten y se corrigen, pues, en verdad, Dios es perdonador, Misericordiosísimo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdccxcvii{Y quienes acusen a sus esposas y no aporten más testigos de ello que ellos mismos, que él jure por Dios cuatro veces que dicen la verdad\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdccxcviii{y la quinta vez, [que diga] que Dios le maldiga si lo que dice es mentira.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdccxcix{Pero ella se librará del castigo si jura por Dios cuatro veces que él miente\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdccc{y la quinta vez (ella dice) que la ira de Dios caiga sobre ella si lo que él dice es cierto.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdccci{Y si no hubiera sido por el favor de Dios sobre vosotros y porque Dios acepta el arrepentimiento y es sabio…\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdcccii{En verdad, quienes vinieron con la calumnia son un grupo de entre vosotros. No penséis que es un mal para vosotros. Al contrario, es un bien para vosotros. Cada uno de ellos recibirá conforme a su pecado y el mayor responsable entre ellos tendrá un inmenso castigo.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdccciii{¿Por qué, cuando escuchasteis hablar de ello, los creyentes y las creyentes no pensaron bien para sus adentros y dijeron: «Esto es una calumnia evidente?»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdccciv{¿Por qué no vinieron ellos con cuatro testigos? Al no venir con los testigos, ante Dios, ellos son los mentirosos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdcccv{Si no hubiese sido por el favor y la misericordia de Dios con vosotros en esta vida y en la otra, habrías sufrido un castigo inmenso por el pecado que habéis cometido\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdcccvi{cuando lo pasasteis de unas lenguas a otras, diciendo con vuestras bocas algo de lo que no teníais conocimiento, considerando que era algo sin importancia cuando, ante Dios, es algo grave.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdcccvii{Si no, cuando lo escuchasteis, habríais dicho: «No es algo de lo que nosotros debamos hablar. ¡Gloria a Ti! ¡Eso es una calumnia terrible!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcccviii{Dios os exhorta a no repetir algo semejante jamás si sois creyentes.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcccix{Dios os explica con claridad las señales. Dios todo lo conoce, es sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcccx{En verdad, quienes desean que se extienda la indecencia entre los creyentes tendrán un castigo inmenso en esta vida y en la otra. Y Dios conoce y vosotros no conocéis.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcccxi{Y si no hubiese sido por el favor de Dios sobre vosotros y por Su misericordia y porque Dios es compasivo, misericordiosísimo…\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcccxii{¡Oh, creyentes! ¡No sigáis la senda extraviada de Satanás! Y quien siga la senda extraviada de Satanás ha de saber que, en verdad, él ordena los actos indecentes y lo que está mal. Y si no hubiese sido por el favor de Dios sobre vosotros y Su misericordia, ninguno de vosotros habría conseguido jamás ser puro. Pero Dios purifica a quien Él quiere. Y Dios todo lo oye, todo lo conoce.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcccxiii{Aquellos de vosotros que tienen posición y medios no deben negarse a ayudar a sus familiares, a los necesitados y a quienes han emigrado por la causa de Dios, y deben perdonarles y olvidar. ¿Acaso no queréis que Dios os perdone a vosotros? Y Dios es perdonador, Misericordiosísimo con los creyentes.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcccxiv{En verdad, quienes acusen a las mujeres casadas honestas, inocentes y creyentes, serán maldecidos en esta vida y en la otra y obtendrán un castigo inmenso\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcccxv{el día que sus propias lenguas, manos y pies testifiquen contra ellos por lo que hacían.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcccxvi{Ese día, Dios les otorgará su justa recompensa y sabrán que Dios es la Verdad evidente.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcccxvii{Las mujeres indecentes son para los hombres indecentes y los hombres indecentes para las mujeres indecentes y las buenas mujeres son para los buenos hombres y los buenos hombres para las buenas mujeres. Ellos están libres de lo que dicen. Obtendrán perdón y una provisión generosa.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcccxviii{¡Oh, creyentes! No entréis en una casa distinta a la vuestra sin anunciaros y sin saludar a su gente. Esto es mejor para vosotros. Quizás así recapacitéis.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcccxix{Y si no encontráis a nadie en ella, entonces no entréis hasta que obtengáis permiso y si se os dice que regreséis [más tarde] regresad. Eso es más adecuado. Y Dios conoce bien lo que hacéis.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdcccxx{No cometéis nada malo si entráis en una casa deshabitada que contenga algo que os pertenece. Y Dios conoce lo que manifestáis y lo que ocultáis.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcccxxi{Di a los creyentes que recaten sus miradas y que protejan sus partes privadas. Eso es más puro. En verdad, Dios está bien informado de lo que hacen.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcccxxii{Y di a las creyentes que recaten sus miradas y protejan sus partes privadas y no muestren sus encantos, excepto lo que está a simple vista. Que cubran sus pechos y que no muestren sus encantos excepto a sus esposos, sus padres, los padres de sus esposos, sus hijos, los hijos de sus esposos, sus hermanos, los hijos de sus hermanos, los hijos de sus hermanas, sus mujeres, sus esclavas, los hombres con deficiencia mental que carezcan de deseo sexual o los niños que aún no reconocen las partes privadas de las mujeres. Y que no golpeen con sus pies para dar a conocer sus encantos ocultos. Volveos todos arrepentidos hacia Dios ¡Oh, creyentes! para que, quizás así, tengáis éxito.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdcccxxiii{Y casad a quienes estén solteros de vuestra gente y a vuestros esclavos y esclavas en condiciones de contraerlo. Si son pobres Dios les enriquecerá con Su favor. Y Dios todo lo abarca, todo lo conoce.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdcccxxiv{Y quienes no cuenten con recursos para contraer matrimonio que mantengan el celibato hasta que Dios les enriquezca con Su favor. Y a quienes, de entre vuestros esclavos, deseen su escritura, escribídsela si sabéis que en ellos hay bien. Y dadles de los bienes de Dios que Él os ha otorgado. Y, buscando obtener las ganancias de esta vida mundanal, no forcéis a vuestras esclavas a la prostitución si desean permanecer célibes. Pero si son obligadas, en verdad, Dios, tras haber sido ellas obligadas, es perdonador, misericordiosísimo.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdcccxxv{Ciertamente, hemos hecho descender para vosotros señales evidentes y ejemplos de quienes vivieron antes que vosotros y amonestación para los temerosos.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcccxxvi{Dios es la Luz de los cielos y la Tierra. El ejemplo de Su Luz es como un nicho en el que hay una lámpara. La lámpara está en un recipiente de cristal. El cristal es como una estrella resplandeciente. Se enciende gracias a un árbol bendito de aceitunas, que no es oriental ni occidental, cuyo aceite casi alumbra sin que le haya tocado el fuego. Luz sobre luz. Guía Dios a Su Luz a quien Él quiere. Pone Dios los ejemplos para las gentes. Y Dios conoce bien todas las cosas.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcccxxvii{En casas que Dios ha permitido que sean erigidas y en las que es recordado Su nombre. En ellas Él es glorificado mañana y tarde\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcccxxviii{por hombres a quienes ni los negocios ni las ventas distraen del recuerdo de Dios, de hacer la oración y de dar el impuesto purificador de la riqueza y que temen el día en el que los corazones y las miradas sean puestos del revés,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcccxxix{para que Dios les recompense conforme a lomejor que hicieron y les incremente de Su favor. Y Dios provee sin medida a quien Él quiere.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcccxxx{Y los actos de quienes no creyeron son como un espejismo en una llanura desierta. El sediento cree que es agua hasta que llega a ella y no encuentra nada. Y encontrará a Dios junto a él que le abonará sus cuentas. Y Dios es rápido saldando la cuenta.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcccxxxi{O como tinieblas en medio de un mar profundo. Cubierto por olas sobre las que hay más olas sobre las cuales hay nubes. Tinieblas sobre tinieblas. Cuando saca su mano casi no puede verla. A quien Dios no le proporciona luz no dispone de luz alguna.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcccxxxii{¿Acaso no has visto que quienes están en los cielos y en la Tierra y las aves con sus alas desplegadas glorifican a Dios? Cada cual sabe como rezar y glorificar y Dios sabe bien lo que ellos hacen.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcccxxxiii{A Dios pertenece el reino de los cielos y la Tierra y Dios es el destino final.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcccxxxiv{¿No has visto que Dios conduce las nubes y las junta entre sí y las amontona y ves entonces como la lluvia sale de su interior y desciende de las montañas que hay en el cielo el granizo con el que perjudica a quien Él quiere y del que libra a quien Él quiere, y que el resplandor del rayo casi ciega?\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcccxxxv{Dios alterna la noche y el día. En verdad, en ello hay motivo de reflexión para quienes poseen visión.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdcccxxxvi{Y Dios ha creado a todos los animales a partir del agua y, de ellos, algunos caminan sobre sus vientres, otros sobre dos piernas y otros sobre cuatro. Dios crea lo que quiere. En verdad, Dios tiene poder sobre todas las cosas.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdcccxxxvii{Ciertamente, hemos hecho descender señales claras. Y Dios guía a quien Él quiere a un camino recto.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdcccxxxviii{Ellos dicen: «Creemos en Dios y en el Mensajero y obedecemos.» Después de eso, un grupo de ellos da la espalda y no tiene fe.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdcccxxxix{Y, cuando son llamados a Dios y a Su Mensajero para que juzgue entre ellos, una parte de ellos se aleja.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdcccxl{Pero cuando el derecho está de su lado vienen a él complacientes.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdcccxli{¿Acaso hay una enfermedad en sus corazones, o tienen dudas, o temen que Dios y Su Mensajero sean injustos con ellos? Al contrario. Ellos son los opresores.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdcccxlii{En verdad, la respuesta de los creyentes cuando son llamados a Dios y a Su Mensajero para que juzgue entre ellos es decir: «¡Oímos y obedecemos!» y ellos son quienes obtienen éxito.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdcccxliii{Quienes obedezcan a Dios y a Su Mensajero y teman a Dios y sean buenos serán los triunfadores.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdcccxliv{Juran por Dios con juramentos solemnes que, si tú se lo ordenases, sí saldrían. Di: «¡No juréis! ¡Dad señales de una obediencia pura! En verdad, Dios está bien informado de lo que hacéis.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdcccxlv{Di: «¡Obedeced a Dios y obedeced al Mensajero!» Y si dais la espalda, él sólo es responsable de su propia carga y vosotros de la vuestra. Y si le obedecéis estaréis bien guiados. La obligación del Mensajero es únicamente transmitir el mensaje de manera clara.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdcccxlvi{Dios ha prometido que designará herederos y representantes Suyos en la Tierra a quienes de entre vosotros sean creyentes y realicen buenas acciones, igual que designó herederos y representantes Suyos a quienes vinieron antes de ellos. Que hará que fructifiquen y se consoliden las creencias que Él ha hecho satisfactorias para ellos y que transformará el miedo que han pasado en seguridad, si Me adoran sin asociar en su adoración nada junto a Mí. Y quienes abandonen la fe tras eso serán los transgresores.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdcccxlvii{Haced la oración, dad el impuesto que purifica la riqueza y obedeced al Mensajero para que, quizás así, se tenga misericordia de vosotros.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdcccxlviii{No penséis que quienes no creen podrán escapar en la Tierra. Su morada será el fuego. ¡Qué mal destino!\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdcccxlix{¡Oh, creyentes! Que vuestros esclavos y quienes de los vuestros todavía no hayan llegado a la pubertad os pidan permiso en tres momentos: Antes de la oración del amanecer, cuando os quitáis vuestros vestidos al mediodía y tras la oración de la noche. Tres momentos de intimidad para vosotros. Después de ellos, no hay falta para vosotros ni para ellos en que os frecuentéis unos a otros. Así es como Dios os aclara sus señales. Y Dios todo los conoce, es sabio.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdcccl{Y cuando vuestros hijos pequeños alcancen la pubertad, que pidan permiso, como pidieron permiso quienes les precedieron.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdcccli{Y las mujeres mayores, que no tienen esperanza de contraer matrimonio, no cometen pecado si relajan su vestimenta sin llegar a mostrar sus adornos. Pero es mejor para ellas que se recaten. Y Dios todo lo oye, es sabio.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdccclii{No hay falta en que el ciego, el lisiado, el enfermo o vosotros mismos, comáis en vuestras casas o en las casas de vuestros padres o de vuestras madres, de vuestros hermanos, de vuestras hermanas, o en las casas de vuestros tíos paternos o de vuestras tías paternas o de vuestros tíos maternos o de vuestras tías maternas o en aquellas de las que poseéis las llaves o en las de vuestros amigos. No hay falta si coméis juntos o separados. Y cuando entréis en las casas saludaos con una fórmula venida de Dios, bendita y buena. Así es como Dios aclara para vosotros Sus señales, para que, quizás de esa manera, reflexionéis.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdcccliii{En verdad, los creyentes son quienes creen en Dios y en Su Mensajero y cuando están con él en un asunto colectivo no se retiran sin pedirle permiso. En verdad, quienes te piden permiso son quienes creen en Dios y en Su Mensajero. Cuando te pidan permiso para algún asunto suyo, autoriza a quien quieras de ellos y pide el perdón de Dios para ellos. En verdad, Dios es perdonador, misericordiosísimo.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdcccliv{No consideréis la invitación del Mensajero como consideráis la invitación de unos a otros. Ciertamente, Dios conoce a quienes de vosotros se retiran con disimulo. Que quienes desobedecen sus órdenes tengan cuidado de que les sobrevenga una prueba penosa o tengan que sufrir un castigo doloroso.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdccclv{¿Acaso, en verdad, no pertenece a Dios lo que hay en los cielos y en la Tierra? Ciertamente, Él conoce bien en lo que estáis. Y el día en el que se les haga regresar a Él, les informará de lo que hacían. Y Dios conoce bien todas las cosas.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdccclvi{\basmalahes Bendito sea Quien hizo descender El Discernimiento a Su siervo para que amoneste a toda la humanidad.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdccclvii{Aquel a quien pertenece la soberanía de los cielos y de la Tierra, que no tiene un hijo y que no comparte la soberanía con nadie y que lo ha creado todo y lo ha determinado absolutamente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdccclviii{Y ellos toman, en lugar de Él, dioses que nada han creado y que han sido creados y que no poseen poder para perjudicarse a ellos mismos ni para beneficiarse, ni disponen de la muerte, ni de la vida, ni de la resurrección.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdccclix{Y los que no creen dicen: «En verdad, esto no es más que una mentira que él ha inventado con ayuda de otro grupo.» Ciertamente, ellos vienen con opresión y mentiras.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdccclx{Y dicen: «¡Fábulas de los primitivos que él ha pedido que le escriban y que le son leídas mañana y tarde!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdccclxi{Di: «Lo hace descender Quien conoce el secreto de los cielos y la Tierra. En verdad, Él es perdonador, misericordiosísimo.»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdccclxii{Pero ellos dicen: «¿Qué clase de Mensajero es éste que come alimentos y transita por los mercados? ¿Por qué no se ha hecho que descienda un ángel que amoneste con él\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdccclxiii{o se le ha proporcionado un tesoro o un jardín del que pueda comer?» Y dicen los opresores: «No seguís sino a un hombre hechizado.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdccclxiv{¡Mira con lo que te comparan! Pero se extravían y no pueden encontrar el camino.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdccclxv{Bendito sea Quien, si Él hubiera querido, habría puesto para ti algo mejor que eso, jardines de cuyas profundidades brotasen los arroyos, y habría puesto para ti palacios.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdccclxvi{Pero ellos desmienten la Hora. Y a quienes desmienten la Hora les daremos el fuego infernal.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdccclxvii{Cuando les vea desde lejos, ellos escucharán su furor y bramido.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdccclxviii{Y cuando se les sitúe encadenados en un lugar estrecho y reducido de él, gritarán pidiendo su aniquilación.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdccclxix{«¡No pidáis hoy una simple aniquilación, pedid muchas aniquilaciones!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdccclxx{Di: «¿Es mejor esto o el Jardín de la Eternidad que fue prometido a los temerosos como recompensa y destino final?»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdccclxxi{Allí tendrán eternamente lo que deseen. Es una promesa que obliga a tu Señor.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdccclxxii{Y el día en que Él les reúna a ellos y a lo que ellos adoraban en lugar de Dios, Él dirá: «¿Fuisteis vosotros quienes desviaron a Mis siervos o fueron ellos quienes extraviaron el camino?»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdccclxxiii{Ellos responderán: «¡Glorificado seas! No era adecuado para nosotros tomar protectores aparte de Ti, pero Tú les permitiste disfrutar a ellos y a sus padres hasta que olvidaron el Recuerdo y fueron un pueblo echado a perder.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdccclxxiv{Ciertamente, ellos desmentirán lo que vosotros decís y no podréis cambiar ni ser auxiliados y a quien de vosotros oprima le haremos probar un gran castigo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdccclxxv{Y no hemos enviado antes de ti Mensajero alguno que no comiera alimentos y fuese a los mercados. Y os pusimos a unos como prueba para los otros ¿Seréis pacientes? Y tu Señor todo lo ve.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdccclxxvi{Quienes no esperan el encuentro con Nosotros dicen: «¿Por qué no se hace que desciendan los ángeles a nosotros o que veamos a nuestro Señor?» Ciertamente, sus almas se han llenado de arrogancia y endiosado enormemente.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdccclxxvii{El día que vean a los ángeles, no habrá para los pecadores buenas noticias y dirán: «¡Dadnos refugio!»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdccclxxviii{Nos ocuparemos de cada obra que realizaron y la dejaremos como polvo disperso en el aire.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdccclxxix{Ese día la gente del Jardín estará en la mejor morada y en el mejor lugar de descanso.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdccclxxx{El día en el que el cielo y las oscuras nubes se abran y se haga descender a los ángeles de forma majestuosa.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdccclxxxi{Ese día la soberanía verdadera pertenecerá al Misericordiosísimo y será un día difícil para los que no creían.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdccclxxxii{Un día en el que el opresor se morderán las manos diciendo: «¡Ojalá hubiese tomado el camino junto al Mensajero!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdccclxxxiii{¡Ay de mí! ¡Ojalá no hubiese tomado a fulano como amigo!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdccclxxxiv{¡Después de que el recuerdo había llegado a mí, me desvió de él!» ¡Ciertamente, Satanás siempre deja al hombre abandonado!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdccclxxxv{Y el Mensajero dirá: «¡Oh, Señor mío! ¡En verdad, mi pueblo ha abandonado este Corán!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdccclxxxvi{Y, así mismo, designamos a cada profeta un enemigo de entre los pecadores, pero tu Señor es suficiente guía y auxilio.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdccclxxxvii{Y los que no creen dicen: «¿Por qué no le ha sido revelado el Corán de una sola vez?» Así es, te lo hemos recitado gradual y ordenadamente para afianzar con ello tu corazón.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdccclxxxviii{No vendrán a ti con un argumento sin que Nosotros te traigamos la verdad y una interpretación mejor.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdccclxxxix{Aquellos que sean reunidos frente al Infierno serán quienes tengan el peor lugar y el camino más extraviado.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcccxc{Y, ciertamente, dimos a Moisés la Escritura y pusimos a su hermano Aarón para que le ayudase.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcccxci{Y dijimos: «Id al pueblo que desmiente Nuestras señales.» Y les destruimos totalmente.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcccxcii{Y cuando las gentes del pueblo de Noé desmintieron a los Mensajeros, les ahogamos e hicimos de ellos una señal para las gentes. Hemos preparados para los opresores un castigo doloroso.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcccxciii{Y a Ad y a Zamud y a los habitantes de Al-Rass y a muchas generaciones entre ellos.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcccxciv{A todos ellos les pusimos ejemplos. Y a todos ellos les destruimos totalmente.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcccxcv{Ciertamente, ellos han pasado por la ciudad sobre la que cayó una lluvia maléfica. ¿Acaso no la han visto? Lo que sucede es que no esperan ser resucitados.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcccxcvi{Cuando te ven se burlan de ti: «¿Éste es al que Dios ha designado Mensajero?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcccxcvii{Casi nos desvía de nuestros dioses si no hubiera sido porque hemos sido perseverantes con ellos.» Pronto sabrán, cuando vean el castigo, quien está más desviado del camino.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcccxcviii{¿Has visto a quien ha tomado como dios a sus pasiones? ¿Acaso eres tú su protector?\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcccxcix{¿Crees que la mayoría de ellos escuchan o razonan? La verdad es que son como el ganado. No, aún más extraviados del camino.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcm{¿Acaso no has visto cómo tu Señor alarga la sombra? Si Él hubiese querido habría hecho que permaneciera inmóvil. Pusimos al Sol como causa de su existencia.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcmi{Luego, la recogemos hacia Nosotros lenta y suavemente.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcmii{Él es Quien ha hecho para vosotros de la noche una vestidura y del sueño descanso y del día movimiento y búsqueda de la provisión.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcmiii{Y Él es Quien envía los vientos como portadores de buenas noticias, anunciando Su misericordia. Y hacemos descender del cielo agua purificadora\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcmiv{con la que Nosotros revivimos una tierra muerta y con la que damos de beber a muchos animales y humanos de los que hemos creado.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcmv{Y, ciertamente, la distribuimos entre ellos para que reflexionen. Pero la mayoría de las personas se niegan a ser agradecidos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcmvi{Si hubiéramos querido habríamos enviado un amonestador a cada ciudad.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcmvii{No obedezcas, pues, a quienes no creen y libra con él una gran batalla contra ellos.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcmviii{Y Él es Quien ha unido los dos mares, uno de aguas dulces y agradables y el otro de aguas saladas y amargas y ha puesto entre ambos una barrera y un límite infranqueable.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcmix{Y es Él Quien ha creado del agua al ser humano y dispuso para él lazos familiares paternos y maternos. Tu Señor es poderoso.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcmx{Pero ellos adoran en lugar de Dios lo que no puede beneficiarles ni perjudicarles. Quien no es creyente es un ayudante contra su Señor.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcmxi{Y no te hemos enviado sino como portador de buenas nuevas y amonestador.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcmxii{Di: «No os pido por ello una recompensa excepto que quien quiera tome un camino hacia su Señor.»\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcmxiii{Y confía en el Vivo que no muere y glorifícale con alabanzas. Él es suficiente para estar informado de los pecados de Sus siervos.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcmxiv{Él es Quien creó en seis días los cielos y la Tierra y lo que entre ambos hay. Luego, Se estableció sobre el Trono. El Clementísimo. Pregúntale, pues Él está bien informado.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcmxv{Y si se les dice: «¡Prosternaos para el Clementísimo!” dicen: “¿Y qué es el Clementísimo? ¿Habremos de prosternarnos ante lo que nos ordenéis?» Y se incrementa su rechazo.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcmxvi{Bendito sea Quien ha puesto constelaciones en el cielo y ha puesto en él una lámpara y una Luna luminosa.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcmxvii{Y Él es Quien ha puesto la noche y el día sucediéndose, para quien quiera reflexionar o quiera agradecer.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcmxviii{Y los siervos del Clementísimo son quienes van por la Tierra con humildad y si los ignorantes se dirigen a ellos, les dicen: «¡Paz!»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcmxix{y quienes pasan parte de la noche prosternados o en pie para su Señor\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcmxx{y quienes dicen: «¡Señor nuestro! ¡Aparta de nosotros el castigo del Infierno!» En verdad, su castigo es abrumador y eterno.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcmxxi{Una mala residencia y morada.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcmxxii{Y quienes, cuando gastan, no despilfarran ni son tacaños, pues el equilibrio está entre ambos extremos.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcmxxiii{Y quienes no invocan junto a Dios a otro dios y no matan al ser humano, pues Dios lo ha prohibido, excepto por causa justa, y no cometen fornicación ni adulterio. Y quien haga tales cosas se encontrará con su castigo.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcmxxiv{Les será doblado el castigo el Día del Levantamiento y en él permanecerán eternamente humillados.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcmxxv{Excepto quienes se arrepientan y tengan fe y realicen buenas acciones, pues a ellos Dios les cambiará el mal por bien. Dios es perdonador, misericordiosísimo.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcmxxvi{Y quien se arrepiente y realiza buenas acciones, en verdad, regresa hacia Dios.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcmxxvii{Y aquellos que no dan falso testimonio y que cuando se tropiezan con palabras vanas pasan de largo con dignidad.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcmxxviii{Y aquellos a quienes, si les son recordadas las señales de su Señor, no las reciben con oídos sordos y ojos ciegos.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcmxxix{Y aquellos que dicen: «¡Oh, Señor nuestro! ¡Haz que nuestras esposas y nuestros hijos sean la alegría de nuestros ojos y sitúanos al frente de los temerosos de Dios!»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcmxxx{Ellos serán recompensados por su paciencia con un alto aposento y allí serán recibidos con ofrendas y saludos de paz.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcmxxxi{Allí estarán eternamente. ¡Excelente lugar y residencia!\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcmxxxii{Di: «¡Mi Señor no os prestará atención si no le suplicáis! Desmentíais y pronto seréis castigados.»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcmxxxiii{\basmalahes Ta, Sim, Mim\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcmxxxiv{Estos son los versículos de la Escritura clara.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcmxxxv{Puede que quieras morir de pena porque no son creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcmxxxvi{Si hubiéramos querido habríamos hecho descender del cielo sobre ellos una señal ante la que sus cuellos se inclinarían humillados.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcmxxxvii{No llega a ellos ningún nuevo recuerdo del Clementísimo sin que ellos se aparten de él.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcmxxxviii{Ciertamente, desmienten, pero pronto les llegarán las noticias de aquello de lo que se burlaban.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcmxxxix{¿Acaso no ven como hemos hecho crecer en la Tierra parejas de todo tipo de plantas hermosas y buenas?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcmxl{En verdad, en ello hay una señal, pero la mayoría de ellos no tiene fe.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcmxli{Y, en verdad, tu Señor es el Todopoderoso, el Misericordiosísimo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcmxlii{Y (recuerda) cuando tu Señor llamó a Moisés: «¡Ve al pueblo de los opresores!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcmxliii{El pueblo del Faraón ¿Por qué no temen a Dios?»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcmxliv{Dijo él: «¡Señor mío! Temo que me desmientan\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcmxlv{y que mi pecho se angustie y mi lengua no sea suficientemente elocuente. Envía, pues, a Aarón.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcmxlvi{¡Y tienen cargos contra mí y temo que me maten!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcmxlvii{Dijo Él: «¡No será así! ¡Id, pues, ambos con Nuestras señales! En verdad, Nosotros estaremos escuchando junto a vosotros.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcmxlviii{Id, pues, al Faraón y decidle: “En verdad, soy un Mensajero del Señor del Universo\qt@no{16}}
\qt@newcmd\qurantrans@es@mmcmxlix{para que dejes ir con nosotros a los Hijos de Israel.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmcml{Dijo [Faraón]: «¿Acaso no te hemos criado entre nosotros de pequeño y permaneciste entre nosotros muchos años de tu vida\qt@no{18}}
\qt@newcmd\qurantrans@es@mmcmli{y luego hiciste lo que hiciste? Eres de los desagradecidos.»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmcmlii{Dijo: «Hice eso cuando era de los extraviados\qt@no{20}}
\qt@newcmd\qurantrans@es@mmcmliii{y huí porque tuve miedo de vosotros, pero mi Señor me otorgó juicio y me hizo uno de Sus Mensajeros.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmcmliv{Y éste es el favor que me has hecho: esclavizar a los Hijos de Israel.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmcmlv{Faraón dijo: «¿Y qué es eso de ‘el Señor del Universo’?»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmcmlvi{Dijo: «El Señor de los cielos y de la Tierra y de lo que hay entre ambos, si es que sois gente de certezas.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmcmlvii{Dijo a quienes estaban a su alrededor: «¿No estáis oyendo?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmcmlviii{Dijo: «Señor vuestro y Señor de vuestros primeros padres.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmcmlix{Dijo: «¡En verdad, ese Mensajero que os ha sido enviado está loco!»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmcmlx{Dijo: «El Señor del Oriente y del Occidente y de lo que entre ambos hay, si es que razonáis.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmcmlxi{Dijo: «Si tomas otro dios diferente a mí, te pondré entre los que están en la cárcel.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmcmlxii{Dijo: «¿Aunque te traiga algo evidente?»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmcmlxiii{Dijo: «¡Tráelo pues, si eres de los que dicen la verdad!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmcmlxiv{Entonces, lanzó su bastón y fue claramente una serpiente\qt@no{32}}
\qt@newcmd\qurantrans@es@mmcmlxv{y sacó su mano y era blanca para los que observaban.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmcmlxvi{Dijo a los principales que había a su alrededor: «¡En verdad, éste es un mago muy experto!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmcmlxvii{Quiere echaros de vuestra tierra por medio de su magia, así pues, ¿Qué queréis que haga?»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmcmlxviii{Dijeron: «Dales un plazo a él y a su hermano y envía unos emisarios a las ciudades.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmcmlxix{Que te traigan todos los magos expertos.»\qt@no{37}}
\qt@newcmd\qurantrans@es@mmcmlxx{Así pues, fueron congregados los magos en el lugar acordado para el encuentro el día establecido\qt@no{38}}
\qt@newcmd\qurantrans@es@mmcmlxxi{y se dijo a la gente: «¿Queréis acudir?»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmcmlxxii{«Quizás así sigamos a los magos si son ellos los vencedores.»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmcmlxxiii{Así que, cuando llegaron los magos, dijeron al Faraón: «¿Obtendremos una recompensa si somos los vencedores?»\qt@no{41}}
\qt@newcmd\qurantrans@es@mmcmlxxiv{Dijo: «Sí. Y, en verdad, seréis entonces de los cercanos a mí.»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmcmlxxv{Moisés les dijo: «¡Lanzad lo que tengáis que lanzar!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmcmlxxvi{Así pues, lanzaron sus cuerdas y bastones y dijeron: «¡Por el poder del Faraón! ¡Con seguridad, seremos los vencedores!»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcmlxxvii{Entonces, Moisés lanzó su bastón y éste engulló inmediatamente lo que ellos habían transformado.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcmlxxviii{Los magos cayeron prosternados.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcmlxxix{Dijeron: «¡Creemos en el Señor del Universo!\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcmlxxx{El Señor de Moisés y de Aarón.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcmlxxxi{Dijo: «¿Habéis creído en él antes de que yo os diera permiso? En verdad, él es el mayor de vosotros y quien os ha enseñado la magia. ¡Vais a saber! ¡Os cortaré las manos y los pies opuestos y os crucificare a todos!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcmlxxxii{Dijeron: «No nos perjudicará. En verdad, nosotros regresaremos a nuestro Señor.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcmlxxxiii{Verdaderamente, tenemos esperanza de que nuestro Señor perdone nuestros errores por haber sido los primeros en creer.»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcmlxxxiv{Y revelamos a Moisés: «Parte con Mis siervos durante la noche, pues seréis perseguidos.»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcmlxxxv{Entonces, el Faraón envió emisarios a las ciudades:\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcmlxxxvi{«En verdad, ellos son una pequeña banda.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcmlxxxvii{y, en verdad, han provocado nuestra ira,\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcmlxxxviii{pero nosotros somos un colectivo que está en guardia.»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcmlxxxix{Y les sacamos de los jardines y las fuentes\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcmxc{y de los tesoros y espléndidos lugares.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcmxci{Así fue. Y se lo dimos en herencia a los Hijos de Israel.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcmxcii{Entonces les persiguieron al amanecer.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcmxciii{Y cuando los dos grupos se vieron, los compañeros de Moisés dijeron: «En verdad, nos están alcanzando.»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcmxciv{Dijo [Moisés]: «No. En verdad, mi Señor está conmigo y me guiará.»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcmxcv{Entonces revelamos a Moisés: «¡Golpea el mar con tu bastón!» y éste se partió y cada una de las partes era como una montaña inmensa.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcmxcvi{Luego, hicimos que los otros se acercarán\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcmxcvii{y salvamos a Moisés y a todos los que con él estaban\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcmxcviii{y entonces ahogamos a los otros.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcmxcix{En verdad, en ello hay una señal. Y la mayoría de ellos no eran creyentes.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmm{Y, en verdad, tu Señor es el Poderoso, el Misericordiosísimo.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmi{Y relátales la historia de Abraham\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmii{cuando dijo a su padre y a su pueblo: «¿Qué es lo que adoráis?»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmiii{Dijeron: «Adoramos ídolos y continuaremos haciéndolo.»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmiv{Dijo: «¿Acaso os escuchan si les llamáis\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmv{u os benefician o perjudican?»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmvi{Dijeron: «No. Pero encontramos que nuestros padres hacían lo mismo.»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmvii{Dijo: «¿Habéis visto, pues, lo que estabais adorando\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmviii{vosotros y vuestros antepasados?\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmix{Ellos son enemigos para mí, pero no el Señor del Universo,\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmx{el Cual me ha creado y es Quien me guía\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmxi{y Quien me alimenta y me da de beber\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmxii{y cuando estoy enfermo me cura\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmxiii{y Quien me hará morir y luego me dará la vida\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmxiv{y Quien, espero, perdonará mis errores el Día de la Recompensa.»\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmxv{«¡Dios mío! ¡Otórgame juicio y reúneme con los Rectos!»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmxvi{«Y dame una lengua sincera ante las generaciones futuras.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmxvii{Y ponme entre los herederos del Jardín de las Delicias.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmxviii{y perdona a mi padre. En verdad, él era de los extraviados.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmxix{Y no me dejes sin ayuda el día en que sean devueltos a la vida.»\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmxx{El día en el que en nada beneficien bienes ni hijos,\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmxxi{sino el llegar a Dios con un corazón sano\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmxxii{y sea aproximado el Jardín para los temerosos de Dios\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmxxiii{y se muestre el Infierno a los extraviados\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmxxiv{y se les pregunte: “¿Dónde está lo que adorabais\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmxxv{en lugar de Dios? ¿Os auxilian o se auxilian entre ellos?”\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmxxvi{Entonces, serán arrojados de cara a él, ellos y los extraviados unos tras otros\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmxxvii{y el ejército de Iblís, todos juntos.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmxxviii{Allí, peleando entre ellos, dirán:\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmxxix{«¡Por Dios que estábamos en un extravío evidente\qt@no{97}}
\qt@newcmd\qurantrans@es@mmmxxx{cuando os equiparábamos con el Señor del Universo!\qt@no{98}}
\qt@newcmd\qurantrans@es@mmmxxxi{¡Nadie, sino los pecadores, nos extraviaron!\qt@no{99}}
\qt@newcmd\qurantrans@es@mmmxxxii{Ahora no tenemos quien interceda por nosotros,\qt@no{100}}
\qt@newcmd\qurantrans@es@mmmxxxiii{ni amigo intimo.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmmxxxiv{Si hubiera para nosotros otra oportunidad seríamos de los creyentes.»\qt@no{102}}
\qt@newcmd\qurantrans@es@mmmxxxv{En verdad, es esto hay una señal, pero la mayoría no cree.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmmxxxvi{Y, en verdad, tu Señor es el Todopoderoso, el Misericordiosísimo.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmmxxxvii{El pueblo de Noé desmintió a los Mensajeros\qt@no{105}}
\qt@newcmd\qurantrans@es@mmmxxxviii{cuando su hermano Noé les dijo: «¿No vais a ser temerosos de Dios?\qt@no{106}}
\qt@newcmd\qurantrans@es@mmmxxxix{En verdad, soy para vosotros un Mensajero digno de confianza.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmmxl{Temed, pues, a Dios y obedecedme.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmmxli{No os pido por ello una recompensa. Mi recompensa sólo concierne al Señor del Universo.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmmxlii{Temed, pues, a Dios y obedecedme.»\qt@no{110}}
\qt@newcmd\qurantrans@es@mmmxliii{Dijeron: «¿Vamos a seguirte cuando sólo te siguen los de abajo?»\qt@no{111}}
\qt@newcmd\qurantrans@es@mmmxliv{Dijo: «Yo no tengo conocimiento de lo que ellos hacen,\qt@no{112}}
\qt@newcmd\qurantrans@es@mmmxlv{pues su cuenta la lleva sólo mi Señor ¿No lo comprendéis?\qt@no{113}}
\qt@newcmd\qurantrans@es@mmmxlvi{No voy yo a rechazar a los creyentes.\qt@no{114}}
\qt@newcmd\qurantrans@es@mmmxlvii{En verdad, yo sólo soy un amonestador que habla con claridad.»\qt@no{115}}
\qt@newcmd\qurantrans@es@mmmxlviii{Ellos dijeron: «Si no cesas ¡Oh Noé! ten por seguro que te lapidaremos.»\qt@no{116}}
\qt@newcmd\qurantrans@es@mmmxlix{Él dijo: «¡Señor mío! ¡Mi pueblo me desmiente!\qt@no{117}}
\qt@newcmd\qurantrans@es@mmml{Abre, pues, entre yo y ellos una brecha y sálvame a mí y a los creyentes que están conmigo.»\qt@no{118}}
\qt@newcmd\qurantrans@es@mmmli{Así pues, salvamos, en el Arca repleta a él y quienes con él estaban.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmmlii{Luego, ahogamos a los que quedaron.\qt@no{120}}
\qt@newcmd\qurantrans@es@mmmliii{En verdad, en ello hay una señal. La mayoría de ellos no creían.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmmliv{Y en verdad, tu Señor es el Todopoderoso, el Misericordiosísimo.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmmlv{El pueblo de Ad desmintió a los Mensajeros\qt@no{123}}
\qt@newcmd\qurantrans@es@mmmlvi{cuando su hermano Hud les dijo: «¿No vais a ser temerosos de Dios?\qt@no{124}}
\qt@newcmd\qurantrans@es@mmmlvii{En verdad, soy para vosotros un Mensajero digno de confianza.\qt@no{125}}
\qt@newcmd\qurantrans@es@mmmlviii{Temed, pues, a Dios y obedecedme.\qt@no{126}}
\qt@newcmd\qurantrans@es@mmmlix{No os pido por ello una recompensa. Mi recompensa sólo concierne al Señor del Universo.»\qt@no{127}}
\qt@newcmd\qurantrans@es@mmmlx{«¿Vais a construir vanamente una señal en cada promontorio\qt@no{128}}
\qt@newcmd\qurantrans@es@mmmlxi{y castillos como si fueseis a vivir eternamente?\qt@no{129}}
\qt@newcmd\qurantrans@es@mmmlxii{Y cuando hacéis uso de la fuerza la ejercitáis con prepotencia.\qt@no{130}}
\qt@newcmd\qurantrans@es@mmmlxiii{Temed, pues, a Dios y obedecedme.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmmlxiv{Y temed a Quien os ha beneficiado con lo que sabéis.\qt@no{132}}
\qt@newcmd\qurantrans@es@mmmlxv{Os ha beneficiado con ganado e hijos,\qt@no{133}}
\qt@newcmd\qurantrans@es@mmmlxvi{con jardines y viñedos.»\qt@no{134}}
\qt@newcmd\qurantrans@es@mmmlxvii{«En verdad, temo para vosotros el castigo de un día grandioso.»\qt@no{135}}
\qt@newcmd\qurantrans@es@mmmlxviii{Ellos dijeron: «Nos da igual que nos amonestes o que no nos amonestes.\qt@no{136}}
\qt@newcmd\qurantrans@es@mmmlxix{Eso no es más que el comportamiento de los primitivos.\qt@no{137}}
\qt@newcmd\qurantrans@es@mmmlxx{y nosotros no seremos castigados.»\qt@no{138}}
\qt@newcmd\qurantrans@es@mmmlxxi{Así pues, le desmintieron y Nosotros les destruimos. En verdad, en ello hay una señal. La mayoría de ellos no creía.\qt@no{139}}
\qt@newcmd\qurantrans@es@mmmlxxii{Y, en verdad, tu Señor es el Todopoderoso, el Misericordiosísimo.\qt@no{140}}
\qt@newcmd\qurantrans@es@mmmlxxiii{El pueblo de Zamud desmintió a los Mensajeros\qt@no{141}}
\qt@newcmd\qurantrans@es@mmmlxxiv{cuando su hermano Salih les dijo: «¿No vais a ser temerosos de Dios?\qt@no{142}}
\qt@newcmd\qurantrans@es@mmmlxxv{En verdad, soy para vosotros un Mensajero digno de confianza.\qt@no{143}}
\qt@newcmd\qurantrans@es@mmmlxxvi{Temed, pues, a Dios y obedecedme.\qt@no{144}}
\qt@newcmd\qurantrans@es@mmmlxxvii{No os pido por ello una recompensa. Mi recompensa sólo concierne al Señor del Universo.»\qt@no{145}}
\qt@newcmd\qurantrans@es@mmmlxxviii{«¿Acaso se os dejará en todo esto a salvo?\qt@no{146}}
\qt@newcmd\qurantrans@es@mmmlxxix{¿En los jardines y viñedos\qt@no{147}}
\qt@newcmd\qurantrans@es@mmmlxxx{cultivos y palmerales de frutos dulces y maduros,\qt@no{148}}
\qt@newcmd\qurantrans@es@mmmlxxxi{excavando casas en la montaña con maestría?»\qt@no{149}}
\qt@newcmd\qurantrans@es@mmmlxxxii{«Temed, pues, a Dios y obedecedme\qt@no{150}}
\qt@newcmd\qurantrans@es@mmmlxxxiii{y no obedezcáis las órdenes de los inmoderados,\qt@no{151}}
\qt@newcmd\qurantrans@es@mmmlxxxiv{que corrompen en la Tierra y no corrigen lo que está mal.»\qt@no{152}}
\qt@newcmd\qurantrans@es@mmmlxxxv{Ellos dijeron: «En verdad, tú estás embrujado.\qt@no{153}}
\qt@newcmd\qurantrans@es@mmmlxxxvi{Tú no eres más que un ser humano como nosotros. Tráenos una señal si eres de los que dicen la verdad.»\qt@no{154}}
\qt@newcmd\qurantrans@es@mmmlxxxvii{Él dijo: «Aquí tenéis una camella. Ella tendrá su turno para beber y vosotros el vuestro los días señalados.\qt@no{155}}
\qt@newcmd\qurantrans@es@mmmlxxxviii{Y no la maltratéis, pues sufriríais el castigo de un día grandioso.»\qt@no{156}}
\qt@newcmd\qurantrans@es@mmmlxxxix{Pero la desjarretaron y luego se arrepintieron.\qt@no{157}}
\qt@newcmd\qurantrans@es@mmmxc{Y fueron castigados. En verdad, en ello hay una señal. La mayoría de ellos no creían.\qt@no{158}}
\qt@newcmd\qurantrans@es@mmmxci{Y, en verdad, tu Señor es el Todopoderoso, el Misericordiosísimo.\qt@no{159}}
\qt@newcmd\qurantrans@es@mmmxcii{El pueblo de Lot desmintió a los Mensajeros\qt@no{160}}
\qt@newcmd\qurantrans@es@mmmxciii{cuando su hermano Lot les dijo: «¿No vais a ser temerosos de Dios?\qt@no{161}}
\qt@newcmd\qurantrans@es@mmmxciv{En verdad, soy para vosotros un Mensajero digno de confianza.\qt@no{162}}
\qt@newcmd\qurantrans@es@mmmxcv{Temed, pues, a Dios y obedecedme.\qt@no{163}}
\qt@newcmd\qurantrans@es@mmmxcvi{No os pido por ello una recompensa. Mi recompensa sólo concierne al Señor del Universo.\qt@no{164}}
\qt@newcmd\qurantrans@es@mmmxcvii{¿Vais a los varones de los seres humanos\qt@no{165}}
\qt@newcmd\qurantrans@es@mmmxcviii{abandonando a las mujeres que Dios ha creado para vosotros? Sois un pueblo trasgresor.»\qt@no{166}}
\qt@newcmd\qurantrans@es@mmmxcix{Ellos dijeron: «Si no cesas ¡Oh, Lot! serás expulsado.»\qt@no{167}}
\qt@newcmd\qurantrans@es@mmmc{Él dijo: «En verdad, soy de los que detestan vuestra conducta.\qt@no{168}}
\qt@newcmd\qurantrans@es@mmmci{¡Dios mío! ¡Sálvame junto a mi familia de lo que hacen!»\qt@no{169}}
\qt@newcmd\qurantrans@es@mmmcii{Y les salvamos, a él y a su familia, a todos ellos.\qt@no{170}}
\qt@newcmd\qurantrans@es@mmmciii{Excepto a una mujer anciana que se quedó.\qt@no{171}}
\qt@newcmd\qurantrans@es@mmmciv{Entonces, destruimos a los otros\qt@no{172}}
\qt@newcmd\qurantrans@es@mmmcv{haciendo caer una lluvia sobre ellos. ¡Qué mala la lluvia de quienes habían sido amonestados!\qt@no{173}}
\qt@newcmd\qurantrans@es@mmmcvi{En verdad, en ello hay una señal. La mayoría de ellos no creían.\qt@no{174}}
\qt@newcmd\qurantrans@es@mmmcvii{Y, en verdad, tu Señor es el Todopoderoso, el Misericordiosísimo.\qt@no{175}}
\qt@newcmd\qurantrans@es@mmmcviii{El pueblo de Al-Aykah desmintió a los Mensajeros\qt@no{176}}
\qt@newcmd\qurantrans@es@mmmcix{cuando Shuayb les dijo: «¿No vais a ser temerosos?\qt@no{177}}
\qt@newcmd\qurantrans@es@mmmcx{En verdad, soy para vosotros un Mensajero digno de confianza.\qt@no{178}}
\qt@newcmd\qurantrans@es@mmmcxi{Temed, pues, a Dios y obedecedme.\qt@no{179}}
\qt@newcmd\qurantrans@es@mmmcxii{No os pido por ello una recompensa. Mi recompensa sólo concierne al Señor del Universo.\qt@no{180}}
\qt@newcmd\qurantrans@es@mmmcxiii{¡Dad con equidad la medida y no seáis de los que sisan!\qt@no{181}}
\qt@newcmd\qurantrans@es@mmmcxiv{¡Y pesad con una balanza ajustada!\qt@no{182}}
\qt@newcmd\qurantrans@es@mmmcxv{Y no deis de menos a la gente en sus cosas al pesar y medir y no corrompáis en la Tierra.\qt@no{183}}
\qt@newcmd\qurantrans@es@mmmcxvi{Y temed a Quien os ha creado a vosotros y a las generaciones primeras.»\qt@no{184}}
\qt@newcmd\qurantrans@es@mmmcxvii{Ellos dijeron: «¡En verdad, tú estás embrujado!»\qt@no{185}}
\qt@newcmd\qurantrans@es@mmmcxviii{y «Solamente eres un ser humano como nosotros y creemos que eres un mentiroso.\qt@no{186}}
\qt@newcmd\qurantrans@es@mmmcxix{Haz que caiga sobre nosotros un trozo de cielo, si eres de los que dicen la verdad.»\qt@no{187}}
\qt@newcmd\qurantrans@es@mmmcxx{El dijo: «Mi señor es Quien mejor sabe lo vosotros hacéis.»\qt@no{188}}
\qt@newcmd\qurantrans@es@mmmcxxi{Así que le desmintieron y les alcanzó el castigo del día de la nube que les daba sombra. En verdad, fue el castigo de un día grandioso.\qt@no{189}}
\qt@newcmd\qurantrans@es@mmmcxxii{En verdad, en ello hay una señal. La mayoría de ellos no creían.\qt@no{190}}
\qt@newcmd\qurantrans@es@mmmcxxiii{Y en verdad, tu Señor es el Todopoderoso, el Misericordiosísimo.\qt@no{191}}
\qt@newcmd\qurantrans@es@mmmcxxiv{Y, en verdad, lo hace descender el Señor del Universo.\qt@no{192}}
\qt@newcmd\qurantrans@es@mmmcxxv{Lo baja el Espíritu digno de confianza\qt@no{193}}
\qt@newcmd\qurantrans@es@mmmcxxvi{sobre tu corazón, para que seas de los amonestadores,\qt@no{194}}
\qt@newcmd\qurantrans@es@mmmcxxvii{en lengua árabe clara.\qt@no{195}}
\qt@newcmd\qurantrans@es@mmmcxxviii{Y, en verdad, ello estaba en la Escrituras de los primeros.\qt@no{196}}
\qt@newcmd\qurantrans@es@mmmcxxix{¿Acaso no es una señal para ellos que los sabios de los Hijos de Israel lo supieran?\qt@no{197}}
\qt@newcmd\qurantrans@es@mmmcxxx{Y si lo hubiéramos hecho descender sobre alguien no árabe\qt@no{198}}
\qt@newcmd\qurantrans@es@mmmcxxxi{y se lo hubiera recitado a ellos no habrían creído en él.\qt@no{199}}
\qt@newcmd\qurantrans@es@mmmcxxxii{Así es como lo hacemos entrar en el corazón de los pecadores:\qt@no{200}}
\qt@newcmd\qurantrans@es@mmmcxxxiii{No creerán en él hasta que vean el castigo doloroso.\qt@no{201}}
\qt@newcmd\qurantrans@es@mmmcxxxiv{Y llegará a ellos por sorpresa y ellos no se darán cuenta.\qt@no{202}}
\qt@newcmd\qurantrans@es@mmmcxxxv{Entonces dirán: «¿Se nos dará un plazo?»\qt@no{203}}
\qt@newcmd\qurantrans@es@mmmcxxxvi{¿Acaso no pedían que se apresurase Nuestro castigo?\qt@no{204}}
\qt@newcmd\qurantrans@es@mmmcxxxvii{¿No has visto que les dejaremos disfrutar unos años\qt@no{205}}
\qt@newcmd\qurantrans@es@mmmcxxxviii{y luego llegará a ellos lo que les ha sido prometido?\qt@no{206}}
\qt@newcmd\qurantrans@es@mmmcxxxix{De nada les habrá servido lo que hayan disfrutado.\qt@no{207}}
\qt@newcmd\qurantrans@es@mmmcxl{Y no hemos destruido ciudad alguna sin antes haberles amonestado\qt@no{208}}
\qt@newcmd\qurantrans@es@mmmcxli{para que recordasen, pues no somos opresores.\qt@no{209}}
\qt@newcmd\qurantrans@es@mmmcxlii{No han sido los demonios quienes han descendido con él.\qt@no{210}}
\qt@newcmd\qurantrans@es@mmmcxliii{No les corresponde a ellos ni tienen poder para hacerlo.\qt@no{211}}
\qt@newcmd\qurantrans@es@mmmcxliv{En verdad, ellos están lejos de oírlo.\qt@no{212}}
\qt@newcmd\qurantrans@es@mmmcxlv{Y no invoques junto a Dios a ningún otro dios, pues serías de los castigados.\qt@no{213}}
\qt@newcmd\qurantrans@es@mmmcxlvi{Y amonesta a tus familiares más cercanos\qt@no{214}}
\qt@newcmd\qurantrans@es@mmmcxlvii{y protege bajo tus alas a los creyentes que te sigan.\qt@no{215}}
\qt@newcmd\qurantrans@es@mmmcxlviii{Pero si te desobedecen, di: «Yo soy inocente de lo que hacéis.»\qt@no{216}}
\qt@newcmd\qurantrans@es@mmmcxlix{Y confía en el Todopoderoso, el Misericordiosísimo.\qt@no{217}}
\qt@newcmd\qurantrans@es@mmmcl{Quien te ve cuando te pones en pie\qt@no{218}}
\qt@newcmd\qurantrans@es@mmmcli{y cuando te mueves con los que se prosternan.\qt@no{219}}
\qt@newcmd\qurantrans@es@mmmclii{En verdad, Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{220}}
\qt@newcmd\qurantrans@es@mmmcliii{¿Queréis que os informe sobre quiénes descienden los demonios?\qt@no{221}}
\qt@newcmd\qurantrans@es@mmmcliv{Descienden sobre todo mentiroso pecador.\qt@no{222}}
\qt@newcmd\qurantrans@es@mmmclv{Transmiten lo que escuchan, pero la mayor parte de lo que dicen es mentira.\qt@no{223}}
\qt@newcmd\qurantrans@es@mmmclvi{En cuanto a los poetas, sólo los extraviados les siguen.\qt@no{224}}
\qt@newcmd\qurantrans@es@mmmclvii{¿Acaso no has visto como divagan por todos los valles\qt@no{225}}
\qt@newcmd\qurantrans@es@mmmclviii{y que dicen lo que no hacen?\qt@no{226}}
\qt@newcmd\qurantrans@es@mmmclix{Excepto aquellos que son creyentes y hacen buenas obras y recuerdan mucho a Dios y se toman la revancha después de haber sido oprimidos. Los opresores pronto sabrán a qué lugar regresarán.\qt@no{227}}
\qt@newcmd\qurantrans@es@mmmclx{\basmalahes Ta, Sim. Estos son los versículos del Corán y una Escritura clara.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmclxi{Una guía y una buena nueva para los creyentes.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmclxii{Aquellos que hacen la oración y dan el impuesto purificador de la riqueza y que tienen certeza de la otra vida.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmclxiii{En verdad, a quienes no creen en la otra vida les adornaremos sus obras y vagarán perdidos, ciegas sus almas.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmclxiv{Les aguarda un mal castigo y en la otra vida serán quienes más pierdan.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmclxv{En verdad, tú recibes el Corán de Uno que es sabio, que todo lo conoce.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmclxvi{[Recuerda] Cuando Moisés dijo a su familia: «En verdad, he divisado un fuego. Os traeré alguna noticia de él o una brasa para que, quizás así, os calentéis.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmclxvii{Y cuando llegó allí, le llamaron: «Bendito sea Quien está en el fuego y alrededor de él y glorificado sea Dios, Señor del Universo.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmclxviii{«¡Oh, Moisés! ¡En verdad, yo soy Dios, el Todopoderoso, el Sabio!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmclxix{¡Lanza tu bastón!» Y, cuando lo vio que reptaba como una serpiente dio la espalda sin mirar atrás. «¡Oh, Moisés! ¡No temas! En verdad, los Mensajeros no tienen miedo ante Mí,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmclxx{sino quien oprime y luego cambia su mal por bien, pues Yo soy perdonador, misericordiosísimo.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmclxxi{«Introduce tu mano en tu costado, saldrá blanca, sin defecto. [Eso es] Parte de las nueve señales destinadas al Faraón y su pueblo. En verdad, ellos son un pueblo de transgresores.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmclxxii{Cuando llegaron a ellos Nuestras señales esclarecedoras dijeron: «Esto es magia manifiesta.»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmclxxiii{Y las negaron, a pesar de la certeza de sus almas, con opresión y altivez.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmclxxiv{Ciertamente, dimos a David y a Salomón conocimiento y ambos dijeron: «Alabado sea Dios que nos ha favorecido por encima de la mayoría de Sus siervos creyentes»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmclxxv{Y Salomón heredó a David y dijo: «¡Oh, gentes! ¡Nos ha sido enseñado el lenguaje de las aves y se nos ha dado de todo! ¡En verdad, ello es un favor evidente!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmclxxvi{Las tropas de Salomón, compuestas de genios, hombres y aves, fueron reunidas ante él y puestas en formación.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmclxxvii{Cuando llegaron al Valle de las Hormigas, una hormiga dijo: «¡Oh, hormigas! ¡Entrad en vuestros hogares, no sea que Salomón y sus tropas os aplasten sin darse cuenta!»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmclxxviii{Sonrió ante sus palabras y dijo: «¡Señor mío! Inspírame para que te agradezca las mercedes con las que me has agraciado y has agraciado a mis padres y pueda realizar buenos actos de los que Tú estés satisfecho y admíteme, por Tu misericordia, entre Tus siervos rectos.»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmclxxix{Pasó revista a las aves y dijo: «¿Por qué no veo a la abubilla? ¿O es que está ausente?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmclxxx{He de castigarla duramente o he de degollarla si no me ofrece una excusa clara.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmclxxxi{No esperó mucho [hasta que ella regresó] y dijo: «He tenido conocimiento de algo que tú desconoces y te traigo de Saba una información segura.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmclxxxii{«En verdad, he encontrado a una mujer gobernándoles y le ha sido dado de todas las cosas y posee un trono grandioso.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmclxxxiii{He encontrado que ella y su pueblo se prosternan ante el Sol en lugar de hacerlo ante Dios y que Satanás les ha embellecido su comportamiento, por lo que les ha apartado del camino y no están guiados.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmclxxxiv{No se prosternan ante Dios, que hace salir lo que no era manifiesto en los cielos y la Tierra y que conoce lo que hay en vuestro interior y lo que es manifiesto en vosotros.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmclxxxv{«Dios, no hay más dios que Él, Señor del Trono inmenso.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmclxxxvi{Dijo [Salomón]: «Pronto veremos si has dicho la verdad o eres un mentiroso.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmclxxxvii{Lleva esta carta mía y déjala caer junto a ellos, luego regresa cerca de ellos y observa cómo reaccionan.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmclxxxviii{Dijo ella: «¡Oh, nobles! Me ha sido enviada una noble misiva.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmclxxxix{Es de Salomón y en el nombre de Dios, el Clementísimo, el Misericordiosísimo:\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcxc{No seáis altaneros ante mí y venid a mí con sumisión.»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcxci{Dijo ella: «¡Oh, nobles! Dadme vuestra opinión en este asunto mío. Yo no decido sobre ningún asunto sin contar con vuestra presencia.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcxcii{Ellos dijeron: «Nosotros poseemos fuerzas y poseemos una gran bravura, pero a ti te corresponde decidir sobre este asunto. Mira, pues, lo que ordenas.»\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcxciii{Ella dijo: «En verdad, cuando los reyes entran en un país, lo corrompen totalmente y arruinan a los poderosos de él. Eso es lo que hacen.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcxciv{En verdad, le enviaremos un regalo y veremos con lo que regresan los mensajeros.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcxcv{Y cuando llegó a Salomón dijo: «¿Queréis incrementar mi riqueza? Lo que Dios me ha otorgado es mejor que lo que os ha otorgado a vosotros. Sois vosotros quienes os alegráis de vuestro regalo.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcxcvi{¡Regresad a ellos! ¡Iremos a ellos con un ejército que no podrán enfrentar y les sacaremos de ella arruinados y quedarán empequeñecidos!»\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmcxcvii{Dijo: «¡Oh, nobles! ¿Quién de vosotros me traerá el trono de ella antes de que vengan a mí sometidos?»\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmcxcviii{Un ifrit de entre los genios dijo: «Yo te lo traeré antes de que te levantes de tu sitio. Puedo hacerlo y soy digno de confianza.»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmcxcix{El que poseía un conocimiento procedente de la Escritura Sagrada dijo: «Yo te lo traeré en un abrir y cerrar de ojos.» Y cuando lo vio ante él dijo: «¡Esto es un favor procedente de mi Señor para poner a prueba si soy agradecido o desagradecido! ¡Quien es agradecido lo es para su propio beneficio y quien sea desagradecido (sepa) que mi Señor es rico en Sí mismo, no necesita de nadie y es generoso.»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmcc{Dijo: «Modificad su trono para ella, que yo vea si discierne o es de los que no tienen discernimiento.»\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmcci{Y, cuando ella llegó, le dijeron: «¿Es éste tu trono?» Ella dijo: «Se parece a él. Ya se nos había informado antes de ello y nos habíamos sometido.»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccii{La había limitado lo que adoraba en lugar de Dios. En verdad, ella pertenecía a un pueblo que no creía.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmcciii{Se le dijo: «¡Entra en el palacio!» Pero al verlo creyó que era un estanque de agua y descubrió sus piernas. Él dijo: «En verdad, es un palacio de cristal pulido.» Ella dijo: «¡Dios mío! En verdad, he oprimido mi alma y me someto, junto a Salomón, al Señor del Universo.»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmcciv{Y, ciertamente, enviamos a Zamud a su hermano Salih: «¡Adorad a Dios!» Pero se dividieron en dos grupos que disputaban entre ellos.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccv{Él dijo: «¡Oh, pueblo mío! ¿Por qué pedís que se apresure lo malo antes que lo bueno? ¿Por qué no pedís el perdón de Dios para que, quizás así, se tenga misericordia con vosotros?»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccvi{Ellos dijeron: «Tú y los que contigo están nos parecéis aves de mal agüero.» Él dijo: «Vuestra ave está junto a Dios. Sois un pueblo al que se está poniendo a prueba.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccvii{En la ciudad había nueve grupos de personas que corrompían la Tierra y no reformaban lo que estaba mal.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccviii{Ellos dijeron: «Juremos por Dios que atacaremos a él y a su familia durante la noche. Luego, diremos a sus herederos que no estuvimos presentes en la destrucción de su familia y que decimos la verdad.»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmccix{Ellos trazaron un plan y Nosotros trazamos un plan sin que ellos se diesen cuenta.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmccx{Y observa cual fue el final de su plan. Cómo les destruimos a ellos y a su pueblo todos juntos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmccxi{Esas son sus casas, vacías por la injusticia que cometieron. En esto hay una señal para gente que tiene conocimiento.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmccxii{Y pusimos a salvo a quienes creían y eran temerosos de Dios.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmccxiii{Y [recuerda] a Lot cuando dijo a su pueblo: «¿Cometéis esa indecencia a pesar de que sabéis lo que hacéis?\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmccxiv{¿Vais a los hombres con deseo en lugar de a las mujeres? Sois una gente ignorante.»\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmccxv{Y la respuesta de su pueblo no fue otra que decir: «Expulsad a la familia de Lot de vuestro pueblo. Verdaderamente, son un grupo de puritanos.»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmccxvi{Así que le salvamos a él y a su familia excepto a su esposa. Decretamos que ella fuera de los que se quedaban.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmccxvii{E hicimos que sobre ellos cayese una lluvia. ¡Qué mala la lluvia de quienes habían sido advertidos!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmccxviii{Di: «¡Alabado sea Dios y la paz sea con aquellos de Sus siervos que Él ha escogido! ¿Es mejor Dios o aquello que asocian a Él?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmccxix{¿Quién ha creado los cielos y la Tierra y hace descender para vosotros desde el cielo agua, mediante la cual hacemos surgir espléndidos jardines cuyos árboles vosotros no habríais podido hacer surgir? ¿Hay otro dios junto a Dios?» Pero ellos son gente cambiante.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmccxx{¿Quién ha hecho la Tierra estable y ha puesto en ella ríos y firmes montañas y ha colocado entre los dos mares una barrera? ¿Hay otro dios junto a Dios? Pero la mayoría de ellos no saben.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmccxxi{¿Quién responde al que sufre cuando Le invoca y alivia el mal y os ha puesto a vosotros sucesores de la Tierra? ¿Hay otro dios junto a Dios? ¡Qué poco reflexionáis!\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmccxxii{¿Quién os guía en las tinieblas de la tierra y del mar y quién envía los vientos como anunciadores de Su misericordia? ¿Hay otro dios junto a Dios? ¡Ensalzado sea Dios por encima de lo que asocian a Él!\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmccxxiii{¿Quién inicia la Creación y la renueva y os provee de lo que hay en los cielos y la Tierra? ¿Hay otro dios junto a Dios? Di: «¡Aportad vuestra prueba si sois de los que dicen la verdad!»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmccxxiv{Di: «Nadie más que Dios conoce lo oculto de los cielos y la Tierra y no saben cuándo serán resucitados.»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmccxxv{Su conocimiento no alcanza a la otra vida. Tienen dudas sobre ella. Más aún, están ciegos sobre ella.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmccxxvi{Y los que no creen dicen: «¿Acaso cuando nosotros y nuestros padres seamos polvo, seremos sacados?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmccxxvii{Ya nos fue prometido eso anteriormente a nosotros y a nuestros padres. No son más que mitos de los primitivos.»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmccxxviii{Di: «Viajad por la Tierra y observad cuál fue el final de los pecadores.»\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmccxxix{No te entristezcas por ellos ni te angusties por sus intrigas.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmccxxx{Y dicen: «¿Cuándo tendrá lugar lo que nos prometes, si es que dices la verdad?»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmccxxxi{Di: «Puede que algo de aquello cuya venida queréis apresurar esté ya muy cerca, detrás de vosotros.»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmccxxxii{Y, en verdad, tu Señor favorece a los seres humanos, pero la mayoría de ellos no agradecen.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmccxxxiii{Y, en verdad, tu Señor conoce bien lo que esconden en sus pechos y lo que manifiestan.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmccxxxiv{Y no hay nada de lo que está oculto en los cielos y en la Tierra que no esté consignado en una Escritura clara.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmccxxxv{En verdad, este Corán relata a los Hijos de Israel la mayoría de las cosas en la que ellos no se ponen de acuerdo.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmccxxxvi{Y es, en verdad, una guía y una misericordia para los creyentes.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmccxxxvii{En verdad, tu Señor emitirá sentencia entre ellos con Su juicio y Él es el Todopoderoso, Quien todo lo sabe.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmccxxxviii{Y confía en Dios. Ciertamente, tú estás en la Verdad evidente.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmccxxxix{En verdad, tú no puedes hacer que los muertos oigan ni que los sordos escuchen la llamada si se vuelven de espaldas,\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmccxl{ni puedes guiar a los ciegos sacándoles de su extravío. Sólo puedes hacer que oigan quienes creen en Nuestras señales y se han sometido.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmccxli{Y cuando se pronuncie la sentencia sobre ellos, haremos salir para ellos una bestia de la tierra que proclamará ante ellos: «¡Los hombres no creyeron en Nuestras señales!»\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmccxlii{Y [recuerda] el día que reunamos, de cada comunidad, al grupo de los que desmentían Nuestras señales y sean detenidos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmccxliii{Hasta que, cuando vengan, Él diga: «¿Desmentíais Mis señales cuando no teníais el conocimiento necesario para entenderlas en su totalidad? ¿Qué es lo que hacíais?»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmccxliv{Y se emita la sentencia contra ellos por haber oprimido y ellos no hablarán.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmccxlv{¿No han visto que pusimos la noche para que puedan descansar en ella y el día para que puedan ver? En verdad, en ello hay señales para gente que es creyente.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmccxlvi{Y el día en que sea tocada la trompeta se aterrorizarán quienes están en los cielos y en la Tierra, excepto quien Dios quiera. Y todos vendrán a Él con humildad.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmccxlvii{Y verás las montañas, que tú creías sólidas, pasando como pasan las nubes. Obra de Dios, que todo lo hace a la perfección. En verdad, Él está bien informado de lo que hacéis.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmccxlviii{«Quien venga con buenas obras obtendrá algo mejor aún y ellos estarán a salvo del terror de ese día.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmccxlix{Y quienes vengan con malas obras serán arrojados de cara al fuego: ¿Se os ha recompensado por otra cosa que por lo que hacíais?\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmccl{En verdad, se os ordenó adorar al Señor de esta ciudad, la cual Él declaró sagrada. Y a Él pertenecen todas las cosas. Y se me ordenó que fuese de los sometidos a Él.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmccli{y que recitase el Corán.» Por tanto, quien se guía, en verdad, se guía para su propio bien y a quien se extravía, dile: «En verdad, yo soy solamente uno de los que advierten.»\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmcclii{Y di: «Alabado sea Dios que pronto os hará ver Sus señales y vosotros las reconoceréis.» Y tu Señor no está desatento a lo que hacéis.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmccliii{\basmalahes Ta, Sim, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmccliv{Estos son los versículos de la Escritura clara.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcclv{Te recitamos la verdad sobre la historia de Moisés y el Faraón para una gente que es creyente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcclvi{En verdad, el Faraón fue un tirano altivo en la Tierra. Dividió a la gente de ella en grupos. Debilitaba a uno de ellos, degollando a sus hijos y dejando con vida a sus mujeres. Verdaderamente, él era de los corruptores.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcclvii{Nosotros quisimos favorecer a quienes habían sido desfavorecidos en la Tierra y les hicimos dirigentes y les hicimos los herederos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcclviii{Y [quisimos] darles posición en la Tierra y hacer ver por medio de ellos al Faraón, a Haman y al ejército de ambos aquello que temían.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcclix{Y revelamos a la madre de Moisés: «¡Amamántale! y cuando temas por él, ponle en el río y no temas ni estés triste. En verdad, Nosotros te lo devolveremos y le haremos uno de los Mensajeros.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcclx{Así pues, le encontró la gente del Faraón, para que terminase siendo enemigo y motivo de preocupación para ellos. En verdad, el Faraón, Haman y el ejército de ambos se equivocaban.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcclxi{Y la mujer del Faraón dijo: «Será un motivo de alegría para mí y para ti. No le matéis, puede que nos sea útil o que lo adoptemos como hijo.» Pero ellos no eran conscientes.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcclxii{El corazón de la madre de Moisés quedó desolado y a punto habría estado de revelar lo ocurrido si no hubiésemos fortificado su corazón para que fuese de los que tienen fe.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcclxiii{Así pues, dijo a su hija: «¡Síguele!» Y ella le fue siguiendo de lejos y ellos no se dieron cuenta.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcclxiv{Nosotros impedimos antes que aceptase ninguna nodriza. Y ella dijo: «¿Queréis que os muestre una familia que se haga cargo de él para vosotros y lo cuide?»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcclxv{Así le devolvimos a su madre, para que ella se alegrase y no estuviese triste y para que supiese que la promesa de Dios es verdadera. Pero la mayoría de ellos no tienen conocimiento.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcclxvi{Y cuando se hizo mayor y capaz le dimos juicio y sabiduría. Así es como recompensamos a quienes son buenos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcclxvii{Y entró en la ciudad cuando sus gentes estaban distraídas y encontró en ella a dos hombres que se estaban golpeando, uno de su grupo y el otro de sus enemigos. Y el que era de su grupo le pidió ayuda contra el que era de sus enemigos y Moisés le dio un puñetazo y acabó con él. Dijo: «Esto es obra de Satanás. En verdad, él es un enemigo, un extraviador declarado.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcclxviii{Dijo: «¡Dios mío! Verdaderamente, me he oprimido a mí mismo. ¡Perdóname pues!» y Él le perdonó. En verdad, Él es el Perdonador, el Misericordiosísimo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcclxix{Dijo: «¡Señor mío! Por el favor que me has otorgado, nunca más ayudaré a los pecadores.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcclxx{Y amaneció en la ciudad, temeroso, vigilante. Y cuando aquel a quien había ayudado el día anterior le pidió ayuda nuevamente a gritos, Moisés le dijo: «Eres claramente un desviado.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcclxxi{Y cuando quiso separarle de quien era enemigo de ambos, él dijo: «¡Oh, Moisés! ¿Acaso quieres matarme como al que mataste ayer? ¡No quieres más que ser un tirano en la Tierra en lugar de querer mejorarla!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcclxxii{Y de lo más alejado de la ciudad vino un hombre corriendo. Dijo: «¡Oh, Moisés! Los notables están deliberando sobre ti para matarte. Por tanto ¡Sal! En verdad, soy para ti un buen consejero.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcclxxiii{Así pues, salió de ella temeroso, vigilante. Dijo: «¡Señor mío! ¡Sálvame del pueblo opresor!»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcclxxiv{Y cuando se dirigía a Madyan dijo: «¡Quizás mi Señor me dirija por el camino recto.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcclxxv{Y cuando llegó al pozo de Madyan encontró en él a un grupo de gente abrevando a su ganado y encontró a dos mujeres manteniendo al suyo apartado. Él dijo: «¿Qué hacéis?» Ellas dijeron: «No abrevamos a nuestro ganado hasta que los pastores no se vayan, pues nuestro padre es muy anciano.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcclxxvi{Así pues, él abrevó el ganado para ellas y luego se volvió a la sombra y dijo: «¡Señor mío! ¡En verdad, estoy necesitado de cualquier bien que envíes para mí!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcclxxvii{Entonces vino una de las mujeres con pasos recatados. Ella dijo: «En verdad, mi padre te invita para compensarte por haber abrevado nuestro ganado.» Cuando llegó ante él y le relató la historia de lo que le había sucedido, él le dijo: «No temas. Te has salvado de los opresores.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcclxxviii{Una de las dos dijo: «¡Oh, padre mío! ¡Contrátale! En verdad, ¿A quién mejor puedes contratar? Es un hombre fuerte y digno de confianza.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcclxxix{Él dijo: «En verdad, quiero casarte con una de estas dos hijas mías a condición de que trabajes para mí durante ocho años. Y si completas diez años eso dependerá de ti. No quiero forzarte. Me encontrarás, si Dios quiere, de los rectos.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcclxxx{Él dijo: «Esto es entre yo y tú. Así pues, cualquiera de los dos plazos que cumpla no me será reprochado. Y Dios es garante de lo que hemos dicho.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcclxxxi{Y cuando Moisés completo el plazo y partió con su familia, divisó un fuego en las cercanías del monte y dijo a su familia: «¡Esperad! He divisado un fuego. Puede que os traiga de él alguna noticia o una brasa del fuego para que, quizás así, podáis calentaros.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcclxxxii{Y cuando se aproximó a él, fue llamado desde el lugar bendito en el que se encontraba un árbol, en el lado derecho del valle: «¡Oh, Moisés! En verdad, yo soy Dios, Señor del Universo.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcclxxxiii{¡Arroja tu bastón!» Y cuando lo vio reptando como si fuera una serpiente se volvió de espaldas sin mirar atrás. «¡Oh, Moisés! ¡Regresa y no temas! ¡En verdad, estás a salvo!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcclxxxiv{Introduce tu mano en tu costado y saldrá blanca, sin defecto. Pon tu mano sobre tu corazón si sientes temor. Estas son dos pruebas procedentes de tu Señor para el Faraón y sus notables. En verdad, ellos son una gente corruptora.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcclxxxv{Él dijo: «¡Señor mío! En verdad, he matado a uno de ellos y temo que me maten.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcclxxxvi{Y mi hermano Aarón posee una lengua más elocuente. Envíale, pues, conmigo para que me ayude y confirme mis palabras. En verdad, temo que me desmientan.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcclxxxvii{Dijo: «Fortaleceré tu brazo con tu hermano y os daré a ambos tal poder que no podrán tocaros. Con la ayuda de Mis señales, vosotros y quienes os sigan seréis los vencedores.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcclxxxviii{Así pues, cuando Moisés vino a ellos con Nuestras pruebas claras, dijeron: «Esto no es más que magia inventada y no oímos nada de esto a nuestros primeros padres.»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcclxxxix{Y dijo Moisés: «¡Mi Señor es Quien mejor sabe quién vino con la guía de Su parte y quién obtendrá la Morada Final! ¡Los opresores no triunfarán!»\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmccxc{Y el Faraón dijo: «¡Oh, notables! No conozco ningún otro dios para vosotros más que yo.» «¡Oh, Haman! Hazme un fuego sobre el barro y construye para mí una torre alta para que, quizás así, pueda echar un vistazo al dios de Moisés, porque creo que él es un mentiroso.»\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmccxci{Él y su ejército se volvieron altivos en la Tierra sin ningún derecho y creyeron que no regresarían a Nosotros.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmccxcii{Pero les tomamos a él y a su ejército y les arrojamos al mar. Y observa cuál fue el final de los opresores.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmccxciii{Les hicimos dirigentes llamando al Fuego y el Día del Levantamiento no serán auxiliados.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmccxciv{Hicimos que en esta vida les persiguiera una maldición y el Día del Levantamiento estarán entre los poseedores de un horrible rostro.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccxcv{Y, ciertamente, entregamos a Moisés la Escritura después de que destruyéramos a las primeras generaciones, para abrir los ojos a las gentes y como una guía y una misericordia, para que, quizás así, reflexionasen.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmccxcvi{Tú no estuviste en el lado occidental cuando Nosotros dimos la orden a Moisés y no fuiste uno de los testigos,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmccxcvii{pero hicimos surgir otras generaciones y alargamos sus vidas. Tú no residías entre la gente de Madyan para recitarles Nuestros versículos, sino que somos Nosotros quienes enviamos Mensajeros.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccxcviii{Y no estabas en la ladera del monte cuando Nosotros llamamos, pero es una misericordia de tu Señor para amonestar a un pueblo al que no habíamos enviado antes de ti un amonestador, para que así, quizás, reflexionen.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccxcix{Pues, si no, cuando les hubiese afligido una desgracia por lo que sus manos enviaron por delante, habrían dicho: «¡Señor nuestro! ¿Por qué no nos enviaste un Mensajero para que siguiéramos Tus señales y fuésemos de los creyentes?»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccc{Pero cuando llega a ellos la Verdad que viene de Nosotros, dicen: «¿Por qué no se le ha dado lo mismo que le fue dado a Moisés?» ¿Acaso no descreyeron también de lo que le fue dado a Moisés anteriormente? Dicen: «¡Ambos son magia manifiesta!» Y dicen: «¡No creemos en nada de ello!»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccci{Di: «Traed, pues, una Escritura procedente de Dios que guíe mejor que esas dos para que yo la siga, si es que decís la verdad.»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcccii{Pero si no te responden, sabe entonces que lo que siguen son sus pasiones y ¿Quién está más extraviado que quien sigue sus pasiones sin guía de Dios? ¡En verdad, Dios no guía a la gente opresora!\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmccciii{Y, ciertamente, hemos compuesto y relacionado para ellos la Palabra para que, quizás así, reflexionen.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmccciv{Aquellos a quienes Nosotros dimos la Escritura antes de él, creen en él\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcccv{y, cuando se les recita, dicen: Creemos en él. Ciertamente, es la Verdad que proviene de nuestro Señor. Ciertamente, nosotros éramos musulmanes desde antes de él.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcccvi{A ellos se les recompensará dos veces por lo pacientes que fueron. Y ellos se defienden del mal con el bien y reparten de aquello que Nosotros les hemos proveído\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcccvii{y cuando oyen conversaciones vanas se apartan de ellas y dicen: «Nosotros somos responsables de nuestros actos y vosotros de los vuestros. Quedad en paz. No tratamos con los ignorantes.»\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcccviii{En verdad, tú no puedes guiar a quien quieras, sino que Dios guía a quien Él quiere y Él es quien mejor conoce quiénes están guiados.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcccix{Y dicen: «Si seguimos la guía contigo seríamos desposeídos de nuestro territorio.» ¿Acaso no les hemos establecido en un lugar sagrado, seguro, al que llegan toda clase de frutos, como provisión de parte Nuestra? Pero la mayoría de ellos no tienen conocimiento.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcccx{¿Cuántos pueblos hemos destruido que se enorgullecían de su nivel de vida? Esos son sus hogares, los cuales, después de ellos, no están habitados más que por unos pocos y Nosotros fuimos los herederos.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcccxi{Y tu Señor no destruyó las ciudades hasta haber enviado a su metrópoli un Mensajero que les recitara Nuestros versículos y no destruimos ciudad alguna en la que sus gentes no fueran opresoras.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcccxii{Y lo que os ha sido concedido es sólo el disfrute de la vida mundanal y sus encantos, pero lo que hay junto a Dios es mejor y más duradero. ¿Es que no razonáis?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcccxiii{¿Acaso a quien Nosotros hicimos una buena promesa y se encontrará con ella es como aquel a quien Nosotros hemos dado a disfrutar los placeres de esta vida mundanal y luego, el Día del Levantamiento, será de los que tendrán que presentarse?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmcccxiv{Y el día en que Él les llame y diga: «¿Dónde están aquellos que vosotros suponíais que eran Mis socios?»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmcccxv{aquellos que hayan sido sentenciados dirán: «¡Señor nuestro! ¡Estos son a quienes nosotros habíamos extraviado! ¡Les extraviamos de la misma manera en que nosotros estábamos extraviados! Nosotros somos inocentes ante Ti. No era a nosotros a quienes ellos adoraban.»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmcccxvi{Y se les dirá: «¡Invocad a quienes asociabais a Dios en vuestra adoración!» Y les invocarán, pero ellos no les contestarán, y verán el castigo. ¡Ojalá hubieran seguido la buena guía!\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmcccxvii{Y el día en que Él les llame y les diga: «¿Qué respondisteis a los Mensajeros?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmcccxviii{Ese día las noticias estarán ciegas para ellos y no se preguntarán unos a otros.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmcccxix{Pero quien se haya arrepentido y haya tenido fe y realizado buenas acciones puede que esté entre los triunfadores.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmcccxx{Y tu Señor crea lo que quiere y elige, mientras que ellos no tienen elección. ¡Glorificado sea Dios y ensalzado por encima de lo que le asocian!\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmcccxxi{Y tu Señor conoce lo que ocultan sus pechos y lo que manifiestan.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmcccxxii{Y Él es Dios. No hay más dios que Él. A Él pertenece la alabanza en esta vida y en la Otra y a Él pertenece el juicio y a Él se os hará regresar.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmcccxxiii{Di: «¿Habéis visto? Si Dios hiciera la noche perpetua sobre vosotros hasta el Día del Levantamiento ¿Qué dios, aparte de Dios, os traería luz? ¿Acaso no escucháis?»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmcccxxiv{Di: «¿Habéis visto? Si Dios hiciera el día perpetuo sobre vosotros hasta el Día del Levantamiento ¿Qué dios, aparte de Dios, os traería la noche para que descanséis en ella? ¿Es que no veis?»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmcccxxv{Y por Su misericordia, ha puesto para vosotros la noche para que descanséis en ella y el día para que busquéis el favor de Dios y, quizás así, seáis agradecidos.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmcccxxvi{Y el día en que Él les llame y diga: «¿Dónde están aquellos que vosotros suponíais que eran Mis socios?»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmcccxxvii{y hagamos salir un testigo de cada comunidad y digamos: «¡Aportad vuestras prueba!» Sabrán entonces que el derecho pertenece a Dios y se apartará de ellos lo que inventaban.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmcccxxviii{En verdad, Qarun era del pueblo de Moisés, pero se comportó altivamente con ellos. Nosotros le dimos tantos tesoros que las llaves de los mismos resultaban pesadas para un grupo de hombres forzudos. Cuando su pueblo le dijo: «No te vanaglories, pues Dios no ama a quienes se vanaglorian\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmcccxxix{y busca, con lo que Dios te ha otorgado, la Morada de la otra vida y no olvides tu parte de esta vida y haz el bien igual que Dios te ha hecho el bien a ti y no busques corromper en la Tierra. En verdad, Dios no ama a los corruptores.»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmcccxxx{Dijo: «En verdad, se me ha dado todo esto por el conocimiento que poseo.» ¿Acaso no sabía que Dios ha destruido antes de él generaciones que eran más poderosas que él y que habían atesorado más? Los pecadores no serán preguntados por sus pecados.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmcccxxxi{Y salía ante su pueblo con todos sus adornos y aquellos que deseaban la vida mundanal decían: «¡Ojalá nosotros tuviésemos algo semejante a lo que le ha sido dado a Qarun! ¡En verdad, él posee una riqueza inmensa!»\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmcccxxxii{Pero aquellos a quienes les había sido dado el conocimiento dijeron: «¡Ay de vosotros! ¡La recompensa de Dios es mejor para quienes tienen fe y realizan buenas acciones, pero no la obtendrán más que quienes sean pacientes!»\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmcccxxxiii{Hicimos que la tierra se tragase a él y a su casa y no hubo ningún grupo que le auxiliara ante Dios y no pudo ayudarse a sí mismo.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmcccxxxiv{Y quienes ayer deseaban su posición amanecieron diciendo: «¡Ay! ¡Dios expande y restringe la provisión a quien Él quiere de sus siervos! ¡Si Dios no nos hubiese agraciado, nos habría tragado a nosotros!» ¡Ay! ¡Quienes no son creyentes no triunfarán!\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmcccxxxv{Esa es la morada de la otra vida que Nosotros otorgamos a quienes no desean mostrarse altaneros en la Tierra ni corromper. El buen final es para quienes son temerosos de Dios.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmcccxxxvi{Quien venga con buenas obras obtendrá algo mejor que ellas y quien venga con malas acciones sólo será retribuido por el mal que hacía.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmcccxxxvii{En verdad, Quien ha hecho para ti obligatorio el Corán te hará volver al lugar de retorno. Di: «Mi Señor es Quien mejor sabe quién sigue la buena guía y quién está en un extravío evidente.»\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmcccxxxviii{Tú no esperabas que te fuese entregada la Escritura. No fue sino una misericordia procedente de tu Señor. No respaldes, pues, a quienes no tienen fe\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmcccxxxix{y no les permitas que te aparten de las señales de Dios después de que han sido hechas descender para ti. Convoca a las gentes hacia tu Señor y no seas de los que adoran a otros como si fueran Dios.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmcccxl{Y no invoques junto a Dios a otros dioses. No hay otro dios más que Él. Todas las cosas perecen excepto Su rostro. Al Él pertenece el juicio y hacía Él se os hará regresar.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmcccxli{\basmalahes Alif, Lam, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcccxlii{¿Acaso las gentes piensan que se les permitirá decir «¡Creemos!» y no serán puestos a prueba?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcccxliii{Ciertamente, Nosotros pusimos a prueba a quienes les precedieron y Dios conoce a quienes dicen la verdad y conoce a los mentirosos.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcccxliv{¿Acaso quienes hacen el mal piensan que podrán escapar de Nosotros? ¡Qué mal juzgan!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcccxlv{Quien tenga la esperanza de encontrarse con Dios [sepa] que, en verdad, la cita con Dios llegará y Él es Quien todo lo oye, Quien todo lo conoce.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcccxlvi{Y quien combate por Dios, en verdad, combate por sí mismo. En verdad, Dios no necesita de las criaturas.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcccxlvii{Y a quienes son creyentes y realizan buenas obras les ocultaremos sus malas acciones y les recompensaremos conforme a lo mejor que hayan hecho.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcccxlviii{Y hemos ordenado a los seres humanos que sean buenos con sus padres. Pero si ellos se esfuerzan para que asocies en tu adoración a Mí algo de lo que tú no tienes conocimiento, entonces no les obedezcas. Regresaréis a Mí y Yo os informaré de lo que hacíais.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcccxlix{Y a quienes tengan fe y realicen buenas obras les haremos entrar entre los Rectos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcccl{Y entre los hombres hay quienes dicen: «¡Creemos en Dios!» pero cuando sufren perjuicio por la causa de Dios toman la prueba a que los hombres les someten como un castigo de Dios. En cambio, si viene una ayuda de tu Señor, con seguridad dirán: «¡En verdad, estábamos con vosotros!» ¿Acaso no es Dios Quien mejor conoce lo que hay en el pecho de las criaturas?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcccli{Y Dios conoce con certeza quienes son los que creen y conoce con certeza quienes son los hipócritas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmccclii{Y los que no creen dicen a los que tienen fe: «¡Seguid nuestro camino y nosotros cargaremos con vuestros errores!» Pero ellos no cargarán con sus errores en absoluto. En verdad, son unos mentirosos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcccliii{Y, ciertamente, tendrán que cargar sus propias cargas y otras cargas junto con sus propias cargas. Y el Día del Levantamiento serán interrogados sobre lo que inventaban.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcccliv{Ciertamente, Nosotros enviamos a Noé a su pueblo y permaneció entre ellos mil años menos cincuenta. Después, el diluvio les sorprendió siendo unos opresores.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmccclv{Y le salvamos a él y a los compañeros del Arca e hicimos de ella una señal para toda la humanidad.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmccclvi{Y [recuerda] a Abraham cuando dijo a su pueblo: «¡Adorad a Dios y temedle! Eso es mejor para vosotros, si es que sabéis.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmccclvii{En verdad, lo que adoráis en lugar de Dios son ídolos y creáis una mentira. Lo que adoráis en lugar de Dios no posee provisión. Buscad, pues, vuestra provisión junto a Dios, adoradle y agradecedle. Hacía Él se os hará regresar.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmccclviii{Y si desmentís, ya desmintieron otras generaciones antes de vosotros, pero la responsabilidad del Mensajero es solamente la transmisión clara.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmccclix{¿Es que no ven cómo Dios inicia la creación y luego la reproduce? En verdad, eso es fácil para Dios.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmccclx{Di: «¡Viajad por la Tierra y observad cómo Él ha originado la creación! Luego, Dios hará surgir la creación de la otra vida. En verdad, Dios tiene poder sobre todas las cosas.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmccclxi{«Castigará a quien Él quiera y tendrá misericordia de quien Él quiera. Y a Él se os hará regresar.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmccclxii{«Y no podréis escapar ni en la Tierra ni en el cielo y no tendréis, aparte de Dios, protector ni auxiliador.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmccclxiii{Y aquellos que no creen en las señales de Dios y en el encuentro con Él han desesperado de Mi misericordia y tendrán un castigo doloroso.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmccclxiv{Y la respuesta de su pueblo no fue otra que decir: «¡Matadle!» o «¡Quemadle!» y Dios le salvó del fuego. En verdad, en ello hay una señal para gente que tiene fe.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmccclxv{[Abraham] dijo: «En verdad, lo que tomáis en lugar de Dios son ídolos, para establecer lazos de afecto entre vosotros en la vida mundanal. Luego, el Día del Levantamiento, renegaréis unos de otros y os maldeciréis unos a otros. Vuestra morada será el fuego y no tendréis quien os auxilie.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmccclxvi{Lot creyó en él y dijo: «En verdad, soy un emigrante hacia mi Señor. En verdad, Él es el Poderoso, el Sabio.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmccclxvii{Y le otorgamos a Isaac y a Jacob y pusimos en su descendencia la profecía y la Escritura Sagrada y le dimos su recompensa en esta vida y, en verdad, en la otra será de los Rectos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmccclxviii{Y [recuerda] a Lot cuando dijo a su pueblo: «En verdad, cometéis una indecencia que ningún ser humano había cometido antes de vosotros.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmccclxix{¿Vais a los hombres, cortáis los caminos y cometéis lo reprobable en vuestras reuniones?» Pero la única respuesta de su pueblo fue decir: «¡Tráenos el castigo de Dios si eres de los que dicen la verdad!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmccclxx{Él dijo: «¡Señor mío! ¡Auxíliame contra el pueblo de los corruptores!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmccclxxi{Y cuando vinieron Nuestros mensajeros a Abraham con la buena nueva, dijeron: «En verdad, destruiremos a la gente de esta ciudad. Verdaderamente, sus gentes son opresoras.»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmccclxxii{Él dijo: «Lot también está en ella.» Ellos dijeron: «Nosotros sabemos bien quienes están en ella. Le salvaremos a él y a su familia, excepto a su esposa, que será de los que se queden.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmccclxxiii{Y cuando Nuestros Mensajeros vinieron a Lot, él se preocupó por ellos y se angustió su corazón, pero ellos dijeron: «No tengas miedo y no estés preocupado. En verdad, os salvaremos a ti y a tu familia, excepto a tu esposa que será de los que se queden.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmccclxxiv{Haremos descender un castigo del cielo sobre la gente de esa ciudad porque son transgresores.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmccclxxv{Ciertamente, hemos dejado con ella una señal clara para una gente que razona.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmccclxxvi{Y [enviamos] a Madyan a su hermano Shuayb que les dijo: «¡Oh, pueblo mío! ¡Adorad a Dios y tened esperanza en el Último Día y no corrompáis en la Tierra!»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmccclxxvii{Pero le desmintieron y el terremoto les sorprendió y amanecieron muertos, caídos de bruces en sus casas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmccclxxviii{Y a Ad y a Zamud. Y es evidente para vosotros por sus moradas. Satanás les embelleció sus acciones y les apartó del camino, a pesar de que ellos eran perspicaces.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmccclxxix{Y Qarun y Faraón y Haman. Y, ciertamente, Moisés vino a ellos con las pruebas claras, pero ellos obraron con arrogancia en la Tierra y no triunfarán.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmccclxxx{Así pues, tomamos a cada uno de ellos por sus pecados. A algunos de ellos Nosotros les enviamos una tormenta huracanada de piedras, a otros les sorprendió el Grito, a otros hicimos que se los tragase la tierra y a otros les ahogamos. Y no fue Dios quien les oprimió, ellos se oprimieron a sí mismos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmccclxxxi{Si ellos supieran que el ejemplo de quienes toman otros amigos y protectores en lugar de Dios es como la araña que se hace una casa. En verdad, la más débil de las casas es la casa de la araña. Si ellos supieran…\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmccclxxxii{En verdad, Dios conoce lo que ellos invocan en lugar de Él. Él es el Poderoso, el Sabio.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccclxxxiii{Y Nosotros ponemos estos ejemplos a las gentes, pero sólo los comprenden en profundidad las gentes de conocimiento.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmccclxxxiv{Dios ha creado los cielos y la Tierra con la Verdad. En verdad, en ello hay una señal para los creyentes.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmccclxxxv{Recita lo que te ha sido revelado de la Escritura y haz la oración. En verdad, la oración protege del pecado y de la equivocación y el recuerdo de Dios es más grande. Y Dios sabe lo que hacéis.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccclxxxvi{Y no discutáis con la gente de la Escritura sino de la mejor manera -excepto con aquellos que son opresores- y dicen: «Creemos en lo que fue hecho descender a nosotros y en lo que fue hecho descender a vosotros y nuestro dios y el vuestro es uno y nosotros estamos sometidos a Él.»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccclxxxvii{Y, de la misma manera, hemos hecho descender a ti la Escritura. Y aquellos a quienes hemos dado la Escritura creen en ella y de estos algunos creen en ella. Y nadie combate Nuestras señales excepto quienes no son creyentes.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccclxxxviii{Y tú no recitabas ninguna Escritura antes de ésta ni la escribías con tu mano derecha, si no, los que falsean la Verdad habrían sembrado dudas.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccclxxxix{Pero son señales claras en el pecho de aquellos a quienes les ha sido dado el conocimiento. Y no luchan contra Nuestras señales más que los opresores.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcccxc{Y ellos dicen: «¿Por qué no se han hecho descender para él señales procedentes de su Señor?» Di: «En verdad, las señales están junto a Dios y, en verdad, yo sólo soy un claro amonestador.»\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmcccxci{¿Acaso no es suficiente para ellos el que Nosotros hagamos descender a ti la Escritura que les es recitada? En verdad, en ello hay una misericordia y un recuerdo para gente que es creyente.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmcccxcii{Di: «Es suficiente con Dios de testigo entre yo y vosotros. Él conoce lo que hay en los cielos y en la Tierra. Y quienes creen en la falsedad y no creen en Dios son los perdedores.»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcccxciii{Y te piden que apresures su castigo. Si no fuera porque existe un plazo establecido, les habría llegado el castigo. Con seguridad, les llegará repentinamente, sin que se den cuenta.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcccxciv{Te piden que les apresures el castigo y, en verdad, el Infierno rodeará a los que no son creyentes\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcccxcv{el día en que el castigo les cubra por encima y por debajo y Él diga: «¡Probad lo que hacíais!»\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcccxcvi{«¡Oh, siervos Míos creyentes! ¡Mi Tierra es amplia, por tanto, adoradme sólo a Mí!»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcccxcvii{Todo ser probará la muerte. Luego se os hará regresar a Nosotros.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcccxcviii{Y a aquellos que hayan creído y realizado buenas acciones les alojaremos en el Jardín en aposentos elevados bajo los cuales fluyen los ríos, en donde estarán eternamente. ¡Qué buena la recompensa de quienes obran bien!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcccxcix{¡Esos que son pacientes y confían en su Señor!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcd{¡Cuántos animales hay que no cargan con su sustento! ¡Dios proporciona su sustento y el vuestro! Y Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcdi{Y si les preguntas: «¿Quién ha creado los cielos y la Tierra y ha sometido al Sol y a la Luna?» seguro que dirán: «¡Dios!» Entonces ¿Por qué mienten?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmcdii{Dios otorga con largueza Su provisión a quien Él quiere de Sus siervos y la restringe a quien Él quiere. Ciertamente, Dios es Quien mejor conoce todas las cosas.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmcdiii{Y si les preguntas: «¿Quién hace descender agua del cielo y da vida con ella a la tierra después de haber estado muerta?» Seguro que dirán: «¡Dios!» Di: «¡Alabado sea Dios!» Pero la mayoría de ellos no razonan.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmcdiv{Y la vida de este mundo no es más que distracción y juego y, en verdad, la morada de la otra vida es verdaderamente la Vida. ¡Si supieran!\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmcdv{Y cuando suben al barco invocan a Dios poniendo su fe en Él exclusivamente, pero cuando les deja a salvo en tierra adoran a los ídolos.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmcdvi{¡Que rechacen lo que Nosotros les hemos dado y que disfruten! ¡Pronto sabrán!\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmcdvii{¿Acaso no ven que hemos establecido un santuario seguro mientras alrededor de ellos la gente es despojada? ¿Acaso tienen fe en la falsedad y descreen de la merced de Dios?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmcdviii{¿Quién es más opresor que quien inventa una mentira sobre Dios o desmiente la Verdad cuando viene a él? ¿No está en el Infierno la morada de los que niegan la Verdad?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmcdix{Y a quienes se esfuerzan por Nosotros, ciertamente, les guiaremos a Nuestros caminos. En verdad, Dios está con quienes hacen el bien.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmcdx{\basmalahes Alif, Lam, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcdxi{Los bizantinos han sido vencidos\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcdxii{en la tierra más próxima. Pero, tras haber sido vencidos, ellos vencerán\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcdxiii{dentro de pocos años. A Dios pertenecen los asuntos pasados y futuros. Y ese día, los creyentes se alegrarán\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcdxiv{por el auxilio de Dios. Él auxilia a quien quiere y Él es el Poderoso, el Misericordiosísimo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcdxv{Promesa de Dios. Dios no falta a Su promesa, pero la mayoría de las personas no saben.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcdxvi{Conocen lo aparente de la vida de este mundo y no prestan atención a la Otra Vida.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcdxvii{¿Acaso no reflexionan en su interior que Dios no ha creado los cielos y la Tierra y lo que hay entre ambos sino con la Verdad y por un plazo determinado? Pero lo cierto es que mucha gente no cree en el encuentro con su Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcdxviii{¿Acaso no viajan por la Tierra y observan como terminaron quienes les precedieron? Eran mucho más fuertes que ellos, levantaron la tierra y la desarrollaron mucho más de lo que ellos la han desarrollado y vinieron a ellos sus Mensajeros con las señales claras. Y Dios no les oprimía, sino que ellos mismos se oprimían.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcdxix{Luego, el final de quienes hicieron el mal fue desmentir las señales de Dios y burlarse de ellas.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcdxx{Dios inicia la creación, luego la recrea y luego se os hace regresar a Él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcdxxi{Y el día en que tenga lugar la Hora, los pecadores se desesperarán\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcdxxii{y no habrá quien de sus socios interceda por ellos y ellos renegarán de sus socios.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcdxxiii{Y el día en que tenga lugar la Hora, ese día se separarán unos de otros.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcdxxiv{Y quienes hayan sido creyentes y hayan realizado buenas obras estarán en un vergel disfrutando.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcdxxv{Pero quienes no hayan sido creyentes y hayan desmentido Nuestras señales y el encuentro de la Otra Vida serán enviados al castigo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcdxxvi{Glorificado sea Dios al anochecer y al amanecer.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcdxxvii{Y a Él pertenece la alabanza en los cielos y la Tierra y en la noche y al mediodía.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcdxxviii{Él hace salir lo vivo de lo muerto y hace salir lo muerto de lo vivo y da vida a la tierra después de haber estado muerta y de esa misma manera se os hará salir a vosotros.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcdxxix{Y entre Sus señales está el haberos creado de tierra. Y luego, cuando devenís seres humanos, os expandís [por la Tierra.]\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcdxxx{Y entre Sus señales está el haber creado de vosotros mismos parejas para que encontréis la calma junto a ellas. Y ha puesto entre vosotros afecto y misericordia. En verdad, en ello hay señales para gente que reflexiona.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcdxxxi{Y entre Sus señales está la creación de los cielos y la Tierra y las diferencias de lengua y de color entre vosotros. En verdad, en ello hay señales para gente que conoce.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcdxxxii{Y entre Sus señales está vuestro sueño en la noche y en el día, y vuestra búsqueda de Su favor. En verdad, en ello hay señales para gente que escucha.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcdxxxiii{Y entre Sus señales está el que os muestre el relámpago, motivo de temor y de esperanza, y el hacer descender del cielo agua con la que da vida a la tierra después de haber estado muerta. En verdad, en ello hay señales para gente que razona.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcdxxxiv{Y entre Sus señales está el que los cielos y la Tierra se mantengan en pie por orden Suya. Luego, cuando os llame para que salgáis de la tierra, saldréis inmediatamente.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcdxxxv{Y a Él pertenecen quienes están en los cielos y en la Tierra. Todos están sometidos a Él.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcdxxxvi{Y Él es Quién ha iniciado la creación, luego la recrea. Y eso es más sencillo para Él. Y a Él pertenecen las más elevadas descripciones en los cielos y en la Tierra. Y Él es el Poderoso, el Sabio.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcdxxxvii{Él os pone un ejemplo que tiene que ver con vosotros mismos: «¿Hay entre vuestros siervos quienes compartan con vosotros las riquezas que Nosotros os hemos proporcionado y seáis iguales a ellos en eso y les temáis igual que os teméis entre vosotros?» Así explicamos en detalle las señales para gente que razona.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcdxxxviii{Pero los opresores siguen sus propias pasiones sin conocimiento alguno. Así pues ¿Quién puede guiar a quien Dios extravía? Y ellos no tendrán quien les auxilie.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcdxxxix{Levanta, pues, tu rostro hacia la religión, como un buscador de la fe pura, siguiendo la naturaleza esencial en la que Dios ha creado a los seres humanos—En la creación de Dios no hay cambios. Esta es la verdadera religión pero la mayoría de las personas no tienen conocimiento—\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcdxl{volviéndoos a Él contritos. Y sed temerosos de Dios y haced la oración y no seáis de los idólatras.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcdxli{De esos que escinden su religión haciendo partidos, cada partido contento de lo que posee.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcdxlii{Y cuando a los seres humanos les sobreviene un percance, invocan a su Señor volviéndose a Él contritos. Luego, cuando Él les da a probar de Su misericordia, algunos de ellos asocian otros dioses a su Señor,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcdxliii{ocultando lo que les hemos dado. ¡Disfrutad pues! ¡Pronto sabréis!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcdxliv{¿Acaso hemos hecho descender para ellos alguna prueba que justifique lo que asocian a Él?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcdxlv{Y cuando hacemos que los seres humanos prueben una misericordia se alegran de ella y si sufren un perjuicio por culpa de lo que ellos mismos hicieron, entonces, se desesperan.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcdxlvi{¿Acaso no ven que Dios otorga la provisión en abundancia o la restringe a quien Él quiere? En verdad, en ello hay señales para gente que tiene fe.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmcdxlvii{Así pues, da a los parientes cercanos su derecho y al necesitado y al viajero. Eso es mejor para quienes desean contemplar el rostro de Dios. Y esos son quienes triunfarán.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmcdxlviii{Y lo que dais con usura, para obtener beneficios de los bienes de la gente, no obtendrá beneficios ante Dios, pero la limosna purificadora de la riqueza que dais buscando agradar a Dios, eso os será multiplicado.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmcdxlix{Dios es quien os ha creado, luego os ha proporcionado los medios de subsistencia, luego os hace morir, luego os da la vida. ¿Hay entre aquellos que vosotros asociáis a Dios alguno que pueda hacer algo de eso? ¡Glorificado y ensalzado sea por encima de aquello que le asocian!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmcdl{La corrupción se ha manifestado en la tierra y el mar por lo que los seres humanos han hecho, para que prueben algo de lo que han hecho y así, quizás, regresen al buen camino.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmcdli{Di: «Id por la Tierra y observad cuál fue el final de los que vivieron antes. La mayoría de ellos eran idólatras.»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmcdlii{Así pues, levanta tu rostro hacia la religión viva antes de que llegue un día en el que nadie podrá retroceder ante Dios. Ese día [los seres humanos] serán divididos\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmcdliii{-Quien haya ocultado la verdad sufrirá las consecuencias de ello y quienes hayan obrado rectamente se habrán preparado para ellos mismos un lugar en el que descansar-\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmcdliv{para que Él recompense con Su favor a quienes hayan creído y obrado rectamente. En verdad, el no ama a quienes ocultan la verdad.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmcdlv{Y entre Sus señales está el enviar los vientos como portadores de buenas noticias y el hacer que probéis de Su misericordia y el que los barcos naveguen a una orden Suya y el que bus seáis agradecidos.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmcdlvi{Y, ciertamente, antes de ti ya habíamos enviado Mensajeros a sus pueblos que llegaron a ellos con las pruebas claras y Nos vengamos de quienes habían cometido malas acciones. Y es una obligación para Nosotros auxiliar a los creyentes.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmcdlvii{Es Dios quien envía los vientos que hacen surgir las nubes que Él dispersa por el cielo como quiere. Y las fragmenta y puedes ver como el aguacero sale de su interior. Y cuando favorece con ella a quien Él quiere de Sus siervos, ellos se regocijan y se transmiten unos a otros la buena nueva,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmcdlviii{pues antes de que descendiera sobre ellos estaban desesperados.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcdlix{Observa, pues, los efectos de la misericordia de tu Señor. Cómo hace vivir la tierra después de haber estado muerta. En verdad, eso es ser el Revivificador de lo muerto. Y Él tiene poder sobre todas las cosas.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmcdlx{Pero si enviamos un viento y ven que todo lo [vuelve] amarillo, regresan de nuevo a su falta de fe.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmcdlxi{Pues, en verdad, tú no puedes hacer oír al muerto ni hacer que el sordo oiga la llamada si se da la vuelta.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcdlxii{Y tú no puedes guiar al ciego de su extravío. Y, en verdad, no puedes hacer que oiga más que quien crea en Nuestras señales, pues ellos se han sometido, son musulmanes.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcdlxiii{Dios, Quien os ha creado débiles y después de esa debilidad os hace fuertes. Después de fuertes os hace débiles y ancianos. Él crea lo que quiere. Y Él es Quien todo lo sabe, el Poderoso.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcdlxiv{Y el día en que llegue la Hora, los que hayan hecho el mal jurarán que no han permanecido más de una hora. Así mismo mentían.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcdlxv{Y aquellos a quienes les fue dado el conocimiento y la fe dirán: «Permanecisteis hasta el Día de la Resurrección según está en la Escritura de Dios y éste es el Día de la Resurrección, pero vosotros no sabíais.»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcdlxvi{Pero ese día no les servirán sus excusas a quienes fueron opresores, ni se les evitará la condena.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcdlxvii{Y, ciertamente, pusimos a los hombres todo tipo de ejemplos en este Corán. Y si vas a ellos con una señal, quienes no son creyentes seguro que dirán: «Vosotros no sois más que falsarios.»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcdlxviii{Así es como Dios sella el corazón de los que no saben.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcdlxix{Pero se paciente. En verdad, la promesa de Dios es verdadera. Que no te encuentren débil quienes no tienen certeza.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcdlxx{\basmalahes Alif, Lam, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcdlxxi{Estos son los versículos de la Escritura Sabia.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcdlxxii{Guía y misericordia para quienes son buenos.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcdlxxiii{Aquellos que hacen la oración, dan el impuesto purificador de su riqueza y creen en la otra vida.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcdlxxiv{Esos están en la guía que procede de su Señor y serán los triunfadores.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcdlxxv{Y entre la gente hay quien compra historias vanas para extraviar, sin conocimiento, del camino de Dios, tomándolo a broma. Esos tendrán un castigo humillante.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcdlxxvi{Y cuando le son recitados Nuestros versículos se da la vuelta altivo como si no los hubiera oído, como si fuera duro de oído. ¡Anúnciale un castigo doloroso!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcdlxxvii{En verdad, quienes son creyentes y obran rectamente obtendrán los Jardines del Edén.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcdlxxviii{Estarán eternamente en ellos. La promesa de Dios es cierta. Y Él es el Poderoso, el Sabio.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcdlxxix{Ha creado los cielos sin columnas que puedas ver y ha colocado en la Tierra firmes montañas para que no tiemble con vosotros y ha hecho surgir en ella toda clase de animales. Y hacemos descender de los cielos agua con la que hacemos surgir un noble par de todo tipo de plantas.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcdlxxx{Esta es la creación de Dios, así pues ¡Hacedme ver lo que han creado otros aparte de Él! ¡Los opresores se encuentran en un extravío evidente!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcdlxxxi{Y, ciertamente, dimos a Luqman la sabiduría [y le dijimos]: “¡Da gracias a Dios!” Quien agradece, agradece en beneficio propio. Y quien no agradece, (sepa que) en verdad, Dios no necesita de Sus criaturas, es rico en Sí mismo, digno de ser alabado.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcdlxxxii{Y (recuerda) cuando Luqman le dijo a su hijo, aconsejándole: «¡Oh, hijito mío! No adores nada junto a Dios. En verdad, el politeísmo es una opresión inmensa.»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcdlxxxiii{Y encomendamos al ser humano con respecto a sus padres - Su madre le llevó, soportando debilidad sobre debilidad, terminando su lactancia a los dos años-: «¡Se agradecido conmigo y con tus padres! ¡A Mí regresáis!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcdlxxxiv{Y si se esfuerzan para que tú adores junto a Mí algo de lo que tú no tienes conocimiento, no les obedezcas. Trátales en este mundo con bondad, pero sigue el camino de quien se vuelve a Mí contrito. Luego, regresaréis a Mí y Yo os informaré de lo que hacíais.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcdlxxxv{«¡Oh, hijito mío! Aunque tus actos tengan el peso de un grano de mostaza y estén bajo una piedra o en los cielos o en la Tierra, Dios los traerá. En verdad, Dios es sutil, está bien informado.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcdlxxxvi{«¡Oh, hijito mío! ¡Haz la oración y ordena lo que es bueno, prohíbe lo que es malo y se paciente cuando sufras una desgracia! En verdad, esto es una de las cuestiones que exigen mayor entereza y decisión.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcdlxxxvii{«No gires tu rostro ante la gente con altivez y no camines por la Tierra con arrogancia. En verdad, Dios no ama a quien es vanidoso y engreído.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcdlxxxviii{«Y se modesto en tu caminar y habla poco y con tono suave. En verdad, la más insoportable de las voces es el rebuzno del asno.»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcdlxxxix{¿No veis cómo Dios ha sometido para vosotros lo que hay en los cielos y en la Tierra y os ha colmado con Sus favores, tanto internos como externos? Y entre los hombres hay quienes discuten sobre Dios sin conocimiento ni guía ni Escritura luminosa.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcdxc{Y si se les dice: «Seguid lo que Dios hizo descender» dicen: «¡No! Seguiremos aquello mismo en lo que encontramos a nuestros padres.» ¿Y si Satanás les estuviese llamando al castigo del Fuego llameante?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcdxci{Y quien rinde su rostro ante Dios y es bueno, se habrá aferrado al asidero más firme. Y en Dios concluyen los asuntos.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcdxcii{¡Qué no te entristezca la falta de fe de aquellos que no creen! Ellos regresarán a Nosotros y les informaremos de lo que hicieron. En verdad, Dios conoce bien lo que hay en la esencia de los pechos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcdxciii{Les dejaremos disfrutar un poco y luego les arrastraremos a un castigo durísimo.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcdxciv{Y si les preguntas «¿Quién ha creado los cielos y la Tierra?» Seguro que dicen: «¡Dios!» Di: «¡Alabado sea Dios!» Pero la mayoría de ellos no saben.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcdxcv{A Dios pertenece lo que hay en los cielos y la Tierra. En verdad, Dios es el Rico por sí mismo, el Digno de alabanza.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcdxcvi{Si todos los árboles que hay en la Tierra fuesen plumas y se añadiese al mar otros siete mares más, no agotarían las palabras de Dios. En verdad, Dios es todopoderoso, sabio.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcdxcvii{Vuestra creación y resurrección no es sino como la creación de un solo ser. En verdad, Dios todo lo oye, todo lo ve.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcdxcviii{¿No has visto cómo hace Dios que la noche entre en el día y el día entre en la noche y ha sometido al Sol y a la Luna, haciendo que cada uno de ellos se mueva hacia un plazo establecido, y que Dios está bien informado de lo que hacéis?\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcdxcix{Eso es porque Dios es la Verdad y porque lo que ellos invocan en lugar de Él es falso y porque Dios es el Excelso, el Grande.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmd{¿No has visto como el barco surca el mar por el favor de Dios, para haceros ver una de Sus señales? En verdad, en ello hay señales para todo el que es paciente, agradecido.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdi{Y cuando les cubre una ola como una nube sombría, invocan a Dios, creyendo únicamente en Él. Pero cuando les pone a salvo en tierra, unos pocos de ellos permanecen firmes en su propósito. Y no niega Mis señales excepto quien es un mentiroso redomado y un encubridor de la realidad.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdii{¡Oh, gentes! Sed temerosos de vuestro Señor y tened miedo de un día en el que un padre no pueda expiar las faltas de su hijo, ni un hijo pueda expiar las faltas de su padre en absoluto. En verdad, la promesa de Dios es cierta. Por tanto, que la vida mundanal no os vuelva soberbios y que el Soberbio no os haga soberbios frente a Dios.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdiii{En verdad, Dios posee el conocimiento de la Hora. Él hace descender la lluvia y conoce lo que hay en el seno materno. Y ningún ser sabe lo que obtendrá mañana y nadie sabe en qué tierra ha de morir. En verdad, Dios todo lo sabe, está bien informado.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdiv{\basmalahes Alif, Lam, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdv{El descenso de la Escritura en la que no hay duda procede del Señor del Universo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdvi{Ellos dicen: «¡Él lo ha inventado!» Pero él es la Verdad que procede de tu Señor para amonestar a un pueblo al que no ha venido un amonestador antes de ti, para que así, quizás, se guíen.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdvii{Dios, el Cual creó los cielos y la Tierra y lo que hay entre ambos en seis días y luego se instaló en el Trono. Aparte de Él no tenéis protector ni intercesor. ¿Es que no reflexionaréis?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdviii{Él dirige todos los asuntos, desde los cielos hasta la Tierra. Luego, ascienden a Él en un día que dura mil años de los que vosotros contáis.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdix{Es el Conocedor de lo oculto y lo manifiesto, el Todopoderoso, el Misericordiosísimo con los creyentes.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdx{Quien ha hecho perfecto todo lo que ha creado y Quien creó inicialmente a los seres humanos de barro.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdxi{Luego, puso su descendencia en la esencia que se extrae de una gota de líquido insignificante.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdxii{Luego le dio forma e insufló en él parte de Su Espíritu y puso para vosotros el oído y la vista y el corazón. ¡Poco es lo que agradecéis!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdxiii{Y ellos dicen: «¿Acaso cuando nos hayamos perdido, confundidos con la tierra, seremos creados de nuevo?» Ellos no creen en el encuentro con su Señor.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdxiv{Di: «El ángel de la muerte, al cual habréis sido confiados, tomará vuestras almas y luego se os hará regresar a vuestro Señor.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdxv{Y si vieras cuando los pecadores inclinen sus cabezas ante su Señor: «¡Señor nuestro! ¡Hemos visto y hemos oído! ¡Haznos, pues, regresar y obraremos con rectitud! ¡En verdad, (ahora) tenemos certeza!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdxvi{Si hubiésemos querido habríamos dado a cada ser su guía, pero se cumplirá Mi promesa: «¡He de llenar el Infierno con los genios y los hombres!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdxvii{«¡Gustad [el castigo] por haber olvidado el encuentro de este vuestro día! ¡En verdad, Nosotros también nos olvidamos de vosotros! ¡Gustad el castigo eterno por lo que hacíais!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdxviii{En verdad, creen en Nuestras señales quienes, cuando se les recuerdan, caen prosternados y glorifican con alabanzas a su Señor y no se muestran arrogantes.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdxix{Sus costados abandonan los lechos para invocar a su Señor con temor y esperanza y de lo que Nosotros les hemos provisto reparten.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdxx{Nadie sabe la alegría que ha sido reservada para aquellos en recompensa por lo que hacían.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdxxi{¿Acaso quien es creyente es igual a quien es transgresor? ¡No son iguales!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdxxii{Quienes son creyentes y actúan rectamente obtendrán los Jardines de la Morada, como regalo por lo que hacían.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdxxiii{Pero quienes transgreden tendrán de morada el Fuego. Siempre que quieran salir de él regresarán a él y se les dirá: «¡Gustad el castigo del Fuego! ¡Ese que solíais desmentir!»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdxxiv{Y les haremos gustar algo del pequeño castigo, no del gran castigo. Quizás así regresen.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdxxv{Y ¿Quién es más opresor que cuando le son recordados los versículos de su Señor se aparta de ellos? En verdad, tomaremos venganza de los ofensores criminales.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdxxvi{Y, ciertamente, hicimos entrega a Moisés de la Escritura -así pues, no seas escéptico respecto al encuentro con Él- y la pusimos como guia para los Hijos de Israel\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdxxvii{Y, de entre ellos, pusimos dirigentes espirituales que les guiasen conforme a Mi mandato, pues eran pacientes y tenían certeza de Nuestras señales.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdxxviii{En verdad, tu Señor es Quien juzgará entre ellos el Día del Levantamiento sobre aquello en lo que mantenían diferencias.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdxxix{¿Acaso no les ha quedado claro cuántas generaciones antes de ellos hemos destruído, sobre cuyas casas ellos caminan ahora? En verdad, en ello hay indicaciones. ¿Es que no oyen?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdxxx{¿Acaso no ven que Nosotros suministramos el agua a la tierra seca y árida y hacemos salir con ella cosechas de las que comen sus ganados y ellos mismos? ¿Es que no observan?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdxxxi{Y dicen: «¿Cuándo será esa victoria, si decís la verdad?»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdxxxii{Dí: «El día de la victoria no le será de utilidad la fe a quienes no la tenían y ellos no serán tenidos en cuenta.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdxxxiii{Así pues, ¡Apártate de ellos y espera! ¡En verdad, ellos también están a la espera!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdxxxiv{\basmalahes ¡Oh, profeta! Se temeroso de Dios y no obedezcas a los que no son creyentes ni a los hipócritas. En verdad, Dios todo lo sabe, es sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdxxxv{Y sigue lo que te fue revelado procedente de tu Señor. En verdad, Dios está bien informado de lo que hacéis.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdxxxvi{Y confía en Dios. Dios es suficiente para proteger.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdxxxvii{Dios no ha puesto dos corazones en el interior de ningún hombre ni convierte a la mujer que repudia en su madre, ni hace que vuestros hijos adoptados sean vuestros propios hijos. Eso son cosas que decís con vuestras bocas, pero Dios dice la Verdad y es Quien guía al camino.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdxxxviii{Llamadles por el nombre de su padre. Eso es más equitativo ante Dios. Y si no conocéis el nombre de su padre, entonces, son hermanos vuestros en la fe y vuestros protegidos. No cometéis pecado si os equivocáis en ello, sino en lo que premeditan vuestros corazones. Pero Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdxxxix{El Profeta posee mayores derechos sobre los creyentes que ellos mismos y sus esposas son sus madres. Los familiares consanguíneos tienen preferencia, unos más que otros, en la Escritura de Dios respecto a los creyentes y a los emigrantes, excepto en el bien que podáis hacer a vuestros compañeros. Esto está recogido en la Escritura.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdxl{Y [recuerda] cuando tomamos de los profetas un juramento, de ellos y de ti, de Noé, de Abraham, de Moisés y de Jesús hijo de María. Y hemos tomado de ellos un grave juramento\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdxli{para que Él pregunte a los sinceros por su sinceridad y castigue a los que no creen con un castigo doloroso.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdxlii{¡Oh, los que sois creyentes! Recordad el favor que Dios os hizo cuando venía a vosotros un ejército y Él envió contra ellos un viento y un ejército que vosotros no veíais. Pero Dios observa cuanto hacéis.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdxliii{Cuando vinieron contra vosotros desde arriba y desde abajo y los ojos se desorbitaban de temor y los corazones se subían a la garganta y comenzasteis a especular y a dudar de Dios.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdxliv{De esa manera fueron puestos a prueba los creyentes y temblaron fuertemente conmocionados.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdxlv{Y cuando dijeron los hipócritas y aquellos cuyos corazones estaban enfermos: «No nos ha prometido Dios nada más que engaños.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdxlvi{Y cuando un grupo de ellos dijo: «¡Oh, gente de Yatrib! ¡No tenéis donde estableceros! ¡Regresad!» Un grupo de ellos pidió permiso al Profeta diciendo: «En verdad, nuestras casas están desprotegidas.» Pero no estaban desprotegidas, solamente querían escapar.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdxlvii{Si les hubieran invadido por los flancos de sus casas y les hubieran pedido su apostasía, con seguridad la habrían dado sin demorarse mucho en ello.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdxlviii{Ciertamente, habían prometido a Dios anteriormente que no darían la espalda y de las promesas hechas a Dios hay que responder.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdxlix{Di: «De nada os servirá huir si pretendéis escapar de la muerte o de que os maten. De todos modos solo disfrutareis un breve plazo.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdl{Di: «¿Quién podría protegeros de Dios si Él quisiera un mal para vosotros o quisiera para vosotros una misericordia?» No encontrarán a nadie aparte de Dios que les proteja y les auxilie.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdli{Con certeza, Dios conoce a quienes os ponen dificultades y a los que dicen a sus hermanos: «¡Venid a nosotros!» y no van al frente excepto poco,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdlii{escatimándoos su ayuda. Y cuando llega el miedo les verás mirándoos con los ojos desorbitados como al que le viene la muerte. Y cuando se va el miedo, os golpean con lenguas afiladas, disgustados y ávidos del bien que habéis obtenido. Esos jamás han tenido fe. Por ello, Dios ha invalidado sus acciones. Eso es fácil para Dios.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdliii{Creen que los partidos no se han ido. Y si los partidos volviesen de nuevo, desearían estar en el desierto entre los beduinos preguntando las noticias que hay sobre vosotros. Y si estuviesen entre vosotros apenas participarían en la batalla.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdliv{Ciertamente, en el Mensajero de Dios tenéis un buen modelo para quien tiene su esperanza puesta en Dios y en el Último Día y recuerda mucho a Dios.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdlv{Y cuando los creyentes vieron a los partidos dijeron: «Esto es lo que nos prometieron Dios y Su Mensajero y Dios y Su Mensajero dijeron la verdad.» Y no hizo sino incrementarse su fe y su sometimiento a Dios.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdlvi{Entre los creyentes hay hombres que cumplen lo que han prometido a Dios. Entre ellos hay quienes ya han cumplido su promesa y hay otros que aun esperan y no han cambiado en absoluto.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdlvii{Para que Dios recompense a quienes han cumplido su promesa por su sinceridad y castigue a los hipócritas si quiere o se vuelva a ellos y les perdone si se arrepienten. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdlviii{Dios hizo regresar a los incrédulos llenos de ira y preocupación sin haber obtenido el bien que esperaban y Dios evitó que los creyentes tuvieran que combatir. Dios es fuerte, poderoso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdlix{Él hizo descender de sus fortalezas a quienes de entre la gente de la Escritura les había apoyado e infundió el temor en sus corazones. A un grupo les matasteis y a otro les hicisteis prisioneros.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdlx{Y os dio en herencias sus tierras, sus casas y sus bienes y un territorio que todavía no habéis pisado. Dios tiene poder sobre todas las cosas.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdlxi{¡Oh, Profeta! Di a tus esposas: «Si deseáis la vida de este mundo y sus adornos, venid y os daré para que podáis disfrutarlo y os dejaré ir de buena manera.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdlxii{Pero si queréis a Dios y a Su Mensajero y la morada de la Otra Vida, Dios ha preparado para quienes sois virtuosas una recompensa inmensa.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdlxiii{¡Oh, esposas del Profeta! ¡Quien de vosotras cometa un pecado evidente, recibirá doble castigo! Eso es fácil para Dios.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdlxiv{Y, a quienes de vosotras obedezcan a Dios y a Su Mensajero y obren rectamente les daremos dos veces su recompensa y les otorgaremos una provisión generosa.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdlxv{¡Oh, esposas de Profeta! ¡Vosotras no sois como cualquier otra mujer! Si sois temerosas de Dios, no elevéis vuestro tono de voz al hablar, de manera que se despierte el deseo de quien tiene una enfermedad en el corazón, y hablad de manera buena y adecuada.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdlxvi{Y permaneced en vuestras casas y no os mostréis ante los hombres como se mostraban en los tiempos de ignorancia anteriores y haced la oración y dad el impuesto purificador de la riqueza y obedeced a Dios y a Su Mensajero. Ciertamente, Dios quiere apartar de vosotros la impureza ¡Gente de la Casa! y purificaos absolutamente.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdlxvii{Y vosotras, recordad lo que es recitado del Corán en vuestras casas relativo a las señales de Dios y la sabiduría. En verdad, Dios es sutil, está bien informado.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdlxviii{En verdad, para los musulmanes y las musulmanas, los creyentes y las creyentes, los obedientes y a las obedientes a las ordenes de Dios, los sinceros y las sinceras, los pacientes y las pacientes, los humildes y a las humildes ante Dios, los caritativos y las caritativas, los que ayunan y las que ayunan, los que protegen y las que protegen su sexo y los que recuerdan y las que recuerdan mucho a Dios, Dios ha preparado un perdón y una recompensa enormes.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdlxix{Cuando Dios y Su Mensajero deciden un asunto, los creyentes y las creyentes no tienen elección sobre ese asunto y quien desobedezca a Dios y a Su Mensajero se habrá extraviado con un extravío evidente.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdlxx{Y [recuerda] cuando dijiste a quien Dios había agraciado y a quien tú habías agraciado: «Reten a tu esposa contigo y se temeroso de Dios» y guardabas en tu alma lo que Dios habría de manifestar, temiendo a la gente, cuando Dios tiene mayor derecho a que Le temas. Así pues, cuando Zayd cambió de opinión respecto a ella, te la dimos por esposa para que los creyentes no encuentren impedimento en casarse con las esposas de sus hijos adoptivos cuando estos decidan terminar con ellas. Y la orden de Dios se cumple.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdlxxi{No hay impedimento para el Profeta en aquello que Dios ha dispuesto para él. Es lo habitual en Dios para quienes vivieron antes. -Y la orden de Dios es un decreto establecido.-\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdlxxii{Aquellos que difundieron el mensaje de Dios y Le temen y no temen a nadie más que a Dios. Y Dios es suficiente para llevar la cuenta.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdlxxiii{Muhammad no es el padre de ninguno de vuestros hombres, sino el Mensajero de Dios y el Sello de los profetas. Y Dios es Quien mejor conoce todas las cosas.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdlxxiv{¡Oh, creyentes! ¡Recordad mucho a Dios\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdlxxv{y glorificadle mañana y tarde!\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdlxxvi{Él es Quien os bendice, y lo mismo hacen Sus ángeles, para sacaros de las tinieblas hacia la luz, y Él es misericordiosísimo con los creyentes.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdlxxvii{El día que se encuentren con Él, se les saludará diciéndoles: «¡Paz!» y Él les tendrá preparada una generosa recompensa.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdlxxviii{¡Oh, Profeta! En verdad, te hemos enviado como testigo, como portador de buenas nuevas y como amonestador,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdlxxix{como uno que invita hacia Dios con Su permiso y como una lámpara luminosa.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdlxxx{Anuncia a los creyentes la buena noticia de que hay para ellos, procedente de Dios, un favor grande\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdlxxxi{y no obedezcas a quienes no creen, ni a los hipócritas. No hagas caso a sus agresiones y confía en Dios. Dios es protector suficiente.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdlxxxii{¡Oh, creyentes! Cuando os caséis con mujeres creyentes y os divorciéis de ellas antes de haberlas tocado, ellas no tienen que guardar un plazo antes de que puedan volver a casarse. Dotadlas adecuadamente y dejadlas ir con amabilidad.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdlxxxiii{¡Oh, Profeta! Hemos hecho lícitas para ti a tus esposas a las cuales has dado sus dotes, a las cautivas que Dios te ha dado como parte del botín de guerra, las hijas de tus tíos paternos y las hijas de tus tías paternas, las hijas de tus tíos maternos y las hijas de tus tías maternas que emigraron contigo y toda mujer creyente que se dé al Profeta, si el Profeta desea casarse con ella. Esto es exclusivamente para ti, no para el resto de los creyentes -Ya sabemos lo que hemos establecido para ellos sobres sus esposas y cautivas- para que no tengas problemas. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdlxxxiv{Pospón el encuentro con quien quieras de ellas y acerca a ti a quien quieras y si quieres acercar a alguna de las que habías apartado no cometes falta alguna. Eso es mejor para que estén felices y no se sientan desgraciadas y estén satisfechas con lo que des a cada una de ellas. Y Dios sabe lo que hay en vuestros corazones. Dios todo lo conoce, es indulgente.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdlxxxv{En adelante, no te son permitidas las mujeres, -ni tampoco que las cambies por otras esposas, aunque su belleza te impresione- excepto quiénes son tus cautivas. Y Dios todo lo observa.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdlxxxvi{¡Oh, creyentes! No entréis en las casas del Profeta, excepto si se os concede permiso para una comida, pero sin presentarse previamente, a la espera de que esté lista. Más bien, entrad cuando se os invite y marchaos cuando terminéis y no os quedéis charlando. En verdad, tal conducta molesta al Profeta, aunque le da vergüenza decíroslo. Pero Dios no se avergüenza de la verdad. Y cuando queráis pedirles algo de la casa a ellas, hacedlo desde detrás de una cortina. Eso es más puro para vuestros corazones y para los corazones de ellas. No debéis molestar al Mensajero de Dios ni casaros jamás con sus esposas después de él. Eso sería algo gravísimo ante Dios.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdlxxxvii{Si manifestáis algo o lo ocultáis, en verdad, Dios conoce todas las cosas.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdlxxxviii{Ellas no cometen pecado si son sus padres o sus hijos o sus hermanos o los hijos de sus hermanos o los hijos de sus hermanas o sus mujeres o sus esclavas. Y sed temerosas de Dios. En verdad, Dios es testigo de todas las cosas.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdlxxxix{En verdad, Dios y Sus ángeles bendicen al Profeta. ¡Oh, creyentes! ¡Pedid bendiciones por él y saludadle con el mejor de los saludos de paz!\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdxc{En verdad, a quienes molesten a Dios y a Su Mensajero, Dios les maldecirá en esta vida y en la Otra y les tendrá preparado un castigo humillante.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdxci{Y quienes molesten a los creyentes y a las creyentes por algo que no hayan hecho, cometen una calumnia y un pecado evidente.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdxcii{¡Oh, Profeta! Di a tus esposas y a tus hijas y a las mujeres de los creyentes que se cubran todo el cuerpo con sus túnicas. Eso es mejor para que sean reconocidas y no sean molestadas. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdxciii{Si los hipócritas, quienes tienen sus corazones enfermos y los intrigantes de Medina, no cesan, haremos que vayas contra ellos y no permanecerán en ella junto a ti sino por poco tiempo.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdxciv{Donde quiera que se les encuentre serán maldecidos, apresados y matados.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdxcv{Es la costumbre de Dios con quienes pasaron anteriormente. Y no encontrarás cambios en la costumbre de Dios.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdxcvi{La gente te pregunta sobre la Hora. Di: «En verdad, ese conocimiento sólo lo tiene Dios y ¿Quién sabe? Puede que la Hora esté cerca.»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdxcvii{En verdad, Dios maldice a los incrédulos y ha preparado para ellos un Fuego llameante\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdxcviii{en el que permanecerán eternamente. No encontrarán quien les proteja ni quien les auxilie.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdxcix{El día que sus rostros se desfiguren en el Fuego, dirán: «¡Ojalá hubiésemos obedecido a Dios y hubiésemos obedecido al Mensajero!»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdc{Y dirán: «¡Señor nuestro! ¡En verdad, obedecimos a nuestros nobles y a nuestros grandes y nos desviaron del camino!\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdci{¡Señor nuestro! ¡Dales en doble de castigo y maldíceles con una gran maldición!»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdcii{¡Oh, creyentes! No seáis como quienes molestaron a Moisés. Dios le consideró inocente de lo que decían y era honorable ante Dios.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdciii{¡Oh, creyentes! ¡Sed temerosos de Dios y hablad con fundamento y conforme a la verdad!\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdciv{Él corregirá vuestros actos y os perdonará vuestros pecados. Y quien obedezca a Dios y a Su Mensajero, obtendrá, con seguridad, un triunfo inmenso.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdcv{En verdad, ofrecimos el depósito a los cielos, a la Tierra y a las montañas, y rehusaron cargar con él y tuvieron miedo, pero el ser humano cargó con él. En verdad, él es injusto, ignorante.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdcvi{Para que Dios castigue a los hipócritas y a las hipócritas y a los idólatras y a las idólatras y acepte el arrepentimiento de los creyentes y las creyentes. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdcvii{\basmalahes Alabado sea Aquel a quien pertenece lo que hay en los cielos y en la Tierra. A Él pertenece la alabanza en la otra vida y Él es el Sabio, el Bien informado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdcviii{Él conoce lo que entra en la tierra y lo que sale de ella y lo que desciende del cielo y lo que asciende a él y Él es el Misericordiosísimo, el Perdonador.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdcix{Los que no son creyentes dicen: «La Hora no llegará a nosotros.» Di: «No es así. Juro por mi Señor que os llegará con seguridad. Él es el conocedor de lo que está oculto a los sentidos. No escapa de Él ni el peso de un átomo en los cielos y la Tierra, ni hay nada más pequeño que eso ni más grande que no esté en una Escritura clara,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdcx{para recompensar a quienes creen y obran rectamente. Ellos obtendrán un perdón y una provisión generosa.»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdcxi{Pero quienes se esfuerzan en desvirtuar Nuestras señales tendrán un castigo doloroso por su pecado.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdcxii{Y a quienes les fue dado el conocimiento ven que aquello que descendió a ti procedente de tu Señor es la Verdad y que guía al camino del Todopoderoso, el Digno de alabanza.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdcxiii{Y quienes no creen dicen: «¿Queréis que os indiquemos un hombre que os anuncie que, cuando estéis desmembrados y descompuestos, seréis creados nuevamente?»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdcxiv{«Él ha inventado una mentira sobre Dios o está poseído.» Pero, quienes no creen en la otra vida, estarán en el castigo y en un extravío profundo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdcxv{¿Acaso no ven los cielos y la tierra que tienen delante y detrás de ellos? Si Nosotros quisiéramos, haríamos que la tierra se los tragase o que cayese sobre ellos una parte del cielo. En verdad, en ello hay una señal para todo siervo que se vuelve a su Señor.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdcxvi{Ciertamente, otorgamos un favor a Nuestro siervo David: «¡Oh, montañas y aves, cantad alabanzas con él!» E hicimos que el hierro fuese blando para él:\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdcxvii{«Haz cotas de malla y ajusta la medida de los anillos al tejerlas.» Y obrad rectamente. En verdad, Yo observo lo que hacéis.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdcxviii{Y [sometimos] a Salomón el viento, que en una mañana hacía el recorrido de un mes y en una tarde el de otro mes e hicimos que manará para él la fuente de bronce fundido y que algunos genios trabajasen para él con permiso de su Señor. Y a quien de ellos desobedecía Nuestras órdenes le hacíamos probar el castigo del fuego.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdcxix{Ellos hacían para él lo que quería: templos, estatuas, recipientes como estanques y grandes marmitas que no se podían trasladar. «Familia de David ¡Sed agradecidos!» ¡Pocos de Mis siervos son agradecidos!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdcxx{Y, cuando decretamos para él la muerte, nada les indicó su muerte excepto un animal de la tierra que se comió su bastón. Así pues, cuando él cayó, se les hizo claro a los genios que si hubieran tenido conocimiento de lo que está oculto a los sentidos no habrían permanecido en el castigo humillante.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdcxxi{Ciertamente, en el lugar en el que los Sabeos vivían había una señal milagrosa: dos jardines a derecha e izquierda. «¡Comed de la provisión de vuestro Señor y agradecedle [el tener] un buen país y un Señor perdonador!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdcxxii{Pero se apartaron y enviamos sobre ellos la inundación del dique y cambiamos sus dos huertos por otros dos que daban frutos amargos, tamariscos y algunos arbustos de azufaifos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdcxxiii{Esa es la recompensa que tuvieron por su ingratitud ¿Acaso recompensamos así excepto a los desagradecidos?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdcxxiv{Pusimos, entre ellos y las ciudades que Nosotros habíamos bendecido, ciudades que se divisaban y establecimos caminos equidistantes entre ellas. «¡Viajad por ellos de noche y de día con seguridad!»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdcxxv{Pero dijeron: «¡Señor nuestro! Alarga las distancias de nuestros viajes.» Y ellos mismos se oprimieron. Hicimos que fueran leyenda y les dispersamos completamente. En verdad, en ello hay señales para todo el que es muy paciente y muy agradecido.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdcxxvi{Y, ciertamente, Iblís confirmó sus suposiciones sobre ellos, pues le siguieron todos excepto un grupo de los creyentes,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdcxxvii{pues sobre ellos no tenía poder. Sólo queríamos distinguir a quién de ellos creía en la otra vida de quienes tenían dudas sobre ella. Y tu Señor tiene buen cuidado de todas las cosas.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdcxxviii{Di: «¡Invocad a quienes vosotros pensáis que son dioses en lugar de Dios! Ellos no poseen ni el peso de un átomo en los cielos ni en la Tierra, ni tienen parte en ambos, ni ninguno de ellos es Su ayudante.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdcxxix{«Y sólo tiene beneficio la intercesión de aquellos a quienes Él de permiso.» Hasta que, cuando el temor se aleje de sus corazones, digan: «¿Qué ha dicho vuestro Señor?» Ellos dirán: «La Verdad y Él es el Altísimo, el Grande.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdcxxx{Di: «¿Quién os procura el sustento de los cielos y la Tierra?» Di: «¡Dios! Entre nosotros y vosotros unos estamos bien guiados y otros en un error evidente.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdcxxxi{Di: «No se os pedirán cuentas por nuestros pecados, ni a nosotros por los que vosotros cometéis.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdcxxxii{Di: «Nuestro Señor nos reunirá a todos y juzgará entre nosotros con justicia y Él es el Juez que todo lo sabe.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdcxxxiii{Di: «Mostradme a quienes consideráis Sus socios. Pero no es así. Él es Dios, el Todopoderoso, el Sabio.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdcxxxiv{No te hemos enviado a la gente sino como una protección ante el pecado, portador de buenas nuevas y amonestador, pero la mayoría de las gentes no saben\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdcxxxv{y dicen: «¿Cuándo tendrá lugar vuestra promesa, si es que sois sinceros?»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcxxxvi{Di: «Tenéis cita un día que no se os retrasará ni adelantará ni una hora.»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcxxxvii{Y quienes no son creyentes dicen: «No creemos en ese Corán ni en lo que vino antes de él.» Pero, si pudieses ver cuando los opresores estén ante su Señor culpándose unos a otros. Aquellos que fueron oprimidos dirán a los arrogantes: «Si no hubiese sido por vosotros habríamos sido creyentes.»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcxxxviii{Aquellos que fueron arrogantes dirán a los oprimidos: «¿Acaso nosotros os apartamos de la buena guía cuando llegó a vosotros? No. Sino que erais pecadores.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcxxxix{Y los oprimidos dirán a los arrogantes: «No. Fueron vuestras maquinaciones de noche y de día, ordenándonos que no creyésemos en Dios y que le atribuyésemos semejantes.» Cuando vean el castigo, ocultarán su remordimiento. Y pondremos argollas de hierro en los cuellos de quienes no creyeron. ¿Acaso se les retribuirá excepto por lo que hacían?\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcxl{Y no hemos enviado a ningún pueblo un amonestador sin que quienes vivían en la opulencia dijeran: «No creeremos en aquello con lo que habéis sido enviados.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcxli{Y dijeran: «Nosotros poseemos más riqueza e hijos. No seremos castigados»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcxlii{Di: «En verdad, mi Señor incrementa o restringe la provisión a quien Él quiere, pero la mayoría de las personas no saben»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcxliii{Y no es con vuestro dinero ni con vuestros hijos con lo que podéis acercaros a Nosotros, sino quienes crean y obren rectamente. Esos obtendrán dos veces la recompensa por lo que hicieron y estarán a salvo en aposentos elevados.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcxliv{Y quienes se esfuerzan por negar e invalidar Nuestras señales, permanecerán en el castigo\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcxlv{Di: «En verdad, Dios otorga con largueza Su provisión a quien Él quiere de Sus siervos y la restringe a quien Él quiere y Él os restituirá aquello que repartáis, pues Él es el mejor de los proveedores.»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcxlvi{Y el día que les reúna a todos, dirá a los ángeles: «¿Es a vosotros a quienes ellos adoraban?»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcxlvii{Ellos dirán: «¡Gloria a Ti! ¡Tú eres nuestros amigo y protector, no ellos! Ellos adoraban a los genios. La mayoría tenía fe en ellos»\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdcxlviii{Y hoy no podréis beneficiaros ni perjudicaros unos a otros y diremos a quienes oprimieron: «Probad el castigo del Fuego que vosotros desmentíais»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcxlix{Y cuando les son recitados nuestros versículos claros dicen: «Éste no es más que un hombre que quiere apartaros de aquello que adoraban vuestros padres.» Y dicen: «Esto no es más que una mentira inventada.» Y dicen los que no son creyentes cuando la Verdad viene a ellos: «Esto no es más que magia evidente»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcl{Nosotros no les dimos ninguna de las Escrituras [Sagradas] para que la estudiasen ni les habíamos enviado antes de tí ningún amonestador.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdcli{También desmintieron los que vinieron antes de ellos y ellos no han obtenido ni la décima parte de lo que les dimos, pero desmintieron a Mis Mensajeros y ¡cómo fue mi Castigo!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdclii{Di: «En verdad, os recomiendo una cosa: Que os pongáis en pie por Dios, por parejas o individualmente, y reflexionéis.» Vuestro compañero no es un poseso. Verdaderamente, él no es para vosotros más que un advertidor del grave castigo que os aguarda.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcliii{Di: «No os pido una recompensa. Para vosotros. En verdad, mi recompensa sólo concierne a Dios y Él es testigo de todas las cosas»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdcliv{Di: «En verdad, mi Señor aleja la falsedad con la Verdad. Él conoce lo que no se puede percibir con los sentidos»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdclv{Di: «Ha venido la Verdad y la falsedad no puede crear ni recrear\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdclvi{Di: «Si me extravío, me extravío por mi ego y si me guío rectamente es gracias a lo que mi Señor me ha revelado. En verdad, Él todo lo oye, está cerca»\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdclvii{Y, si vieras cuando estén aterrorizados pero no puedan escapar y sean atrapados desde un lugar cercano\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdclviii{y digan: «¡Creémos en él!» Pero ¿cómo podrán alcanzarlo desde un lugar tan alejado?\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdclix{Habiendo descreído de él anteriormente y habiendo rechazado desde un lugar alejado lo que no se percibe con los sentidos.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdclx{Se interpondrá una barrera entre ellos y lo que ellos desean, lo mismo que sucedió con sus semejantes anteriormente. En verdad, ellos tenían una seria duda.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdclxi{\basmalahes Alabado sea Dios, Creador de los cielos y la Tierra y Quien ha puesto a los ángeles como mensajeros y poseedores de alas dobles, triples o cuádruples. Él añade a la creación lo que quiere. En verdad, Dios tiene poder sobre toda la creación\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdclxii{La misericordia que Dios libra para los seres humanos nadie puede obstaculizarla y lo que Él impide nadie después de Él puede realizarlo, pues Él es el Todopoderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdclxiii{¡Oh, gentes! ¡Recordad las mercedes que Dios ha tenido con vosotros! ¿Hay en la creación, aparte de Dios, quien os provea de lo que hay en los cielos y en la Tierra? No hay más dios que Él. ¿Cómo, pues, os desviáis?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdclxiv{Y si te desmienten, también desmintieron a Mensajeros anteriores a ti, pero los asuntos regresan a Dios.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdclxv{¡Oh, humanos! En verdad, la promesa de Dios es verdadera. Por tanto, que la vida mundanal no os vuelva soberbios y que el Soberbio no os haga soberbios frente a Dios.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdclxvi{En verdad, Satanás en un enemigo para vosotros, así pues, tenedle por enemigo. En verdad, él invita a sus partidarios a que sean gente para el Fuego flamígero.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdclxvii{Para quienes no creen hay un duro castigo y para quienes creen y obran rectamente hay perdón y una gran recompensa.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdclxviii{¿Acaso aquel a quien le parecen hermosos sus malos actos y los ve como buenos…? En verdad, Dios extravía a quien Él quiere y guía a quien Él quiere. Así pues, no sientas pena por ellos. En verdad, Dios sabe lo que ellos hacen.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdclxix{Es Dios Quien envía los vientos que levantan las nubes y Nosotros las dirigimos hacia una región muerta y damos vida con ella a la Tierra después de su muerte. Así mismo será la Resurrección.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdclxx{Quien quiera el poder y la gloria, sepa que todo el poder y la gloria pertenecen a Dios. A Él asciende la buena palabra y la obra recta la eleva. Y quienes planean maldades tendrán un duro castigo y sus planes serán destruidos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdclxxi{Dios os ha creado de tierra, luego de una gota, luego os ha puesto en parejas. No hay hembra que conciba o que de a luz sin Su conocimiento y a nadie se le alarga la vida o se le acorta sin que esté consignado en una Escritura. En verdad, eso es fácil para Dios.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdclxxii{No son iguales las dos grandes extensiones de agua. na es pura y dulce, agradable de beber y la otra es salada y desagradable, y de ambas coméis carne fresca y extraéis adornos con los que os vestís. Y ves las naves que las surcan para que busquéis Su favor y, quizás así, agradezcáis.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdclxxiii{Él introduce la noche en el día e introduce el día en la noche y ha sometido al Sol y a la Luna, que transcurren durante un plazo establecido. Ese es Dios vuestro Señor. A Él pertenece el gobierno. Y quienes vosotros invocáis en lugar de Él, no gobiernan ni la piel del hueso de un dátil.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdclxxiv{Si les invocáis no escuchan vuestra invocación y si la escuchan no os pueden dar respuesta y el Día del Levantamiento renegarán de vuestra idolatría. Y nadie te puede informar como Uno que está bien informado.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdclxxv{¡Oh, humanos! Vosotros sois los necesitados de Dios y Dios es el Autosuficiente, el Rico por sí mismo, el Digno de alabanza.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdclxxvi{Sí Él quisiera os eliminaría y haría una nueva creación.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdclxxvii{Eso no es difícil para Dios.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdclxxviii{Nadie cargará con la carga de los pecados de otro y si alguien cuya carga sea muy pesada pide a otro que la lleve, nadie cargará nada de ella, aunque sea un pariente cercano. Y, en verdad, tu amonestación sólo surte efecto sobre quienes temen a su Señor en secreto y hacen la oración. Quien se purifica, se purifica para su propio beneficio y el regreso es hacia Dios.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdclxxix{Y no son iguales el ciego y el que ve,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdclxxx{ni las tinieblas y la luz.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdclxxxi{ni la sombra y el calor abrasador.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdclxxxii{Ni son iguales los vivos y los muertos. En verdad, Dios hace oír a quien Él quiere, pero tú no puedes hacer oír a quienes están en las tumbas.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdclxxxiii{En verdad, tú no eres más que un amonestador.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdclxxxiv{Ciertamente, te hemos enviado con la Verdad, como portador de buenas nuevas y amonestador, pues no hay comunidad por la que no haya pasado un amonestador.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdclxxxv{Y si te desmienten, también desmintieron quienes vinieron antes de ellos. Vinieron a ellos sus Mensajeros con las pruebas claras, con los Salmos y con la Escritura luminosa.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdclxxxvi{Luego, atrapamos a quienes no creyeron y ¡Cuál fue mi rechazo!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdclxxxvii{¿Acaso no has visto que Dios hace descender el agua y hacemos salir con ella frutos de variados colores? Y en las montañas hay vetas de diferentes colores: blancas, rojas y de un negro intenso.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdclxxxviii{Y los humanos, las bestias y el ganado también son de diferentes colores. En verdad, de Sus siervos, sólo temen a Dios los que son sabios. En verdad, Dios es todopoderoso, perdonador.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdclxxxix{En verdad, quienes recitan la Escritura de Dios y hacen la oración y reparten secreta y abiertamente de lo que nosotros les hemos proveído esperan realizar una transacción que no tiene perjuicio\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcxc{Dios les dará su recompensa y les aumentará Su favor. En verdad, Él es perdonador, agradecido.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcxci{Y lo que Nosotros te hemos revelado de la Escritura es la Verdad que confirma lo que fue revelado antes de ella. En verdad, Dios está bien informado, ve a Sus siervos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcxcii{Luego dimos en herencia la Escritura a quienes escogimos de Nuestros siervos, pues entre ellos hay quienes oprimen sus almas, otros que siguen un camino moderado y otros que van por delante en la realización de buenas obras con el permiso de Dios. Ese es el gran favor.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcxciii{Entrarán en los Jardines del Edén y allí se adornarán con pulseras de oro y perlas y sus vestidos allí serán de seda.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcxciv{Y dirán: «Alabado sea Dios que ha apartado de nosotros la congoja. En verdad, nuestro Señor es perdonador, agradecido.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcxcv{Él nos ha hecho lícita, por Su favor, la Morada Permanente en la que no sufriremos adversidad ni sufriremos fatiga.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcxcvi{Y para quienes no creyeron, el fuego del Infierno. No se les permitirá morir ni se les aliviará su castigo. Así es como Nosotros castigamos a todo el que trató de ocultar la Verdad.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcxcvii{Allí se lamentarán a gritos: «¡Señor nuestro! ¡Sácanos para que obremos rectamente, a diferencia de lo que hacíamos!» «¿Es que no os dimos suficiente vida para que quien hubiese querido reflexionar se hubiese dejado amonestar y no vino a vosotros el amonestador?» «Así pues ¡Probad!» Los opresores no tendrán quien les auxilie.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcxcviii{En verdad, Dios es Quien conoce lo que está oculto a los sentidos en los cielos y en la Tierra. En verdad, Él es Quien conoce lo que hay en el fondo de los corazones.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcxcix{Él es Quien os ha puesto como herederos en la Tierra. Así pues, quien trate de ocultar la Verdad, se perjudicará a sí mismo. La falta de fe de quienes niegan la realidad sólo sirve para incrementar el disgusto de su Señor. La falta de fe de quienes niegan la realidad sólo incrementa su propio perjuicio.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcc{Di: «¿Habéis visto a vuestros asociados, aquellos que invocáis en lugar de Dios? Mostradme lo que han creado en la Tierra o si tienen parte alguna en los cielos o si Nosotros les hemos dado alguna Escritura en la cual puedan apoyarse como una prueba clara.» ¡No! Los opresores sólo se prometen mentiras unos a otros.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcci{En verdad, Dios mantiene los cielos y la Tierra para que no se caigan y si se cayesen nadie podría mantenerlos excepto Él. En verdad, Él es indulgente, perdonador.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdccii{Juraron por Dios con solemnes testimonios que si viniese a ellos un amonestador seguirían la guía mejor que ninguna otra comunidad, pero cuando vino a ellos un amonestador sólo incrementó su rechazo,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcciii{comportándose con arrogancia en la Tierra y maquinando el mal. Pero las malas maquinaciones sólo recaen sobre quienes las realizan. Así pues ¿Acaso esperan otra suerte que la que tuvieron los antiguos? No encontrarán cambios en la práctica de Dios ni encontrarán variaciones en la práctica de Dios.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcciv{¿Acaso no han viajado por la Tierra y han visto cuál fue el final de quienes vivieron antes de ellos aunque fueron más fuertes y poderosos que ellos? Nada en los cielos ni la Tierra puede debilitar a Dios. En verdad, Él todo lo conoce, todo lo puede.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdccv{Si Dios castigase a los seres humanos por lo que sus actos merecen no dejaría a ningún ser vivo sobre la superficie de la Tierra, pero lo pospone para un plazo ya establecido. Y cuando llegue su plazo… Dios observa a Sus siervos.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdccvi{\basmalahes Ya, Sin.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdccvii{Juro por el sabio Corán\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdccviii{que tú eres uno de los Mensajeros\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdccix{sobre un camino recto.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdccx{Hecho descender gradualmente por el Todopoderoso, el Misericordiosísimo,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdccxi{para que amonestes con él a un pueblo cuyos padres no fueron amonestados, por lo cual ellos están distraídos.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdccxii{Juro que se ha confirmado lo dicho para la mayoría de ellos, pero ellos no creen.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdccxiii{Hemos puesto en sus cuellos argollas hasta la barbilla que les mantienen la cabeza levantada\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdccxiv{y hemos puesto por delante de ellos una barrera y por detrás de ellos una barrera, de manera que les hemos cubierto totalmente y no pueden ver\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdccxv{y les da igual que les amonestes o no les amonestes, no creerán.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdccxvi{En verdad, solo aprovecha tu amonestación quien sigue el Recuerdo y teme al Clementísimo en secreto. Así pues, anúnciale la buena noticia de un perdón y una recompensa generosa\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdccxvii{En verdad, somos Nosotros quienes damos la vida a los muertos y escribimos lo que han enviado por delante de ellos y las obras que dejan atrás y lo tenemos todo consignado en un libro claro.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdccxviii{Y cítales el ejemplo de los habitantes de la ciudad a la que vinieron los Mensajeros,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdccxix{cuando Nosotros enviamos a ellos a dos y los desmintieron, así que les reforzamos con un tercero y dijeron: «En verdad, somos Mensajeros enviados a vosotros.»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdccxx{Ellos dijeron: «Vosotros no sois más que seres humanos como nosotros y el Clementísimo no ha enviado nada. Sois unos mentirosos.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdccxxi{Ellos dijeron: «Nuestro Señor sabe que somos Mensajeros enviados a vosotros\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdccxxii{y nuestra responsabilidad no es más que comunicar el mensaje claro.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdccxxiii{Dijeron: «Sois un mal presagio. Si no cesáis os apedrearemos y os haremos sufrir un castigo doloroso.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdccxxiv{Ellos dijeron: «¡Vuestro presagio proviene de vuestra actitud! ¿Es que no reflexionaréis? ¡Sois gente transgresora!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdccxxv{Y de lo más lejano de la ciudad vino un hombre corriendo. Dijo: «¡Oh, pueblo mío! ¡Seguid a los Mensajeros!\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdccxxvi{Seguid a quienes no os piden recompensa y están bien guiados.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdccxxvii{Y ¿Por qué no voy yo a adorar a Quien me ha creado y a Quien habréis de regresar?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdccxxviii{¿Voy a tomar otros dioses en lugar de Él? Si el Clementísimo quisiera causarme un mal, la intercesión de ellos no podría beneficiarme en absoluto ni podrían rescatarme.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdccxxix{Estaría entonces en un extravío evidente.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdccxxx{«Ciertamente, he creído en vuestro Señor, escuchadme pues.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdccxxxi{Le fue dicho: «¡Entra en el Jardín!» Él dijo: «¡Ojalá mi pueblo supiese\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdccxxxii{que mi Señor me ha perdonado y me ha puesto entre los ennoblecidos y honrados!»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdccxxxiii{Y, tras él, no hicimos descender sobre su pueblo un ejército desde el cielo ni nunca lo hemos hecho descender.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdccxxxiv{No hubo más que un grito y repentinamente todos murieron.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdccxxxv{¡Qué pena de siervos! No vino a ellos Mensajero alguno del que no se burlaran.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdccxxxvi{¿Acaso no ven cuántas generaciones antes de ellos hemos destruido que ya no volverán a ellos?\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdccxxxvii{Todos ellos serán reunidos sin excepción ante Nosotros.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdccxxxviii{La tierra muerta es una señal para ellos. Nosotros la hacemos vivir y sacamos de ella grano del que comen.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdccxxxix{Y ponemos en ella jardines de palmeras y viñedos y hacemos que broten en ella fuentes\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdccxl{para que coman de sus frutos, que no hacen con sus manos. ¿Es que no agradecerán?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdccxli{Glorificado sea Quien ha creado parejas de todo, de las plantas que surgen de la tierra, de ellos mismos y de lo que ellos no conocen.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdccxlii{Y una señal para ellos es la noche, de la que extraemos el día y quedan en tinieblas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdccxliii{Y el Sol, que se mueve hacia su lugar de descanso por decreto del Todopoderoso, el Sabio.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdccxliv{Y la Luna. Nosotros hemos decretado casas para ella, hasta que se vuelve como una rama vieja de palmera.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdccxlv{Ni el Sol puede alcanzar a la Luna, ni la noche adelantar al día y cada uno navega en su órbita.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdccxlvi{Y una señal para ellos es que Nosotros subiéramos a sus descendientes en la nave abarrotada\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdccxlvii{y creásemos para ellos otros semejantes en los que cabalgar.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdccxlviii{Y, si Nosotros hubiésemos querido, les habríamos ahogado. Nadie habría escuchado sus gritos y no se habrían salvado,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdccxlix{si no fuera por una misericordia de Nuestra parte para que disfrutasen por algún tiempo.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdccl{Y cuando se les dice: «Sed temerosos de lo que tenéis ante vosotros y de lo que está a vuestras espaldas, para que así se tenga misericordia de vosotros»,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdccli{no viene a ellos una sola de las señales de su Señor sin que se aparten de ella.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcclii{Y cuando se les dice: «¡Repartid de lo que Dios os ha proveído!» quienes niegan la realidad dicen a quienes son creyentes: «¿Vamos nosotros a alimentar a quienes, si Dios hubiera querido, Él mismo habría alimentado? En verdad, vosotros estáis en un extravío evidente.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdccliii{Y dicen: «¿Cuándo será eso que nos prometéis, si es que decís la verdad?»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdccliv{No tendrán que esperar más que un solo grito que les alcanzará mientras discuten\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdcclv{y no podrán hacer testamento ni regresar a sus familiares.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdcclvi{Será tocada la trompeta y se apresurarán a salir de sus tumbas para ir hacia su Señor.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdcclvii{Dirán: «¡Ay de nosotros! ¿Quién nos ha levantado del lugar en el que dormíamos? Esto es lo que nos había prometido el Clementísimo. Los Mensajeros decían la verdad.»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdcclviii{No habrá más que un solo grito y todos estarán presentes ante Nosotros.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdcclix{«¡Hoy nadie será oprimido en absoluto y sólo serán recompensados por lo que hacían!»\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdcclx{En verdad, las gentes del Jardín tendrán hoy una ocupación que les hará sentirse felices.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdcclxi{Ellos y sus parejas estarán a la sombra, reclinados en cojines.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdcclxii{Allí habrá para ellos frutas y todo lo que pidan.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdcclxiii{Y se les dirá: «¡Paz, de parte de un Señor misericordioso!»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdcclxiv{«Y vosotros, pecadores ¡Apartaos hoy!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdcclxv{¿Acaso no se os aconsejo: ¡Oh, hijos de Adán! que no adoraseis a Satanás? En verdad, él es para vosotros un enemigo claro.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdcclxvi{¿Y que Me adoraseis a Mí? Ese es un camino recto.»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdcclxvii{«Ciertamente, él ha extraviado a muchos grupos de vosotros. ¿Es que no razonáis?»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdcclxviii{«¡Éste es el Infierno que se os prometía!\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdcclxix{¡Entrad hoy en él por no haber creído!»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdcclxx{Hoy sellaremos sus bocas y sus manos Nos hablarán y sus pies darán testimonio de lo que ellos hacían.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdcclxxi{Si Nosotros quisiéramos eliminaríamos sus ojos. Entonces, cuando quisiesen competir para alcanzar el camino recto ¿Cómo verían?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdcclxxii{Y si nosotros quisiéramos les trasformaríamos en estatuas en el mismo sitio en el que se encuentran y no podrían avanzar ni retroceder.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdcclxxiii{Y a quien alargamos la vida le hacemos perder sus facultades ¿Es que no razonan?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdcclxxiv{Y no le hemos enseñado poesía, ni eso es adecuado para él. Esto no es más que un recordatorio y una recitación clara\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdcclxxv{para amonestar a quien esté vivo y para que se cumpla lo dicho sobre los que niegan la Verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdcclxxvi{¿Acaso no han visto que, de entre las cosas que hemos hecho, hemos creado para ellos ganados de los que ellos son dueños\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdcclxxvii{y que hemos sometido a ellos y en algunos de los cuales ellos cabalgan y de otros comen?\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdcclxxviii{De ellos obtienen beneficios y de ellos beben. ¿No serán, pues, agradecidos?\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdcclxxix{Pero toman otros dioses aparte de Dios con la esperanza de que les auxilien.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmdcclxxx{Ellos no pueden auxiliarles y, en cambio, ellos se convierten en un ejército presente para ellos.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmdcclxxxi{Así pues, que no te entristezca lo que dicen. En verdad, Nosotros sabemos lo que ocultan en secreto y lo que manifiestan.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmdcclxxxii{¿Acaso no ve el ser humano que le hemos creado de una gota y en cambio él es un discutidor permanente, siempre en abierta oposición?\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmdcclxxxiii{Y, olvidando su creación, Nos pone ejemplos diciendo: «¿Quién dará vida a los huesos revistiéndolos de carne?»\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmdcclxxxiv{Di: «Los dará vida el mismo que los creó por primera vez y que conoce a toda la creación.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmdcclxxxv{El que ha hecho para vosotros fuego del árbol verde con el que os alumbráis.»\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmdcclxxxvi{¿Acaso Quien creó los cielos y la Tierra no tiene poder para crear algo semejante a ellos? Sí, pues Él es el Creador de todo, el Sabio.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmdcclxxxvii{En verdad, Su orden cuando desea algo es decirle: «¡Sé!» y ello es.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmdcclxxxviii{Así pues, glorificado sea Quien tiene en su mano el poder sobre todas las cosas y hacia Quien se os hará regresar.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmdcclxxxix{\basmalahes Juro por los que han sido ordenados en filas,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdccxc{que apartan vigorosamente,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdccxci{que recitan un Recuerdo.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdccxcii{En verdad, vuestro dios es Uno.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdccxciii{El Señor de los cielos y la Tierra y de lo que hay entre ambos y el Señor de los Orientes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdccxciv{En verdad, hemos embellecido el cielo de este mundo con las estrellas, como adorno\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdccxcv{y protección contra cualquier demonio rebelde,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdccxcvi{para que no puedan escuchar al Consejo Supremo y sean apedreados desde todas partes\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdccxcvii{y expulsados. Y les aguarda, necesariamente, un castigo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdccxcviii{Y si alguno escucha algo, es perseguido por una estrella fugaz certera.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdccxcix{Pregúntales: ¿Son ellos más difíciles de crear o aquellos a quienes Nosotros hemos creado? En verdad, a ellos los hemos creado de barro viscoso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdccc{Tú te asombras, pero ellos se burlan\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdccci{y si se les amonesta no recapacitan\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdcccii{y cuando ven un milagro se burlan\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdccciii{y dicen: «Eso no es más que magia evidente.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdccciv{¿Acaso cuando muramos y seamos tierra y huesos seremos resucitados\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdcccv{y también nuestros primeros padres?»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdcccvi{Di: «Sí. Y seréis humillados.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdcccvii{Será un solo grito y todos lo verán\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdcccviii{y dirán: «¡Ay de nosotros! ¡Este es el Día de la Recompensa!»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdcccix{Este es el Día de la Separación que negabais.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdcccx{Reunid a los opresores, a sus pares y a lo que adoraban\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdcccxi{en lugar de Dios, guiadles hacia El camino Del infierno\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdcccxii{y paradles. En verdad, se les preguntara:\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdcccxiii{«¿Qué os pasa que no os ayudáis unos a otros?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdcccxiv{Pero ese día estarán sometidos\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdcccxv{y enfrentados. Unos interrogarán a otros\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdcccxvi{diciendo: «En verdad, vinisteis a nosotros por la derecha.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdcccxvii{Ellos dirán: «¡Vosotros no erais creyentes!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcccxviii{Nosotros no teníamos ninguna autoridad sobre vosotros. ¡Erais una gente endiosada y rebelde!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcccxix{«Se ha verificado sobre nosotros la palabra de nuestro Señor. En verdad, lo probaremos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcccxx{¡Claro que os extraviamos! ¡Nosotros mismos estábamos extraviados!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcccxxi{Así que, ese día compartirán el castigo.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcccxxii{En verdad, eso es lo que hacemos con los pecadores.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcccxxiii{En verdad, ellos se mostraban altivos cuando se les decía: «Hay un solo Dios.»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcccxxiv{Y decían: «¿Vamos a abandonar a nuestros dioses por un poeta loco?»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcccxxv{Pero el traía la Verdad y confirmaba a los Mensajeros [anteriores].\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcccxxvi{En verdad, probaréis el castigo doloroso.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcccxxvii{Solamente seréis retribuidos por lo que hacíais.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcccxxviii{Excepto los siervos puros de Dios.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcccxxix{Para ellos habrá una provisión conocida:\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdcccxxx{Frutos variados. Y serán tratados con generosidad\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcccxxxi{en los Jardines de las Delicias.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcccxxxii{Estarán sobre lechos, unos frente a otros\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdcccxxxiii{y (sirvientes) circularán a su alrededor escanciándoles copas de un líquido transparente,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdcccxxxiv{blanco y delicioso al paladar de los bebedores,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcccxxxv{que no les perjudicará ni les embriagará.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdcccxxxvi{Junto a ellos habrá seres de modesta mirada y hermosos ojos\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdcccxxxvii{como si fuesen perlas semicerradas.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdcccxxxviii{Y, vueltos unos hacia los otros, se preguntarán entre ellos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdcccxxxix{Uno de ellos dirá: «Yo tenía un compañero\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdcccxl{que decía: ¿Eres tú de los que afirman\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdcccxli{que cuando muramos y seamos polvo y huesos seremos vueltos a la vida y recompensados por nuestros actos?»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdcccxlii{Él dirá: «¿Podéis investigar?»\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdcccxliii{Investigarán y le verán en mitad del Infierno.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdcccxliv{Él dirá: «Juro por Dios que estuviste a punto de hacerme caer\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdcccxlv{y si no hubiese sido por el favor de mi Señor habría sido de los destinados al castigo.»\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdcccxlvi{«¿Es cierto que ya no moriremos\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdcccxlvii{después de nuestra primera muerte y que no seremos castigados?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdcccxlviii{¡En verdad, éste es el triunfo inmenso!»\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdcccxlix{Que quienes trabajan trabajen para conseguir algo como esto!\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdcccl{¿Es éste mejor alojamiento o el árbol de Zaqqum?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdcccli{En verdad, lo hemos puesto como una prueba para los opresores.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdccclii{Es, en verdad, un árbol que surge en el fondo del Infierno,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdcccliii{cuyos brotes semejan cabezas de demonios\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdcccliv{y del que ellos comerán y del que llenarán sus estómagos.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdccclv{Luego, beberán una mezcla con agua hirviente y abrasadora.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdccclvi{Luego, regresarán al Infierno.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdccclvii{Allí se encontrarán con sus padres extraviados,\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdccclviii{por haberse apresurado a seguir las huellas de sus pasos.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdccclix{Ciertamente, antes de ellos se extraviaron la mayoría de los antepasados,\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdccclx{aunque, ciertamente, les habíamos enviado amonestadores.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdccclxi{Observa cuál fue el final de los amonestados\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdccclxii{exceptuando a los siervos puros de Dios.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmdccclxiii{Ciertamente, Noé Nos invocó y ¡Qué bien le respondimos!\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmdccclxiv{Y le salvamos, a él y a su familia, de la agonía inmensa.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmdccclxv{E hicimos que sus descendientes sobreviviesen\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmdccclxvi{y dejamos su buen nombre para la posteridad.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmdccclxvii{¡La paz sea con Noé en todos los mundos!\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmdccclxviii{Así es cómo Nosotros recompensamos a quienes hacen el bien.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmdccclxix{En verdad, él era uno de Nuestros siervos creyentes.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmdccclxx{Por tanto, hicimos que los demás se ahogasen.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmdccclxxi{Y, en verdad, entre Nuestros seguidores está Abraham.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmdccclxxii{[Recuerda] cuando vino a su Señor con un corazón sano\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmdccclxxiii{y cuando dijo a su padre y a su pueblo: «¿Qué es lo que adoráis?”\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmdccclxxiv{“¿Queréis falsos dioses en lugar de Dios?\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmdccclxxv{¿Cuál es vuestra idea acerca del Señor de los Mundos?»\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmdccclxxvi{Y miró a las estrellas\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmdccclxxvii{y dijo: «En verdad, estoy enfermo.»\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmdccclxxviii{y le dieron la espalda y se alejaron.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmdccclxxix{Entonces se dirigió hacia los dioses de ellos y dijo: «¿Es que no coméis?»\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmdccclxxx{«¿Por qué no habláis?»\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmdccclxxxi{Así que fue hacia ellos y les golpeó con la mano derecha.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmdccclxxxii{Ellos fueron apresuradamente junto a él.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmdccclxxxiii{Él dijo: «¿Adoráis lo que vosotros mismos esculpís\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmdccclxxxiv{cuando Dios os ha creado a vosotros y lo que vosotros hacéis?»\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmdccclxxxv{Ellos dijeron: «Construid una estructura para él y ponedle en medio del fuego llameante.»\qt@no{97}}
\qt@newcmd\qurantrans@es@mmmdccclxxxvi{Quisieron tramar un plan contra él pero Nosotros les humillamos.\qt@no{98}}
\qt@newcmd\qurantrans@es@mmmdccclxxxvii{Dijo: «En verdad, voy hacia mi Señor y Él me guiará.»\qt@no{99}}
\qt@newcmd\qurantrans@es@mmmdccclxxxviii{«¡Señor mío! ¡Otórgame un hijo de los Rectos!»\qt@no{100}}
\qt@newcmd\qurantrans@es@mmmdccclxxxix{Y Nosotros le anunciamos la buena noticia de un joven complaciente.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmmdcccxc{Así pues, cuando tuvo edad para esforzarse le dijo: «¡Oh, hijito mío! He visto en mi sueño que te sacrificaba. ¿Qué opinas?» Él dijo: «¡Oh padre mío! ¡Haz lo que se te ha ordenado! Encontrarás que soy, si Dios quiere, de los pacientes.»\qt@no{102}}
\qt@newcmd\qurantrans@es@mmmdcccxci{Así pues, cuando ambos se hubieron sometido y le puso la sien en el suelo,\qt@no{103}}
\qt@newcmd\qurantrans@es@mmmdcccxcii{le llamamos: «¡Oh, Abraham!\qt@no{104}}
\qt@newcmd\qurantrans@es@mmmdcccxciii{¡Ciertamente, ya has verificado tu visión!» En verdad, así es como recompensamos a quienes hacen el bien.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmmdcccxciv{Ésta fue una prueba evidente.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmmdcccxcv{Y le rescatamos a cambio de un sacrificio inmenso.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmmdcccxcvi{y dejamos de él un buen nombre para la posteridad.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmmdcccxcvii{¡La paz sea sobre Abraham!\qt@no{109}}
\qt@newcmd\qurantrans@es@mmmdcccxcviii{Así es como recompensamos a quienes hacen el bien.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmmdcccxcix{En verdad, él era uno de Nuestros siervos creyentes.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmmcm{Y le dimos la buena nueva de Isaac, profeta y uno de los Rectos.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmmcmi{Y le bendijimos a él y a Isaac. Y, entre los descendientes de ambos, algunos fueron virtuosos y otros oprimieron su alma de manera evidente.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmmcmii{Y, ciertamente, favorecimos a Moisés y a Aarón\qt@no{114}}
\qt@newcmd\qurantrans@es@mmmcmiii{y salvamos a ellos y a su pueblo de la gran dificultad.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmmcmiv{Y les auxiliamos y fueron ellos los vencedores.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmmcmv{Y dimos a ambos la Escritura esclarecedora.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmmcmvi{Y les guiamos a ambos al camino recto\qt@no{118}}
\qt@newcmd\qurantrans@es@mmmcmvii{y dejamos de ambos un buen nombre para la posteridad.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmmcmviii{¡La paz sea sobre Moisés y Aarón!\qt@no{120}}
\qt@newcmd\qurantrans@es@mmmcmix{Así es como recompensamos a quienes hacen el bien.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmmcmx{En verdad, ambos eran de Mis siervos creyentes.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmmcmxi{Y, en verdad, Elías era de los Mensajeros.\qt@no{123}}
\qt@newcmd\qurantrans@es@mmmcmxii{[Recuerda] Cuando dijo a su pueblo: «¿Es que no seréis temerosos de Dios?\qt@no{124}}
\qt@newcmd\qurantrans@es@mmmcmxiii{¿Invocáis a Baal y abandonáis al mejor de los creadores:\qt@no{125}}
\qt@newcmd\qurantrans@es@mmmcmxiv{Dios, vuestro Señor y el Señor de vuestros primeros padres?»\qt@no{126}}
\qt@newcmd\qurantrans@es@mmmcmxv{Pero le desmintieron y, en verdad, se les hará comparecer.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmmcmxvi{Excepto a los siervos puros de Dios.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmmcmxvii{Y dejamos de él un buen nombre para la posteridad.\qt@no{129}}
\qt@newcmd\qurantrans@es@mmmcmxviii{¡La paz sea sobre la familia de Ya Sin!\qt@no{130}}
\qt@newcmd\qurantrans@es@mmmcmxix{Así es como recompensamos a quienes hacen el bien.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmmcmxx{En verdad, él era uno de Nuestros siervos creyentes.\qt@no{132}}
\qt@newcmd\qurantrans@es@mmmcmxxi{Y, en verdad, Lot fue uno de los Mensajeros.\qt@no{133}}
\qt@newcmd\qurantrans@es@mmmcmxxii{[Recuerda] Cuando le salvamos a él y a su familia, a todos ellos,\qt@no{134}}
\qt@newcmd\qurantrans@es@mmmcmxxiii{excepto a una anciana, que fue de los que se quedaron atrás.\qt@no{135}}
\qt@newcmd\qurantrans@es@mmmcmxxiv{Luego, aniquilamos a los demás.\qt@no{136}}
\qt@newcmd\qurantrans@es@mmmcmxxv{Y vosotros pasáis por sus ruinas por la mañana\qt@no{137}}
\qt@newcmd\qurantrans@es@mmmcmxxvi{y por la noche. ¿Es que no pensáis?\qt@no{138}}
\qt@newcmd\qurantrans@es@mmmcmxxvii{Y, en verdad, Jonás fue uno de los Mensajeros.\qt@no{139}}
\qt@newcmd\qurantrans@es@mmmcmxxviii{[Recuerda] Cuando se escapó en la nave repleta\qt@no{140}}
\qt@newcmd\qurantrans@es@mmmcmxxix{y echaron a suertes y salió elegido\qt@no{141}}
\qt@newcmd\qurantrans@es@mmmcmxxx{y el pez se lo tragó y ese fue su castigo.\qt@no{142}}
\qt@newcmd\qurantrans@es@mmmcmxxxi{Y si no hubiese sido de los que glorifican a Dios\qt@no{143}}
\qt@newcmd\qurantrans@es@mmmcmxxxii{habría permanecido en su estómago hasta el día en que todos serán resucitados.\qt@no{144}}
\qt@newcmd\qurantrans@es@mmmcmxxxiii{Y le arrojamos enfermo a una playa sin sombra\qt@no{145}}
\qt@newcmd\qurantrans@es@mmmcmxxxiv{e hicimos crecer sobre él una gran planta de calabaza.\qt@no{146}}
\qt@newcmd\qurantrans@es@mmmcmxxxv{Y le enviamos a una comunidad de cien mil o más,\qt@no{147}}
\qt@newcmd\qurantrans@es@mmmcmxxxvi{que creyeron y Nosotros les permitimos disfrutar hasta un plazo establecido.\qt@no{148}}
\qt@newcmd\qurantrans@es@mmmcmxxxvii{Pregúntales: «¿Son para tu Señor las hijas y para ellos los hijos?\qt@no{149}}
\qt@newcmd\qurantrans@es@mmmcmxxxviii{¿O hemos creado a los ángeles del género femenino y ellos fueron testigos?»\qt@no{150}}
\qt@newcmd\qurantrans@es@mmmcmxxxix{¿Acaso no mienten cuando dicen:\qt@no{151}}
\qt@newcmd\qurantrans@es@mmmcmxl{«Dios tiene hijos.»? ¡Mienten!\qt@no{152}}
\qt@newcmd\qurantrans@es@mmmcmxli{¿Ha preferido Él las hijas a los hijos?\qt@no{153}}
\qt@newcmd\qurantrans@es@mmmcmxlii{¿Qué os pasa? ¿Cómo juzgáis de esa manera?\qt@no{154}}
\qt@newcmd\qurantrans@es@mmmcmxliii{¿Es que no reflexionáis?\qt@no{155}}
\qt@newcmd\qurantrans@es@mmmcmxliv{¿O es que poseéis una prueba evidente?\qt@no{156}}
\qt@newcmd\qurantrans@es@mmmcmxlv{¡Traed pues vuestra Escritura si es verdad lo que decís!\qt@no{157}}
\qt@newcmd\qurantrans@es@mmmcmxlvi{Y han establecido un lazo de parentesco entre Él y los genios. Los genios saben que ellos habrán de comparecer.\qt@no{158}}
\qt@newcmd\qurantrans@es@mmmcmxlvii{Glorificado sea Dios por encima de lo que Le atribuyen,\qt@no{159}}
\qt@newcmd\qurantrans@es@mmmcmxlviii{excepto los siervos puros de Dios.\qt@no{160}}
\qt@newcmd\qurantrans@es@mmmcmxlix{Ciertamente, vosotros y lo que vosotros adoráis\qt@no{161}}
\qt@newcmd\qurantrans@es@mmmcml{no podréis extraviar a nadie\qt@no{162}}
\qt@newcmd\qurantrans@es@mmmcmli{más que a quienes arderán en el Infierno.\qt@no{163}}
\qt@newcmd\qurantrans@es@mmmcmlii{«No hay ninguno de nosotros que no ocupe su lugar determinado,\qt@no{164}}
\qt@newcmd\qurantrans@es@mmmcmliii{y, en verdad, somos nosotros los que estamos ordenados en filas\qt@no{165}}
\qt@newcmd\qurantrans@es@mmmcmliv{y, en verdad, somos nosotros quienes celebramos la gloria de Dios.»\qt@no{166}}
\qt@newcmd\qurantrans@es@mmmcmlv{En verdad, ellos siempre dicen:\qt@no{167}}
\qt@newcmd\qurantrans@es@mmmcmlvi{«Si poseyésemos un Recuerdo procedente de los primeros\qt@no{168}}
\qt@newcmd\qurantrans@es@mmmcmlvii{sólo adoraríamos a Dios.»\qt@no{169}}
\qt@newcmd\qurantrans@es@mmmcmlviii{Pero no creyeron en él y ¡Pronto van a saber!\qt@no{170}}
\qt@newcmd\qurantrans@es@mmmcmlix{Ciertamente, Nuestra promesa ya vino anteriormente a Nuestros siervos los Mensajeros:\qt@no{171}}
\qt@newcmd\qurantrans@es@mmmcmlx{«Con seguridad, ellos serán los auxiliados\qt@no{172}}
\qt@newcmd\qurantrans@es@mmmcmlxi{y, en verdad, Nuestras tropas serán las vencedoras.»\qt@no{173}}
\qt@newcmd\qurantrans@es@mmmcmlxii{Así pues, dales un plazo\qt@no{174}}
\qt@newcmd\qurantrans@es@mmmcmlxiii{y obsérvales. Pronto verán.\qt@no{175}}
\qt@newcmd\qurantrans@es@mmmcmlxiv{¿Quieren apresurar Nuestro castigo?\qt@no{176}}
\qt@newcmd\qurantrans@es@mmmcmlxv{Cuando descienda en su lugar ¡Qué mal amanecer el de quienes ya habían sido amonestados!\qt@no{177}}
\qt@newcmd\qurantrans@es@mmmcmlxvi{Así pues, ¡Apártate de ellos hasta un plazo\qt@no{178}}
\qt@newcmd\qurantrans@es@mmmcmlxvii{y observa! ¡Pronto van a ver!\qt@no{179}}
\qt@newcmd\qurantrans@es@mmmcmlxviii{¡Glorificado sea tu Señor, Señor del Poder, por encima de lo que le atribuyen!\qt@no{180}}
\qt@newcmd\qurantrans@es@mmmcmlxix{Y la paz sea con los Mensajeros\qt@no{181}}
\qt@newcmd\qurantrans@es@mmmcmlxx{y alabado sea Dios, Señor del Universo.\qt@no{182}}
\qt@newcmd\qurantrans@es@mmmcmlxxi{\basmalahes Sad. Juro por el Corán, poseedor del Recuerdo,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcmlxxii{que quienes tratan de ocultar la Verdad están en una actitud prepotente y rebelde.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcmlxxiii{¡Cuántos pueblos habremos aniquilado antes de ellos que, cuando descendió el castigo sobre ellos, imploraban a gritos, cuando ya se les había pasado el tiempo de salvarse del castigo.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcmlxxiv{Y se sorprenden de que quien venga a amonestarles sea uno de entre ellos mismos. Y dicen los que no creen: «¡Éste es un mago mentiroso!»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcmlxxv{«¿No ha puesto en lugar de los dioses a un solo Dios? ¡Eso es algo verdaderamente asombroso!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcmlxxvi{Los notables se fueron diciendo: «¡Marchaos y defended a vuestros dioses! ¡Eso es lo que debéis hacer!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcmlxxvii{¡No habíamos escuchado algo semejante en las últimas creencias! ¡Esto no es más que un invento!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcmlxxviii{¿De entre nosotros, se le ha escogido a él para hacer descender el Recuerdo?» Dudan de Mi recuerdo. ¡Todavía no han probado mi castigo!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcmlxxix{¡Acaso poseen ellos los tesoros de la misericordia de tu Señor, el Todopoderoso, el Otorgador?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcmlxxx{¿O poseen el reino de los cielos y la Tierra y de lo que hay entre ambos? Pues, entonces, que suban por ellos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcmlxxxi{¡Uno de los insignificantes ejércitos de partidos será allá derrotado!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcmlxxxii{Antes de ellos también desmintieron el pueblo de Noé y Ad y Faraón, el de las estacas,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcmlxxxiii{y Zamud y el pueblo de Lot y la gente de Al-Aika. Esos son los partidos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcmlxxxiv{Cada uno de ellos desmintió a los Mensajeros y se cumplió Mi castigo.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcmlxxxv{No les aguarda más que un solo grito y no tendrán marcha atrás.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcmlxxxvi{Ellos dicen: «¡Señor nuestro! ¡Apresura nuestra parte antes del Día de la Cuenta!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcmlxxxvii{Se paciente con lo que dicen y recuerda a Nuestro siervo David, poseedor de una gran fuerza. En verdad, el se volvía continuamente a su Señor.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcmlxxxviii{En verdad, Nosotros dispusimos que las montañas glorificasen con Él por la noche y al amanecer\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcmlxxxix{y las aves que se reunían en bandadas. Todo Le glorifica.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcmxc{Nosotros fortalecimos su reino y le dimos la sabiduría y la capacidad de discernir la verdad de las palabras.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcmxci{No ha llegado a ti la noticia de los que mantenían un contencioso y saltaron el muro del templo.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcmxcii{Cuando entraron ante David, él se sobresaltó. Ellos dijeron: «¡No temas! Somos dos partes litigantes una de las cuales ha oprimido a la otra. Juzga entre nosotros con justicia, imparcialmente, e indícanos el buen camino.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcmxciii{«En verdad, este hermano mío posee noventa y nueve ovejas pero yo sólo una oveja y me dice: ‘Déjala en mi rebaño’ y es más poderoso que yo discutiendo.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcmxciv{Él dijo: «Sí. Juro que ha sido injusto pidiéndote que juntases tu oveja con las suyas. En verdad, muchos socios se perjudican unos a otros, excepto quienes son creyentes y obran rectamente, pero pocos son así.» Y David supo que Nosotros le habíamos puesto a prueba y pidió perdón a su Señor y se inclinó arrepentido.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcmxcv{Y Nosotros le perdonamos por ello y, en verdad, él posee una posición de cercanía ante Nosotros y un buen destino.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcmxcvi{«¡Oh, David! En verdad, te hemos hecho heredero en la Tierra, así pues, juzga entre los hombres con la Verdad y no sigas tus pasiones, pues te desviarían de la senda de Dios.» En verdad, quienes se desvían de la senda de Dios sufrirán un castigo doloroso por haber olvidado el Día de la Cuenta.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcmxcvii{No hemos creado los cielos y la Tierra y lo que hay entre ambos en vano. Eso es lo que piensan quienes no son creyentes. ¡Cuidado con el Fuego los que no son creyentes!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcmxcviii{¿Vamos a tratar igual a los que creen y obran rectamente que a los que corrompen la Tierra? ¿O vamos a tratar a quienes son temerosos de Dios como a los pecadores?\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcmxcix{Esta es una Escritura bendita que Nosotros hacemos descender a ti para que mediten sobres sus signos y para que las gentes de entendimiento reflexionen.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmm{Y otorgamos Salomón a David. ¡Qué bendición de siervo! ¡Ciertamente, él era un alma volcada a su Señor!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmi{[Recuerda] Cuando le mostraron al final del día unos hermosos caballos de carreras\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmii{y dijo: «En verdad, he amado más las cosas bellas que el recuerdo de mi Señor y el Sol se ha ocultado.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmiii{Haced que vuelva atrás para mí y pasad vuestras manos por los pies y el cuello.»\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmiv{Y pusimos a prueba a Salomón y colocamos un cuerpo sin vida en su trono. Entonces, se volvió hacia su Señor contrito.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmv{Dijo: «¡Señor mío! ¡Perdóname y otórgame un reino que no sea adecuado para nadie después de mí! ¡En verdad, Tú eres el Otorgador!»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmvi{Y sometimos los vientos a él, que soplaban suavemente por orden suya donde él quería.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmvii{Y a los demonios, que construían y buceaban para él.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmviii{Y al resto los encadenamos.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmix{«¡Esto es un don de Nuestra parte! Así pues, da de él o restríngelo sin limitaciones.»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmx{En verdad, él posee junto a Nosotros cercanía y un buen lugar de retorno.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmxi{Y recuerda a Nuestro siervo Job, cuando invocó a su Señor: «El demonio me ha tocado con desgracia y castigo.»\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmxii{«¡Golpea con tu pie! Ahí tienes agua fresca para lavarte y beber.»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmxiii{Y le otorgamos a su familia y otro tanto como una misericordia procedente de Nosotros y como un recuerdo para los dotados de entendimiento.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmxiv{«Toma un puñado de ramas y golpea con él y no rompas tu promesa.» En verdad encontramos que era paciente. ¡Qué bendición de siervo! ¡En verdad, él era un alma volcada a su Señor!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmxv{Y recuerda a Nuestros siervos Abraham, Isaac y Jacob. Eran fuertes y clarividentes en su adoración\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmxvi{Les escogimos por causa de su pura dedicación al recuerdo de la morada\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmxvii{y, en verdad, ellos son, ante Nosotros, de los escogidos entre los buenos.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmxviii{Y recuerda a Ismael, a Eliseo y a Du l-Kifl, todos ellos eran de los mejores.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmxix{Este es un recuerdo. Y, en verdad, para los temerosos de Dios hay un buen destino:\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmxx{los Jardines del Edén, cuyas puertas estarán abiertas para ellos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmxxi{Reclinados en ellos, pedirán de las frutas y bebidas abundantes.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmxxii{Junto a ellos, esposas que sólo a ellos mirarán, de su misma edad y belleza.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmxxiii{«¡Esto es lo que se os había prometido para el Día de la Cuenta!»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmxxiv{«¡En verdad, ésta es Nuestra provisión inagotable!»\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmxxv{Así es. Y, en verdad, los rebeldes tendrán un mal destino.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmxxvi{El Infierno en el que arderán. ¡Qué mal lugar de reposo!\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmxxvii{Así es. ¡Que lo prueben! ¡Agua hirviente y pus\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmxxviii{y otras cosas semejantes!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmxxix{«¡Ese es otro grupo condenado con vosotros!» «No hay bienvenida para ellos. En verdad, arderán en el Fuego.»\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmxxx{Ellos dirán: «¡Tampoco para vosotros hay bienvenida! ¡Vosotros preparasteis esto para nosotros! ¡Qué mal lugar!»\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmxxxi{Ellos dirán: «¡Señor nuestro! ¿A quien preparó esto para nosotros dóblale el castigo en el Fuego!»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmxxxii{Dirán: «¿Qué nos pasa que no vemos a hombres a los que considerábamos de lo peor?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmxxxiii{¿Nos burlábamos de ellos o es que no les podemos ver?»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmxxxiv{Ciertamente, esa es la verdad de lo que discutirá la gente del Fuego.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmxxxv{Di: «Lo que yo soy es un amonestador y no hay más dioses que Dios, el Uno, el Dominador.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmxxxvi{El Señor de los cielos y la Tierra y de lo que hay entre ambos, el Todopoderoso, el Perdonador.»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmxxxvii{Di: «Es una gran noticia\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmxxxviii{de la que vosotros os desentendéis.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmxxxix{Yo no tenía conocimiento de lo que en el Consejo Supremo discutían.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmxl{Sólo me ha sido revelado que yo soy un amonestador claro.»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmxli{[Recuerda] Cuando tu Señor dijo a los ángeles: «En verdad, crearé un ser humano de barro.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmxlii{Así pues, cuando le haya dado forma y sople en él de Mi espíritu, prosternaos ante él.»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmxliii{Así que todos los ángeles se prosternaron\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmxliv{excepto Iblís, que se ensoberbeció y fue de los que tratan de ocultar la Verdad.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmxlv{Dijo Él: «¡Oh, Iblís! ¿Qué te impidió prosternarte ante lo que Yo he creado con mis manos? ¿Te consideras demasiado grande o eres de los que están por encima de ello?»\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmxlvi{Dijo: «Yo soy mejor que él. A mí me creaste de fuego y a él le has creado de barro.»\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmxlvii{Dijo Él: «Pues entonces ¡Sal de él! En verdad eres de los maldecidos.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmxlviii{Y, en verdad, Mi maldición pesará sobre ti hasta el Día de la Recompensa.»\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmxlix{Dijo: «¡Señor mío! ¡Dame de plazo hasta el día en que los resucites!»\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmml{Dijo Él: «Sé, pues, de los que tienen un plazo\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmli{hasta el día cuyo tiempo está determinado.»\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmlii{Dijo: «Juro, pues, por Tu poder, que extraviaré a todos ellos\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmliii{a excepción de quienes entre ellos sean tus siervos puros.»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmliv{Dijo Él: «La verdad -y lo que Yo digo es siempre la verdad-\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmlv{es que llenaré el Infierno contigo y con todos los que te sigan.»\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmlvi{Di: «No os pido recompensa por ello y no soy de los que tratan de imponerse sobre los demás.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmlvii{Esto no es más que un recuerdo para todo el Universo.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmlviii{Y, sin duda, sabréis lo que anuncia cuando llegue el plazo señalado.»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmlix{\basmalahes Ésta es la Escritura que desciende gradualmente parte de Dios, el Todopoderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmlx{En verdad, hemos hecho descender a ti la Escritura que dice la Verdad, por tanto, adora a Dios con una creencia pura, volcada únicamente a Él.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmlxi{¿Acaso la adoración no debe ser para Dios únicamente? Y a quienes toman protectores aparte de Él diciendo: «No los adoramos sino para que nos aproximen a Dios», en verdad, Dios les juzgará sobre aquello en lo que disentían. En verdad, Dios no guía a quien es mentiroso y trata de ocultar la Verdad.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmlxii{Si Dios hubiera querido tomar un hijo, podría haber elegido lo que hubiese querido de lo que Él ha creado. ¡Glorificado sea! ¡El es Dios, el Uno, el Dominador!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmlxiii{Él ha creado los cielos y la Tierra con la Verdad. Él hace que la noche cubra al día y que el día cubra a la noche. Y somete el Sol y la Luna. Cada uno fluye en su curso el tiempo establecido. ¿No es Él el Todopoderoso, el Perdonador?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmlxiv{Él os ha creado de una sola alma, luego ha hecho de ella a su pareja. E hizo descender para vosotros ocho pares de reses. Él os crea en el seno de vuestras madres, creación tras creación, en una triple oscuridad. Ese es Dios vuestro Señor. A Él pertenece el reino. No hay más dioses que Él ¿Cómo entonces cambiáis?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmlxv{Si sois desagradecidos, [sabed que] en verdad, Dios es rico por Sí mismo, no necesita de vosotros y no Le satisface que sus siervos sean desagradecidos. Y si sois agradecidos, Él estará satisfecho de que seáis así. Nadie cargará con la carga de otro. Luego, vuestro lugar de regreso será Dios y Él os informará de lo que hacíais. En verdad, Él sabe bien lo que hay en el fondo de los corazones.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmlxvi{Cuando al ser humano le aflige una desgracia invoca a su Señor, volviéndose a Él contrito. Luego, cuando le llega un favor procedente de Él, olvida lo que Le imploraba anteriormente y pone semejantes junto a Dios, desviando a otros de Su camino. Di: «Disfruta de tu alejamiento de Dios un poco. En verdad, tú eres de la gente del Fuego.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmlxvii{¿Acaso quien adora en mitad de la noche prosternado y en pie, temeroso del castigo en la otra vida y esperando la misericordia de su Señor…? Di: «¿Acaso son iguales el que sabe y el que no sabe?» En verdad, sólo se deja amonestar la gente dotada de entendimiento.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmlxviii{Di: «¡Oh, siervos Míos creyentes! ¡Sed temerosos de vuestro Señor! Quienes hagan el bien en este mundo obtendrán el bien.» «Y la Tierra de Dios es amplia. En verdad, Él concederá a los pacientes su recompensa sin medida.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmlxix{Di: «En verdad, me ha sido ordenado que adore a Dios con una creencia pura, volcada únicamente a Él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmlxx{Y me ha sido ordenado que sea el primero de los que se someten a Él.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmlxxi{Di: «En verdad, temo, si desobedezco a mi Señor, el castigo de un día inmenso.»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmlxxii{Di: «Adoro a Dios con una creencia pura, volcada únicamente a Él.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmlxxiii{Así pues, adorad lo que queráis aparte de Él.» Di: «En verdad, los perdedores son quienes se pierden a sí mismos y a su familia el Día del Levantamiento.» ¿No es esa acaso la pérdida evidente?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmlxxiv{Las sombras del Fuego les cubrirán por encima y por debajo. Así es como Dios atemoriza a Sus siervos. «¡Oh, siervos Míos! ¡Sed, pues, temerosos de Dios!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmlxxv{Para quienes se abstienen de adorar a los ídolos y a los falsos dioses y se vuelven arrepentidos hacia Dios hay una buena noticia. Da, pues, la buena noticia a Mis siervos,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmlxxvi{aquellos que escuchan la Palabra y siguen la excelencia que en ella hay. Esos son a quienes Dios guía y ellos son los dotados de entendimiento.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmlxxvii{¿Acaso aquellos en quienes se cumpla la promesa del castigo…? ¿Podrás tú rescatar a quienes están en el Fuego?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmlxxviii{Pero, quienes son temerosos de su Señor, tendrán aposentos elevados sobre los que hay construidos otros aposentos y bajo los cuales fluirán los arroyos. Promesa de Dios. Dios no incumple su promesa.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmlxxix{¿Acaso no has visto cómo Dios hace descender agua del cielo y la conduce bajo tierra y crea fuentes y luego hace surgir con ella cosechas de variados colores, que después se marchitan y ves como se tornan amarillas y las hace quebradizas? En verdad, en ello hay un motivo de reflexión para los dotados de entendimiento.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmlxxx{¿Acaso aquel a quien Dios ha expandido su pecho para que acepte el Islam y por tanto está sobre una luz que procede de su Señor…? ¡Ay de quienes tienen sus corazones endurecidos para el recuerdo de Dios! ¡Ellos están en un extravío evidente!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmlxxxi{Dios ha hecho descender la mejor de las palabras. Una Escritura cuyas partes se armonizan y explican unas a otras. Con ella se estremecen quienes son temerosos de su Señor. Luego, sus cuerpos y sus corazones se calman y enternecen por el recuerdo de Dios. ¡Esa es la guía de Dios, mediante la que guía a quien Él quiere! Y a quien Dios extravía, no hay quien pueda guiarle.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmlxxxii{¿Acaso quien en este mundo y por medio de su temor de Dios se protege del castigo del Día del Levantamiento…? Y se dirá a los opresores: «¡Probad lo que habéis obtenido!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmlxxxiii{Quienes vivieron antes de ellos desmintieron y el castigo les alcanzó cuándo y de dónde menos se lo esperaban.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmlxxxiv{Dios les hizo probar la humillación en esta vida. Y si ellos supieran que el castigo de la otra es mayor…\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmlxxxv{En verdad, hemos puesto a los seres humanos, en este Corán, toda clase de ejemplos, para que, quizás así, reflexionen.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmlxxxvi{Es un Corán en árabe, sin desviaciones ni ambigüedades, para que, quizás así, sean temerosos.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmlxxxvii{Dios pone el ejemplo de una persona que pertenece a unos socios que no se ponen de acuerdo entre ellos y otra persona que pertenece a un solo amo ¿Son ambos iguales? ¡Alabado sea Dios! Pero la mayoría de ellos no saben.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmlxxxviii{En verdad, tú morirás y ellos morirán.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmlxxxix{Luego, el Día del Levantamiento, argumentaréis cada uno ante vuestro Señor.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmxc{¿Quién, pues, es más opresor que quien miente sobre Dios y desmiente la Verdad cuando ésta llega a él? ¿Acaso no es el Infierno el lugar para quienes tratan de ocultar la Verdad?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmxci{Y quien viene con la Verdad y quien la reconoce y confirma, esos son los temerosos de Dios.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmxcii{Ellos tienen lo que quieran junto a su Señor. Esa es la recompensa de quienes hacen lo mejor.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmxciii{Dios ocultará lo peor de lo que ellos hicieron y les recompensará con la recompensa que merezca lo mejor de lo que hacían.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmxciv{¿No es Dios suficiente para Su siervo? ¡Y tratan de asustarte con los que no son Él! A quien Dios extravía no hay quien le guíe\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmxcv{y a quien Dios guía no hay quien pueda extraviarle. ¿Acaso Dios no es todopoderoso, dueño de la venganza?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmxcvi{Y si les preguntases: «¿Quién ha creado los cielos y la Tierra?» dirían: «Dios». Di: «¿Habéis visto, pues, si aquellos a quienes adoráis en lugar de Dios, en caso de que Dios quisiera un perjuicio para mí, podrían evitarlo?, o si quisiera para mí un beneficio ¿Podrían ellos impedirlo?» Di: «¡Dios es suficiente para mí! ¡Es en Él en Quien ponen su confianza quienes ponen su confianza en la Verdad!»\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmxcvii{Di: «¡Oh, pueblo mío! Continuad en vuestras posiciones que yo también continuaré en las mías. Y pronto sabréis\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmxcviii{quién está condenado al fuego que le devorará y sobre quién se ha hecho lícito el castigo eterno.»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmxcix{En verdad, Nosotros hacemos descender para la gente la Escritura con la Verdad. Así pues, quien se guíe, para sí mismo lo hace y quien se extravíe, a sí mismo se extravía y tú no eres su protector.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmc{Dios recoge las almas cuando les llega la muerte y las de quienes no han muerto cuando duermen. Y toma aquella sobre la que ha sido decretada la muerte y envía las otras para que permanezcan hasta un plazo establecido. En verdad, en ello hay señales para la gente que reflexiona.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmci{«¿Vais a tomar otros intercesores aparte de Dios?» Di: «¿Aunque no tengan poder alguno y no razonen?»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcii{Di: «Toda la intercesión pertenece a Dios. A Él pertenecen los cielos y la Tierra y luego regresaréis hacia Él.»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmciii{Y cuando es recordado Dios en Su unicidad, los corazones de quienes no creen en la otra vida se contraen de disgusto y aversión. Y cuando se menciona a los que no son Él, se refleja en sus rostros la felicidad y satisfacción que ello les proporciona.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmciv{Di: «¡Oh, Dios mío! ¡Originador de los cielos y la Tierra! ¡Conocedor de lo que está oculto a los sentidos y lo que está manifiesto! ¡Tú juzgarás entre Tus siervos sobre aquello en lo que disentían!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcv{Si los opresores, que niegan la otra vida, tuvieran de nuevo todo lo que poseían en la Tierra y otro tanto, lo darían para librarse del castigo del Día del Levantamiento. Y se manifestará para ellos, de parte de Dios, aquello con lo que no contaban.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcvi{Y se les hará evidente el mal que realizaron y se verificará para ellos aquello de lo que se burlaban.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcvii{Y, cuando al ser humano le toca un mal, Nos invoca suplicante. Pero cuando hacemos que le llegue un beneficio que procede de Nosotros, dice: «En verdad, lo he obtenido gracias a mi inteligencia.» Pero, en realidad, es una prueba, aunque la mayoría de ellos no saben.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcviii{Eso mismo decían quienes vinieron antes de ellos. Pero nada de lo que obtuvieron les benefició\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcix{y pronto les alcanzó el castigo por el mal que hicieron. Y, quienes de ellos hayan sido opresores, pronto sufrirán el mal que hicieron y no podrán escapar del castigo de Dios.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcx{¿Acaso no saben que Dios incrementa la provisión de quien Él quiere o la disminuye? En verdad, en ello hay señales para gente que tiene fe.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcxi{Di: «¡Oh, siervos Míos que os habéis excedido con vosotros mismos! ¡No desesperéis de la misericordia de Dios! ¡En verdad, Dios perdona todos los pecados! En verdad, Él es el Perdonador, el Misericordiosísimo.»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcxii{Y volveos a vuestro Señor y someteos a Él antes de que llegue a vosotros el castigo. Luego no seréis auxiliados.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcxiii{Y seguid lo mejor de lo que ha descendido a vosotros procedente de vuestro Señor antes de que llegue a vosotros el castigo repentinamente, sin que vosotros os deis cuenta.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcxiv{y cada cual se diga a sí mismo: «¡Ay de mí por mi negligencia con Dios! ¡En verdad, yo era de los que se burlaban.»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcxv{O diga: «Si Dios me hubiera guiado habría sido de los temerosos.»\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcxvi{O diga cuando vea el castigo: «Si tuviera otra oportunidad sería de los que hacen el bien.»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcxvii{Sí. Vinieron a ti Mis señales pero las desmentiste y te mostraste altivo y fuiste de los que tratan de ocultar la Verdad.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcxviii{Y el Día del Levantamiento verás que los rostros de quienes dijeron mentiras sobre Dios se ennegrecen. ¿Acaso no hay un lugar en el Infierno para los arrogantes?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcxix{Y Dios salvará a quienes fueron temerosos dándoles el éxito. El mal no les tocará y no estarán tristes.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcxx{Dios es el Creador de toda cosa y Él cuida de todo.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcxxi{A Él pertenecen las llaves de los cielos y la Tierra. Y, quienes tratan de ocultar las señales de Dios, esos son los perdedores.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcxxii{Di: «¿Me ordenáis que adore a otro distinto que Dios ¡Oh, ignorantes!?»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcxxiii{Y, ciertamente, juro que fue revelado, a ti y a quienes vinieron antes de ti, que si adoras a otros dioses invalidarás tus obras y serás de los perdedores.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcxxiv{Así pues, adora a Dios y se de los agradecidos.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcxxv{No han valorado a Dios en Su verdadera magnitud. Y toda la Tierra estará en su puño el Día del Levantamiento y los cielos estarán enrollados en Su mano derecha. ¡Glorificado sea y ensalzado por encima de lo que Le asocian!\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcxxvi{Será soplada la trompeta y morirán quienes están en los cielos y en la Tierra, excepto quien Dios quiera. Luego, se soplará en ella otra vez y se pondrán en pie expectantes.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcxxvii{Y se iluminará la Tierra por la Luz de su Señor y se expondrá la escritura y se hará comparecer a los profetas y a los testigos y se juzgará entre ellos con la Verdad y nadie será oprimido.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcxxviii{Y cada alma recibirá la recompensa de lo que haya hecho. Y Él es Quien mejor sabe lo que hicieron.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcxxix{Y quienes negaban la Verdad serán conducidos al Infierno en grupos y cuando lleguen a él se abrirán sus puertas y sus ángeles les dirán: «¿Acaso no vinieron a vosotros Mensajeros de entre vosotros mismos que os recitaron las señales de vuestro Señor y os amonestaron con el encuentro de éste vuestro día?» Dirán: «Sí, pero…» Y se verificará la promesa del castigo sobre quienes no quisieron creer.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcxxx{Se les dirá: «¡Entrad por las puertas del Infierno en el que permaneceréis eternamente!» ¡Qué mal lugar el destinado a los arrogantes!\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcxxxi{Y quienes fueron temerosos de su Señor serán conducidos al Jardín en grupos y cuando lleguen a él se abrirán sus puertas y sus ángeles les dirán: «¡Paz sobre vosotros! ¡Fuisteis buenos! ¡Entrad, pues, en él para siempre!»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcxxxii{Y ellos dirán: «¡Alabado sea Dios, que ha hecho realidad Su promesa y nos hizo heredar la Tierra para que nos establezcamos en el Jardín donde queramos!» ¡Qué buena la recompensa de los que actuaron bien!\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcxxxiii{Y verás a los ángeles alrededor del Trono divino, celebrando a su Señor con alabanzas. Se juzgará entre ellos con la Verdad y se dirá: «¡Alabado sea Dios, Señor del Universo!»\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcxxxiv{\basmalahes Ha, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcxxxv{El descenso de la Escritura proviene de Dios, el Todopoderoso, el Sabio,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcxxxvi{perdonador del pecado, aceptador del arrepentimiento, severo en el castigo, favorecedor duradero. No hay más dios que Él y a Él es el regreso.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcxxxvii{No discuten las señales de Dios más que quienes tratan de ocultar la Verdad. ¡Que no te engañe la facilidad con que se desenvuelven por el país!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcxxxviii{Antes de ellos desmintió el pueblo de Noé y después de él los partidos. Y todas las comunidades hicieron planes para capturar a su Mensajero y discutieron vanamente para destruir con ello la Verdad. Pero les atrapé y ¡Cómo fue Mi castigo!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcxxxix{Y así se cumplió la palabra de tu Señor sobre aquellos que tratan de ocultar la verdad de que serían la gente del Fuego.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcxl{Quienes portan el Trono divino y quienes están alrededor de él celebran a su Señor con alabanzas y creen en Él y le piden que perdone a quienes son creyentes: «¡Señor nuestro! Tú todo lo abarcas con Tu misericordia y Tu conocimiento. Perdona, pues, a quienes se vuelven a Ti arrepentidos y a quienes siguen Tu senda y líbrales del castigo del Infierno.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcxli{«¡Señor nuestro! Hazles entrar en los Jardines del Edén que les habías prometido a ellos y a quienes de sus padres, parejas y descendientes, fueran rectos. En verdad, Tú eres el Todopoderoso, el Sabio.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcxlii{«¡Líbrales del mal! Habrás bendecido con Tu misericordia a quien hayas protegido del mal de ese día. ¡Ese es el triunfo inmenso!»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcxliii{En verdad, a quienes tratan de ocultar la Verdad se les dirá: «La ira de Dios con vosotros es mayor que vuestra propia ira contra vosotros mismos cuando fuisteis llamados a tener fe y no creísteis.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcxliv{Dirán: «¡Señor nuestro! Nos has hecho morir dos veces y nos has dado la vida dos veces. Admitimos nuestros pecados. ¿Hay un camino para salir?»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcxlv{«Esto os sucede porque, cuando se invocaba a Dios en Su unicidad no creíais, pero cuando se Le asociaban otros falsos dioses creíais.» Así pues, el juicio pertenece a Dios, el Altísimo, el Más grande.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcxlvi{Él es Quien os muestra Sus señales y hace que descienda del cielo la provisión para vosotros. Pero solamente reflexionan quienes se vuelven a Él con contrición.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcxlvii{Por tanto ¡Volveos a Dios poniendo vuestra fe únicamente en Él, aunque ello moleste a los que tratan de ocultar la Verdad!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcxlviii{Él es Quien eleva los grados, el Señor del Trono. Él hace descender el Espíritu que procede de Su mandato sobre quien Él quiere de Sus siervos para que advierta del Día del Encuentro.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcxlix{El día en que todos surjan y nada de ellos se oculte a Dios. ¿A quién pertenece la soberanía ese día? A Dios, el Uno, el Victorioso.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcl{«Hoy cada alma recibirá la recompensa por lo que hizo. Hoy no hay opresión. En verdad, Dios es rápido haciendo la cuenta.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcli{Así pues, adviérteles del Día Inminente, cuando los corazones se suban a las gargantas a causa de la angustia. Los opresores no tendrán amigo ni intercesor aceptado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmclii{Él conoce la traición de los ojos y lo que ocultan los pechos.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcliii{Y Dios juzga con la Verdad y quienes ellos invocan en lugar de Él no tienen poder para juzgar nada. En verdad, Dios es Quien todo lo oye, Quien todo lo ve.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcliv{¿Acaso no han viajado por la Tierra y han observado cuál fue el final de quienes vivieron antes de ellos? Tuvieron más poder que ellos y dejaron más huellas en la Tierra, pero Dios se apoderó de ellos por sus pecados y no tuvieron quien les protegiera de Dios.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmclv{Eso fue porque vinieron a ellos sus Mensajeros con las pruebas claras y no creyeron en ellas, por eso Dios se apoderó de ellos. En verdad, Él es fuerte, severo en el castigo.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmclvi{Y, ciertamente, Nosotros enviamos a Moisés con Nuestras pruebas claras y una autoridad evidente\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmclvii{al Faraón, a Hamam y a Qarun, pero dijeron: «¡Es un mago! ¡Un mentiroso!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmclviii{Así pues, cuando llegaron a ellos con la Verdad procedente de Nosotros, dijeron: «¡Matad a los hijos de los creyentes que están con él y dejad con vida a sus mujeres!» Pero los planes de quienes trataban de ocultar la Verdad no tuvieron éxito.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmclix{Y dijo el Faraón: «¡Dejadme que mate a Moisés! ¡Y que él invoque a su Señor! En verdad, temo que cambie vuestras creencias o que haga surgir la corrupción en la Tierra.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmclx{Y Moisés dijo: «Me refugio en mi Señor y vuestro Señor de todo arrogante que no crea en el Día de la Cuenta.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmclxi{Y un hombre creyente de la gente del Faraón que ocultaba su fe dijo: «¿Vais a matar a un re por decir: Mi señor es Dios, y que ha venido a vosotros con las pruebas claras procedentes de vuestro Señor?» «Y si es mentiroso su mentirá recaerá sobre él y si es sincero sufriréis algunas de las cosas con que os amenaza. En verdad, Dios no guía a quien es inmoderado, mentiroso.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmclxii{«¡Oh, pueblo mío! Hoy el reino os pertenece a vosotros y vosotros domináis la Tierra, pero ¿Quién nos auxiliará del castigo de Dios si viene a nosotros?» El Faraón dijo: «No os muestro más que lo que yo veo y no os guío más que al camino de la rectitud.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmclxiii{El que creía dijo: «¡Oh pueblo mío! Temo para vosotros algo semejante al día de los partidos.”\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmclxiv{Semejante al castigo del pueblo de Noé y de Ad y de Zamud y de los que vinieron tras ellos. Y Dios no desea oprimir a Sus siervos.»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmclxv{«Y ¡Oh, pueblo mío! En verdad, temo para vosotros el Día del Griterío.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmclxvi{El día en que trataréis de huir y no tendréis quien os proteja de Dios. Y a quien Dios extravía no hay nadie que pueda guiarle.»\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmclxvii{«Y, ciertamente, vino a vosotros José anteriormente con las pruebas claras, pero siempre dudasteis de lo que os trajo, hasta que, cuando murió, dijisteis: Dios no enviará después de él ningún otro Mensajero.» Así es como Dios extravía a quien es inmoderado, escéptico.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmclxviii{Aquellos que discuten las señales de Dios sin que les haya sido concedida ninguna autoridad. Eso es muy detestable para Dios y para quienes son creyentes. Así es como Dios sella el corazón de todo el que es arrogante, prepotente.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmclxix{Y Faraón dijo: «¡Oh, Haman! Construye para mí una alta torre, quizás así pueda alcanzar los caminos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmclxx{Los caminos de los cielos, y pueda echar un vistazo al dios de Moisés. Aunque, en verdad, pienso que es un mentiroso.» Así es como aparecían adornados ante el Faraón sus malos actos y fue apartado del camino. Y los planes del Faraón sólo obtuvieron el fracaso.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmclxxi{Y el que creía dijo: «¡Oh, pueblo mío! ¡Seguidme! ¡Yo os guiaré al camino de la rectitud!\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmclxxii{¡Oh, pueblo mío! En verdad, la vida de este mundo es un disfrute que tiene un plazo limitado y la otra vida es la casa de la permanencia.»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmclxxiii{A quien haya cometido un mal no se le recompensará más que con algo semejante y quienes hayan hecho un bien, hombre o mujer, y sean creyentes, entrarán en el Jardín y allí se les recompensará sin medida.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmclxxiv{«Y ¡Oh pueblo mío! ¿Cómo es que yo os invito a la salvación y vosotros me invitáis al Fuego?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmclxxv{Me invitáis a que no crea en Dios y a que asocie a Él aquello de lo que no tengo conocimiento, mientras que yo os invito al Todopoderoso, al Perdonador.»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmclxxvi{«Es evidente que aquello a lo que me invitáis no tiene poder de convocatoria ni en esta vida ni en la Otra y que regresaremos a Dios y que los inmoderados son gente del Fuego.»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmclxxvii{«Entonces recordaréis lo que ahora os digo, mientras que yo he confiado mis asuntos a Dios. En verdad, Dios ve el estado de Sus siervos.»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmclxxviii{Dios le protegió del daño de lo que ellos tramaron y confirmó el castigo para la gente del Faraón:\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmclxxix{el fuego al que se verán siempre expuestos, mañana y tarde. Y el día en que llegue la Hora: «¡Haced entrar a la gente del Faraón en lo más severo del castigo!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmclxxx{Y cuando estén discutiendo en el Fuego, los débiles dirán a los arrogantes: «En verdad, fuimos vuestros seguidores. ¿Soportaréis por nosotros una parte del Fuego?»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmclxxxi{Los arrogantes dirán: «En verdad, estamos todos en él. En verdad, Dios ha juzgado entre Sus siervos.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmclxxxii{Y los que estén en el Fuego dirán a los guardianes del Infierno: «¡Invocad a vuestro Señor para que nos reduzca un día del castigo!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmclxxxiii{Ellos dirán: «¿No vinieron a vosotros vuestros Mensajeros con las pruebas claras?» Ellos dirán: «Sí.» Ellos dirán: «Pues entonces, invocad vosotros mismos» Pero lo que invoquen los que no creyeron será en vano.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmclxxxiv{En verdad, Nosotros auxiliaremos a Nuestros Mensajeros y a quienes tuvieron fe, en esta vida y en el día en el que se pongan en pie los testigos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmclxxxv{El día en que de nada sirvan a los opresores sus excusas y sean maldecidos y estén en la mala morada.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmclxxxvi{Y, ciertamente, dimos a Moisés la guía e hicimos que los Hijos de Israel heredasen la Escritura,\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmclxxxvii{guía y recuerdo para la gente de entendimiento.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmclxxxviii{Así pues, ten paciencia, pues la promesa de Dios es verdadera. Y pide perdón por tus pecados y celebra con alabanzas a tu Señor al atardecer y al amanecer.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmclxxxix{En verdad, quienes discuten sobre las señales de Dios sin que haya venido a ellos ninguna autoridad, en sus pechos sólo tienen arrogancia. Nunca conseguirán sus propósitos. Buscad, pues, la protección de Dios. En verdad, Él es Quien todo lo oye, Quien todo lo ve.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcxc{Ciertamente, la creación de los cielos y la Tierra es más grande que la creación del ser humano, pero la mayoría de la gente lo desconoce.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcxci{Y no son lo mismo el ciego y el que ve, ni quienes son creyentes y realizan buenas acciones y quienes obran mal. ¡Qué poco es lo que reflexionáis!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcxcii{En verdad, la Hora llegará. No hay duda en ello. Pero la mayoría de ellos no creen.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcxciii{Y vuestro Señor dice: «Invocadme y Yo os contestaré. En verdad, quienes se muestran arrogantes ante su obligación de adorarme pronto entrarán en el Infierno humillados.»\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcxciv{Dios es Quien ha puesto para vosotros la noche para que descanséis en ella y el día para que podáis ver. En verdad, Dios es Quien posee el poder de favorecer a las personas, pero la mayoría de las personas no lo agradecen.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcxcv{Ese es Dios vuestro Señor. Creador de todas las cosas. No hay más dios que Él. ¿Cómo entonces os desviáis?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcxcvi{Así fue como se desviaron quienes rechazaban las señales de Dios.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcxcvii{Dios es Quien ha puesto para vosotros la Tierra como un lugar en el que vivir y el cielo como una cúpula y Quien os ha dado forma, la mejor de las formas, y os ha proporcionado todas las cosas buenas. Ese es Dios vuestro Señor. Así pues ¡Bendito sea Dios, Señor del Universo!\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcxcviii{Él es el Vivo. No hay más dios que Él. Así pues ¡Invocadle con una fe volcada solamente a Él! ¡Alabado sea Dios, Señor del Universo!\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcxcix{Di: «Se me ha prohibido adorar aquello que vosotros adoráis en lugar de Dios, pues han venido a mí las pruebas claras procedentes de mi Señor y me ha sido ordenado que me someta al Señor del Universo.»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcc{Él es Quien os ha creado de tierra, luego de una gota, luego de algo suspendido, luego os hace nacer infantes, luego os hace alcanzar la madurez, luego que seáis ancianos -aunque algunos morís antes- hasta que alcanzáis el plazo señalado, para que, quizá así, razonéis.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcci{Él es Quien da la vida y da la muerte y, cuando decreta algo, le dice: «¡Sé!» y ello es.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmccii{¿No has visto que quienes discuten las señales de Dios se desvían?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcciii{Son aquellos que desmienten la Escritura y aquello con lo que enviamos a Nuestros Mensajeros. Pero ¡Pronto van a saber!\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcciv{Cuando, con argollas en sus cuellos y encadenados, sean arrastrados\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmccv{al agua hirviente y luego ardan en el Fuego.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmccvi{Entonces se les dirá: «¿Dónde está aquello que adorabais como si fuera Dios\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmccvii{en lugar de Dios?» Ellos dirán: «Se han apartado de nosotros. Aunque, lo que invocábamos antes no era nada.» Así es como Dios extravía a quienes tratan de ocultar la Verdad.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmccviii{«¡Esto es por lo que os regocijabais en la Tierra sin derecho y por vuestra exultante arrogancia!\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmccix{¡Entrad por las puertas del Infierno en el que permaneceréis eternamente!» ¡Qué mala estancia la de los arrogantes!\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmccx{Así pues ¡Se paciente! En verdad, la promesa de Dios es verdadera. Así que, o bien te mostraremos parte de aquello que les hemos prometido o bien te haremos morir antes, pero ellos volverán a Nosotros.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmccxi{En verdad, antes de ti habíamos enviado Mensajeros. De algunos de ellos te hemos hablado y de otros no te hemos hablado, pero ningún Mensajero viene con una señal sino es con el permiso de Dios. Así pues, cuando llegue la orden de Dios, se juzgará conforme a la Verdad y, entonces, los perdedores serán quienes falseaban la realidad.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmccxii{Dios es Quien ha creado para vosotros los ganados para que montéis en ellos y para que comáis de ellos.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmccxiii{En ellos hay beneficio para vosotros y con ellos podéis satisfacer las necesidades que guardáis en vuestros pechos. Y sois llevados sobre ellos y sobre los barcos.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmccxiv{Así os muestra Sus señales ¿Cuál, pues, de las señales de Dios negaréis?\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmccxv{¿Acaso no viajan por la Tierra y ven cual ha sido el final de quienes existieron antes de ellos? Eran más que ellos y poseían más fuerza y dejaron más huellas en la Tierra, pero de nada les sirvió lo que obtuvieron.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmccxvi{Cuando llegaron a ellos sus Mensajeros con las pruebas claras, ellos se sintieron satisfechos del conocimiento que poseían. Pero se verificó sobre ellos aquello de lo que se burlaban.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmccxvii{Y cuando vean Nuestro castigo dirán: «¡Creemos en Dios y sólo en Él y renegamos de aquello que asociábamos a Él!»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmccxviii{Pero, una vez que hayan visto Mi castigo, su fe no les servirá de nada. Esa es la manera en que Dios ha tratado a Sus siervos en el pasado. Ahí es cuando pierden quienes trataron de ocultar la Verdad.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmccxix{\basmalahes Ha, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmccxx{Desciende del Clementísimo, el Misericordiosísimo\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmccxxi{una Escritura cuyos versículos han sido explicados detalladamente. Una recitación en árabe para una gente que posee conocimiento,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmccxxii{portadora de buenas nuevas y de amonestación. Pero la mayoría de ellos se alejan y no escuchan.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmccxxiii{Y dicen: «Nuestros corazones están velados de aquello a lo que nos invitas, nuestros oídos están sordos y hay una barrera entre nosotros y tú. Así pues, ¡Actúa que nosotros también actuaremos!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmccxxiv{Di: «En verdad, yo soy un ser humano como vosotros. Me ha sido revelado que vuestro dios es un dios único. Dirigíos, pues, hacia Él y pedidle perdón y ¡Ay de quienes adoran falsos dioses!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmccxxv{Esos que no dan la limosna purificadora de la riqueza y niegan la existencia de la otra vida.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmccxxvi{En verdad, quienes creen y hacen buenas obras tendrán una recompensa ilimitada.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmccxxvii{Di: «¿No vais a creer en Quien ha creado la Tierra en dos días y vais a poner junto a Él semejantes? Ese es el Señor del Universo.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmccxxviii{«Y, en cuatro días, ha puesto en lo alto de ella firmes montañas y la ha bendecido y ha decretado sus variados alimentos, en igualdad para todos los que los necesitan.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmccxxix{«Luego, se ha dirigido a los cielos que eran humo y les ha dicho a ellos y a la Tierra: Venid a Mí de buen grado o a la fuerza. Y ellos han dicho: Venimos de buen grado.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmccxxx{«Y los separó en siete cielos en dos días y reveló a cada cielo su función.» Y adornamos el cielo de este mundo con lámparas y lo protegimos. Ese es el decreto del Todopoderoso, el Sabio.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmccxxxi{Y si se alejan de ti, di: «Os he advertido de una destrucción similar a la destrucción de Ad y Zamud.»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmccxxxii{Cuando vinieron a ellos los Mensajeros diciéndoles por delante y por detrás: «No adoréis más que a Dios.» Ellos dijeron. «Si nuestro Señor hubiese querido habría hecho descender ángeles. En verdad, no creemos en aquello con lo que habéis sido enviados.»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmccxxxiii{En cuanto a los Ad, fueron arrogantes en la Tierra sin derecho y dijeron: «¿Quién es más fuerte que nosotros?» ¿Es que no veían que Dios, que les había creado, era más fuerte que ellos? Pero negaban Nuestras señales.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmccxxxiv{Así pues, enviamos contra ellos un viento frío huracanado, en días desafortunados, para hacerles probar el castigo humillante en esta vida mundanal. Y el castigo de la otra es todavía más humillante y no serán auxiliados.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmccxxxv{En cuanto a Zamud, Nosotros les guiamos, pero prefirieron la ceguera a la guía, así que les alcanzó la destrucción de un castigo humillante por lo que hacían.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmccxxxvi{Y salvamos a quienes eran creyentes y temerosos de Dios\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmccxxxvii{Y recuerda el día en que los enemigos de Dios sean reunidos a la fuerza y llevados hacia el Fuego y se haga esperar a las filas de los primeros hasta que se unan a ellos las filas de los últimos,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmccxxxviii{hasta que, al llegara a él, sus oídos, sus vistas y sus pieles, den testimonio contra ellos por lo que hacían.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmccxxxix{Y dirán a sus pieles: «¿Por qué testificáis contra nosotros?» Ellas dirán: «Nos ha hecho hablar Dios, que es Quien hace hablar a todas las cosas y que es Quien os creó la primera vez y hacia Quien regresáis.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmccxl{«No podíais esconderos para que vuestros oídos y vuestra vista y vuestra piel no atestiguasen contra vosotros, pero creíais que Dios no conocía mucho de lo que hacíais\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmccxli{y esa suposición que vosotros teníais sobre vuestro Señor os destruyó y os convertisteis en los perdedores.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmccxlii{Y aunque tengan paciencia su morada será el Fuego y aunque traten de evitar la censura no serán de los redimidos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmccxliii{Y les asignamos compañeros que les embellecieron lo que tenían entre sus manos y tras ellos. Y se verificó contra ellos lo dicho a las generaciones de genios y humanos que pasaron antes de ellos. En verdad, ellos fueron perdedores.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmccxliv{Y quienes no creen dicen: «¡No escuchéis este Corán y hablad sin sentido cuando se recite, quizás así seáis vencedores!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccxlv{Y haremos gustar a los que no creen un duro castigo y les retribuiremos por el mal que hacían.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmccxlvi{Esa es la recompensa de los enemigos de Dios: el Fuego. En él está para ellos la morada eterna. Recompensa por negar Nuestras señales.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmccxlvii{Quienes no creen dirán: «¡Señor nuestro! Muéstranos a los genios y a los humanos que nos desviaron para que los pongamos bajo nuestros pies y así estén en lo más bajo.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmccxlviii{En verdad, los ángeles descienden sobre quienes dicen: «Nuestro señor es Dios», y se mantienen en el camino de la rectitud y la justicia: ¡No temáis y no estéis tristes y recibid la buena nueva del Jardín que se os había prometido!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccxlix{«Nosotros fuimos vuestros protectores en la vida mundanal y lo somos en la vida siguiente y en ella tendréis lo que vuestras almas deseen y en ella tendréis lo que pidáis.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccl{Hospitalidad de Un perdonador misericordiosísimo.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmccli{Y ¿Quién dice mejores palabras que quien invoca a Dios y realiza buenas obras y dice: «En verdad, soy de los que se someten a Dios.»?\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcclii{No son iguales las buenas acciones que las malas. Rechaza el mal con lo que es mejor y aquel con el que estabas enemistado se comportará como si fuera un amigo íntimo.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmccliii{Y eso sólo lo consigue quien tiene paciencia. Eso sólo lo consigue quien posee una inmensa porción.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmccliv{Si el Demonio te incita al mal, busca refugio en Dios. En verdad, Él es Quien todo lo oye, el Sabio.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcclv{Y entre Sus señales están la noche y el día y el Sol y la Luna. No os prosternéis ante el Sol ni ante la Luna, prosternaos ante Dios que es Quien los ha creado a ambos, si es sólo a Él a quien adoráis.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcclvi{Pero si se muestran altivos, quienes están cerca de tu Señor Le glorifican noche y día sin cansarse.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcclvii{Y entre Sus señales está el que tú veas la tierra seca y desolada pero, cuando hacemos que descienda sobre ella el agua, se reanima con energía y brotan las plantas. En verdad, quien la hace vivir es el Vivificador de lo muerto. En verdad, Él tiene poder sobre todas las cosas.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcclviii{En verdad, quienes no creen en Nuestras señales no pueden ocultarse de Nosotros. ¿Quién, pues, es mejor? ¿Quién será arrojado al Fuego o quién estará seguro cuando venga el Día del Levantamiento? ¡Haced lo que queráis! En verdad, Él ve lo que hacéis.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcclix{En verdad, quienes no creen en el Recuerdo cuando llega a ellos… Y, en verdad, es una Escritura poderosa,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcclx{a la que no alcanzará jamás la falsedad. Desciende gradualmente de Uno que es sabio, digno de alabanza.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcclxi{No se te dice sino lo que les fue dicho a los Mensajeros anteriores a ti. En verdad, tu Señor es el dueño del perdón y del castigo doloroso.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcclxii{Y si hubiésemos hecho llegar a ellos un Corán en lengua no árabe, con seguridad habrían dicho: “¿Cómo es que sus versículos no se explican con claridad y detalladamente? ¿No es árabe siendo él árabe? Di: «Es, para quienes creen, una guía y una cura y quienes no creen son duros de oído y están ciegos ante ella. Como si se les llamase desde un lugar alejado.»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcclxiii{Y, ciertamente, dimos a Moisés la Escritura y disintieron de ella. Y si no hubiese sido por una palabra anterior de tu Señor, habría juzgado entre ellos, pues, en verdad, dudaron seriamente de ella.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcclxiv{Quien obre rectamente, obra para su propio beneficio y quien haga el mal, obra contra sí mismo. Tu Señor no oprime a Sus siervos.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcclxv{El conocimiento de la Hora Le pertenece y no sale ningún fruto de su envoltura, ni concibe o da a luz mujer alguna, sin Su conocimiento. El día en que Él les pregunte: «¿Dónde están Mis socios?» dirán: «Te anunciamos que no hay entre nosotros ninguno que lo atestigüe.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcclxvi{Y se apartarán de ellos aquellos a los que antes invocaban y sabrán que no hay escape para ellos.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcclxvii{El ser humano no se cansa de buscar el bien, pero cuando le alcanza un mal se desanima y desespera.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcclxviii{Y cuando, después de haber sufrido una contrariedad, le hacemos probar una misericordia proveniente de Nosotros, dice: «Esto es mío y no creo que llegue la Hora. Y en caso de que se me hiciese regresar a mi Señor sólo bien obtendría de Él.» En verdad, informaremos a los que no creían de lo que hacían y les haremos probar un castigo contundente.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcclxix{Cuando favorecemos al ser humano, éste es desagradecido y se aleja de la Verdad con arrogancia, pero cuando sufre un perjuicio no deja de suplicar.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcclxx{Di: «Decidme. Si viniese de Dios y vosotros no creyeseis en ella ¿Quién estará más extraviado que quien disiente de manera tan evidente?»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcclxxi{Pronto les mostraremos Nuestras señales en el horizonte y en ellos mismos, hasta que sea evidente para ellos que Él es la Verdad. ¿No es suficiente que tu Señor sea testificable en todas las cosas?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcclxxii{Ved cómo dudan del encuentro con su Señor. ¿Acaso no abarca Él todas las cosas?\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcclxxiii{\basmalahes Ha, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcclxxiv{‘Ain, Sin, Qaf.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcclxxv{De esta misma manera es como Dios, el Todopoderoso, el Sabio, ha enviado la revelación, a ti y a quienes vinieron antes de ti.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcclxxvi{A Él pertenece lo que hay en los cielos y en la Tierra y Él es el Altísimo, el Inmenso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcclxxvii{Los cielos casi se rompen en pedazos sobre ellos y los ángeles glorifican con alabanzas a su Señor y piden perdón para quienes están en la Tierra. Sabed que, en verdad, Dios es el Perdonador, el Misericordiosísimo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcclxxviii{Dios guarda memoria de quienes toman como protectores a otros en lugar de a Él y tú no eres el guardián ni el abogado de ellos.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcclxxix{Y, así mismo, te hemos revelado un Corán árabe para que amonestes a la madre de las ciudades y a quienes están alrededor de ella y amonestes sobre el Día de la Reunión, sobre el que no hay duda. Un grupo estará en el Jardín y otro grupo estará en el Fuego llameante.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcclxxx{Y, si Dios hubiera querido, habría hecho de ellos una sola comunidad, pero hace entrar en Su misericordia a quien Él quiere y los opresores no tendrán quien les proteja ni quien les auxilie.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcclxxxi{¿Han tomado protectores aparte de Él? Pues Dios es el Protector y Él es Quien da vida a lo muerto y Él es Quien tiene poder sobre todas las cosas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcclxxxii{Y cualquier cosa sobre la que discrepéis, Dios la juzgará. ¡Ese es Dios, mi Señor! En Él confío y a Él me vuelvo contrito.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcclxxxiii{El Originador de los cielos y la Tierra. Ha hecho parejas para vosotros de vuestras propias almas y parejas del ganado. De ese modo Él os multiplica. No hay nada como Él. Él es Quien todo lo oye, Quien todo lo ve.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcclxxxiv{A Él pertenecen las llaves de los cielos y de la Tierra. Incrementa o restringe la provisión de quien Él quiere. En verdad, Él conoce bien todas las cosas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcclxxxv{Él ha establecido para vosotros los mandatos de la fe que ya había encomendado a Noé y que también Nosotros te hemos revelado a ti, y lo que habíamos encomendado a Abraham, Moisés y Jesús: “Estableced la creencia y no os dividáis por causa de ella.” A los idólatras les resulta difícil aquello a lo que tú les convocas. Dios escoge para Sí a quien Él quiere y guía a Él a quien se vuelve con arrepentimiento.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcclxxxvi{Y no se dividieron en distintos grupos hasta después de haberles llegado el conocimiento, por envidia entre ellos. Y si no hubiese sido por una palabra anterior de tu Señor estableciendo un plazo, habría juzgado entre ellos. Y, en verdad, aquellos a quienes se hizo heredar la Escritura tienen serias dudas respecto a ella.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcclxxxvii{Por ello, predica a las gentes y mantente firme como te ha sido ordenado y no sigas sus pasiones y di: «Creo en lo que Dios ha hecho descender de la Escritura y se me ha ordenado que establezca la justicia entre vosotros. Dios es nuestro Señor y vuestro Señor. Nosotros responderemos por nuestros actos y vosotros por los vuestros. No hay preferencias entre nosotros y vosotros. Dios nos reunirá. Todo regresa a Él.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcclxxxviii{Y los argumentos de quienes discuten sobre Dios, después de que Su llamada ha sido aceptada, no tienen validez alguna ante su Señor. Sufrirán la ira y un duro castigo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcclxxxix{Dios es Quien hace descender la Escritura con la Verdad y la Balanza y ¿Quién sabe? Puede que la Hora esté cerca.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmccxc{Quienes no creen en ella piden que se adelante, pero quienes creen se estremecen de miedo al pensar en ella y saben que ella es cierta. Sabed que quienes insisten en negar la Hora están muy extraviados.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmccxci{Dios es delicado con Sus siervos. Provee a quien Él quiere y Él es el Fuerte, el Todopoderoso.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmccxcii{A quienes deseen la cosecha de la otra vida Nosotros les incrementaremos su cosecha y a quien desee la cosecha de la vida mundanal Nosotros le daremos de ella, pero no tendrá parte alguna en la otra.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmccxciii{¿Acaso tienen socios que han prescrito para ellos en la religión lo que Dios no ha permitido? Si no se hubiese establecido un plazo se habría juzgado entre ellos. Y, en verdad, los opresores tendrán un castigo doloroso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmccxciv{Verás a los opresores temerosos por lo que cometieron y sufrirán las consecuencias. Y quienes son creyentes y realizan buenas acciones estarán en los Jardines del Paraíso. Tendrán lo que deseen junto a su Señor. Ese es el gran favor.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmccxcv{Esa es la buena nueva que Dios anuncia a Sus siervos que son creyentes y realizan buenas acciones. Di: «No os pido recompensa por ello, excepto el amor a los familiares.» Y a quien realice una buena acción le incrementaremos la recompensa de su acción. En verdad, Dios es perdonador, agradecido.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmccxcvi{Ellos dicen: «Inventa mentiras sobre Dios.» Pero si Dios quisiera sellaría tu corazón. Dios elimina la falsedad y establece la Verdad con Sus palabras. En verdad, Él conoce bien lo que hay en el fondo de los pechos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmccxcvii{Y Él es Quien acepta el arrepentimiento de Sus siervos y perdona los pecados y conoce lo que hacéis.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmccxcviii{Y responde a quienes son creyentes y obran rectamente y les incrementa Sus favores. Pero a quienes tratan de ocultar la realidad les aguarda un duro castigo.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccxcix{Si Dios incrementase la provisión para Sus siervos, estos se volverían injustos y opresores en la Tierra, por eso hace que descienda en su medida aquello que Él quiere. En verdad, Él está bien informado y observa a Sus siervos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmccc{Y es Él Quien hace descender la lluvia reparadora cuando ya habían desesperado y distribuye Su misericordia y Él es el Protector, el Digno de alabanza.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmccci{Entre Sus señales está la creación de los cielos y la Tierra y los seres vivos que en ambos ha diseminado. Y Él tiene poder para reunirlos cuando quiera.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcccii{Y cualquier desgracia que sufráis es consecuencia de lo que vosotros mismos habéis cometido, pero Él perdona mucho.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccciii{Y no podréis escapar a Su poder en la Tierra y no tenéis, aparte de Dios, quien os proteja y auxilie.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccciv{Y entre Sus señales están los barcos, como montañas en el mar.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcccv{Y, si Él quiere, aquieta el viento y los inmoviliza en su superficie. En verdad, en ello hay señales para todo el que sea muy paciente, muy agradecido.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcccvi{O les aniquila por lo que han cometido -pero Él perdona mucho-\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcccvii{para que quienes discuten Nuestras señales sepan que no tendrán lugar al que escapar.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcccviii{Todo lo que se os ha dado es disfrute pasajero de esta vida mundanal y lo que hay junto a Dios es mejor y más duradero para quienes tienen fe y confían en su Señor\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcccix{y se abstienen de los pecados mayores y la inmoralidad y, cuando se les irrita, perdonan.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcccx{Y que responden a su Señor, hacen la oración, se consultan entre ellos los asuntos y reparten de aquello que Nosotros les proveemos\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcccxi{y cuando sufren una injusticia, un ultraje, se ayudan entre sí.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcccxii{La recompensa del mal es un mal semejante. Así pues, quien perdone y corrija el mal será recompensado por Dios. En verdad, Él no ama a los opresores.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcccxiii{Y quienes se defiendan tras haber sido oprimidos no serán censurados.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcccxiv{En verdad, la censura es para quienes oprimen a las gentes y van agrediendo en la Tierra sin derecho. Ellos tendrán un castigo doloroso.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcccxv{Y ser pacientes y perdonar es señal de quienes poseen una gran firmeza.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcccxvi{Y a quien Dios extravíe no encontrará tras Él quien le proteja y verás a los opresores, cuando les llegue el castigo, diciendo: «¿Hay algún camino para regresar?»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcccxvii{Les verás expuestos a él, abatidos por la humillación, con la mirada baja y desorbitada. Entonces, los creyentes dirán: «En verdad, los perdedores son quienes han perdido a sus almas y a sus familias el Día del Levantamiento.» Sabed que, en verdad, los opresores estarán en el castigo permanente\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcccxviii{y no tendrán, aparte de Dios, protector alguno que les auxilie. Y no hay camino para aquel a quien Dios extravía.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcccxix{¡Responded a vuestro Señor antes de que Dios haga llegar un día del que no hay manera de regresar! Ese día no encontraréis refugio ni nadie que os defienda.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcccxx{Y si se alejan, no te hemos enviado para que seas su protector. Tu obligación es solamente transmitir el mensaje. Y, en verdad, cuando hacemos que el ser humano pruebe una misericordia que viene de parte Nuestra, se regocija de su suerte y si le aqueja un mal por lo que ha cometido, entonces se muestra desagradecido.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcccxxi{A Dios pertenece el reino de los cielos y de la Tierra. Él crea lo que quiere. Otorga hijas a quien Él quiere y otorga hijos a quien Él quiere.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcccxxii{O les da de ambos, varones y hembras y hace estéril a quien Él quiere. En verdad, Él es sabio, poderoso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcccxxiii{Y no es posible que Dios hable directamente al ser humano, sino a través de la revelación o tras un velo o enviándole un Mensajero, para que le sea revelado, con Su permiso, lo que Él quiera. En verdad, Él es altísimo, sapientísimo.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcccxxiv{Así es como te hemos revelado un Espíritu por orden Nuestra. Tú no sabías lo que era la Escritura ni la fe pero Nosotros la pusimos como una luz con la que guiamos a quien queremos de Nuestros siervos. Y, en verdad, tú guías hacia un camino recto,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcccxxv{el camino de Dios, a Quien pertenece lo que hay en los cielos y en la Tierra. Sabe que a Dios regresan todas las cosas.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcccxxvi{\basmalahes Ha, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcccxxvii{Juro por la Escritura clara\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcccxxviii{que la hemos hecho una recitación árabe. Quizás así, razonéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcccxxix{Y, en verdad, ella está en La madre de las Escrituras [Sagradas] que hay junto a Nosotros, en verdad sublime, sapientísima.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcccxxx{¿Os privaremos, pues, del Recuerdo por ser un pueblo inmoderado?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcccxxxi{¡Cuántos profetas Hemos enviado a los primeros pueblos!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcccxxxii{Y no llegó a ellos profeta alguno sin que se burlasen de él.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcccxxxiii{Así pues, destruimos a quienes eran más poderosos que estos. Ya vimos lo que les sucedió a los primeros pueblos.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcccxxxiv{Y si les preguntases: «¿Quién ha creado los cielos y la Tierra?» sin duda, dirían: «Los ha creado el Todopoderoso, el Sapientísimo.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcccxxxv{Él mismo que ha puesto para vosotros la Tierra como un lecho y ha puesto para vosotros en ella caminos para que así os guiéis.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcccxxxvi{Y Quien hace descender del cielo agua en una cantidad determinada con la que Nosotros damos la vida a una región que estaba muerta. Así mismo seréis sacados vosotros.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcccxxxvii{Y Quien ha creado las parejas de todo y ha puesto para vosotros los barcos y los animales en que montáis,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcccxxxviii{para que os sentéis en sus lomos. Luego, recordéis las bendiciones de vuestro Señor cuando estéis sentados sobre ellos y digáis: «Glorificado sea Quien a puesto esto a nuestro servicio, pues nosotros no lo habríamos logrado.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcccxxxix{¡Y, en verdad, regresaremos a nuestro Señor!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcccxl{Ellos han considerados a algunos de Sus siervos parte de Él. En verdad, el ser humano es un clarísimo desagradecido.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcccxli{¿Iba a tomar hijas de lo que Él ha creado y os iba a conceder los hijos a vosotros?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcccxlii{Y cuando a alguno de ellos se le anuncia la buena nueva de lo que él atribuye al Clementísimo, su rostro se ensombrece, se llena de preocupación y disgusto:\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcccxliii{«¿Alguien que crece entre adornos y es incapaz de razonar con claridad?»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcccxliv{Y han considerado a los ángeles, que son siervos del Clementísimo, hembras. ¿Acaso ellos han sido testigos de su creación? Se tomará nota de su testimonio y serán interrogados.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcccxlv{Y dicen: «Si el Clementísimo hubiera querido, no les habríamos adorado.» ¡No tienen ningún conocimiento de eso! ¡No hacen más que conjeturas!\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcccxlvi{¿Acaso les hemos dado una Escritura anterior a ésta, a la que ellos puedan aferrarse?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcccxlvii{Pero dicen: «En verdad, encontramos a nuestros padres siguiendo una creencia y, en verdad, siguiendo sus huellas estamos bien guiados.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcccxlviii{Y, de la misma manera, no hemos enviado antes de ti a ningún amonestador a pueblo alguno sin que los ricos del mismo dijeran: «En verdad, encontramos a nuestros padres siguiendo una creencia y, en verdad, seguimos sus huellas.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcccxlix{Di: «¿Y si os trajera una guía mejor que aquella en la que encontrasteis a vuestros padres?» Dirán: «En verdad, no creemos en aquello con lo que habéis sido enviados.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcccl{Así pues, nos vengamos de ellos y ¡Mira cual fue el final de los desmentidores!\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcccli{Y (recuerda) cuando Abraham dijo a su padre y a su pueblo: «En verdad, rechazo aquello que adoráis,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccclii{pero no a Quien me ha creado, pues, en verdad, Él me guiará.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcccliii{Y Él las puso como palabras que permaneciesen en su descendencia para que, quizás así, regresasen.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcccliv{Pero les permití disfrutar a ellos y a sus padres hasta que llegase a ellos la Verdad y un Mensajero que habla claro.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmccclv{Pero cuando llegó a ellos la Verdad, dijeron: «Esto es magia y, en verdad, nosotros no creeremos en ella.»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccclvi{Y dijeron: «¿Por qué este Corán no ha sido revelado a un hombre importante de una de estas dos ciudades?»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccclvii{¿Son acaso ellos quienes reparten la misericordia de tu Señor? Somos Nosotros Quienes repartimos entre ellos sus medios de vida en este mundo y Quienes hemos elevado el grado de unos sobre otros para que unos tomen a otros a su servicio. Y la misericordia de tu Señor es mejor que lo que ellos reúnen.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmccclviii{Y si no fuera para que los humanos no terminasen siendo una sola comunidad, habríamos puesto en las casas de quienes no creen en el Clementísimo, techos y escaleras de plata para ascender a ellos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmccclix{y en las puertas de sus casas y en los lechos en los que se reclinan,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmccclx{y adornos de oro. Pero todo esto no es más que disfrute de esta vida mundanal y la otra vida junto a tu Señor es para los temerosos.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmccclxi{Y a quien esté ciego al recuerdo del Clementísimo le asignaremos un demonio que será su compañero permanente.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmccclxii{Y, en verdad, ellos les apartarán del camino y creerán que están bien guiados\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmccclxiii{hasta que, cuando vengan a Nosotros, digan: «¡Ojalá entre yo y tú hubiese la distancia de los dos orientes! ¡Qué mal compañero!»\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmccclxiv{¡Hoy no os beneficiará lo que oprimisteis, pues compartiréis el castigo!\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmccclxv{¿Acaso puedes hacer que el sordo oiga o guiar al ciego y a quien está en un extravío evidente?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmccclxvi{Así pues, aunque te llevemos, en verdad, nos vengaremos de ellos.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmccclxvii{O te haremos ver aquello que les prometimos, pues, en verdad, tenemos poder sobre ellos.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmccclxviii{Por tanto ¡Aférrate a lo que te hemos revelado! En verdad, tú estás sobre un camino recto.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmccclxix{Y, en verdad, ello es un recuerdo para ti y para tu pueblo y pronto seréis preguntados.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmccclxx{Y pregunta a los Mensajeros que Nosotros hemos enviado antes de ti. ¿Acaso pusimos, aparte del Clementísimo, otros dioses para que fuesen adorados?\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmccclxxi{Y, ciertamente, enviamos a Moisés con Nuestras señales al Faraón y a sus notables y dijo: «En verdad, soy el Mensajero del Señor del Universo.»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmccclxxii{Y, cuando llegó a ellos con Nuestras señales, se rieron de ellas.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmccclxxiii{A pesar de que no les mostramos una señal que no fuese mayor que su hermana. Les hicimos sufrir el castigo para que, quizás así, regresasen.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmccclxxiv{Y dijeron: «¡Oh tú, mago! ¡Pide por nosotros a tu Señor en nombre del pacto que ha realizado contigo! ¡Nosotros nos dejaremos guiar!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmccclxxv{Pero, cuando apartamos de ellos el castigo, no cumplieron su promesa.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmccclxxvi{Y, llamando el Faraón a su pueblo, dijo: «¿Acaso no soy yo el rey de Egipto y de estos ríos que corren a mis pies? ¿Es que no os dais cuenta?»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmccclxxvii{«¿No soy yo mejor que éste, que es un pobre siervo y no sabe expresarse con claridad?»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmccclxxviii{«Si no, ¿Por qué no le han sido puestos brazaletes de oro o han venido con él los ángeles acompañándole?»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmccclxxix{Así engañó a su pueblo y estos le obedecieron. En verdad, eran un pueblo trasgresor.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmccclxxx{Por ello, cuando Nos enojaron, Nos vengamos de ellos y les ahogamos a todos.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmccclxxxi{Y les colocamos a la vanguardia e hicimos de ellos un ejemplo para la posteridad.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmccclxxxii{Y, cuando se pone de ejemplo al hijo de María, tu pueblo se burla.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmccclxxxiii{Y dicen: «¿Son mejores nuestros dioses o él?» Ellos sólo le citan para discutir contigo. Son gente quienes les gusta disputar.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmccclxxxiv{Él es, en verdad, un siervo al que Nosotros favorecimos y al que pusimos como ejemplo para los Hijos de Israel.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmccclxxxv{Y si Nosotros hubiésemos querido, habríamos hecho que algunos de vosotros fuesen ángeles que se sucediesen en la Tierra.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmccclxxxvi{Y, en verdad, él es un medio para el conocimiento de la Hora. Así pues, no dudéis de ella y seguidme. Éste es el camino recto.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmccclxxxvii{Y que Satanás no os aparte. En verdad, él es un claro enemigo para vosotros.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmccclxxxviii{Y cuando vino Jesús con las pruebas claras, dijo: «He venido a vosotros con la sabiduría y para aclararos algunas de las cosas en las que discrepáis. Así pues, sed temerosos de Dios y obedecedme.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmccclxxxix{En verdad, Dios es mi Señor y vuestro Señor, así pues ¡Adoradle! Ese es el camino recto.»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcccxc{Pero los partidos disintieron entre ellos. Así pues ¡Ay de quienes oprimieron! ante el castigo de un día doloroso\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcccxci{¿Acaso esperan otra cosa excepto que la Hora llegue a ellos súbitamente sin que ellos se den cuenta?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcccxcii{Ese día los amigos serán enemigos unos de otros, excepto los temerosos de Dios:\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcccxciii{«¡Oh, siervos Míos! ¡Hoy no tenéis de que temer ni por qué estar tristes!»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcccxciv{Quienes creyeron en Mis señales y se sometieron.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcccxcv{«¡Entrad en el Jardín, vosotros y vuestras esposas, radiantes de felicidad!»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcccxcvi{Circularán entre ellos con bandejas de oro y copas y en ellas tendrán lo que deseen sus almas y un deleite para la vista: «En él estaréis eternamente.»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcccxcvii{«Este es el Jardín que se os ha dado en herencia por lo que hacíais.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcccxcviii{Hay en él para vosotros frutas abundantes para que comáis de ellas.»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcccxcix{En verdad, los malhechores estarán en el castigo del Infierno eternamente.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcd{No se les atenuará y se desesperarán allí.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcdi{No les oprimiremos, sino que ellos habrán sido los opresores.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmcdii{Y clamarán: «¡Oh, Málik! ¡Que tu Señor nos haga perecer!» Él dirá: «En verdad, vosotros permaneceréis.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmcdiii{Ciertamente, vinimos a vosotros con la Verdad, pero la mayoría de vosotros aborrecéis la Verdad.»\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmcdiv{Ellos han establecido un plan pero Nosotros también planificamos.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmcdv{¿O creen que Nosotros no oímos lo que piensan en secreto y lo que hablan en secreto? Claro que sí. Y Nuestros Mensajeros están junto a ellos tomando nota.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmcdvi{Di: «Si el Clementísimo tuviera un hijo yo sería el primero en adorarle.»\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmcdvii{«¡Glorificado sea el Señor de los cielos y la Tierra, el Señor del Trono, por encima de lo que Le atribuyen!»\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmcdviii{Así pues ¡Déjales que se pierdan en su error y jueguen hasta que se encuentren con el día que se les ha prometido!\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmcdix{Él es Aquel que es un dios en los cielos y un dios en la Tierra. Él es el Sabio, el Conocedor de todo.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmcdx{¡Bendito sea Aquel a Quien pertenece el reino de los cielos y de la Tierra y de lo que hay entre ambos y que posee el conocimiento de la Hora y a Quien habréis de regresar!\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmcdxi{Y aquellos a quienes invocan aparte de Él no tienen el poder de interceder, sino aquellos que dan testimonio de la Verdad y que conocen.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmcdxii{Y si les preguntas quién les ha creado, seguro que dirán: «Dios.» Entonces ¿Por qué se extravían?\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmcdxiii{Y él dice: «¡Oh, Señor mío! ¡En verdad, ellos son un pueblo que no cree!»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmcdxiv{¡Apártate, entonces, de ellos! Y di: «¡Paz!». ¡Pronto sabrán!\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmmcdxv{\basmalahes Ha, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcdxvi{Juro por la Escritura clara\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcdxvii{que, en verdad, la hicimos descender en una noche bendita. En verdad, siempre hemos sido amonestadores.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcdxviii{En ella se detallan de manera diferenciada todos los asuntos establecidos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcdxix{Asuntos que proceden de Nosotros. En verdad, Nosotros somos Quienes la enviamos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcdxx{Una misericordia de tu Señor. En verdad, Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcdxxi{El Señor de los cielos y la Tierra y de lo que hay entre ambos, si es que tenéis certeza.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcdxxii{No hay más dios que Él. Da la vida y da la muerte. Es vuestro Señor y el Señor de vuestros primeros padres.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcdxxiii{Pero ellos dudan y juegan.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcdxxiv{Así pues ¡Espera el día en que el cielo traiga un humo evidente\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcdxxv{que cubra a la gente! «¡Esto es un castigo doloroso!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcdxxvi{¡Señor nuestro! ¡Aparta de nosotros este castigo! ¡Creemos!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcdxxvii{De qué les servirá el recuerdo si ha venido a ellos un Mensajero claro\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcdxxviii{y se han apartado de él y han dicho: «¡Es un loco al que otros han instruido!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcdxxix{En verdad, apartaremos un poco el castigo, pero vosotros reincidiréis.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcdxxx{El día que les ataquemos con la gran violencia, nos vengaremos de ellos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcdxxxi{En verdad, antes que a ellos pusimos a prueba al pueblo del Faraón y vino a ellos un noble Mensajero:\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcdxxxii{«Someteos a mí, siervos de Dios. En verdad, yo soy para vosotros un Mensajero digno de confianza.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcdxxxiii{«Y no os rebeléis contra Dios, pues he venido a vosotros con una autoridad evidente\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcdxxxiv{y me refugio en mi Señor y vuestro Señor de que me lapidéis.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcdxxxv{Y si no creéis en mí ¡Apartaos!»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcdxxxvi{E imploró a su Señor: «¡Este es un pueblo de malhechores!»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcdxxxvii{[Dios le respondió:] «Ponte en marcha con Mis siervos durante la noche, pues seréis perseguidos,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcdxxxviii{y salid del mar con calma. En verdad, ellos son un ejército que será ahogado.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcdxxxix{¡Cuántos jardines y fuentes dejaron atrás!\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcdxl{¡Cuántos campos de cultivo y bellas mansiones\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmcdxli{y bendiciones de las que disfrutaban!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcdxlii{Así fue. Y se lo dimos en herencia a otro pueblo.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcdxliii{Y ni los cielos ni la Tierra lloraron por ello. Y no se les hizo esperar.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcdxliv{Y salvamos a los Hijos de Israel del castigo humillante\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmcdxlv{del Faraón. En verdad, él era altivo, de los transgresores.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmcdxlvi{Ciertamente, con conocimiento, les elegimos sobre todos los pueblos\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcdxlvii{y les dimos señales con las que les pusimos claramente a prueba.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcdxlviii{En verdad, ellos dicen:\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcdxlix{«Sólo moriremos esta primera vez y no seremos resucitados.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcdl{¡Haced volver a nuestros padres si es verdad lo que decís!»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcdli{¿Son ellos mejores o el pueblo de Tuba y quienes vivieron antes de ellos? Nosotros les destruimos. En verdad, eran malhechores.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcdlii{Y no hemos creado los cielos y la Tierra y lo que hay entre ambos por juego.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcdliii{No hemos creado ambos sino con la Verdad, pero la mayoría de ellos no saben.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcdliv{En verdad, el Día de la Diferencia será el momento de encuentro de todos ellos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcdlv{El día en que un amigo no podrá beneficiar a otro amigo y no serán auxiliados\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcdlvi{excepto aquellos de quien Dios tenga clemencia. En verdad, Él es el Todopoderoso, el Clementísimo.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcdlvii{En verdad, el árbol de Saqqum\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcdlviii{será el alimento del pecador.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcdlix{Como metal fundido hirviendo en las entrañas\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcdlx{como hierve el agua hirviente.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcdlxi{«Atrapadle y arrastradle en medio del Infierno\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcdlxii{y luego arrojad sobre su cabeza el castigo hirviente.»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcdlxiii{«¡Prueba! ¡En verdad, tú eres el poderoso, el noble!\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcdlxiv{Esto es aquello de lo que vosotros dudabais.»\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcdlxv{En verdad, los temerosos de Dios estarán en un lugar seguro\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcdlxvi{entre jardines y fuentes\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcdlxvii{vestidos de sedas y brocados, unos frente a otros.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcdlxviii{Así será. Y les emparejaremos con huríes de grandes ojos.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcdlxix{Solicitarán allí todo tipo de frutas y estarán seguros.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcdlxx{Allí no probarán más muerte que la muerte primera y estarán a salvo del castigo del Infierno.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcdlxxi{Es un favor que procede de tu Señor. ¡Ese es el triunfo inmenso!\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcdlxxii{En verdad, lo hemos facilitado en tu lengua para que, quizás así, se dejen amonestar.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcdlxxiii{Así pues ¡Espera! Que ellos también están a la espera.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcdlxxiv{\basmalahes Ha, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcdlxxv{El descenso de la Escritura proviene del Todopoderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcdlxxvi{En verdad, en los cielos y la Tierra hay señales para los creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcdlxxvii{Y en vuestra creación y en los animales que Él ha diseminado hay señales para un pueblo que tiene certeza.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcdlxxviii{Y en la diferencia entre la noche y el día y en la provisión que Dios ha hecho descender del cielo, con la que da vida a la tierra después de haber estado muerta, y en la variación de los vientos, hay señales para un pueblo que razona.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcdlxxix{Esas son las señales de Dios que Nosotros te recitamos con la Verdad. ¿En qué creerán después de Dios y de Sus señales?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcdlxxx{¡Ay de todo el que sea un mentiroso pecador!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxi{Que oye las señales de Dios que le son recitadas y persiste en la arrogancia como si no las hubiera oído. ¡Anúnciale un castigo doloroso!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxii{Y que, cuando conoce algo de Nuestras señales, las toma a burla. Esos son quienes tendrán un castigo humillante.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxiii{Tras ellos está el Infierno y no les servirá nada de lo que adquirieron ni los que tomaron por protectores en lugar de Dios. Y tendrán un castigo inmenso.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxiv{¡Esta es una guía! Y quienes no creen en las señales de su Señor tendrán un castigo extremadamente doloroso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxv{Dios es Quien ha puesto a vuestro servicio el mar para que lo surquen los barcos por orden Suya y para que busquéis Su favor y para que, quizás así, seáis agradecidos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxvi{Y ha puesto a vuestro servicio lo que hay en los cielos y en la Tierra. Todo ello procede de Él. En verdad, en ello hay señales para un pueblo que reflexiona.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxvii{Di a los creyentes que perdonen a quienes no tienen esperanza en los días de Dios, en los que Él recompensa a la gente por lo que han hecho.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxviii{Quien obra rectamente obra para su propio beneficio y quien obra mal obra contra sí mismo. Luego, todos regresaréis a vuestro Señor.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxix{En verdad, dimos a los Hijos de Israel la Escritura, el juicio y la profecía y les proveímos de las cosas buenas y les favorecimos por encima de todos los pueblos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcdxc{Y les otorgamos pruebas claras del asunto. Así pues, no tuvieron diferencias hasta después de haber venido a ellos el conocimiento, por envidia entre ellos. En verdad, tu Señor juzgará entre ellos el Día del Levantamiento sobre aquello en lo que tenían diferencias.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcdxci{Luego, te pusimos en la senda del asunto. ¡Síguela pues y no sigas los deseos de quienes no saben!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcdxcii{En verdad, ellos no te podrán beneficiar en nada frente a Dios. Y, en verdad, los opresores se protegen unos a otros y Dios es el protector de quienes Le temen.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcdxciii{Este es un medio para que los seres humanos profundicen su visión de las cosas y una guía y una misericordia para un pueblo que tiene certeza.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcdxciv{¿O creen quienes hacen el mal que les trataremos igual que a quienes creen y obran rectamente y que sus vidas y sus muertes serán iguales? ¡Qué mal juzgan!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcdxcv{Y Dios ha creado los cielos y la Tierra con la Verdad y para recompensar a cada ser por lo que hizo. Y ellos no serán oprimidos.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcdxcvi{¿Has visto a quien toma como dios a sus deseos y pasiones? Dios extravía su conocimiento y sella su oído y su corazón y pone una venda en su vista. Así pues ¿Quién le guiará después de Dios? ¿Es que no reflexionan?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcdxcvii{Y dicen: «No existe más vida que nuestra vida de este mundo. Morimos y vivimos y sólo el tiempo nos destruye.» pero no tiene conocimiento de esto. Solamente conjeturan.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcdxcviii{Y cuando se les recitan Nuestros versículos claros su único argumento es decir: «¡Traed de vuelta a nuestros padres si sois sinceros!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcdxcix{Di: «Dios os hace vivir, luego os hace morir, luego os reúne el Día del Levantamiento. No hay duda de ello.» Pero la mayoría de los seres humanos no saben.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmd{Y a Dios pertenece el reino de los cielos y la Tierra y el día en que la Hora tenga lugar, ese día, los falseadores perderán.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdi{Y verás a cada comunidad arrodillada. Cada comunidad será remitida a su libro: «Hoy seréis recompensados por lo que hacíais.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdii{«Este libro Nuestro os dice la Verdad. En verdad, Nosotros escribíamos una copia de lo que vosotros hacíais.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdiii{Y a quienes son creyentes y obran rectamente su Señor les hará entrar en Su misericordia. Ese es el triunfo evidente.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdiv{Pero a quienes no creyeron: «¿No se os recitaron mis versículos y os mostrasteis arrogantes y fuisteis malhechores?»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdv{Y cuando se os decía: «En verdad, la promesa de Dios es verdadera y no hay duda sobre la Hora» decíais: «No sabemos lo que es la Hora. Sólo hacemos conjeturas pero no tenemos certeza.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdvi{Y aparecerá ante ellos el mal que hicieron y les rodeará aquello de lo que se burlaban\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdvii{y se les dirá: «Hoy os olvidamos como vosotros olvidasteis el encuentro de este día y vuestra morada será el Fuego. Y no tendréis quien os auxilie.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdviii{«Eso es para vosotros por haber tomado a burla las señales de Dios y porque os sedujo la vida mundanal.» Así pues, hoy no serán sacados de él ni les serán aceptadas sus disculpas.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdix{Así pues ¡Alabado sea Dios! Señor de los cielos y Señor de la Tierra. Señor del Universo.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdx{A Él pertenece la supremacía en los cielos y la Tierra y Él es el Todopoderoso, el Sabio.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdxi{\basmalahes Ha, Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdxii{El descenso de la Escritura proviene del Todopoderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdxiii{No hemos creado los cielos y la Tierra ni lo que hay entre ellos excepto con la Verdad y por un plazo determinado. Pero quienes no creen no hacen caso de aquello con lo que se les amonesta.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdxiv{Di: «¿Habéis visto aquello que invocáis en lugar de Dios? Mostradme lo que ellos han creado de la Tierra. ¿Tienen alguna participación en los cielos? Traedme una Escritura anterior a ésta o algún vestigio de conocimiento si es que sois sinceros.»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdxv{Y ¿Quién está más extraviado que quien invoca en lugar de Dios a quien no le responderá hasta el Día del Levantamiento y que no presta atención a sus invocaciones?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdxvi{Y que, cuando los seres humanos sean sacados, serán enemigos para ellos y rechazarán su adoración.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdxvii{Y cuando les son recitados Nuestros versículos claros, aquellos que no creen dicen de la Verdad cuando llega a ellos: «Esto es magia evidente.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdxviii{o dicen: «Él lo ha inventado.» Di: «Si yo lo hubiera inventado no podríais hacer nada por mí ante Dios. Él es Quien mejor sabe lo que difundís sobre él. Él es suficiente testigo entre mí y vosotros y Él es el Perdonador, el Clementísimo con los creyentes.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdxix{Di: «Yo no soy el primer Mensajero que ha venido y no sé lo que se hará conmigo ni con vosotros. Sólo sigo lo que me ha sido revelado y sólo soy un amonestador claro.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdxx{Di: «¿Habéis visto si acaso procede de Dios y vosotros no creéis en él y un testigo de los Hijos de Israel da testimonio de algo semejante y cree en ello mientras vosotros os mostráis altivos ante ello? En verdad, Dios no guía a la gente opresora.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdxxi{Y los que no creen dicen sobre los creyentes: «Si fuera algo bueno no se nos habrían adelantado en ello.» Y, como ellos no son guiados por él, dicen: «Es una vieja mentira.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdxxii{Y, antes de él, la Escritura de Moisés fue una guía y una misericordia y ésta es una Escritura que la confirma en lengua árabe, para amonestar a quienes oprimen y una buena noticia para quienes son buenos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdxxiii{En verdad, quienes dicen: «Nuestro Señor es Dios.» y luego se mantienen firmes, no tendrán que temer y no estarán tristes.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdxxiv{Ellos son la gente del Jardín en el que estarán eternamente en recompensa por lo que hacían.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdxxv{Y hemos encomendado al ser humano que sea bueno con sus padres. Su madre le cargó con esfuerzo y con esfuerzo le dio a luz. Y su embarazo y su lactancia toman treinta meses. Hasta que, al alcanzar la edad adulta y alcanzar la madurez a los cuarenta años, dice: «¡Señor mío! Inspírame para que agradezca los favores con que nos has agraciado a mí y a mis padres y para realizar actos buenos de los que Tú estés satisfecho y haz que mis descendientes sean rectos.» «En verdad, a Ti me vuelvo arrepentido y, en verdad, soy de los sometidos a Ti.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdxxvi{Esos son aquellos de quienes Nosotros aceptamos lo mejor de lo que hacen y perdonamos sus faltas. Y estarán entre la gente del Jardín. Es la promesa verdadera que se les ha hecho.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdxxvii{Y quien diga a sus padres: «¡Uf con vosotros dos! ¿Acaso me prometéis que seré sacado de la tumba, cuando otras generaciones han pasado antes de mí?» Y ambos invocarán la ayuda de Dios: «¡Ay de ti! ¡Cree! ¡En verdad, la promesa de Dios es verdadera!» Y él diga: «¡Eso no son más que mitos de los primitivos!»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdxxviii{Esos son sobre quienes se verificará la palabra dada a las comunidades de genios y de humanos que pasaron antes de ellos. En verdad, ellos serán los perdedores.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdxxix{Para cada persona hay un grado conforme a lo que hizo. Él les recompensará plenamente por sus actos y no serán oprimidos.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdxxx{Y el día en que quienes no creen sean expuestos sobre el Fuego [se les dirá]: «Consumisteis las buenas cosas en vuestra vida mundanal y disfrutasteis de ellas. Así pues, hoy seréis retribuidos con el castigo humillante por haber sido arrogantes en la Tierra sin derecho y por haber sido transgresores.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdxxxi{Y recuerda al hermano de Ad, cuando amonestaba a su pueblo en Al-Ahqaf, y otros amonestadores habían venido antes y vendrían después de él: «No adoréis más que a Dios. En verdad, temo para vosotros el castigo de un día inmenso.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdxxxii{Ellos dijeron: «¿Has venido a nosotros para apartarnos de nuestros dioses? Tráenos, pues, aquello con lo que nos amenazas, si es que eres sincero.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdxxxiii{Él dijo: «En verdad, el conocimiento lo tiene Dios y yo os transmito aquello con lo que he sido enviado, pero veo que vosotros sois un pueblo ignorante.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdxxxiv{Así, cuando lo vieron como una gran nube en el horizonte que avanzaba hacia sus valles, dijeron: «Esa nube nos trae la lluvia.» «No. Es aquello cuya venida pedíais que se apresurase. Un viento que porta un doloroso castigo,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdxxxv{que destruye todas las cosas por orden de su Señor.» Y cuando amaneció no se veían más que sus moradas. «Así es como retribuimos a la gente malhechora.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdxxxvi{Y, ciertamente, les dimos una fuerza que no os hemos dado a vosotros y les dimos oído y vista e intelecto. Pero de nada les sirvió su vista ni su oído ni su intelecto, pues negaron las señales de Dios y se verificó en ellos aquello de lo que se burlaban.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdxxxvii{Y, ciertamente, destruimos las ciudades que había alrededor vuestro, pues les habíamos dado abundantes y variadas señales por si, de esa manera, regresaban.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdxxxviii{¿Por qué no les auxiliaron aquellos que tomaron como dioses en lugar de Dios para obtener cercanía? Al contrario, se apartaron de ellos. Así pues, eran mentiras que ellos inventaron.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdxxxix{Y recuerda cuando te enviamos a un grupo de genios para que escuchasen el Corán y cuando estuvieron presentes, dijeron: «¡Escuchad en silencio!» Y cuando terminó regresaron a su gente.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdxl{Dijeron: «¡Oh, pueblo nuestro! En verdad, hemos escuchado una Escritura que ha sido hecha descender después de Moisés, confirmando lo que había antes de ella. Guía a la Verdad y a un camino recto.»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdxli{«¡Oh, pueblo nuestro! Responded al que llama a Dios y creed en Él. Él os perdonará algunos de vuestros pecados y os protegerá de un castigo doloroso.»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdxlii{Y quien no responda a la llamada de Dios, ni podrá debilitar a Dios en la Tierra ni tendrá otros protectores aparte de Él. Estarán en un extravío evidente.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdxliii{¿Acaso no ven que Dios, que ha creado los cielos y la Tierra y que no ha tenido limitaciones para crearlos, es capaz de dar vida a los muertos? Así es. En verdad, Él tiene poder para hacer cualquier cosa.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdxliv{Y el día que quienes no creen sean expuestos al Fuego: «¿No es esto cierto?» Dirán: «¡Sí! ¡Lo juramos por nuestro Señor!» Dirá Él: «¡Probad, pues, el castigo por no haber creído!»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdxlv{Así pues, se paciente, de la misma manera que fueron pacientes los Mensajeros poseedores de una fuerte determinación, y no quieras apresurar su castigo. El día en que ellos vean lo que se les ha prometido creerán que sólo han permanecido una hora de un día. Es un comunicado. ¿Acaso alguien va a ser destruido aparte de la gente trasgresora?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdxlvi{\basmalahes Él hará que se pierdan las obras de quienes no son creyentes y ponen obstáculos en el camino de Dios.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdxlvii{Y Él ocultará los malos actos y corregirá la situación de quienes son creyentes, hacen buenas obras y creen en lo que se hizo descender sobre Muhammad, que es la Verdad que procede de su Señor.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdxlviii{Eso es porque quienes no creen siguen lo que es falso y quienes creen siguen la Verdad que viene de su Señor. Así es como Dios explica a los seres humanos su situación.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdxlix{Cuando os encontréis [en batalla] con los que no creen, golpeadles en los cuellos hasta que les hayáis diezmado y apresadles atándoles fuertemente. Luego, o bien otorgadles la libertad o bien pedid un rescate por ellos, para que termine la carga de la guerra. Así sea. Y si Dios hubiera querido Él mismo les habría castigado, pero lo hace para poner a prueba a algunos de vosotros por medio de otros. Y Dios no dejará que se pierdan las obras de quienes han sido matados en la senda de Dios.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdl{Él les guiará inmediatamente y arreglará su situación\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdli{y les hará entrar en el Jardín que les había descrito.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdlii{¡Oh, creyentes! ¡Si auxiliáis a Dios, Él os auxiliará y consolidará vuestros pasos!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdliii{Y quienes no creen estarán perdidos y sus obras habrán sido en vano.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdliv{Eso es porque rechazaron lo que Dios hizo descender y Él ha invalidado sus obras.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdlv{¿Acaso no han viajado por la Tierra y han observado cuál fue el final de quienes les precedieron? Dios les destruyó y los que no creen tendrán un fin similar.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdlvi{Eso es porque Dios es el protector de quienes son creyentes y los que no creen no tienen quien les proteja.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdlvii{En verdad, Dios hará entrar a quienes creen y realizan buenas obras en Jardines de cuyas profundidades brotan ríos y quienes no creen disfrutan y comen como come el ganado y el lugar para ellos será el Fuego.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdlviii{¡Cuántas ciudades más poderosas que tu ciudad, la cual te ha expulsado, hemos destruido y no tuvieron quien les auxiliase!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdlix{¿Acaso quien se basa sobre una prueba clara que procede de su Señor es como aquel a quien sus malas acciones le parecen buenas y sigue sus deseos y pasiones?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdlx{Descripción del Jardín que ha sido prometido a los temerosos de Dios: En él hay ríos de agua fresca e incorruptible, ríos de leche cuyo sabor no varía, ríos de vino delicioso para quienes lo beben y ríos de miel pura. En él habrá para ellos todo tipo de frutos y el perdón de su Señor. ¿Serán ellos como quien estará eternamente en el Fuego y recibirá para beber agua hirviente que le destrozará los intestinos?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdlxi{Y, entre ellos, algunos te escuchan, pero cuando abandonan tu presencia dicen a quienes les ha sido dado el conocimiento: «¿Qué es lo que acaba de decir?» Esos son a quienes Dios ha puesto un sello sobre sus corazones y que siguen sus propios deseos y pasiones.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdlxii{Y a quienes siguen la buena guía, Él les incrementa la guía y les da temor de Dios.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdlxiii{¿Acaso esperan otra cosa excepto que la Hora llegue a ellos por sorpresa? Ciertamente, sus señales ya han venido y de nada les servirá recordar cuando llegue a ellos.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdlxiv{Así pues, sabe que no hay más dios que Dios y pide el perdón de tus pecados y el de los creyentes y las creyentes. Y Dios conoce vuestros cambios de estado y aquello en lo que sois firmes y estables.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdlxv{Quienes son creyentes dicen: «¿Por qué no se hará descender una sura?» Pero cuando se hace descender una sura en la que se menciona el combate claramente, ves a quienes tienen una enfermedad en su corazón que te miran con la mirada de quien está cerca de la muerte. Mejor sería para ellos\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdlxvi{obediencia y nobles palabras. Así pues, una vez resuelto el asunto, si permanecen leales a Dios será mejor para ellos.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdlxvii{¿Habéis tenido en cuenta que si dais la espalda causaréis corrupción en la Tierra y cortaréis los lazos de sangre?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdlxviii{Esos son aquellos a quienes Dios ha maldecido, por lo cual les ha dejado sordos y ciegos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdlxix{¿Es que no meditan en el Corán? ¿O tienen candados en sus corazones?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdlxx{En verdad, a quienes dan la espalda después de que les ha sido explicada claramente la guía, Satanás les ha seducido y les ha dado vanas esperanzas.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdlxxi{Eso es por decir a quienes aborrecen lo que Dios hace descender: «Os obedeceremos en algunos asuntos.» Pero Dios conoce sus secretos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdlxxii{¿Qué pasará cuando los ángeles les golpeen sus rostros y sus espaldas?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdlxxiii{«Eso por seguir lo que disgusta a Dios y aborrecer lo que a Él le satisface.» Así pues, Él frustrará sus obras.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdlxxiv{¿O creían quienes tienen una enfermedad en sus corazones que Dios no iba a sacara a la luz el profundo odio que ellos tienen?\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdlxxv{Y, si Nosotros quisiéramos, te los haríamos ver para que les reconocieses por sus rasgos, pero les reconocerás por su manera de hablar. Dios conoce vuestros actos.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdlxxvi{Y, ciertamente, os pondremos a prueba, hasta saber quiénes son los combatientes esforzados de entre vosotros y los pacientes y pondremos a prueba lo que se dice de vosotros.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdlxxvii{En verdad, quienes no creen y ponen trabas en el camino de Dios y desafían al Mensajero después de que les ha sido claramente explicada la guía, no perjudican a Dios en nada y Él pronto frustrará sus obras.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdlxxviii{¡Oh, creyentes! ¡Obedeced a Dios y obedeced al Mensajero y no hagáis que vuestras obras no valgan nada!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdlxxix{En verdad, a quienes no creen y ponen trabas en el camino de Dios y luego mueren sin ser creyentes, Dios no les perdonará.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdlxxx{Así pues, no flaqueéis invitando a la paz, pues vosotros sois los vencedores y Dios está con vosotros y Él no reducirá la recompensa por vuestras obras.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdlxxxi{En verdad, la vida de este mundo es juego y vanidad y, si creéis y sois temerosos de Dios, Él os dará vuestra recompensa y no os pedirá vuestros bienes.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdlxxxii{Si os los pidiera y os presionara os mostraríais avariciosos y provocaría vuestro odio.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdlxxxiii{Se os invita a contribuirán a la causa de Dios, pero algunos de vosotros os mostráis avaros. Y quien es avaro, en verdad, se perjudica a sí mismo con su avaricia, pues, ciertamente, Dios es rico por Sí mismo y vosotros sois los necesitados. Y si dais la espalda, Él os sustituirá por otro pueblo que no será como vosotros.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdlxxxiv{\basmalahes En verdad, [Muhammad] te hemos proporcionado una victoria evidente\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdlxxxv{para que Dios te disculpe de los cargos anteriores y de los últimos y para completar Su favor sobre ti y guiarte a un camino recto.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdlxxxvi{Y Dios te auxiliará con un auxilio poderoso.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdlxxxvii{Él es Quien hizo descender la tranquilidad en el corazón de los creyentes para que añadiesen fe a su fe. A Dios pertenecen los ejércitos de los cielos y de la Tierra y Dios es conocedor, sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdlxxxviii{Y para que Él haga entrar a los creyentes y a las creyentes en Jardines de cuyas profundidades surgen los ríos, en los que estarán eternamente, y para perdonar sus pecados. Y esto es ante Dios una victoria inmensa.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdlxxxix{Y para que Él castigue a los hipócritas y a las hipócritas y a los idólatras y a las idólatras, que tienen mala opinión de Dios. Sobre ellos caerá la rueda del mal. Y Dios estará enojado con ellos y les maldecirá y les preparará el Infierno. ¡Qué mal destino!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdxc{Y a Dios pertenecen los ejércitos de los cielos y de la Tierra y Dios es todopoderoso, sabio.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdxci{En verdad, te hemos enviado como un testigo, uno que porta la buena nueva y un amonestador\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdxcii{para que creáis en Dios y en Su mensajero y para que Le apoyéis y Le reverenciéis y Le glorifiquéis mañana y tarde.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdxciii{En verdad, quienes te juran lealtad, a Dios le juran lealtad. La mano de Dios está sobre sus manos. Así pues, quien rompe su juramento lo rompe en su propio detrimento y a quien es fiel a la promesa que ha hecho a Dios, Él pronto le otorgará una enorme recompensa.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdxciv{Los beduinos que se quedaron atrás te dirán: «Nuestros bienes y nuestras familias nos mantuvieron ocupados, así pues, pide perdón para nosotros.» Dicen con sus lenguas lo que no hay en sus corazones. Di: «¿Quién tiene algún poder ante Dios si Él quisiera perjudicaros o quisiera beneficiaros? Pero Dios está bien informado de lo que hacéis.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdxcv{Pensasteis que el Mensajero y los creyentes no regresarían a sus familias jamás. Eso es lo que el demonio os hizo creer en vuestros corazones. Tuvisteis un mal pensamiento. Fuisteis una gente corruptora.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdxcvi{Quien no crea en Dios y en Su Mensajero sepa que hemos preparado un fuego llameante para los que no creen.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdxcvii{A Dios pertenece el reino de los cielos y de la Tierra. Perdona a quien Él quiere y castiga a quien Él quiere. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdxcviii{Los que se quedaron atrás dirán cuando salgáis a capturar el botín: «¡Dejad que os sigamos!» Quisieran cambiar la palabra de Dios. Di: «¡Jamás nos seguiréis! Ya lo dijo así Dios anteriormente.» Entonces dirán: «¡Tenéis envidia de nosotros!» Pero es que poseen muy poco entendimiento.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdxcix{Di a los beduinos que se quedaron atrás: «Pronto se os convocará contra un pueblo poseedor de una gran fuerza. Les combatiréis si no se hacen musulmanes. Así pues, si obedecéis, Dios os dará una buena recompensa, pero si dais la espalda, como disteis la espalda anteriormente, os castigará con un castigo doloroso.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdc{No tienen obligación de salir a combatir los ciegos ni los cojos ni los enfermos. Y a quienes obedezcan a Dios y a Su Mensajero, Él les hará entrar en Jardines de cuyas profundidades brotan los ríos, y a quienes den la espalda Él les castigará con un castigo doloroso.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdci{Ciertamente, Dios quedó satisfecho de los creyentes cuando te juraron lealtad bajo el árbol, pues sabía lo que había en sus corazones. Por ello, hizo descender la tranquilidad sobre ellos y les favoreció con una victoria cercana\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcii{y con la captura de abundantes botines. Y Dios es todopoderoso, sabio.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdciii{Dios os ha prometido que obtendréis abundantes botines y por eso Él ha acelerado éste y ha apartado de vosotros las manos de la gente. Y para que sea una señal para los creyentes y para guiaros a un camino recto.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdciv{Y otros que todavía no habéis obtenido pero que Dios tiene bajo control. Y Dios tiene poder sobre todas las cosas.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcv{Y, si los que no creen os combaten, darán la espalda. Luego, no encontrarán quien les proteja ni quien les auxilie.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcvi{Es la costumbre de Dios, que también existió en el pasado. Y no encontrarás cambios en la costumbre de Dios.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcvii{Él es Quien ha apartado sus manos de vosotros y vuestras manos de ellos en el interior de La Meca, después de daros la victoria sobre ellos. Y Dios posee una profunda visión de lo que hacéis.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcviii{Ellos son quienes no creyeron y os impidieron acceder a la Mezquita Sagrada y que vuestras ofrendas llegasen al lugar del sacrificio. Y si no hubiese sido por los hombres creyentes y las mujeres creyentes que vosotros no conocíais, a los que habríais podido matar sin querer y que habría hecho que fueseis censurados… Para que Dios haga entrar en Su misericordia a quien Él quiera. Si ellos hubiesen estado separados, habríamos castigado, con seguridad, a quienes de ellos no creían, con un castigo doloroso\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcix{cuando el corazón de los no creyentes se llenó de furia, la furia propia de la ignorancia pagana, y Dios hizo descender Su tranquilidad sobre Su Mensajero y sobre los creyentes y les impuso la palabra del temor de Dios, pues ellos y sus familias eran quienes más derecho tenían a ella. Y Dios es Quien mejor conoce todas las cosas.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcx{Ciertamente, Dios confirmó a Su Mensajero la visión verdadera: «Entraréis en la Mezquita Sagrada, si Dios quiere, seguros, con vuestras cabezas afeitadas o el pelo cortado y sin temor.» Y Él conoce lo que vosotros no conocéis y os dará, aparte de esto, una victoria próxima.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcxi{Él es Quien ha enviado a Su Mensajero con la guía y con la religión verdadera para que prevalezca sobre todas las religiones. Y Dios es suficiente como testigo.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcxii{Muhammad el Mensajero de Dios y los que con él están son duros con los que tratan de ocultar la Verdad y misericordiosos entre ellos. Les verás inclinándose y prosternándose, buscando el favor de Dios y Su satisfacción. En sus rostros se perciben las señales por efecto de su prosternación. Así están descritos en la Torá y en el Evangelio. Son como un sembrado en el que germinan sus semillas, crecen y se ensanchan y fortalecen en su tallo, sorprendiendo a los sembradores. Y con ello Él enoja a los que no creen. Y Dios ha prometido a quienes de ellos crean y realicen buenas obras, perdón y una recompensa inmensa.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcxiii{\basmalahes ¡Oh, creyentes! Nos pongáis nada por delante de Dios y Su Mensajero y sed temerosos. En verdad, Dios todo lo oye, todo lo sabe.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcxiv{¡Oh, creyentes! No levantéis vuestras voces sobre la voz del Mensajero y no le habléis a gritos como os habláis los unos a los otros, no sea que vuestras obras se malogren sin que os deis cuenta.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcxv{En verdad, quienes bajan su voz ante el Mensajero de Dios son a quienes Dios ha elegido sus corazones para el temor. Tendrán perdón y una recompensa inmensa.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcxvi{En verdad, la mayoría de quienes te llaman desde fuera de las habitaciones privadas no razonan.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcxvii{Y si tuviesen paciencia hasta que salgas ante ellos sería mejor para ellos. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdcxviii{¡Oh, creyentes! Si viene a vosotros un trasgresor con una noticia ¡Verificadla! No sea que perjudiquéis a alguien por ignorancia y tengáis que arrepentiros de lo que habéis hecho.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcxix{Y sabed que el Mensajero de Dios está entre vosotros. Si os obedeciera en muchas de las cosas sufriríais. Pero Dios os ha hecho amar la fe y la ha adornado en vuestros corazones y os ha hecho odiar la falta de fe, la trasgresión y la desobediencia. Esos son los bien guiados.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcxx{Un favor y una merced de Dios. Y Dios es Quien todo lo conoce, es sabio.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdcxxi{Si dos grupos de creyentes pelean entre sí, poned paz entre ellos. Pero si uno de ellos oprime y maltrata al otro, combatid contra el que agrede hasta que regrese a la orden de Dios. Y si regresa, entonces poned paz entre ellos con justicia y equidad. En verdad, Dios ama a quienes son ecuánimes.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdcxxii{En verdad, los creyentes son hermanos, así pues, poned paz entre vuestros hermanos, Y sed temerosos de Dios para que, quizás así, se tenga misericordia de vosotros.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdcxxiii{¡Oh, creyentes! ¡Que un pueblo no se burle de otro, no vayan a ser mejor que ellos! Ni una mujer de otra mujer, no vaya a ser mejor que ella. Y no os difaméis unos a otros ni os insultéis con motes. ¡Qué mal ser llamado «trasgresor» después de haber recibido la fe! ¡Y quienes no se arrepienten, esos son los opresores!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdcxxiv{¡Oh, creyentes! ¡Absteneos mucho de las dudas! En verdad, algunas dudas son pecado. Y no os espiéis ni os difaméis unos a otros. ¿Acaso alguno de vosotros quiere comer la carne de su hermano muerto? ¡Lo aborreceríais! Y sed temerosos de Dios. En verdad, Dios acepta el arrepentimiento, es misericordiosísimo con los creyentes.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdcxxv{¡Oh, gentes! En verdad, os hemos creado de un macho y una hembra y hemos hecho de vosotros pueblos y tribus para que os conozcáis. En verdad, el más noble de vosotros ante Dios es quien posee mayor temor de Dios. En verdad, Dios todo lo conoce, está bien informado.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdcxxvi{Los beduinos dicen: «¡Creemos!» Di: «No creéis. Mejor decid: ‘Nos hemos hecho musulmanes’ pues todavía no ha entrado la fe en vuestros corazones.» Y si obedecéis a Dios y a Su Mensajero, Él no os disminuirá en nada la recompensa por vuestras obras. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxxvii{En verdad, los creyentes son aquellos que tienen fe en Dios y en Su Mensajero. Luego, no tienen dudas y combaten con sus bienes y sus personas en la causa de Dios. Esos son los sinceros.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxxviii{Di: «¿Vais a enseñar a Dios vuestra religión, cuando Dios conoce los que hay en los cielos y en la Tierra?» Dios tiene conocimiento de todas las cosas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxxix{Creen que te han hecho un favor por haber aceptado el Islam. Di: «No penséis que me habéis hecho un favor abrazando el Islam. Es Dios Quien os ha hecho un favor a vosotros guiándoos a la fe, si es que sois sinceros.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxxx{En verdad, Dios conoce lo que está oculto a los sentidos en los cielos y en la Tierra y Dios ve claramente lo que hacéis.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxxxi{\basmalahes Qaf. Juro por el glorioso Corán.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcxxxii{Pero ellos se sorprenden de que venga a ellos un amonestador que procede de ellos mismos y por eso, quienes no creen, dicen: «¡Esto es algo sorprendente!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcxxxiii{¿Acaso cuando estemos muertos y seamos polvo…? Ese es un retorno lejano.»\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcxxxiv{Ciertamente, Nosotros sabemos lo que la Tierra disminuye de ellos. Y junto a Nosotros hay una Escritura protectora.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcxxxv{Pero desmienten la Verdad cuando llega a ellos, así que se encuentran en un estado de confusión.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdcxxxvi{¿Acaso no observan cómo hemos construido y adornado el cielo que hay sobre ellos y que no hay fallos en él?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcxxxvii{¿Y que hemos expandido la Tierra y fijado en ella firmes montañas y que hemos hecho crecer en ella una pareja de cada planta que alegra la vista,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcxxxviii{como un medio de profundizar la visión y como un recuerdo para todo siervo contrito?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdcxxxix{Y hemos hecho descender del cielo agua bendecida con la que hemos hecho brotar jardines y las semillas de las cosechas\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdcxl{y esbeltas palmeras datileras de racimos apretados.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdcxli{Provisión para los siervos. Y con ella damos vida a una tierra muerta. Así mismo haremos salir a los muertos de sus tumbas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdcxlii{Antes de ellos desmintió el pueblo de Noé y la gente de Al-Rass y Thamud\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdcxliii{y de Ad y el Faraón y los hermanos de Lot\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdcxliv{y la gente de Al-Aykah y el pueblo de Tuba. Todos ellos desmintieron a los Mensajeros y Mi promesa se verificó.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxlv{¿Acaso Nos agotamos en la primera creación? Pero ellos dudan de una nueva creación.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxlvi{Ciertamente, Nosotros hemos creado al ser humano y sabemos lo que le susurra su alma. Y Nosotros estamos más cerca de él que su vena yugular.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxlvii{Y recuerda) Cuando los dos encargados de recoger recojan, sentados a derecha e izquierda.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxlviii{Él no pronunciará una sola palabra sin que a su lado haya un protector atento.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxlix{Y llegará la embriaguez de la muerte con la Verdad: «Esto es aquello que querías evitar.»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcl{Y será tocada la trompeta: «¡Este es el día prometido!»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcli{Y con cada alma llegará un conductor y un testigo.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdclii{«Ciertamente, no prestabas atención a esto. Así pues, hemos apartado de ti tu velo y hoy tu visión es aguda.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcliii{Y su compañero dirá: «Esto es lo que tengo preparado.»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcliv{«¡Arrojad al Infierno a todo el que negaba la Verdad con obstinación,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdclv{enemigo acérrimo del bien, trasgresor y escéptico! ¡Que ponía otro dios junto a Dios! ¡Arrojadle\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdclvi{al severo castigo!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdclvii{Su compañero dirá: «¡Señor nuestro! No soy yo quien le hizo un tirano prepotente, él ya estaba en un gran extravío.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdclviii{Dirá Él: «¡No discutáis en Mi presencia! ¡Ya os advertí previamente!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdclix{¡Lo que Yo digo es inalterable! ¡Yo no soy opresor con los siervos!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdclx{Recuerda) El día que Nosotros le digamos al Infierno: «¿Estás ya lleno?» y él dirá: «¿Aún hay más?»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdclxi{Y sea aproximado el Jardín para los temerosos de Dios a un lugar no alejado.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdclxii{«Esto es lo que os fue prometido para todo el que se volviera a Dios con frecuencia y fuese cuidadoso.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdclxiii{Para quien temiese al Clementísimo en secreto y viniese con un corazón contrito.»\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdclxiv{«¡Entrad en él en paz! ¡Éste es el Día de la Eternidad!»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdclxv{Allí habrá para ellos lo que deseen y junto a Nosotros más aun.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdclxvi{¡Cuántas generaciones hemos destruido antes de ellos que fueron más fuertes que ellos y que construyeron grandes ciudades! ¿Hay manera de escapar?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdclxvii{En verdad, en ello hay un recuerdo para quien tenga corazón o para quien presta oído y está atento.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdclxviii{Y, ciertamente, hemos creado los cielos y la Tierra y lo que hay entre ambos en seis días, sin que Nos tocase la fatiga.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdclxix{Así pues, se paciente con lo que dicen y glorifica con alabanzas a tu Señor antes de que salga el Sol y antes de que se ponga.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdclxx{Y glorifícale parte de la noche y después de las prosternaciones.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdclxxi{Y permaneced atentos al día en que un pregonero pregone desde un lugar cercano.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdclxxii{Día en el que escucharán el Grito con la Verdad. Ese será el día de la salida de las tumbas.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdclxxiii{En verdad, Nosotros damos la vida y damos la muerte y Nosotros somos el destino final\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdclxxiv{el día en que la tierra se abra sobre ellos y acudan rápidos. Esa reunión es algo fácil para Nosotros.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdclxxv{Nosotros somos Quienes mejor conocemos lo que dicen. Tú no eres alguien que venga a obligarles. Así pues, amonesta con el Corán a quien tema Mi amenaza.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdclxxvi{\basmalahes Juro por los vientos huracanados\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdclxxvii{y por las nubes cargadas de lluvia\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdclxxviii{y por las naves que se deslizan con facilidad\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdclxxix{y por los ángeles que distribuyen las órdenes.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdclxxx{En verdad lo que se os ha prometido es cierto\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdclxxxi{y, en verdad, la recompensa tendrá lugar.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdclxxxii{Juro por los cielos llenos de adornos\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdclxxxiii{que vosotros mantenéis opiniones discrepantes.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdclxxxiv{Quienes discrepan, discrepan de él.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdclxxxv{¡Que mueran los mentirosos!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdclxxxvi{Esos que están en la ignorancia y el descuido\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdclxxxvii{preguntan: «¿Cuándo será el Día de la Recompensa?»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdclxxxviii{Será el día en que ellos se quemarán en el Fuego:\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdclxxxix{«¡Probad vuestro tormento! ¡Esto es lo que pedíais con premura!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxc{En verdad, los temerosos de Dios estarán en Jardines y Fuentes,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxci{recibiendo lo que su Señor les dé. En verdad, antes de ello, eran de los que hacían el bien.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxcii{Eran de los que dormían poco durante la noche\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxciii{y antes del amanecer pedían perdón\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxciv{y daban de sus bienes a los mendigos y a los necesitados su derecho.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcxcv{Y en la Tierra hay señales para quienes tienen certeza,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcxcvi{y en vosotros mismos. ¿Cómo es que no las veis?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcxcvii{Y en el cielo está vuestra provisión y lo que os ha sido prometido.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcxcviii{Así pues, juro por el Señor del cielo y la Tierra, que esto es tan verdad como que vosotros habláis.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcxcix{¿Ha llegado a vosotros la historia de los nobles invitados de Abraham?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcc{Cuando llegaron donde él estaba y dijeron: «Paz!» Él dijo: «¡Paz! Sois gente desconocida.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcci{Se fue discretamente hacia donde estaba su familia y regresó con un cordero bien cebado\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdccii{y lo puso cerca de ellos. Les dijo: «¿Es que no coméis?»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcciii{Y sintió miedo de ellos. Ellos dijeron: «No temas» y le dieron la buena nueva de un hijo sabio.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcciv{Entonces su esposa vino gritando y golpeando con fuerza su rostro y dijo: «¡Soy una anciana estéril!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdccv{Ellos dijeron: «Así lo ha dicho tu Señor. En verdad, Él es el Más sabio, Quien todo lo conoce.»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdccvi{Él dijo: «¿Cuál es vuestra importante misión? ¡Oh, Mensajeros!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdccvii{Ellos dijeron: «En verdad, hemos sido enviados a un pueblo de malhechores\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdccviii{para que lancemos sobre ellos piedras de barro\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdccix{marcadas por tu Señor para los transgresores.»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdccx{E hicimos salir a los creyentes que en ella había\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdccxi{y no hayamos en ella más que una casa de musulmanes.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdccxii{Y dejamos en ella una señal para quienes temen el castigo doloroso.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdccxiii{Y en Moisés, cuando le enviamos al Faraón con una autoridad evidente.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdccxiv{Pero se dio la vuelta, seguro de su poder, y dijo: «¡Un mago o un demente!»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdccxv{Así pues, atrapamos a él y a su ejército y les arrojamos al mar, pues eran censurables.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdccxvi{Y en Ad, cuando enviamos sobre ellos el viento arrasador,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdccxvii{que dejó todo aquello sobre lo que cayó como huesos polvorientos.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdccxviii{Y en Tamud, cuando se les dijo: «¡Disfrutad por un tiempo!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdccxix{Pero desafiaron la orden de su Señor y les alcanzó el rayo mientras lo miraban,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdccxx{sin poder ni levantarse ni ser auxiliados.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdccxxi{Y, anteriormente, el pueblo de Noé. En verdad, fueron un pueblo de trasgresores.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdccxxii{Y hemos construido el cielo con un poder inigualable y, en verdad, Nosotros lo poseemos en una medida incomparable.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdccxxiii{Y hemos expandido la Tierra. ¡Qué bendición de Expandidor!\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdccxxiv{Y hemos creado todas las cosas por parejas. Quizás así reflexionéis.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdccxxv{Así pues, escapad hacia Dios. En verdad, yo soy para vosotros un amonestador claro de Su parte.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdccxxvi{Así pues, no pongáis otro dios junto a Dios. En verdad, yo soy para vosotros un amonestador claro de Su parte.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdccxxvii{De la misma manera, no vino ningún Mensajero a quienes existieron antes de ellos sin que dijesen: «¡Un mago o un demente!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdccxxviii{¿Es que se lo han trasmitido unos otros? No. Lo que sucede es que son gente rebelde.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmdccxxix{Así pues, ¡Apártate de ellos y no serás censurado!\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmdccxxx{¡Y recuerda! pues, en verdad, el recuerdo beneficia a los creyentes.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmdccxxxi{Y no he creado a los genios y los humanos excepto para que Me adoren.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmdccxxxii{No quiero de ellos ninguna provisión ni quiero que Me alimenten.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmdccxxxiii{En verdad, Dios es Quien otorga la provisión con abundancia, el Poseedor de la fuerza, el Firme.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmdccxxxiv{Así pues, quienes oprimieron, en verdad, recibirán su parte, igual que la recibirán sus compañeros. ¡Que no quieran apresurarlo!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmdccxxxv{¡Ay de quienes no creyeron, ese día que les ha sido prometido!\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmdccxxxvi{\basmalahes Juro por el monte\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdccxxxvii{y por la Escritura que fue escrita\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdccxxxviii{en un pergamino desenrollado\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdccxxxix{y por la Casa siempre frecuentada\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdccxl{y por la bóveda elevada\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccxli{y por el mar rebosante:\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdccxlii{En verdad, el castigo de tu Señor tendrá lugar.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdccxliii{Nada podrá impedirlo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccxliv{El día en el que el cielo se agite violentamente\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccxlv{y las montañas se pongan en movimiento\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccxlvi{¡Ay! ese día, de los desmentidores!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccxlvii{¡Aquellos que se entretienen jugando con palabras vanas!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccxlviii{El día en que sean arrastrados al fuego del Infierno:\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccxlix{«¡He ahí el Fuego que vosotros desmentíais!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccl{«¿Es esto magia o es que vosotros no veis?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccli{¡Arded en él! Y tengáis paciencia o no tengáis paciencia os dará igual. En verdad, seréis recompensados conforme a lo que hacíais.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcclii{En verdad, los temerosos de Dios estarán en Jardines cómodamente.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdccliii{Felices por lo que les ha dado su Señor y porque su Señor les ha librado del castigo del Infierno:\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccliv{«¡Comed y bebed a placer por lo que hacíais!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcclv{Estarán reclinados en divanes alineados y les emparejaremos con huríes de grandes ojos.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcclvi{Juntaremos a quienes sean creyentes y a sus descendientes que les hayan seguido en la fe. No disminuiremos en nada (la recompensa de) sus acciones. Cada cual será rehén de lo que haya realizado.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcclvii{Les facilitaremos todas las frutas y la carne que deseen.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcclviii{Allí se ofrecerán unos a otros una copa cuyo contenido no les incitará a las palabras vanas ni pecaminosas.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcclix{Circularán alrededor de ellos jóvenes como perlas guardadas.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcclx{Se volverán unos a otros preguntándose.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcclxi{Dirán: «En verdad, estábamos antes con nuestras familias con un temor reverencial\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcclxii{y Dios nos agració y nos protegió del castigo del viento abrasador.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcclxiii{En verdad, antes siempre le suplicábamos. En verdad, Él es el Benigno, el Misericordiosísimo con los creyentes.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcclxiv{Así pues ¡Amonesta! Por la clemencia de tu Señor no eres ni un adivino ni un loco.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcclxv{Pero dicen: «¡Es un poeta! ¡Esperaremos a que le llegue la conmoción de la muerte!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdcclxvi{Di: «¡Esperad que yo también esperare con vosotros!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdcclxvii{¿Es su propio intelecto quien les ordena esto o es que son gente rebelde?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdcclxviii{O dicen: «Él lo ha inventado.» Pero lo que sucede en que no creen.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdcclxix{¡Que traigan un discurso semejante si es que son sinceros!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdcclxx{¿Fueron ellos creados de la nada o son sus propios creadores?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdcclxxi{¿O han creado ellos los cielos y la Tierra? No. Lo que sucede es que no tienen certeza.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdcclxxii{¿Acaso poseen ellos los tesoros de tu Señor o poseen el control de todo?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdcclxxiii{¿O acaso poseen una escalera con la que escuchar? Pues, que quien lo haya escuchado traiga una prueba clara.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdcclxxiv{¿O para Él serán las hijas y para vosotros los hijos?\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdcclxxv{¿O acaso les pides una recompensa que les abruma con su peso?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdcclxxvi{¿O tienen acceso al mundo oculto a los sentidos y toman nota?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdcclxxvii{¿O es que quieren preparar una trampa? Pues, los que tratan de ocultar la Verdad son quienes caen en la trampa.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdcclxxviii{¿O tienen ellos otro dios distinto a Dios? ¡Glorificado sea Dios por encima de lo que Le asocian!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcclxxix{Y si vieran un trozo del cielo cayendo, dirían: «¡Son cúmulos nubosos!»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcclxxx{Así pues, ¡Déjales, hasta que encuentren su día, en el cual serán destruidos!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxi{El día en el que sus trampas no les servirán de nada y en el que no serán auxiliados.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxii{Y, en verdad, quienes fueron opresores sufrirán otros castigos, pero la mayoría de ellos desconocen.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxiii{Espera pacientemente el juicio de tu Señor, pues, en verdad, tú estás ante Nuestros ojos. Y glorifica con alabanzas a tu Señor cuando te levantes\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxiv{y glorifícale parte de la noche y al ocultarse las estrellas.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxv{\basmalahes Juro por la estrella cuando se oculta.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxvi{Vuestro compañero no se extravía ni se equivoca\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxvii{y no habla conforme a su deseo,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxviii{sino que es una inspiración que se le revela,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxix{que se la ha dado a conocer el poseedor de una fuerza extraordinaria,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccxc{dueño de una gran inteligencia, que se manifestó\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdccxci{en el horizonte más elevado.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdccxcii{Luego, él se acercó hasta estar muy próximo,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccxciii{hasta estar a una distancia de dos arcos o más cerca.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccxciv{Y Él reveló a Su siervo lo que le reveló.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccxcv{El corazón no ha mentido en lo que vio.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccxcvi{¿Discutiréis, pues, con él sobre lo que vio?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccxcvii{Y, ciertamente, él lo vio en otra ocasión\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccxcviii{junto al Loto del Límite,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccxcix{cerca del cual está el Jardín de la Morada,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccc{cuando cubrió el Loto aquello que cubrió.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdccci{No se desvió la mirada ni se equivocó.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcccii{Ciertamente, vio algunas de las grandes señales de su Señor.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccciii{«¿Habéis visto a Al-Lat y a Uzza\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdccciv{y a Manat, la tercera de ellas?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcccv{¿Acaso son para vosotros los varones y para Él las hembras?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcccvi{¡Eso sería entonces un reparto injusto!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcccvii{Ellas no son más que nombres que vosotros y vuestros padres habéis puesto. Dios no ha hecho descender para ellas ninguna autoridad.» Ellos sólo siguen conjeturas y los deseos de su ego aunque, ciertamente, ha llegado a ellos la guía de su Señor.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcccviii{¿Acaso obtendrá el ser humano lo que desea?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcccix{A Dios pertenecen la otra vida y la primera.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcccx{Y ¿Cuántos ángeles hay en los cielos de cuya intercesión no podrán beneficiarse en absoluto excepto después de que Dios de su permiso para quien Él quiera y del que esté satisfecho?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcccxi{En verdad, quienes no creen en la otra vida dan a los ángeles nombres femeninos\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcccxii{aunque no tienen ningún conocimiento de ello. Sólo siguen conjeturas y, en verdad, las conjeturas no sirven de nada frente a la Verdad.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcccxiii{Así pues, apártate de quienes se alejan de Nuestro recuerdo y no desea más que la vida mundanal.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcccxiv{Éste es el límite del conocimiento que ellos pueden alcanzar. En verdad, tu Señor es Quien mejor conoce a quien se extravía de su camino y es Quien mejor conoce a quien se guía.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdcccxv{Y a Dios pertenece lo que hay en los cielos y en la Tierra, para retribuir a quienes hacen el mal por lo que han hecho y recompensar a quienes hacen el bien con lo mejor.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdcccxvi{Aquellos que se abstienen de los grandes pecados e indecencias, excepto los pecados pequeños. En verdad, tu Señor es muy perdonador. Él es Quien mejor os conoce desde que os creó de la tierra y desde que erais fetos en los vientres de vuestras madres. Así pues, no os vanagloriéis. Él es Quien mejor conoce a quienes son temerosos de Dios.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdcccxvii{¿Has visto a quien da la espalda,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdcccxviii{da poco y es tacaño?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdcccxix{¿Acaso posee el conocimiento de lo que está oculto a los sentidos y ve?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdcccxx{¿O no ha sido informado de lo que hay en los escritos de Moisés\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdcccxxi{y de Abraham, el cual fue leal,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdcccxxii{sobre que nadie cargará con la carga de los pecados de otro\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdcccxxiii{y que nada pertenece a la persona excepto aquello por lo que se esfuerza\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdcccxxiv{y que pronto se verán las consecuencias de su esfuerzo,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdcccxxv{que, luego, será recompensado por ello con una recompensa completa\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdcccxxvi{y que el destino final es hacia tu Señor\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdcccxxvii{y que es Él quien te hace reír y llorar\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcccxxviii{y que es Él Quien da la muerte y da la vida?\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcccxxix{Y que es Él Quien ha creado las parejas, el macho y la hembra,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcccxxx{de una gota cuando se eyacula,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxi{y que sobre Él recae la segunda creación,\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxii{y que Él es Quien da la riqueza y la mantiene.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxiii{Y que Él es el Señor de Sirio\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxiv{y que Él es Quien aniquiló a los primeros Ad\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxv{y a Zamud sin dejar a ninguno\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxvi{y, anteriormente, al pueblo de Noé? -En verdad, ellos fueron los más opresores y los más rebeldes-\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxvii{Y a aquellos que destruyó poniendo lo de arriba abajo\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxviii{y cubriéndolas con lo que las cubrió.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxix{¿Cuál, pues, de las mercedes de vuestro Señor pondréis en duda?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmdcccxl{Éste es un amonestador como los amonestadores primeros.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmdcccxli{Se aproxima lo inminente.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmdcccxlii{Nadie, aparte de Dios, puede librar de ello.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmdcccxliii{¿Acaso os sorprenderéis de estas palabras?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmdcccxliv{¿Y reiréis y no lloraréis,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmdcccxlv{permaneciendo distraídos?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmdcccxlvi{Así pues, ¡Prosternaos y adorad a Dios!\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmdcccxlvii{\basmalahes La Hora está muy cerca y la Luna se ha partido.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcccxlviii{Y si ven una señal se alejan y dicen: «¡Magia! ¡Continuamente!»\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcccxlix{Y desmienten y siguen sus deseos. Pero todo asunto está establecido\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcccl{y, ciertamente, han venido a ellos noticias con amonestación,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcccli{con una sabiduría absoluta. Pero la amonestación no les beneficia.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccclii{Así pues, apártate de ellos. El día en el que el pregonero convoque hacia algo horroroso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcccliii{con la mirada humillada, saldrán de las tumbas como si fueran langostas dispersas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcccliv{acudiendo apresuradamente hacia quien les convoca. Los que no creían dirán: «Este es un día difícil.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccclv{El pueblo de Noé desmintió antes de ellos. Desmintieron a Nuestro siervo y dijeron: «¡Es un loco y los espíritus le torturan!»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccclvi{Así pues, él suplicó a su Señor: «¡En verdad, he fracasado! ¡Toma Tú la revancha!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccclvii{Así que, abrimos las puertas del cielo con un agua torrencial\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccclviii{e hicimos que brotasen de la Tierra fuentes y se juntaron las aguas en la medida decretada\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccclix{y le subimos sobre una armazón de tablas y clavos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccclx{que navegó bajo Nuestra mirada atenta, como un castigo para quienes no creían.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccclxi{Y, ciertamente, lo hemos dejado como una señal. Así pues ¿Habrá alguien que recapacite?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccclxii{¡Cómo fueron Mi castigo y Mis advertencias!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdccclxiii{Ciertamente, hemos hecho el Corán fácil de recordar. ¿Habrá quien se deje amonestar?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdccclxiv{Ad desmintió y ¡Cómo fueron Mi castigo y Mis advertencias!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccclxv{En verdad, Nosotros enviamos contra ellos un viento violento y helado en un día nefasto e interminable\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdccclxvi{que derribaba a las gentes como troncos de palmeras sacados de cuajo de sus raíces\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdccclxvii{y ¡Cómo fueron Mi castigo y Mis advertencias!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdccclxviii{Ciertamente, hemos hecho el Corán fácil de recordar. ¿Habrá quien se deje amonestar?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdccclxix{Zamud desmintió Mis amonestaciones.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdccclxx{Y dijeron: «¿Acaso vamos a seguir a una persona que es uno de nosotros? Entonces estaríamos extraviados y dementes.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdccclxxi{¿Iba a recibir el Recuerdo él de entre todos nosotros? ¡No! Más bien es alguien muy mentiroso y arrogante.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdccclxxii{«¡Mañana van a saber ellos quién es el mentiroso arrogante!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdccclxxiii{En verdad, Les enviaré la camella como una prueba. Así pues, vigílales y ten paciencia.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdccclxxiv{«E infórmales que deberán repartir el agua entre ellos y que cada uno deberá estar presente para beber cuando le toque su turno.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdccclxxv{Pero ellos llamaron a su compañero que se ocupó de ello y la mató.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdccclxxvi{y ¡Cómo fueron Mi castigo y Mis advertencias!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdccclxxvii{En verdad, Enviamos sobre ellos un solo grito y quedaron como arbustos secos amontonados por el ganadero.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdccclxxviii{Ciertamente, hemos hecho el Corán fácil de recordar. ¿Habrá quien se deje amonestar?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdccclxxix{El pueblo de Loť desmintió Mis advertencias.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdccclxxx{En verdad, enviamos sobre ellos un huracán de piedras, excepto a la familia de Lot. Les salvamos un poco antes del amanecer.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxi{Una merced de Nuestra parte. Así es como Nosotros recompensamos a quien es agradecido.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxii{Ciertamente, él les advirtió de Nuestro rigor, pero ellos discutieron Nuestras advertencias.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxiii{Le exigieron que les entregase a sus invitados y cegamos sus ojos: «Probad Mi castigo y Mis advertencias.»\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxiv{Y, ciertamente, temprano al amanecer les sorprendió un castigo firme y duradero.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxv{«Probad, pues, Mi castigo y Mis advertencias.»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxvi{Ciertamente, hemos hecho el Corán fácil de recordar. ¿Habrá quien se deje amonestar?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxvii{Y, ciertamente, a las gentes del Faraón les llegaron las advertencias.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxviii{Desmintieron todas Nuestras señales, así que, les atrapamos como atrapa Uno que es todopoderoso, omnipotente.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxix{«¿Acaso vuestros incrédulos son mejores que ellos? ¿O hay para vosotros en las Escrituras una excepción?»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcccxc{¿O dicen: «Nosotros somos un grupo que se auxilia mutuamente y es invencible»?\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcccxci{¡El grupo será derrotado y dará la espalda!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcccxcii{Pero se les ha prometido la Hora, y la Hora será más terrible y más amarga.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcccxciii{¡En verdad, los malhechores están extraviados y dementes!\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcccxciv{El día en que sean arrastrados boca abajo al Fuego: «¡Probad el contacto del Infierno!»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcccxcv{En verdad, hemos creado todo en su justa medida.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcccxcvi{Nuestra orden es como un parpadeo de ojos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdcccxcvii{Y, ciertamente, aniquilamos en el pasado a vuestros semejantes. Así pues ¿Hay alguien que se deje amonestar?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdcccxcviii{Todo lo que ellos han hecho está recogido en el libro de sus obras\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdcccxcix{y todo acto, pequeño o grande está registrado.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcm{En verdad, los temerosos de Dios estarán en Jardines y Arroyos\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcmi{en una reunión de gente sincera junto a un soberano todopoderoso.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcmii{\basmalahes El Clementísimo\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcmiii{ha enseñado el Corán,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcmiv{ha creado al ser humano,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcmv{le ha enseñado a hablar.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcmvi{El Sol y la Luna se mueven con precisión\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcmvii{y la hierba y el árbol se prosternan ante Él.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcmviii{Él ha elevado el cielo y ha establecido la balanza\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcmix{para que no engañéis al pesar.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcmx{¡Dad el peso justo y no deis de menos al pesar!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcmxi{Y ha puesto la Tierra al servicio de los seres humanos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcmxii{En ella hay frutas y palmeras datileras,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcmxiii{grano con vaina y arrayán.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcmxiv{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcmxv{Él ha creado al ser humano de barro seco como la cerámica\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcmxvi{y ha creado a los genios de fuego puro, sin humo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcmxvii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcmxviii{El Señor de los dos Orientes y el Señor de los dos Occidentes.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcmxix{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcmxx{Él ha hecho fluir los dos mares que se juntan.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcmxxi{Entre ellos hay una barrera que no traspasan.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcmxxii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcmxxiii{De ambos salen la perla y el coral.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcmxxiv{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcmxxv{A Él pertenecen las naves que hay en el mar como montañas.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcmxxvi{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcmxxvii{Todo el que está en ella perecerá\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmcmxxviii{y sólo permanecerá el rostro de tu Señor, Dueño y Señor de la Majestad y la Generosidad.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcmxxix{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcmxxx{A Él imploran quienes están en los cielos y la Tierra y Él cada día está ocupado en una nueva actividad.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcmxxxi{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmcmxxxii{Pronto nos ocuparemos de vosotros ¡Oh, los dos pesos!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmcmxxxiii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcmxxxiv{¡Oh, asamblea de genios y humanos! Si podéis atravesar los confines de los cielos y la Tierra ¡Atravesadlos! No los atravesaréis sin una autoridad.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcmxxxv{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcmxxxvi{Se lanzará sobre vosotros dos una llamarada de fuego verde y humo del color del bronce y no podréis auxiliaros unos a otros.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcmxxxvii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcmxxxviii{Así pues, cuando se rasgue el cielo y sea como una piel de color rojo encendido\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcmxxxix{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcmxl{Ese día, ni los genios ni los humanos serán preguntados por sus pecados\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcmxli{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcmxlii{Los malhechores serán reconocidos por sus rasgos y serán atrapados por los flequillos y los pies.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcmxliii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcmxliv{¡Ese es el Infierno que negaban los malhechores!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcmxlv{Circularán entre él y un agua hirviente.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcmxlvi{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcmxlvii{Y para quien temió comparecer ante su Señor habrá dos Jardines\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcmxlviii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcmxlix{Con frutas variadas.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcml{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcmli{En ambos habrá dos fuentes manando.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcmlii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcmliii{En ambos habrá dos clases de cada fruta.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcmliv{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcmlv{Estarán reclinados en cojines tejidos de seda y la fruta madura de ambos Jardines estará al alcance de la mano.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcmlvi{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcmlvii{En ellos estarán las de mirada recatada, a las que ningún humano o genio habrá tocado antes de ellos,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcmlviii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcmlix{como si ellas fuesen rubíes y corales.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcmlx{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcmlxi{¿Acaso la recompensa de hacer el bien es otra que el bien mismo?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcmlxii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcmlxiii{Y, aparte de esos dos, habrá otros dos Jardines\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcmlxiv{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcmlxv{de color verde intenso.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcmlxvi{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcmlxvii{En ambos, [habrá] dos fuentes manando con fuerza.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcmlxviii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcmlxix{En ambos, frutales y palmeras datileras y granados.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcmlxx{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcmlxxi{En ellos, doncellas buenas y hermosas.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcmlxxii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcmlxxiii{Huríes de grandes ojos en pabellones protegidos,\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcmlxxiv{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcmlxxv{a las que ningún humano o genio habrá tocado antes de ellos.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcmlxxvi{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcmlxxvii{Reclinados sobre cojines verdes y hermosas alfombras.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmcmlxxviii{¿Cuál, pues, de las bendiciones de vuestro Señor negaréis?\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmcmlxxix{¡Bendito sea el nombre de tu Señor, Dueño y Señor de la Majestad y la Generosidad!\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmcmlxxx{\basmalahes Cuando tenga lugar el acontecimiento\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxi{no habrá nada que pueda desmentir su acontecer.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxii{Abatidor, exaltador.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxiii{Cuando la Tierra tiemble con fuerza\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxiv{y las montañas se pulvericen totalmente\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxv{y se conviertan en polvo disperso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxvi{seréis divididos en tres grupos:\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxvii{Los compañeros de la derecha. ¿Quiénes son los compañeros de la derecha?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxviii{y los compañeros de la izquierda ¿Quiénes son los compañeros de la izquierda?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxix{y los que van por delante, que serán los que vayan por delante.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcmxc{Esos son los más cercanos\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcmxci{Estarán en los Jardines de las Delicias.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcmxcii{Muchos de los primeros\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcmxciii{y pocos de los últimos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcmxciv{Sobre lechos tejidos en oro,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcmxcv{recostados en ellos, mirándose a la cara unos a otros.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcmxcvi{Circularán alrededor de ellos sirvientes de eterna juventud\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcmxcvii{con copas y jarras y un vaso lleno de un vino que mana de una fuente\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcmxcviii{que no les levantará dolor de cabeza ni les embriagará,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcmxcix{y las frutas que prefieran\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmm{y carne de las aves que les apetezca\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmi{y huríes de grandes ojos,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmii{semejantes a perlas bien guardadas,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmiii{en recompensa por lo que hacían.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmiv{Allí no escucharán conversaciones vanas ni pecaminosas\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmv{sino la palabra «¡Paz!» «¡Paz!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmvi{Y los compañeros de la derecha ¿Qué son los compañeros de la derecha?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmvii{Estarán entre lotos sin espinas\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmviii{y plataneros llenos de racimos,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmix{bajo una sombra extensa y permanente\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmx{y tendrán agua que manará eternamente\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmxi{y frutas abundantes\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmxii{que no se agotarán ni estarán prohibidas\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmxiii{y lechos elevados.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmxiv{En verdad, a ellas las hemos creado de una manera especial\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmxv{y las hemos hecho vírgenes\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmxvi{amorosas, semejantes,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmxvii{para los compañeros de la derecha.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmxviii{Habrá muchos de los primeros\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmxix{y muchos de los últimos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmxx{Y los compañeros de la izquierda. ¿Qué son los compañeros de la izquierda?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmxxi{Estarán entre un calor abrasador y agua hirviente\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmxxii{y bajo una sombra de humo negro\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmxxiii{ni fresca ni confortable.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmxxiv{En verdad, antes de esto, ellos estuvieron en la embriaguez de la opulencia\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmxxv{y persistieron en el gran pecado.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmxxvi{Y decían: «¿Acaso cuando hayamos muerto y seamos polvo y huesos seremos resucitados?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmxxvii{¿Y también nuestros antepasados?»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmxxviii{Di: «En verdad, los primeros y los últimos\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmxxix{serán reunidos en un momento determinado de un día conocido.»\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmxxx{Entonces, en verdad, vosotros ¡Oh, extraviados, desmentidores!\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmxxxi{comeréis de un árbol de Zaqqum,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmxxxii{del que llenaréis los estómagos\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmmxxxiii{y encima de ello beberéis agua hirviente,\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmmxxxiv{beberéis como beben los camellos enfermos que no pueden calmar su sed.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmmxxxv{Esa será la hospitalidad que ellos recibirán el Día de la Recompensa.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmmxxxvi{Nosotros os hemos creado, así pues ¿Por qué no reconocéis?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmmxxxvii{¿Habéis reparado en lo que eyaculáis?\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmmxxxviii{¿Acaso sois vosotros quienes creáis o somos Nosotros los creadores?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmmxxxix{Somos Nosotros quienes decretamos la muerte entre vosotros y nadie Nos podrá impedir\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmmxl{que os sustituyamos por vuestros semejantes y a vosotros os hagamos renacer a lo que no conocéis.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmmxli{Y, ciertamente, ya habéis conocido la primera creación, así pues, ¿Por qué no reflexionáis?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmmxlii{¿Habéis reparado en lo que sembráis?\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmmxliii{¿Sois vosotros quienes lo hacéis crecer o somos Nosotros quienes lo hacemos crecer?\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmmxliv{Si hubiésemos querido habríamos hecho de ello paja seca. Entonces, os lamentaríais:\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmmxlv{«¡Hemos sufrido una grave pérdida!\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmmxlvi{Mas aún. ¡Estamos arruinados!»\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmmxlvii{¿Habéis reparado en el agua que bebéis?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmmxlviii{¿Sois vosotros quienes la hacéis descender de las nubes o somos Nosotros quienes la hacemos descender?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmmxlix{Si hubiésemos querido la habríamos hecho salobre. Así pues ¿Por qué no sois agradecidos?\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmml{¿Habéis reparado en el fuego que encendéis?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmmli{¿Sois vosotros quienes habéis hecho crecer el árbol que lo alimenta o Nosotros quienes lo hacemos crecer?\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmmlii{Somos Nosotros quienes lo hemos puesto como un recuerdo y para el beneficio de los viajeros.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmmliii{Así pues ¡Glorifica el nombre de tu Señor, el Inmenso!\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmmliv{¡Juro por el lugar en el que se encuentran las estrellas!\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmmlv{-Y, en verdad, si supierais, es un juramento grandioso-,\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmmlvi{que, en verdad, es una noble recitación,\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmmlvii{que está en una Escritura escondida.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmmlviii{No la tocarán más que los purificados.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmmlix{Hecha descender gradualmente por el Señor del Universo.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmmlx{¿Acaso esta palabra os parece poca cosa\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmmlxi{y desmentís lo que es vuestra provisión?\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmmlxii{Entonces ¿Por qué, cuando se sube a la garganta,\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmmlxiii{y vosotros estáis contemplando ese momento?\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmmlxiv{-y Nosotros estamos más cerca de él que vosotros, pero no lo veis-\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmmlxv{¿Por qué, si no vais a ser recompensados,\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmmlxvi{no la hacéis regresar, si es verdad lo que decís?\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmmlxvii{Así, si era de los cercanos,\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmmlxviii{estará tranquilo y bien provisto y tendrá un Jardín de Delicias.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmmmlxix{Y si era de los compañeros de la derecha,\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmmmlxx{pues: «¡Paz para ti! de parte de los compañeros de la derecha.»\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmmmlxxi{Pero, si era de los desmentidores extraviados,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmmmlxxii{será alojado en agua hirviendo\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmmmlxxiii{y arderá en el Infierno\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmmmlxxiv{En verdad, esto es totalmente cierto.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmmmlxxv{Así pues, glorifica el nombre de tu Señor el Inmenso.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmmmlxxvi{\basmalahes Glorifica a Dios lo que hay en los cielos y la Tierra y Él es el Todopoderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmlxxvii{A Él pertenece el reino de los cielos y la Tierra.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmlxxviii{Da la vida y da la muerte y Él tiene poder sobre toda cosa. Él es el Primero y el Último y el Manifiesto y el Oculto y Él conoce toda cosa.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmlxxix{Él es Quien creó los cielos y la Tierra en siete días. Luego, se estableció sobre el Trono. Él conoce lo que se introduce en la tierra y lo que sale de ella y lo que desciende del cielo y lo que asciende a él y Él está con vosotros donde quiera que estéis y ve lo que hacéis.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmlxxx{A Él pertenece el reino de los cielos y de la Tierra y a Dios regresan todos los asuntos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmlxxxi{Hace que la noche entre en el día y que el día entre en la noche y Él conoce muy bien lo que hay en el fondo de los pechos.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmlxxxii{¡Creed en Dios y en Su Mensajero y repartid de lo que Él os ha dado como sucesores! Y, quienes de vosotros crean y repartan, tendrán una recompensa grande.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmlxxxiii{¿Cómo no vais a creer en Dios habiéndoos el Mensajero llamado a que creáis en su Señor y habiendo Él aceptado vuestro compromiso, si sois creyentes?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmlxxxiv{Él es Quien hace descender sobre Su siervo pruebas claras, para que os saque de las tinieblas hacia la luz. Y, en verdad, Dios es con vosotros el más amable, misericordiosísimo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmlxxxv{Y no es apropiado para vosotros que no gastéis por la causa de Dios cuando a Dios pertenece la herencia de los cielos y la Tierra. No son iguales quienes de vosotros repartieron de sus riqueza antes de la victoria y combatieron. Ellos poseen un grado inmensamente superior a quienes repartieron de sus bienes y combatieron después. Y Dios ha prometido el bien a todos ellos y Dios está bien informado de lo que hacéis.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmlxxxvi{¿Quién quiere hacer a Dios un buen préstamo y, así, inmediatamente, Él se lo devolverá duplicado y tendrá una recompensa generosa?\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmlxxxvii{El día en que veas la luz de los creyentes y las creyentes manifestándose delante de ellos y a su derecha: «Vuestra buena noticia hoy son Jardines de cuyas profundidades brotan los ríos.» En ellos estarán eternamente. ¡Ese es el triunfo inmenso!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmlxxxviii{El día en el que los hipócritas y las hipócritas digan a quienes son creyentes: «¡Esperad para que podamos obtener algo de vuestra luz!» Se les dirá: «Retroceded y buscad una luz.» Y se pondrá entre ellos una muralla en la que habrá una puerta. En el interior de ella estará la misericordia y frente a ella, en el exterior, el castigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmlxxxix{Les gritarán: «¿Acaso no estuvimos con vosotros?» Ellos dirán: «Sí, pero vosotros destruisteis vuestras propias almas y quedasteis a la espera y tuvisteis dudas hasta que llegó la orden de Dios. Y el Seductor os sedujo respecto a Dios.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmxc{Pero hoy no se os aceptará rescate alguno ni tampoco a quienes no fueron creyentes. Vuestro único destino será el Fuego. ¡Él será vuestro amigo! ¡Qué mal final!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmxci{¿Acaso no es ya tiempo de que los corazones de quienes tienen fe se humillen y teman ante el recuerdo de Dios y de lo que ha descendido de la Verdad y de que no sean como aquellos a quienes les fue entregada la Escritura anteriormente? El tiempo se cobró su impuesto sobre ellos y endureció sus corazones y muchos de ellos fueron transgresores.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmxcii{Sabed que Dios da vida a la Tierra después de haber estado muerta. Ciertamente os hemos explicado las señales. Quizás así uséis vuestra inteligencia.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmxciii{En verdad, a quienes son sinceros y sinceras y hacen a Dios un préstamo bueno se les doblará su pago y tendrán una recompensa generosa.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmxciv{Y los sinceros son quienes creen en Dios y en Sus Mensajeros y ellos y los testigos tienen junto a Su señor su recompensa y su luz. Y quienes no creen y desmienten Nuestras señales son la gente que irá al Infierno.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmxcv{Sabed que la vida de este mundo no es más que juego y distracción sin sentido y apariencia y orgullo entre vosotros por el mayor número de bienes e hijos. Es como la lluvia. El agricultor se impresiona de la vegetación que hace surgir, luego, continúa su proceso y ves como amarillea y luego se torna pasto seco. Y en la otra vida hay castigo severo y también perdón y satisfacción de Dios. Y la vida de este mundo no es más que el disfrute temporal de la vanidad.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmxcvi{Competid para ser los primeros en obtener el perdón de vuestro Señor y un Jardín tan vasto como los cielos y la Tierra, preparado para quienes crean en Dios y en Sus Mensajeros. Ese es el favor de Dios, que Él otorga a quien quiere. Y Dios es el Dueño del favor inmenso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmxcvii{No hay desgracia en la Tierra ni en vosotros mismos que no esté en una escritura desde antes de que la ocasionemos. Esto es algo fácil para Dios.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmxcviii{Para que no os entristezcáis por lo que perdáis y no os alegréis con arrogancia por lo que Él os dé. Dios no ama a quien es presumido, jactancioso.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmxcix{Aquellos que son avariciosos e incitan a la gente a la avaricia. Y quien dé la espalda sepa que, en verdad, Dios es rico por Sí mismo, digno de alabanza.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmc{Ciertamente, enviamos a Nuestros Mensajeros con las pruebas claras e hicimos descender con ellos la Escritura y la Balanza para que los humanos establezcan la justicia. E hicimos descender el hierro, en el que hay un gran poder y beneficio para los humanos, para que Dios sepa quien acude en ayuda de Él y de Sus Mensajeros en su ausencia. En verdad, Dios es fuerte, poderoso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmci{Y, ciertamente, enviamos a Noé y Abraham y pusimos en la descendencia de ambos la profecía y la Escritura. Y, de ellos, algunos se guiaron y muchos de ellos fueron transgresores.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcii{Luego, tras ellos, enviamos a Nuestros Mensajeros y enviamos a Jesús hijo de María y le dimos el Evangelio y pusimos en los corazones de quienes le siguieron amabilidad y misericordia. Pero el monacato fue una innovación de ellos -Nosotros no se la prescribimos- buscando agradar a Dios. Pero no lo observaron como debían. Así pues, a quienes de ellos creyeron les dimos su recompensa, pero muchos de ellos fueron transgresores.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmciii{¡Oh, creyentes! Sed temerosos de Dios y creed en Su Mensajero y Él os dará el doble de Su misericordia y os pondrá una luz con la que podáis caminar y os perdonará. Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmciv{Que la Gente de la Escritura sepa que ellos no tienen poder sobre nada del favor de Dios y que el favor de Dios está en Su propia mano y que lo otorga a quien Él quiere. Y Dios es dueño de un favor inmenso.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcv{\basmalahes Ciertamente, Dios ha escuchado las palabras de aquella que discutía contigo acerca de su marido y se quejaba ante Dios. Dios oye la conversación de vosotros dos. En verdad, Dios todo lo oye, todo lo ve.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcvi{Aquellos de vosotros que repudian a sus esposas con el Dihar [deben saber que] ellas no son sus madres. Sus madres son sólo aquellas que les trajeron a la vida. Y, en verdad, dicen algo que es reprobable y falso. Y, en verdad, Dios es indulgente, perdonador.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcvii{Aquellos que repudian a sus esposas con el Dihar y luego se retractan de lo que dijeron, deberán liberar un esclavo antes de poder volver a tocarlas. ¡Se os exhorta a ello! Y Dios está bien informado de lo que hacéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcviii{Quien no pueda hacerlo, deberá ayunar dos meses seguidos antes de volver a tocarse mutuamente. Quien no pueda hacerlo, deberá alimentar a sesenta personas necesitadas. Esto es para que creáis es Dios y en Su Mensajero. Estos son los límites de Dios y para quienes no crean hay un castigo doloroso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcix{En verdad, aquellos que se opongan a Dios y a Su Mensajero serán humillados de la misma manera en que fueron humillados los que vivieron antes de ellos. En verdad, hicimos descender pruebas claras y quienes no crean tendrán un castigo humillante\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcx{el día en que Dios les resucite a todos y les informe de lo que hacían. Dios lleva la cuenta de sus obras y ellos las olvidan. Dios es testigo de todas las cosas.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxi{¿Acaso no has visto que Dios conoce lo que hay en los cielos y lo que hay en la Tierra? No hay conversación secreta entre tres sin que Él sea el cuarto, ni entre cinco sin que Él sea el sexto, ni de menos que esto ni de más sin que Él esté con ellos donde quiera que estén. Luego, el Día del Levantamiento, Él les informará de lo que hicieron. En verdad, Dios posee el conocimiento de todas las cosas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxii{¿Acaso no has visto a aquellos a quienes les fue prohibido hablar en secreto pero vuelven nuevamente a lo que les fue prohibido y hablan en secreto, obrando mal contra sí mismos y contra los demás y desobedeciendo al Mensajero? Y cuando vienen a ti te saludan de manera diferente a como Dios te saluda y dicen para sí mismos: «¿Por qué Dios no nos castiga por lo que decimos?» ¡Será suficiente para ellos el Infierno en el que arderán! ¡Qué mal destino!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxiii{¡Oh, creyentes! Cuando habléis en secreto no lo hagáis de manera que obréis mal contra vosotros mismos y contra los demás y desobedezcáis al Mensajero. Y hablad en secreto con espíritu pío y temor de Dios. ¡Sed temerosos de Dios, pues hacía Él seréis congregados!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxiv{En verdad, las conversaciones en secreto son cosa de Satanás para entristecer a quienes creen. Pero él no puede perjudicarles en nada excepto con el permiso de Dios. ¡Qué los creyentes confíen en Dios!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxv{¡Oh, creyentes! Cuando se os diga: «¡Haced sitio en las asambleas!» vosotros haced sitio y Dios os hará sitio a vosotros. Y cuando se os diga: «¡Levantaos!» vosotros levantaos y Dios elevará el grado a quienes de vosotros tengan fe y a quienes les ha sido dado conocimiento. Dios está bien informado de lo que hacéis.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcxvi{¡Oh, creyentes! Cuando queráis hablar al Mensajero en secreto, dad una limosna antes de hablar con él. Eso es mejor para vosotros y más puro. Y si no podéis, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcxvii{¿Acaso teméis dar una limosna por adelantado antes de hablar en secreto? Si no lo hacéis y Dios acepta vuestro arrepentimiento, haced la oración y dad la limosna que purifica la riqueza y obedeced a Dios y a Su Mensajero. Y Dios está bien informado de lo que hacéis.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcxviii{¿Has visto a quienes se vuelven a un pueblo con el que Dios está disgustado? No son de los vuestros ni son de ellos. Juran en falso y lo saben.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcxix{Dios ha preparado para ellos un severo castigo. En verdad, lo que hacen está mal.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcxx{Se protegen tras sus promesas y dificultan a otros el acceso al camino de Dios. Así pues, para ellos hay un castigo humillante.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcxxi{Sus bienes y sus hijos no les beneficiarán en nada ante Dios. Ellos son la gente del Fuego. En él estarán eternamente.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcxxii{El día en que Dios les resucite a todos, le prometerán a Él como os prometen a vosotros, calculando que están sobre algo firme. ¿Acaso no son ellos los mentirosos?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcxxiii{Satanás les venció y les hizo olvidar el recuerdo de Dios. Ellos son el partido de Satanás. ¿Acaso los del partido de Satanás no son los perdedores?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcxxiv{En verdad, quienes son enemigos de Dios y de Su Mensajero son los más despreciables.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcxxv{Dios ha escrito: «Ciertamente, Yo y Mis Mensajeros somos los vencedores.» En verdad, Dios es fuerte, poderoso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcxxvi{No encontrarás a un pueblo que crea en Dios y en el Último día que simpatice con quienes se oponen a Dios y a Su Mensajero, aunque sean sus padres o sus hijos o sus hermanos o la gente de su tribu. Ellos son a quienes Él ha escrito la fe en sus corazones y les ha fortalecido con un espíritu procedente de Él y les hará entrar en Jardines bajo los cuales brotan los ríos, en los que vivirán eternamente. Dios está satisfecho de ellos y ellos están satisfechos de Él. Ellos son el partido de Dios. ¿No es, en verdad el partido de Dios quienes son los triunfadores?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcxxvii{\basmalahes Glorifica a Dios lo que hay en los cielos y lo que hay en la Tierra y Él es el Todopoderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcxxviii{Él es Quien hizo salir de sus casas, en el primer destierro, a quienes de la Gente de la Escritura no eran creyentes. No creíais que ellos fueran a salir, y ellos pensaban que sus fortalezas les protegerían de Dios. Pero Dios vino a ellos por donde menos lo esperaban y puso el terror en sus corazones. Destruyeron sus casas con sus propias manos y con las manos de los creyentes. Así pues, ¡Oh, gente que reflexiona! ¡Aprended la lección!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcxxix{Y, si Dios no hubiese decretado que ellos abandonasen su patria, les habría castigado en esta vida. Y en la otra vida les espera el castigo del Fuego.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcxxx{Eso es porque ellos desafiaron a Dios y a Su Mensajero. Y quien desafía a Dios…En verdad Dios es severo en el castigo.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcxxxi{Las palmeras datileras que cortasteis o dejasteis en pie sobre sus bases fue con el permiso de Dios y para que Él someta a los transgresores.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcxxxii{Y el botín que, de ellos, Dios dio a Su Mensajero no hizo necesario que montaseis sobre vuestros caballos ni camellos, sino que Dios hace prevalecer a Sus Mensajeros sobre quien Él quiere y Dios tiene poder sobre todas las cosas.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxxxiii{El botín que, de la gente de las ciudades, Dios otorgó a Su Mensajero es para Dios y para el Mensajero, para los familiares y para los huérfanos, los necesitados y los viajeros, para que no vaya a parar a las manos de los ricos que hay entre vosotros. Y lo que el Mensajero os de tomadlo y absteneos de lo que os prohíba. Y sed temerosos de Dios. En verdad, Dios es severo en el castigo\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxxxiv{Y para los pobres de entre los emigrantes, que fueron expulsados de sus casas y privados de sus bienes cuando buscaban el favor de Dios y Su satisfacción y que auxilian a Dios y a Su Mensajero. Ellos son los sinceros.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxxxv{Y quienes prepararon la casa y la fe antes de ellos aman a quienes emigraron a ellos y no encuentran en sus pechos envidia por lo que se les ha dado y les prefieren a sí mismos, aunque se encuentre en una extrema necesidad. Y quienes están a salvo de su propia avaricia, ellos son los triunfadores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxxxvi{Y quienes vinieron tras ellos dicen: «¡Dios nuestro, perdónanos, a nosotros y a nuestros hermanos, aquellos que nos precedieron en la fe, y no pongas en nuestros corazones rencor contra los creyentes! ¡Señor nuestro, en verdad, Tú eres benévolo, misericordiosísimo con los creyentes!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxxxvii{¿No has visto a quienes son hipócritas diciendo a sus hermanos, aquellos que no creen de la gente de la Escritura: «Os juramos que si sois expulsados saldremos con vosotros y jamás obedeceremos a nadie en contra vuestra y si sois atacados os auxiliaremos?» Y Dios es testigo de que ellos son unos mentirosos.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcxxxviii{Juro que si son expulsados no saldrán con ellos y juro que si son atacados no les auxiliarán y juro que si acuden en su auxilio, seguramente darán la espalda. Por tanto, no serán auxiliados.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcxxxix{Ciertamente, vosotros infundís en sus pechos mayor temor que Dios. Eso es porque son gente que no tiene entendimiento.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcxl{No combatirán todos juntos contra vosotros excepto desde ciudades fortificadas o detrás de muros. Son muy valientes entre ellos. Tú calculas que están unidos, pero sus corazones están desunidos. Eso es porque son gente que no razona.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcxli{Son semejantes a los que hubo poco antes de ellos. Probaron las malas consecuencias de su comportamiento y tendrán un castigo doloroso.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcxlii{Su ejemplo es semejante a cuando Satanás dice al ser humano: «¡No creas!» y cuando descree, dice: «En verdad, me aparto de ti. En verdad, yo temo a Dios, Señor del Universo.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcxliii{Y el final de ambos será que estarán en el Fuego eternamente. Esa es la recompensa de los opresores.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcxliv{¡Oh, creyentes! ¡Sed temerosos de Dios y que el alma observe lo que envía por delante para mañana! ¡Y sed temerosos de Dios! En verdad, Dios está bien informado de lo que hacéis.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcxlv{Y no seáis como quienes olvidan a Dios y, por tanto, Él hace que se olviden de sus propias almas. Esos son los transgresores.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcxlvi{No son iguales la gente del Fuego y la gente del Jardín. La gente del Jardín son los triunfadores.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcxlvii{Si hiciera descender este Corán sobre una montaña, la verías humillarse y desmoronarse por temor a Dios. Estos son los ejemplos que ponemos a los seres humanos para que, quizás así, reflexionen.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcxlviii{Él es Dios y no hay más dios que Él. Conocedor de lo oculto a los sentidos y de lo manifiesto. Él es el Clementísimo, el Misericordiosísimo.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcxlix{Él es Dios y no hay más dios que Él. El rey, el Santísimo, la Paz, el Protector, el Amparador, el Poderoso, el Dominador, el Sublime. Glorificado sea Dios por encima de lo que asocian a Él.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcl{Él es Dios, el Creador, el Hacedor, el Formador. A Él pertenecen los nombres mejores. Le glorifica lo que hay en los cielos y en la Tierra y Él es el Todopoderosos, el Sabio.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcli{\basmalahes ¡Oh, creyentes! ¡No toméis a Mis enemigos y a vuestros enemigos como protectores, mostrando afecto hacia ellos, si salís a combatir por Mi causa y buscando Mi satisfacción, porque ellos han descreído de lo que a vosotros ha venido de la Verdad, expulsando al Mensajero y a vosotros por creer en Dios, vuestro Señor. Les mostráis afecto en secreto, pero yo soy Quien mejor conoce lo que ocultáis y lo que manifestáis. Y quien de vosotros lo hace, ciertamente, se ha extraviado del camino recto.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclii{Si tienen más poder que vosotros, serán vuestros enemigos y os maltratarán de palabra y obra y querrán que dejéis de tener fe.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcliii{Ni vuestras familias ni vuestros hijos os serán de utilidad el Día del Levantamiento. Él os separará a unos de otros. Y Dios ve claramente lo que hacéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcliv{Hay para vosotros un buen ejemplo en Abraham y en quienes estaban con él, cuando dijeron a su gente: «En verdad, nos apartamos de vosotros y de lo que adoráis en lugar de Dios. Descreemos de vuestra fe y comienza entre nosotros y vosotros la enemistad y el odio para siempre hasta que creáis en el Dios único.» Exceptuando lo que Abraham dijo a su padre: «Pediré perdón por ti, aunque no puedo hacer nada por ti en contra de Dios.» «¡Señor nuestro! ¡En Ti confiamos y a Ti nos volvemos contritos y hacia Ti es el regreso!»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclv{«¡Señor nuestro! ¡No nos pongas como examen de quienes no son creyentes y perdónanos!» «¡Señor nuestro! ¡En verdad, Tú eres el Todopoderoso, el Sabio!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclvi{Ciertamente, hay para vosotros en ellos un buen ejemplo de quienes tienen su esperanza puesta en Dios y en el Día del Juicio. Y quien dé la espalda (sepa) que Dios es el Rico por Sí mismo, el Digno de alabanza.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclvii{Puede que Dios ponga afecto entre vosotros y aquellos de quienes erais enemigos. Dios es poderoso. Dios es perdonador, misericordiosísimo.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclviii{Dios no os prohíbe que tratéis con amabilidad y equidad quienes no combaten vuestra fe ni os han expulsado de vuestros hogares. En verdad, Dios ama a quienes son equitativos.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclix{Lo que, en verdad, Dios os prohíbe es que seáis amigos de quienes combaten vuestra fe y os expulsan de vuestros hogares o ayudan a que seáis expulsados. Y quienes sean amigos de ellos, esos serán los opresores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclx{¡Oh, creyentes! Cuando lleguen a vosotros las creyentes emigrantes ¡examinadlas! Dios es Quien mejor conoce su fe. Así pues, si verificáis que son creyentes, no las devolváis a los que no son creyentes. Ellas no son lícitas para ellos ni ellos son lícitos para ellas. Dadles lo que gastaron en ellas. Y no cometéis pecado si os casáis con ellas, una vez que les hayáis entregado sus dotes. Y no mantengáis matrimonio con las que no son creyentes. Pedid lo que gastasteis en ellas y que ellos pidan lo que gastaron en ellas. Ese es el juicio de Dios para vosotros. Él juzga entre vosotros. Y Dios todo lo conoce, es sabio.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxi{Y si perdisteis algo de vuestras esposas que se fueron con los incrédulos y conseguís algún botín, dad a aquellos cuyas esposas se fueron algo semejante a lo que gastaron. Y sed temerosos de Dios, en Quien tenéis fe.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxii{¡Oh, profeta! Cuando vengan a ti las creyentes y te juren que no asociarán nada a Dios, que no robarán y no cometerán adulterio ni fornicación y que no matarán a sus hijos, que no mentirán sobre lo que han hecho entre sus manos y sus pies y que no te desobedecerán en las cosas buenas, acepta sus juramentos y pide que Dios las perdone. En verdad, Dios es perdonador, misericordiosísimo.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmclxiii{¡Oh, creyentes! No toméis por amigos a una gente con la que Dios está disgustado. Ciertamente, ellos han desesperado de la otra vida igual que los que no creen han desesperado de la gente de las tumbas.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmclxiv{\basmalahes Glorifica a Dios lo que hay en los cielos y lo que hay en la Tierra y Él es el Todopoderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclxv{¡Oh, creyentes! ¿Por qué decís lo que no hacéis?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmclxvi{¡Dios aborrece mucho que digáis lo que no hacéis!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmclxvii{En verdad, Dios ama a quienes combaten por Su causa en filas apretadas, como un firme edificio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclxviii{Y [recuerda] cuando Moisés dijo a su pueblo: «¡Oh, pueblo mío! ¿Por qué me molestáis cuando sabéis con certeza que yo soy el Mensajero de Dios enviado a vosotros?» Cuando se desviaron, Dios desvió de sus corazones. Y Dios no guía a la gente trasgresora.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclxix{Y [recuerda] cuando Jesús hijo de María dijo: «¡Oh, Hijos de Israel! En verdad, soy el Mensajero de Dios enviado a vosotros para confirmar la Torá anterior a mí y para anunciar a un Mensajero que vendrá tras de mí. Su nombre es Ahmad.» Y cuando vino a ellos con las pruebas claras, dijeron: «¡Esto es magia evidente!»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclxx{Y ¿Quién es más opresor que quien inventa mentiras sobre Dios cuando ha sido llamado al Islam? ¡Y Dios no guía a la gente opresora!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclxxi{Quisieran apagar la luz de Dios con un soplido de sus bocas, pero Dios completa Su luz aunque moleste a los que no creen.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclxxii{Él es Quien ha enviado a Su Mensajero con la guía y con la religión de la Verdad, para hacer que prevalezca sobre todas las creencias, aunque ello moleste a los idólatras.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclxxiii{¡Oh, creyentes! ¿Queréis que os indique un negocio que os salve de un castigo doloroso?:\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxxiv{¡Tener fe en Dios y en Su Mensajero y combatir por la causa de Dios con vuestros bienes y vuestras almas! ¡Eso es mejor para vosotros! ¡Si supieseis…!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxxv{Os perdonará vuestros pecados y os introducirá en Jardines de cuyas profundidades brotan los ríos y en buenas mansiones en los Jardines del Edén. ¡Ese es el triunfo inmenso!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmclxxvi{Y otra [merced] que amaréis: «Un auxilio procedente de Dios y una victoria próxima.» ¡Informa de la buena nueva a los creyentes!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmclxxvii{¡Oh, creyentes! ¡Sed los auxiliares de Dios! como los apóstoles cuando dijo Jesús hijo de María: «¿Quién me auxiliará hacia Dios?» Los apóstoles dijeron: «¡Nosotros seremos los auxiliares de Dios!» Así pues, un grupo de los Hijos de Israel creyó y otro grupo no creyó. Nosotros apoyamos a los que tuvieron fe sobre sus enemigos y se convirtieron en los vencedores.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmclxxviii{\basmalahes Lo que hay en los cielos y lo que hay en la Tierra glorifica a Dios, el Rey, el Santísimo, el Todopoderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclxxix{Él es Quien designó entre los iletrados a un Mensajero de entre ellos para que les recite Sus versículos, les purifique y le enseñe la Escritura y la sabiduría, pues, antes de ello, estaban en un extravío evidente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmclxxx{Y a otros de entre ellos que aún no se han unido a ellos. Y Él es el Todopoderoso, el Sabio.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmclxxxi{Ese es el favor de Dios. Él lo otorga a quien quiere. Y Dios es el Dueño del favor inmenso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclxxxii{Aquellos a quienes les fue encomendada la Torá y luego no actuaron conforme a ella, son semejantes al burro que va cargado de libros. ¡Qué mal ejemplo el de un pueblo que desmiente las señales de Dios! Y Dios no guía a la gente opresora.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclxxxiii{Di: «¡Oh, judíos! Si pretendéis que vosotros sois los únicos amigos de Dios, aparte del resto de la gente, entonces ¡Desead la muerte, si sois sinceros!»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclxxxiv{Pero no la desearán jamás por lo que enviaron por delante a la otra vida con sus propias manos. Y Dios es Quien mejor conoce a los opresores.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclxxxv{Di: «En verdad, la muerte de la cual huís os encontrará y luego seréis devueltos al Conocedor de lo oculto a los sentidos y de lo manifiesto y Él os informará de lo que hacíais.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclxxxvi{¡Oh, creyentes! Cuando se convoque a la oración del viernes, apresuraos a acudir al recuerdo de Dios y dejad el comercio. Eso es mejor para vosotros. ¡Si supierais…!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclxxxvii{Y, cuando termine la oración, dispersaos por la Tierra y buscad el favor de Dios y recordad mucho a Dios, quizás así triunféis.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxxxviii{Pero, cuando ven un negocio o una diversión, escapan hacia ella y te dejan plantado. Di: «Lo que hay junto a Dios es mejor que la diversión y que los negocios y Dios es el mejor de los proveedores.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxxxix{\basmalahes Cuando los hipócritas vienen a ti, dicen: «Damos testimonio de que, en verdad, tú eres el Mensajero de Dios.» Y Dios sabe que tú eres Su Mensajero y Dios da testimonio de que, en verdad, los hipócritas son unos mentirosos.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcxc{Han tomado sus promesas como escudo e impiden el acceso a la senda de Dios. En verdad, ¡Qué malo es lo que han estado haciendo!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcxci{Eso es porque ellos tuvieron fe y luego descreyeron, así que sus corazones han quedado sellados y no comprenden.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcxcii{Y cuando les ves te sorprende su aspecto y cuando hablan escuchas lo que dicen, pero son como palos secos apoyados contra la pared. Creen que cualquier grito va dirigido contra ellos. Son el enemigo, así que, ten cuidado con ellos. ¡Qué Dios acabe con ellos! ¡Qué desviados están!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcxciii{Y cuando se les dice: «¡Venid, el Mensajero de Dios pedirá perdón para vosotros!» giran sus cabezas y les verás apartarse con arrogancia.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcxciv{Da igual que pidas perdón para ellos o que no pidas perdón para ellos, Dios no les perdonará jamás. En verdad, Dios no guía a la gente malvada, trasgresora.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxcv{Ellos son quienes dicen: «No gastéis de vuestros bienes en quienes están con el Mensajero de Dios hasta que no le abandonen.» Y a Dios pertenecen los tesoros de los cielos y la Tierra, pero los hipócritas no entienden.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxcvi{Dicen: «Cuando regresemos a la ciudad, los más poderosos expulsaran, sin duda, a los más débiles.» Y el poder pertenece a Dios, a Su Mensajero y a los creyentes, pero los hipócritas no tienen conocimiento.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxcvii{¡Oh, creyentes! ¡No dejéis que vuestros bienes y vuestros hijos os aparten del recuerdo de Dios! Y quienes obren de esa manera serán los perdedores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxcviii{Y repartid de lo que Nosotros os hemos provisto antes de que a uno de vosotros le llegue la muerte y, entonces, diga: «¡Señor mío! Si solamente me dieses un pequeño plazo, daría limosna y sería de los rectos.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxcix{Pero Dios no dará plazo alguno al alma cuando le llegue su término. Y Dios está bien informado de lo que hacéis.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcc{\basmalahes Glorifica a Dios lo que hay en los cielos y lo que hay en la Tierra. A Él pertenece el reino y a Él pertenece la alabanza y Él tiene poder sobre toda cosa.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcci{Él es Quien os ha creado, pero algunos de vosotros no creéis y otros sois creyentes. Y Dios observa lo que hacéis.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccii{Él ha creado los cielos y la Tierra con la Verdad y os ha dado forma, la mejor de las formas. Y a Él es el retorno.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcciii{Él conoce lo que hay en los cielos y la Tierra y conoce lo que guardáis en secreto y lo que manifestáis. Y Dios conoce lo que hay en el fondo de los pechos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcciv{¿Acaso no ha llegado a vosotros la noticia de quienes no fueron creyentes antes de vosotros? Probaron las malas consecuencias de su comportamiento y hay para ellos un castigo doloroso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccv{Eso es porque vinieron a ellos sus Mensajeros con las pruebas claras y dijeron: «¿Van a guiarnos a nosotros quienes son simples mortales?» y no tuvieron fe y dieron media vuelta. Y Dios no tiene necesidad de ellos. Dios es Rico por Sí mismo, digno de alabanza.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccvi{Los que no creen pretenden que no serán resucitados. Di: «¡Sí! ¡Lo juro por mi Señor! ¡Seréis resucitados y luego se os informará de lo que hicisteis! ¡Eso es fácil para Dios!»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccvii{Así pues, creed en Dios y en Su Mensajero y en la luz que Nosotros hemos hecho descender. Y Dios está bien informado de lo que hacéis.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccviii{El día que Él os reúna para el Día de la Asamblea, ese será el Día del Desengaño Mutuo. Y a quien crea en Dios y obre rectamente le ocultaremos sus errores y le haremos entrar en Jardines de cuyas profundidades brotan los ríos, en los cuales estarán eternamente. Ese es el éxito inmenso.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccix{Y quienes no creyeron y desmintieron Nuestras señales serán la gente del Fuego, en el cual estarán eternamente. ¡Qué mal destino!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccx{No acontece ninguna desgracia sino con permiso de Dios. Y, quien cree en Dios, guía su corazón. Y Dios conoce bien todas las cosas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxi{Y obedeced a Dios y obedeced al Mensajero, pero si dais media vuelta, sabed que la obligación de Nuestro Mensajero es únicamente transmitir el mensaje con claridad.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxii{Dios. No hay más dios que Él. Por eso, ¡Que los creyentes confíen en Dios!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmccxiii{¡Oh, creyentes! En verdad, en algunas de vuestras esposas y de vuestros hijos hay un enemigo para vosotros, así pues, tened cuidado con ellos. Y si les excusáis, sois indulgentes y les perdonáis, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmccxiv{En verdad, vuestros bienes y vuestros hijos son un examen. Y junto a Dios hay una recompensa inmensa.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmccxv{Así pues ¡Sed todo lo temerosos de Dios que podáis y escuchad y obedeced y repartid! Eso es bueno para vosotros mismos. Quienes están a salvo de su propia codicia, esos son los triunfadores.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmccxvi{Si hacéis a Dios un buen préstamo, Él os lo doblará y os perdonará. Y Dios es muy agradecido, muy indulgente.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmccxvii{Él es Quien mejor conoce lo que está oculto a los sentidos y lo manifiesto, el Todopoderoso, el Sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmccxviii{\basmalahes ¡Oh, profeta! Cuando divorciéis a las mujeres, divorciadlas al terminar su periodo y observad el tiempo de espera y sed temerosos de Dios, vuestro Señor. No las expulséis de sus casas y que ellas no salgan, a menos que cometan un pecado evidente. Esas son las leyes de Dios. Y quien viole las leyes de Dios, ciertamente, se oprimirá a sí mismo. No sabes, puede que Dios disponga después de esto alguna otra cosa.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxix{Así, cuando ellas hayan completado su plazo, retenedlas honorablemente o separaos de ellas honorablemente. Y que dos hombres justos de los vuestros sean testigos. Y estableced el testimonio para Dios. Se exhorta a ello a quien sea creyente en Dios y en el Último Día. Y a quien sea temeroso de Dios Él le dará una salida\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxx{y hará que le llegue la provisión por donde menos lo espera. Y quien confíe en Dios tendrá suficiente con Él. En verdad, Dios hace que Su orden se realice. Dios ha establecido una medida para cada cosa.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxxi{Y respecto a aquellas de vuestras esposas que ya no esperan tener menstruación, si tenéis dudas, su tiempo de espera será de tres meses. Y lo mismo para aquellas que todavía no han tenido menstruación. Y aquellas que están embarazadas, su tiempo de espera concluirá cuando den a luz. Y a quien sea temeroso de Dios Él le facilitará sus asuntos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxxii{Esa es la orden de Dios que Él ha hecho descender para vosotros. Y a quien sea temeroso de Dios Él le cubrirá sus errores y le otorgará una gran recompensa.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxxiii{Hospedadlas donde vosotros viváis conforme a vuestros medios y no las perjudiquéis haciéndoles sufrir estrecheces. Y si estuviesen embarazadas gastad en ellas hasta que den a luz. Y si dan de mamar a vuestros hijos dadles su remuneración y consultaos entre vosotros honorablemente. Y si no os ponéis de acuerdo, entonces que otra mujer le amamante.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxxiv{Quien tenga medios que gaste de ellos y aquel cuya provisión ha sido limitada que gaste conforme a lo que Dios le ha otorgado. Dios no obliga a una persona más allá de lo que le otorga. Tras la dificultad Dios pronto os dará la facilidad.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxxv{¡Cuántas ciudades desafiaron la orden de su Señor y de Sus Mensajeros y por ello les ajustamos las cuentas con severidad y les castigamos con un castigo terrible!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccxxvi{Así, probaron las malas consecuencias de su comportamiento y, finalmente, su comportamiento sólo les produjo pérdidas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccxxvii{Dios les castigará con un severo castigo. Así pues ¡Oh, los dotados de inteligencia y que sois creyentes, sed temerosos de Dios! Ciertamente, Dios ha hecho descender para vosotros un recuerdo.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccxxviii{Un Mensajero que os recita los versículos claros de Dios, para que saque a quienes tienen fe y obran rectamente de las tinieblas a la luz. Y a quien cree en Dios y obra rectamente Él le hará entrar en Jardines de cuyas profundidades brotan los ríos, en los que estará eternamente. Ciertamente, Dios ha dispuesto para él la mejor provisión.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxxix{Dios es Quien ha creado siete cielos y otras tantas Tierras. El hace que la orden descienda gradualmente a través de ellos, para que conozcáis que Dios tiene poder sobre todas las cosas y que Dios abarca a todas las cosas con Su conocimiento.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxxx{\basmalahes ¡Oh, Profeta! ¿Por qué prohíbes lo que Dios ha hecho lícito para ti, buscando la satisfacción de tus esposas? Y Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxxxi{Ciertamente, Dios ha hecho permisible para vosotros anular vuestros juramentos. Y Dios es vuestro protector y Él es Quien todo lo conoce, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxxxii{[Recuerda] Cuando el Profeta confió un asunto en secreto a alguna de sus esposas y ella lo divulgó y Dios se lo hizo saber. Cuando él le informó a ella de esto, dándole a conocer parte de ello y omitiendo parte de ello, ella dijo: «¿Quién te informó de eso?» él dijo: «Me informó Quien todo lo conoce, el Bien informado.»\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxxxiii{Si ambas os volvéis a Dios arrepentidas [será mejor], pues, ciertamente, los corazones de vosotras dos se han inclinado [hacia el mal], pero si os confabuláis contra él, [sabed que] en verdad, Dios es su protector y Gabriel y el recto de los creyentes y los ángeles tras ellos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxxxiv{Puede que Su señor, si os divorcia a las dos, le dé esposas mejores que vosotras a cambio, musulmanas, creyentes, obedientes, penitentes, devotas, ayunantes, casadas anteriormente o vírgenes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxxxv{¡Oh, creyentes! Salvaos a vosotros y a vuestras familias de un Fuego cuyo combustible son los seres humanos y las piedras y sobre los cuales habrá ángeles severos y poderosos, que no desobedecen lo que Dios les ha ordenado y hacen lo que les ha sido ordenado.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxxxvi{¡Oh los que no creéis! No pongáis hoy ninguna excusa. En verdad, seréis retribuidos por lo que hacíais.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxxxvii{¡Oh, creyentes! Volveos a Dios con un arrepentimiento sincero. Puede que vuestro Señor oculte vuestros malos actos y os haga entrar en Jardines de cuyas profundidades brotan los ríos, el día en que Dios no humillará al Profeta y a los que con él tienen fe. La luz de ellos se moverá ante ellos y a su derecha y ellos dirán: «¡Señor nuestro! ¡Completa nuestra luz y perdónanos! En verdad, Tú tienes poder sobre toda cosa.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccxxxviii{¡Oh, Profeta! Combate a los que no creen y a los hipócritas y se severo con ellos. Su refugio será el Infierno. ¡Qué mal destino!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccxxxix{Dios pone un ejemplo para los que no creen: La mujer de Noé y la mujer de Lot. Ambas estuvieron bajo la tutela de dos de Nuestros siervos justos y ambas les traicionaron y su relación con ellos no les benefició en nada ante Dios y se les dijo a ambas: «¡Entrad en el Fuego con los que entran en él!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccxl{Y Dios pone un ejemplo para quienes son creyentes: La mujer del Faraón cuando dijo: «¡Señor mío! Constrúyeme una morada junto a Ti en el Jardín y sálvame del Faraón y sus obras y sálvame de la gente opresora.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxli{Y María hija de Imrán, quien protegió la castidad de su vientre, así que, insuflamos en él de Nuestro Espíritu y confirmó las palabras de su Señor y Sus Escrituras y fue de las obedientes.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxlii{\basmalahes Bendito sea Aquel en cuyas manos está el reino y que tiene poder sobre todas las cosas,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxliii{el Cual ha creado la muerte y la vida para poner a prueba cuál de vosotros obra mejor. Y Él es el Todopoderoso, el Perdonador.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxliv{Él es Quien ha creado siete cielos en planos sucesivos. No verás discordancias en la creación del Misericordioso. Vuelve tu vista ¿Has visto algún fallo?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxlv{Luego, haz regresar tu vista una segunda vez. Tu vista regresará a ti cansada y derrotada.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxlvi{Ciertamente, Hemos adornado el cielo de este mundo con lámparas y las hemos puesto para ser lanzadas como proyectiles contra los demonios. Y les daremos el castigo del Fuego llameante.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxlvii{Y para quienes no creyeron en su Señor el castigo del Infierno. ¡Qué mal destino!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxlviii{Cuando sean arrojados a él oirán una larga exhalación y será la superficie hirviente\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxlix{como si estuviese a punto de reventar de ira. Cada vez que un grupo sea arrojado a él sus guardianes les preguntarán: «¿Acaso no vino a vosotros un amonestador?»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccl{Dirán: «Sí, vino a nosotros un amonestador pero le desmentimos y dijimos: Dios no ha hecho descender nada, sino que estáis en un gran extravío.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccli{Y dirán: «Si hubiésemos escuchado o reflexionado no estaríamos entre la gente del Fuego llameante.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcclii{Así reconocerán su pecado. ¡Alejada sea la gente del Fuego llameante!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccliii{En verdad, quienes temen a su Señor por lo que está oculto a los sentidos, obtendrán perdón y una gran recompensa.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccliv{Y, tanto si ocultáis lo que habláis como si lo manifestáis, en verdad, Él es Quien mejor conoce lo que hay en la esencia de los pechos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcclv{¿Acaso no va a conocer Quien creó y es el Sutil, el Bien Informado?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcclvi{Él es Quien ha hecho para vosotros la Tierra dócil, para que vayáis por sus lomas y comáis de sus provisiones. Y a Él es el retorno.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcclvii{¿Acaso estáis seguros de que quienes están en el cielo no harán que la Tierra se hunda con vosotros cuando tiemble?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcclviii{¿O estáis a salvo de que quienes están en el cielo envíen contra vosotros un viento huracanado? Pronto comprenderéis el significado de la amonestación.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcclix{Y juro que quienes vinieron antes de ellos también desmintieron. ¡Y cómo fue Mi castigo!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcclx{¿Acaso no ven las aves sobre ellos desplegando y recogiendo sus alas? Sólo las mantiene el Misericordioso. En verdad, Él tiene todas las cosas bajo observación.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcclxi{¿Quién es el ejército que os ayuda sino el Misericordiosísimo? En verdad, los que no creen sólo están en una ilusión.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcclxii{¿Quién puede proveeros si Él retiene Su provisión? Pero ellos persisten en su desafío y aversión.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcclxiii{¿Está mejor guiado quien camina cabizbajo o quien camina erguido sobre un camino recto?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcclxiv{Di: «Él es Quien os ha otorgado la existencia y ha puesto para vosotros el oído y la vista y el intelecto. ¡Que poco agradecéis!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcclxv{Di: «Él es Quien os ha creado en la Tierra y hacía Él seréis congregados.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcclxvi{Y dicen: «¿Cuándo será esa promesa si es que sois sinceros?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcclxvii{Di: «En verdad, el conocimiento de ello lo tiene Dios y, en verdad, yo sólo soy un amonestador explícito y claro.»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcclxviii{Así pues, cuándo lo vean de cerca, se ennegrecerá el rostro de quienes no eran creyentes y se les dirá: «Esto es lo que reclamabais.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcclxix{Di: «Si Dios acaba conmigo y con quienes conmigo están o tiene misericordia de nosotros ¿Quién librará a los que no creen de un castigo doloroso?»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcclxx{Di: «Él es el Clementísimo. Nosotros hemos creído en Él y en Él confiamos. Así pues, pronto conoceréis quién está en un extravío manifiesto.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcclxxi{Di: «Decidme, si vuestra agua se sumergiese ¿Quién podrá ofreceros agua corriente?»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcclxxii{\basmalahes Nun. Juro por el cálamo y lo que escriben:\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcclxxiii{Tú, gracias a tu Señor, no eres un loco\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcclxxiv{y, en verdad, hay para ti una recompensa sin límite\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcclxxv{y, en verdad, posees un nobilísimo carácter.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcclxxvi{Así pues, pronto verás y ellos pronto verán\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcclxxvii{quién de vosotros está seducido por la demencia.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcclxxviii{En verdad, tu Señor es Quien mejor conoce quién se extravía de Su camino y Él es Quien mejor conoce a quienes están bien guiados.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcclxxix{Así pues, no obedezcas a quienes desmienten.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcclxxx{Ellos quisieran que tú dieses señales de tolerancia con ellos y así ellos darían señales de tolerancia contigo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxi{Y no obedezcas a ningún perjuro vil\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxii{que todo lo critica con ironía y autosuficiencia y es un murmurador, un calumniador,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxiii{que impide el bien, es trasgresor y un gran malhechor,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxiv{opresor arrogante y, además de todo eso, bastardo,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxv{so pretexto de ser dueño de bienes e hijos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxvi{Si le recitas Nuestros versículos, dice: «Fábulas de los primitivos.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxvii{Pronto le marcaremos los morros.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxviii{En verdad, les hemos puesto a prueba igual que pusimos a prueba a los dueños del jardín, cuando juraron que recogerían sus frutos por la mañana,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxix{sin hacer excepciones.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmccxc{En la oscura noche cayó sobre él un azote enviado por tu Señor mientras ellos dormían.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmccxci{Así pues, amaneció como un árbol sin frutos.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmccxcii{Y se llamaban unos a otros por la mañana:\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmccxciii{«Apresuraos para ir a vuestro jardín si queréis recoger la fruta.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmccxciv{Y se fueron hacia allá, hablando en secreto:\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmccxcv{«Hoy no entrará en él ningún necesitado.»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmccxcvi{Y marcharon temprano con premura, con la decisión tomada de cumplir su prohibición y de recoger rápidamente la fruta sin dar ni una pieza a los necesitados.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmccxcvii{Y cuando lo vieron, dijeron: «En verdad, nos hemos extraviado.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmccxcviii{¡No! ¡Hemos sido despojados!»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmccxcix{El más moderado de ellos dijo: «¿No os dije que por qué no glorificabais a Dios?»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmccc{Dijeron: «¡Glorificado sea nuestro Señor! En verdad, hemos sido opresores.»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmccci{Y se volvieron unos a otros con recriminaciones,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcccii{diciendo: «¡Ay de nosotros! ¡Hemos sido rebeldes!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmccciii{Puede que nuestro Señor nos dé a cambio algo mejor que él. En verdad, nos hemos vuelto a nuestro Señor completamente.»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmccciv{Así es el castigo. Y el castigo de la otra vida es, con seguridad, mayor. Si lo supieran...\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmcccv{En verdad, para los temerosos de Dios hay, junto a su Señor, Jardines de Delicias.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmcccvi{¿Acaso vamos a tratar a los musulmanes como a los malhechores?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmcccvii{¿Qué os pasa? ¿Cómo juzgáis?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmcccviii{¿O poseéis una Escritura en la que estudiáis,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmcccix{que, en verdad, os permite hacer lo que queráis?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmcccx{¿O poseéis alguna promesa de Nuestra parte que os garantice hasta el Día del Levantamiento cualquier cosa que juzguéis conveniente?\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmcccxi{Pregúntales quién de ellos garantiza eso.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmcccxii{¿O acaso poseen socios? Entonces, que vengan con sus socios, si son sinceros.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmcccxiii{[Recuérdales] el día en el que se descubran las piernas y sean conminados a prosternarse y no puedan.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmcccxiv{Humillada su mirada, sobrecogidos por el abatimiento. Ciertamente, fueron invitados a prosternarse cuando aún estaban sanos.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmcccxv{Déjame con quienes desmintieron éstas palabras. Les iré llevando gradualmente hacia su perdición sin que se den cuenta.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmcccxvi{Y les doy un plazo. En verdad Mis planes son sólidos y precisos.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmcccxvii{Acaso les pides una recompensa que les abruma por su peso?\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmcccxviii{¿O conocen lo que está oculto a los sentidos y escriben?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmcccxix{Así pues, ten paciencia y espera el juicio de tu Señor y no seas como el hombre del pez cuando suplicaba lleno de ira.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmcccxx{De no haberle alcanzado una merced venida de su Señor habría sido arrojado a un árido desierto, execrado, reprobado, condenado.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmcccxxi{Su Señor le eligió y le puso con los justos y rectos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmcccxxii{Y, en verdad, los que no creen están a punto de fulminarte con la mirada cuando escuchan el Recuerdo y dicen: «¡Verdaderamente, está loco!»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmcccxxiii{¡Y no es más que un recuerdo para beneficiar a todo el mundo!\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmcccxxiv{\basmalahes La inevitable\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcccxxv{¿Qué es la inevitable?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcccxxvi{Y ¿Qué te hará entender lo que es la inevitable?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcccxxvii{Zamud y Ad desmintieron el Día de la Catástrofe.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcccxxviii{Los Zamud fueron destruidos por el Grito.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcccxxix{Y los Ad fueron destruidos por un viento helado y veloz\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcccxxx{que se desencadenó contra ellos durante siete noches y ocho días sucesivos. Y podías ver a las gentes caídas en el suelo, como troncos de palmera arrancados de raíz.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxi{¿Ves algún resto de ellos?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxii{Erraron el Faraón y los que vinieron antes de él y los pueblos de la gente de Lot.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxiii{Desobedecieron al Mensajero de su Señor y Él les arrebató con un arrebato tremendo.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxiv{En verdad, cuando desbordó el agua, os subimos a la nave\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxv{para hacer de ella un recuerdo para vosotros y para que lo transmitáis a los oídos receptivos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxvi{Cuando se sople la trompeta con un solo trompetazo\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxvii{y la Tierra y las montañas sean aplastadas y pulverizadas de un solo temblor,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxviii{ese día tendrá lugar el Acontecimiento.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxix{Se quebrará el cielo y ese día no tendrá consistencia\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcccxl{y los ángeles estarán sobre él y ocho cargarán ese día el Trono de tu Señor sobre ellos.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcccxli{Ese día seréis expuestos. Nada de vosotros quedará oculto.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcccxlii{Así, quienes reciban su libro en su mano derecha, dirán: «¡Tomad y leed mi libro!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcccxliii{En verdad, yo estaba seguro de encontrarme con la cuenta.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcccxliv{Así pues, disfruta ahora una vida satisfactoria\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcccxlv{en un Jardín elevado,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcccxlvi{frutos maduros al alcance de la mano.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcccxlvii{¡Comed y bebed a placer por el bien que hicisteis en los días del pasado!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcccxlviii{Pero quienes reciban su libro en su mano izquierda, dirán: «¡Ay de mí! ¡Ojalá no se me hubiese dado el libro\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcccxlix{y no hubiese sabido lo que era la cuenta!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcccl{¡Ojalá hubiese sido esa el fin de todo!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcccli{¡Todos mis bienes no me sirven de nada!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmccclii{¡He perdido toda autoridad!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcccliii{«¡Prendedlo y encadenadlo!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcccliv{Luego, ¡Enfrentadle al fuego inmenso del Infierno!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmccclv{Luego, ¡Apresadle con una cadena de setenta codos y dejadle así!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmccclvi{En verdad, no creía en Dios Inmenso\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmccclvii{y no animaba a dar alimento al necesitado.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmccclviii{Así que, hoy no tiene aquí ningún amigo.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmccclix{Ni más comida que guislin.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmccclx{No la comerán más que los transgresores pertinaces.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmccclxi{Y juro por lo que veis\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmccclxii{y por lo que no veis\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmccclxiii{que es, en verdad, la palabra de un Mensajero noble.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmccclxiv{Y su palabra no es la de un poeta. ¡Qué poca es la fe que tenéis!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmccclxv{Ni su palabra es la de un adivino. ¡Que poco os dejáis amonestar!\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmccclxvi{Es hecha descender gradualmente de parte del Señor del Universo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmccclxvii{Si él hubiese presentado su palabra como palabra Mía\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmccclxviii{habríamos tomado de él Nuestro derecho,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmccclxix{luego, habríamos cortado su arteria vital\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmccclxx{y ninguno de vosotros habría podido ocultármelo.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmccclxxi{Y, en verdad, él es un recuerdo para los temerosos de Dios.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmccclxxii{Y, en verdad, conocemos que algunos de vosotros son desmentidores\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmccclxxiii{y él es un motivo de remordimiento para los que no creen.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmccclxxiv{Y él es la Verdad cierta.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmccclxxv{Así pues, ¡Glorifica el nombre de tu Señor el Inmenso!\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmccclxxvi{\basmalahes Uno que pide, pide que tenga lugar el castigo.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccclxxvii{Los que no creen no tendrán defensa\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccclxxviii{ante Dios, Dueño de las estaciones graduales.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccclxxix{Ascenderán los ángeles y el Espíritu hacía Él en un día cuya duración es de cincuenta mil años.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccclxxx{Así pues, ¡Se paciente con una paciencia hermosa!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxi{En verdad, ellos lo ven lejano\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxii{pero Nosotros lo vemos cercano.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxiii{Día en el que el cielo estará como derretido, licuado,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxiv{y las montañas serán como copos de algodón rojizo\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxv{y un ser querido no hablará a su ser querido,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxvi{aun viéndole. El malhechor quisiera liberarse del castigo de ese día dando en pago por ello a sus hijos,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxvii{a su mujer y a su hermano,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxviii{la tribu que le considera parte de ellos\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxix{y todos los que están en la Tierra, si pudiera salvarse de él.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcccxc{¡No será así! No. En verdad, es un Fuego de brasas ardientes\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcccxci{que arrancará las extremidades\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcccxcii{y que convoca a quien dio la espalda y se apartó\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcccxciii{y acumuló bienes y fue avaro.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcccxciv{En verdad, el ser humano ha sido creado impaciente.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcccxcv{Cuando le alcanza un mal se desespera\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcccxcvi{y si le alcanza el bien es mezquino.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcccxcvii{Exceptuando a quienes rezan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcccxcviii{Aquellos que son constantes en su oración,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcccxcix{de sus bienes dan su derecho establecido\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcd{al mendigo y al desfavorecido,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdi{confirman el Día de la Recompensa\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdii{y temen el castigo de su Señor.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdiii{¡En verdad, del castigo de su Señor nadie está a salvo!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdiv{Y protegen su sexualidad,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcdv{excepto con sus esposas o sus esclavas. En ese caso, ellos no serán censurados.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcdvi{Pero, quienes busquen más allá de eso, serán los transgresores.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmcdvii{Y son cumplidores con lo que se les confía y de sus promesas.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmcdviii{Y se mantienen firmes en sus testimonios\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmcdix{y protegen sus oraciones.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmcdx{Esos serán honrados en Jardines.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmcdxi{¿Qué les sucede a los que no creen, que acuden presurosos hacia ti sin apartar los ojos\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmcdxii{y que están en grupos a la derecha y a la izquierda?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmcdxiii{¿Tiene cada uno de ellos la esperanza de ser introducido en el Jardín de las Delicias?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmcdxiv{¡No será así! En verdad, les hemos creado para lo que saben.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmcdxv{¡No será así! Juro por el Señor de los Orientes y los Occidentes que Nosotros tenemos poder\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmcdxvi{para cambiarles por otros mejores que ellos, sin que nadie pueda impedírnoslo.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmcdxvii{Así pues, déjales que discutan y jueguen hasta que les llegue el día que les ha sido prometido.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmcdxviii{Día en el que saldrán de las tumbas precipitadamente, como si se dirigiesen apresuradamente a una meta,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmcdxix{abrumada su vista, humillados por el abatimiento. ¡Ese es el día que se os prometía!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmcdxx{\basmalahes En verdad, Nosotros enviamos a Noé a su pueblo: «¡Amonesta a tu pueblo antes que venga a ellos un castigo doloroso!»\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxxi{Él dijo: «¡Oh, pueblo mío! En verdad, yo soy para vosotros un amonestador claro.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdxxii{Adorad a Dios y sed temerosos de Él y obedecedme.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdxxiii{Él os perdonará por vuestros pecados y os dará un plazo por un tiempo determinado. En verdad, habéis de saber que cuando se cumpla el plazo de Dios no será pospuesto.»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdxxiv{Dijo: «¡Señor mío! ¡He llamado a mi pueblo noche y día\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdxxv{y mi invitación sólo ha servido para que se alejen más!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdxxvi{Y, en verdad, cada vez que les invito para que Tú les perdones, ponen sus dedos en sus oídos y se cubren con sus ropas, persisten en su hostilidad y se muestran extremadamente arrogantes.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdxxvii{«Luego, les he invitado en voz alta y manifiesta.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdxxviii{«Luego, les he hablado en público y en privado\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdxxix{y les he dicho: Pedid el perdón de vuestro Señor. En verdad, Él es muy perdonador.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdxxx{«Envía el cielo sobre vosotros cargado de abundantes lluvias\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxi{e incrementa vuestros bienes e hijos y pone para vosotros jardines y pone para vosotros ríos.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxii{«¿Qué pasa con vosotros que no ponéis vuestra esperanza en la grandeza de Dios\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxiii{cuando es Él quien os ha creado con caracteres diferentes?»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxiv{«¿No habéis visto cómo Dios ha creado siete cielos sucesivos\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxv{y cómo ha puesto la Luna en ellos como una luz y ha puesto el Sol como una lámpara?»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxvi{«Y Dios os hace crecer de la Tierra como plantas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxvii{Luego, os hace regresar a ella y (luego) os hace salir totalmente.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxviii{«Y Dios puso la Tierra para vosotros plana como una alfombra\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxix{para que viajéis por sus caminos.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdxl{Noé dijo: «¡Señor mío! Ellos me han desobedecido y han seguido a quien sus bienes e hijos sólo incrementan su perjuicio\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcdxli{y han preparado un gran plan.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcdxlii{Y dicen: «¡No abandonéis a vuestros dioses! ¡No abandonéis a Wad ni a Suwaa ni a Yaguza y Yauqa y Nasr!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcdxliii{«¡Y, con seguridad, ellos han extraviado a muchos! ¡No incrementes a los opresores más que su extravío!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcdxliv{Fueron ahogados por sus iniquidades y se les hará entrar en un Fuego y no encontrarán, aparte de Dios, quien les auxilie.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdxlv{Y Noé dijo: «¡Señor mío! ¡No dejes sobre la Tierra a ninguno de los que no son creyentes!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdxlvi{Si les dejas, extraviarán a Tus siervos y no engendrarán más que hijos corruptos y muy descreídos.»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdxlvii{«¡Dios mío! ¡Perdóname y perdona a mis padres y a quien entre en mi casa siendo creyente, y a los creyentes y a las creyentes, y no incrementes a los opresores más que ruina!»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdxlviii{\basmalahes Di: «Me ha sido revelado que él fue escuchado por un grupo de los genios e inmediatamente dijeron: «Hemos escuchado una recitación sorprendente\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxlix{que guía en la dirección correcta y hemos creído en ella y no asociamos nada a nuestro Señor.»\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdl{«Y que dice que Él, exaltada sea la grandeza de nuestro Señor, no ha tomado compañera ni hijo,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdli{y que nuestros estúpidos habían estado diciendo sobre Dios cosas alejadas de la verdad\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdlii{y que nosotros creíamos que los hombres y los genios no decían mentiras sobre Dios\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdliii{y que hombres de los humanos buscaban refugio en hombres de los genios y ellos les incrementaron su pecado y su rebeldía\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdliv{y que ellos pensaban, como pensabais vosotros, que Dios no había designado Mensajero a nadie.»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdlv{«Y cuando nos acercamos al cielo, encontramos que estaba lleno de guardianes severos y de meteoritos flamígeros.»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdlvi{«Y nosotros nos sentábamos allí en un lugar para escuchar, pero quien escucha ahora encuentra un meteorito flamígero esperándole.»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdlvii{«Y no sabemos si se quiere el mal para quienes están en la Tierra o quiere para ellos su Señor que accedan a la realidad.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdlviii{«Y que, entre nosotros, hay quienes son rectos y entre nosotros hay quienes no lo son. Somos caminos separados.»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdlix{«Y ahora sabemos con certeza que no podemos imponernos a Dios en la Tierra y que no podemos escapar de Él.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdlx{«Y que, cuando escuchamos la guía creímos en ella. Y quien cree en su Señor no temerá ser calumniado ni oprimido.»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdlxi{«Y que de los nuestros, los hay que se han sometido a la orden de Dios y de los nuestros, los hay que tienden a alejarse de la Verdad.» Y quienes se han sometido al mandato de Dios han alcanzado el vértice de la realidad y del encuentro con la Verdad.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdlxii{En cuanto a los que tienden al mal, son leña para el Infierno.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdlxiii{«Y que si se mantienen firmes en la senda, les suministraremos agua en abundancia\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdlxiv{hasta ponerles a prueba con ello.» «Y a quien se aparte del recuerdo de su Señor eso le conducirá a un castigo cada vez mayor.»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdlxv{«Y que las mezquitas pertenecen a Dios. Así pues, no invoquéis a nadie junto a Dios.»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdlxvi{«Y que, cuando el siervo de Dios se levantó para invocarle, acudieron tantos a él que a punto estuvieron de ser multitud.»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdlxvii{Di: «En verdad, invoco a mi Señor y no asocio nadie a Él.»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdlxviii{Di: «En verdad, yo no poseo poder para perjudicaros ni para dirigiros.»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcdlxix{Di: «Nadie puede protegerme de Dios y no encuentro refugio en otro que Él.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcdlxx{Mi única responsabilidad es hablar de Dios y de Sus mensajes.» Y a quien desobedezca a Dios y a Su Mensajero le pertenece el Fuego del Infierno, en el que estará eternamente. Siempre.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxi{Hasta que, cuando vean lo que se les había prometido, comprendan quién es más débil en auxiliares y menor en número.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxii{Di: «No sé si está cercano lo que os ha sido prometido o si mi Señor le ha dado un plazo.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxiii{Él es el Conocedor de lo oculto a los sentidos y nadie accede a Su ocultación\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxiv{excepto aquel de los Mensajeros con quién Él se complace y, entonces, Él le pone guardianes por delante y por detrás\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxv{para saber que, con seguridad, han transmitido los mensajes de Su señor. Él abarca todo lo que tiene que ver con ellos y lleva cuenta de todo.»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxvi{\basmalahes ¡Oh, tú que estás envuelto en un manto!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxvii{Levántate en la noche excepto una pequeña parte,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxviii{la mitad de ella o quita de ella un poco\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxix{o añádele un poco y recita el Corán de manera fluida y clara.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxx{En verdad, pronto te transmitiremos palabras de gran peso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxi{En verdad, la oración de la noche conecta tu lengua con el corazón y pone más presencia y atención en tus palabras.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxii{En verdad, durante en día estás muy ocupado\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxiii{Y recuerda el nombre de tu Señor y ocúpate sólo de suplicarle y rezarle.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxiv{El Señor del Oriente y del Occidente. No hay más dios que Él. Así pues ¡Tómale como protector!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxv{Y ten paciencia con lo que digan y apártate de ellos con educación.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxvi{¡Déjame solo con los desmentidores, esos que disfrutan de bienestar, y dales un pequeño plazo!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxvii{En verdad, con Nosotros estarán las cadenas y el Infierno,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxviii{un alimento que se atraganta y un doloroso castigo,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxix{el día que tiemblen la Tierra y las montañas y sean las montañas como arena que se desmorona.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdxc{En verdad, hemos enviado a vosotros un Mensajero que sea testigo sobre vosotros, igual que enviamos a Faraón un Mensajero.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdxci{Faraón desobedeció al Mensajero y le atrapamos con un castigo duro y pesado.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdxcii{Y, si no creéis, cómo vais a temer un día en el que a los niños se les pondrá el pelo blanco.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdxciii{Ese día, el cielo se partirá y Su promesa se realizará.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdxciv{En verdad, esto es un motivo de reflexión, así pues, quien quiera que tome un camino en dirección a su Señor.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdxcv{En verdad, tu Señor sabe que permaneces levantado casi dos tercios de la noche, la mitad o un tercio de ella, así como un grupo de los que están contigo. Dios establece la noche y el día. Él sabe que no podéis calcularlo con exactitud y acepta vuestro arrepentimiento. Así pues, recitad lo que podáis del Corán. Él sabe que algunos de vosotros estaréis enfermos y otros estáis recorriendo la Tierra buscando el favor de Dios y que otros están combatiendo por la causa de Dios. Así pues, recitad lo que podáis de él. Y haced la oración y dad la limosna purificadora de la riqueza y haced a Dios un buen préstamo. Y el bien que enviéis por delante para vosotros mismos, lo encontraréis junto a Dios como una recompensa mejor y mayor. Y pedid el perdón de Dios. En verdad, Dios es perdonador, misericordiosísimo con los creyentes.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdxcvi{\basmalahes ¡Oh, tú que estás arropado!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxcvii{Levántate y amonesta\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdxcviii{y proclama la grandeza de tu Señor\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdxcix{y purifica tu ropa\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmd{y mantente apartado de la impureza y el pecado.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdi{Y no des pensando que es mucho\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdii{y se paciente por tu Señor.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdiii{Y cuando la trompeta sea soplada,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdiv{ese día será un día de dificultades.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdv{No será fácil para los que no son creyentes.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdvi{Dejadme con quien he creado Yo solo\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdvii{y para quien puse bienes abundantes\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdviii{e hijos que estén junto a él.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdix{Y le he facilitado la vida\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdx{Pero aun desea más.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdxi{¡Pero no será así! En verdad, él se oponía a Nuestras señales.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdxii{Pronto le haré atravesar grandes dificultades.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdxiii{En verdad, él ha reflexionado y decidido.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdxiv{Así pues ¡Que le maten! ¡Cómo ha decidido!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdxv{¡Que le vuelvan a matar! ¡Cómo ha decidido!\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdxvi{Después ha observado,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdxvii{luego ha fruncido el ceño y su rostro ha mostrado su horrible fealdad,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdxviii{luego, ha mostrado su desprecio y arrogancia\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdxix{y ha dicho: «Esto no es más que magia transmitida desde antiguo.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdxx{Esto no son más que palabras de un ser humano.»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdxxi{¡Pronto le enviaré al Infierno de Saqar!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdxxii{Y ¿Qué te hará entender lo que es Saqar?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdxxiii{¡No deja nada vivo, no deja nada!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdxxiv{Abrasa la piel.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdxxv{Sobre él hay diecinueve.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdxxvi{Y no hicimos que los compañeros del Fuego fuesen sino ángeles y no les hicimos que fuesen en ese número sino para poner a prueba a quienes no tienen fe y para que obtengan la certeza quienes tomaron la Escritura e incremente la fe de los creyentes. Y para que no alberguen dudas ni quienes tomaron la Escritura ni los creyentes. Y para que digan aquellos que tienen una enfermedad en su corazón y los que no creen: «¿Qué desea Dios con ese ejemplo?» Así extravía Dios a quien Él quiere y guía a quien Él quiere. Y nadie conoce los ejércitos de tu Señor excepto Él. Y ellos no son más que un recuerdo para los humanos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdxxvii{¡Pero no! ¡Lo juro por la Luna!\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdxxviii{¡Por la noche cuando declina!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdxxix{¡Por la mañana cuando brilla!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdxxx{¡En verdad, él es una de la grandes señales!\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdxxxi{¡Una advertencia para los humanos!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdxxxii{Para quien de vosotros quiera adelantarse o quedarse atrás.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdxxxiii{Cada alma es responsable de lo que hizo.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdxxxiv{Pero los compañeros de la derecha\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdxxxv{estarán en Jardines y preguntarán\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdxxxvi{a los malhechores:\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdxxxvii{«¿Qué os ha llevado al Saqar?»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdxxxviii{Dirán: «No éramos de los que rezaban,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdxxxix{ni éramos de los que alimentan al necesitado\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdxl{y sólo nos preocupábamos de lo intrascendente.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdxli{Y desmentíamos el Día de la Recompensa\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdxlii{hasta que nos llegó la certeza.»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmdxliii{Y no les beneficiará la intercesión de los intercesores.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmdxliv{¿Qué les sucede que se apartan del Recuerdo\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmdxlv{como burros salvajes espantados\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmdxlvi{que huyen del león cazador?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmdxlvii{Cada uno de ellos quiere que le sea entregado un pergamino desplegado.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmdxlviii{¡No será así, pues no temen la otra vida!\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmmdxlix{¡No será así! ¡Él es un Recuerdo!\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmmdl{Así pues, quien quiera que lo recuerde.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmmdli{Y no recordarán más que si quiere Dios. Él es propicio. Es Quien castiga y Quien perdona.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmmdlii{\basmalahes ¡Juro por el Día del Levantamiento!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdliii{¡Y juro por el alma que aconseja el bien!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdliv{¿Piensa el ser humano que no reuniremos sus huesos?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdlv{Pues sí. Tenemos poder para recomponer sus huellas dactilares.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdlvi{Pero el ser humano desea seguir viviendo en el pecado.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdlvii{Pregunta él: «¿Cuándo tendrá lugar el Día del Levantamiento?»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdlviii{Así, cuando se debilite la vista\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdlix{y se oculte la Luna\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdlx{y se junten el Sol y la Luna,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdlxi{ese día el ser humano dirá: «¿Dónde está el lugar por el que escapar?»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdlxii{Pues no. No hay refugio.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdlxiii{Ese día el lugar de encuentro será en dirección a tu Señor.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdlxiv{Ese día será informado el ser humano de lo que envió por delante y de lo que dejó atrás.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdlxv{El ser humano es quien mejor conoce su propia alma\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdlxvi{aunque trate de disculparse.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdlxvii{No muevas con él tu lengua para apresurarle.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdlxviii{En verdad, reunirlo y recitarlo es responsabilidad Nuestra.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdlxix{Así pues, cuando Nosotros lo hayamos terminado de recitar, repite su recitación.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdlxx{Luego, en verdad, Nosotros nos encargamos de explicarlo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdlxxi{¡Pero no! Amáis la vida transitoria\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdlxxii{y descuidáis la Otra.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdlxxiii{Ese día, algunos rostros estarán radiantes\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdlxxiv{mirando a su Señor\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdlxxv{y algunos rostros, ese día, estarán contraídos\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdlxxvi{al saber que sufrirán un castigo que les quebrará la columna.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdlxxvii{¡Pero no! Cuando alcance las clavículas\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdlxxviii{Y se diga: «¿Quién puede salvarle?»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdlxxix{y él sepa que le ha llegado el tiempo de la separación\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdlxxx{y una pierna se junte con la otra,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxi{ese día, será conducido hacia su Señor.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxii{Él nunca aceptó ni rezó\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxiii{sino que desmintió y se apartó.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxiv{Luego, fue hacia su gente con arrogancia.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxv{¡Es lo mejor para ti, es lo mejor!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxvi{¡Sí! ¡Es lo mejor para ti, es lo mejor!\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxvii{¿Acaso cree el ser humano que será dejado a su antojo y no Nos ocuparemos de él?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxviii{¿Acaso no fue una gota de esperma eyaculado?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxix{Luego fue algo suspendido y Él le creó y le dio forma\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdxc{e hizo de él la pareja del macho y la hembra.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdxci{¿Acaso alguien así no es capaz de dar vida a lo muerto?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdxcii{\basmalahes ¿Acaso ha existido un momento en el que el ser humano no haya sido una cosa recordada?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdxciii{En verdad, Nosotros creamos al ser humano de una gota mezclada y le fuimos cambiando de estado y forma y le dimos capacidad de oír y ver.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdxciv{En verdad, le guiamos al camino, lo agradezca o lo rechace.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdxcv{En verdad, para los que rechazan hemos preparado cadenas y argollas y un Fuego abrasador.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdxcvi{En verdad, los píos beberán de una copa sazonada con alcanfor,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdxcvii{procedente de una fuente de la que beberán los siervos de Dios y que ellos harán manar donde y cuando quieran.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdxcviii{Fueron leales a sus promesas y temieron un día cuyo mal se extenderá\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdxcix{Y alimentaron, por amor a Él, al necesitado, al huérfano y al preso:\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdc{«En verdad, os alimentamos por agradar a Dios. No queremos de vosotros recompensa ni agradecimiento.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdci{En verdad, tememos de parte de nuestro Señor un día terrible y fatídico.»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcii{Así pues, Dios les protegerá del mal de ese día y les colmará de felicidad y alegría\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdciii{y su recompensa, por haber sido pacientes, será un Jardín y [vestidos de] seda.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdciv{En él estarán reclinados sobre cojines y no verán Sol ni frío extremos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcv{Sobre ellos una sombra amplia y frutos fáciles de alcanzar.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcvi{[Sirvientes] alrededor de ellos, darán vueltas con recipientes de plata y copas cristalinas,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcvii{de cristal de plata y de las proporciones que ellos deseen.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcviii{Allí, les escanciarán una copa perfumada con jengibre.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcix{Allí, habrá una fuente llamada Salsabil\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcx{y darán vueltas alrededor de ellos sirvientes de eterna juventud que, al verles, pensarías que son perlas esparcidas.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxi{Y, cuando lo veas, verás una gran bendición y un gran reino.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxii{Llevarán vestidos de fina seda verde y brocados y serán adornados con brazaletes de plata y su Señor les dará de beber una bebida pura:\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxiii{«En verdad, ésta es vuestra recompensa. Vuestro esfuerzo ha sido apreciado.»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxiv{En verdad, Nosotros hicimos descender sobre ti el Corán gradualmente.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxv{Así pues, ten paciencia con el juicio de tu Señor y no obedezcas a quienes de ellos son pecadores o desagradecidos\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxvi{y recuerda el nombre de tu Señor mañana y tarde.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxvii{Y en la noche, prostérnate para Él. Y glorifícale por la noche largamente.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxviii{En verdad, esos aman la vida transitoria y descuidan un día duro que viene tras ellos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcxix{Nosotros les hemos creado y hemos fortalecido su constitución y cuando quisiéramos les podríamos cambiar por otros semejantes a ellos.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcxx{En verdad, esto es un motivo de reflexión. Así pues, quien quiera, que tome un camino hacia su Señor.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcxxi{Y no lo querréis a menos que Dios lo quiera. En verdad, Dios es conocedor, sabio.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcxxii{Introduce a quien Él quiere en Su misericordia y a los opresores les ha preparado un castigo doloroso.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcxxiii{\basmalahes Juro por los sucesivos Mensajeros\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcxxiv{que viajan con la velocidad de un viento huracanado\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcxxv{y juro por quienes difunden por todos lados\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcxxvi{y establecen claramente las diferencias\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcxxvii{y juro por quienes facilitan el encuentro con el Recuerdo\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcxxviii{que sirve de justificación y que amonesta:\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcxxix{En verdad, lo que os fue prometido se cumplirá.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcxxx{Así pues, cuando las estrellas pierdan su luz\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxi{y cuando el cielo se parta\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxii{y cuando las montañas sean pulverizadas\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxiii{y cuando sean emplazados los Mensajeros a dar su testimonio\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxiv{¿A qué día serán convocados?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxv{Al Día de la Diferencia.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxvi{Y ¿Qué te hará entender lo que es el Día de la Diferencia?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxvii{¡Ay ese día los desmentidores!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxviii{¿Acaso no destruimos a los primeros\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxix{e hicimos que los últimos les siguieran?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcxl{Así mismo haremos con los malhechores.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcxli{¡Ay ese día los desmentidores!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxlii{¿Acaso no os hemos creado de un líquido viscoso\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxliii{que hemos colocado en un receptáculo seguro\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxliv{durante un periodo determinado\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxlv{y entonces hemos dispuesto? ¡Y qué bien disponemos!\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxlvi{¡Ay, ese día, de los desmentidores!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxlvii{¿Acaso no hemos colocado la Tierra como lugar de encuentro\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxlviii{para los vivos y los muertos?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxlix{¿Y no hemos puesto en ella altas y firmes cordilleras y escanciado para vosotros agua dulce y deliciosa?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcl{¡Ay, ese día, de los desmentidores!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcli{¡Id hacia aquello que desmentíais!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdclii{Id hacia una nube de humo con tres ramificaciones,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcliii{que no da sombra ni protege de las llamas.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcliv{En verdad, él lanza lenguas de fuego como castillos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdclv{¡Como si fueran camellos amarillos!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdclvi{¡Ay, ese día, de los desmentidores!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdclvii{¡Ese día no hablarán\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdclviii{y no se les permitirá ofrecer disculpas!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdclix{¡Ay, ese día, de los desmentidores!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdclx{¡Ese es el Día de la Diferencia, en el que os hemos reunido a vosotros y a los primeros!\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdclxi{Así pues, si tenéis algún plan utilizadlo contra Mí.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdclxii{¡Ay, ese día, de los desmentidores!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdclxiii{En verdad, los temerosos de Dios tendrán sombras y fuentes\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdclxiv{y de las frutas que prefieran.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdclxv{«¡Comed y bebed a placer (en recompensa) por lo que hacíais!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdclxvi{En verdad, así es como recompensamos a quienes hacen el bien.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdclxvii{¡Ay, ese día, de los desmentidores!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdclxviii{«¡Comed y disfrutad un poco! ¡En verdad que sois malhechores!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdclxix{¡Ay, ese día, de los desmentidores!\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmdclxx{Y cuando se les dice «¡Inclinaos!» no se inclinan.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmdclxxi{¡Ay, ese día, de los desmentidores!\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmdclxxii{Así pues, ¿En qué discurso van a creer si no creen en él?\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmdclxxiii{\basmalahes ¿Acerca de qué se preguntan unos a otros?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdclxxiv{Acerca de la grandiosa noticia\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdclxxv{sobre la cual mantienen diferencias.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdclxxvi{¡Pero no es así! ¡Pronto van a saber!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdclxxvii{¡No es así! ¡Pronto van a saber!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdclxxviii{¿Acaso no hemos hecho de la Tierra lecho?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdclxxix{¿Y de las montañas estacas?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdclxxx{¿Y os hemos creado por parejas?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxi{¿E hicimos de vuestro sueño descanso?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxii{¿E hicimos de la noche vestidura?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxiii{¿Y pusimos el día para ganar el sustento?\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxiv{¿Y construimos sobre vosotros siete firmes (cielos)?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxv{¿Y pusimos una lámpara radiante?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxvi{¿E hicimos descender de las nubes agua a torrentes,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxvii{para hacer surgir por medio de ella grano y plantas\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxviii{y jardines frondosos?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxix{En verdad, el Día de la Diferencia está fijado para el último momento.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcxc{El día en el que soplen la trompeta y acudan en tropeles\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcxci{y se abra el cielo y sea todo puertas\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxcii{y se desmoronen las montañas y parezcan un espejismo.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxciii{En verdad, el Infierno será un destino,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxciv{un lugar de regreso para los rebeldes,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxcv{en el que permanecerán indefinidamente.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxcvi{Allí no probarán nada fresco ni bebida alguna,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxcvii{excepto agua hirviendo y pus líquida.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxcviii{Recompensa adecuada.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxcix{En verdad, ellos contaban con que no regresarían\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcc{y desmintieron Nuestras señales categóricamente.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcci{Pero Nosotros hemos contabilizado todo por escrito\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccii{Probad pues. No os incrementaremos más que el castigo.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcciii{En verdad, a los temerosos de Dios les aguarda una gran victoria.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcciv{Jardines y viñedos\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccv{y parejas vírgenes y hermosas de su misma edad\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccvi{y copas desbordantes.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccvii{Allí no escucharán conversaciones vanas ni falsedades\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccviii{Una recompensa de tu Señor. Un regalo calculado.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccix{Señor de los cielos y la Tierra y de lo que entre ellos hay. El Clementísimo. No tendrán derecho a dirigirse a Él.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccx{El día en que vengan las almas y los ángeles en filas, no hablará más que aquel que haya sido autorizado por el Clementísimo y no dirá más que la verdad.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccxi{¡Ese será el día de la Verdad! Así pues, quien quiera, que tome un camino de regreso hacia su Señor.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdccxii{En verdad, os hemos advertido de un castigo cercano el día en que vea el hombre lo que envió por delante de sí mismo. Y el incrédulo dirá: “¡Ay de mí! ¡Ojalá fuese polvo!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccxiii{\basmalahes Juro por los que arrancan con violencia,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdccxiv{por quienes extraen suavemente,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccxv{por quienes se apresuran,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccxvi{por quienes van por delante,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdccxvii{por quienes dirigen los asuntos:\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdccxviii{El día en que sea tocada la trompeta que provoque el temblor\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdccxix{seguido por otro toque,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdccxx{que los corazones, ese día, se estremecerán\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdccxxi{y observarán temerosos\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdccxxii{y dirán: «¿En verdad regresaremos a nuestro estado primitivo\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdccxxiii{después de haber sido huesos descompuestos?»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdccxxiv{Dirán: «Será, entonces, un ruinosos regreso.»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdccxxv{Se producirá un solo tañido\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdccxxvi{y ¡helos aquí! vivos sobre la Tierra pelada.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdccxxvii{¿Te hemos relatado la historia de Moisés\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdccxxviii{cuando le llamó su Señor en el valle sagrado de Tuwa?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdccxxix{«Ve al Faraón. En verdad se ha endiosado.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdccxxx{y dile: «¿Quieres purificarte\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxi{y que yo te guíe hacia tu Señor para que seas temeroso?»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxii{Así pues, le hizo ver la gran señal,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxiii{pero él desmintió y rehusó obedecer.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxiv{Luego, dio la espalda y se esforzó.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxv{Luego, congregó a la gente y la arengó,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxvi{diciendo: «Yo soy vuestro Señor Supremo».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxvii{Así que Dios le infligió el castigo de la otra vida y de ésta.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxviii{En verdad, en todo esto hay una lección para quien tema.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxix{¿Sois vosotros más difíciles de crear o el cielo que Él construyó?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdccxl{Él elevó su altura y lo ordenó armoniosamente\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdccxli{Oscureció su noche y alumbró su día\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccxlii{y, después de ello, expandió la Tierra,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdccxliii{sacando de ella el agua y los pastos\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccxliv{y fijó firmemente las montañas\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccxlv{para vuestro disfrute y el de vuestro ganado.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccxlvi{Y cuando llegue el gran acontecimiento,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccxlvii{el día en el que el ser humano recuerde sus esfuerzos\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccxlviii{y sea mostrado el Infierno a quien vea,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccxlix{quien haya sido rebelde\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccl{y preferido la vida mundanal\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccli{tendrá el Infierno por albergue\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdcclii{y quien haya temido la comparecencia ante su Señor y haya apartado el alma de las pasiones\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccliii{tendrá el Jardín por albergue.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdccliv{Te preguntan sobre la Hora ¿Cuándo tendrá lugar?\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdcclv{Y ¿Quién eres tú para informar de ella?\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdcclvi{Su conclusión corresponde a tu Señor.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdcclvii{En verdad, tú eres sólo un amonestador para quienes la temen.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdcclviii{El día que la vean les parecerá que no han permanecido más que una tarde o una mañana.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdcclix{\basmalahes Frunció el ceño y volvió la espalda\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcclx{cuando el ciego vino junto a él.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcclxi{Y ¿Cómo puedes saber? Puede que él se purificase\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcclxii{o aceptase la amonestación y ésta le aprovechase.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcclxiii{A ese que alardea de su riqueza\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcclxiv{tú le atiendes complacido.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcclxv{¿Y qué te importa si no se purifica?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcclxvi{Pero a quien acude a ti anhelante\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcclxvii{y es temeroso\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcclxviii{no le prestas atención.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcclxix{¡Pero no! En verdad, esto es un recordatorio\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcclxx{-Así pues, quien quiera lo recordará-\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxi{recogido en páginas nobles,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxii{sublimes, purificadas,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxiii{de las manos de enviados\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxiv{nobles y píos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxv{¡Que perezca el ser humano! ¡Qué ingrato es!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxvi{¿De qué cosa le ha creado Él?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxvii{De una gota le ha creado y le ha determinado de manera equilibrada.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxviii{Luego, ha hecho fácil el camino para él.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxix{Luego, le hace morir y le entierra.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxx{Luego, cuando Él quiera, le resucitará.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxi{Pero no. No ha cumplido lo que Él le ha ordenado.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxii{Que el ser humano observe aquello de lo que se alimenta.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxiii{Cómo derramamos el agua en abundancia.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxiv{Luego, Nosotros hacemos que la Tierra se abra\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxv{y hacemos que brote en ella el grano,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxvi{la uva y los vegetales,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxvii{el olivo y la palmera datilera\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxviii{y frondosos jardines\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxix{y frutas y pastos\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccxc{para disfrute vuestro y de vuestro ganado.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccxci{Así pues, cuando llegue a vosotros el Tañido ensordecedor,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccxcii{el día en que huya el hombre de su hermano\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccxciii{y de su madre y de su padre\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccxciv{y de su esposa e hijos,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccxcv{a cada cual, ese día, le bastará su propia preocupación\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccxcvi{Ese día habrá rostros resplandecientes,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccxcvii{sonrientes, felices\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdccxcviii{y otros rostros, ese día, ensombrecidos,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccxcix{cubiertos por la tristeza.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdccc{Esos serán los incrédulos, los depravados.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdccci{\basmalahes Cuando el Sol sea enrollado\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccii{y cuando caigan las estrellas\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccciii{y cuando las montañas se desmoronen\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccciv{y cuando las camellas preñadas de diez meses sean abandonadas\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccv{y cuando las fieras sean agrupadas\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccvi{y cuando los mares se llenen de fuego\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccvii{y cuando las almas sean emparejadas\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccviii{y cuando a la niña enterrada viva se le pregunte\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccix{por qué delito fue matada\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccx{y cuando las páginas escritas sean desenrolladas\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxi{y cuando el cielo sea despellejado\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxii{y cuando el Infierno sea avivado\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxiii{y cuando el Jardín sea aproximado,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxiv{entonces, cada alma conocerá lo que presenta.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxv{¡Pues no! ¡Juro por los que se ocultan!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcccxvi{¡Los planetas que giran a gran velocidad y se esconden!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcccxvii{Y juro por la noche cuando se va\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcccxviii{y juro por la mañana cuando respira\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcccxix{que, en verdad, él es la palabra de un Mensajero noble,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcccxx{poderoso, y distinguido cerca del Dueño del Trono,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxi{donde es obedecido y digno de confianza.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxii{Y vuestro compañero no está loco\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxiii{y, ciertamente, él le vio en el claro horizonte\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxiv{y no es tacaño con lo que está oculto a los sentidos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxv{Y ello no es la palabra de un Satanás maldecido\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxvi{Así pues ¿A dónde vais?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxvii{Ello es sólo un recuerdo para los mundos,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxviii{para quien de vosotros quiera ir recto.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxix{Pero no lo querréis a menos que lo quiera Dios, el Señor de los Mundos.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxx{\basmalahes Cuando el cielo se hienda,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxi{cuando las estrellas se dispersen,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxii{cuando los mares se confundan unos con otros,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxiii{cuando los sepulcros sean vueltos del revés,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxiv{sabrá el alma lo que hizo y lo que dejó de hacer.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxv{¡Oh, humano! ¿Qué fue lo que te sedujo y apartó de tu Señor, el Generosísimo,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxvi{el Cual te creó, te formó y te perfeccionó\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxvii{y te compuso en la forma que quiso?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxviii{¡Pero no! ¡Vosotros desmentís la Recompensa!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxix{Y, en verdad, sobre vosotros hay ángeles guardianes,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxl{honorables escribas de vuestras acciones.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxli{Ellos saben lo que hacéis.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlii{En verdad, los que obraron bien estarán en la bendición\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxliii{y, en verdad, los que hicieron el mal estarán en el Infierno,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxliv{en el que entrarán y arderán el Día de la Recompensa\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlv{y del que no podrán ausentarse.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlvi{¿Y qué te hará entender lo que es el Día de la Recompensa?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlvii{Otra vez ¿Qué te hará entender lo que es el Día de la Recompensa?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlviii{Es el día en el que un alma no poseerá nada que dar a otra alma y el mando en ese día será sólo de Dios.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlix{\basmalahes ¡Ay de los defraudadores!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccl{Esos que, cuando compran, exigen la medida exacta\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcccli{pero, cuando ellos dan la medida o el peso a otros, defraudan.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccclii{¿Acaso no piensan que serán resucitados\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccliii{para un día grandioso,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccliv{el día en el que los humanos comparecerán ante el Señor de los Mundos?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdccclv{¡Pero no! En verdad, el registro de los malvados está en Siyyin.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdccclvi{¿Y qué te hará entender lo que es Siyyin?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdccclvii{Es una escritura detallada.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdccclviii{¡Ay, ese día, de los desmentidores!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdccclix{¡Aquellos que desmentían el Día de la Recompensa!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdccclx{Y nadie lo desmiente, excepto quien es un trasgresor pecador.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdccclxi{Cuando les son recitados nuestros versículos dicen: «¡Fábulas de los primitivos!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdccclxii{¡Pero no! ¡Lo que hacían enmoheció sus corazones!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdccclxiii{¡Pero no! ¡En verdad, ese día no podrán contemplar a su Señor!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdccclxiv{Luego, entrarán y arderán en el Infierno.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdccclxv{Luego, se les dirá: «¡Esto era lo que desmentíais!»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdccclxvi{¡Pero no! ¡En verdad, el registro de los que hacen el bien está en Il.liyyin!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdccclxvii{¿Y qué te hará entender lo que es Il.liyyin?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdccclxviii{Es una escritura detallada\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdccclxix{que los cercanos atestiguarán.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdccclxx{En verdad, quienes hacen el bien estarán entre bendiciones,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxi{reclinados en asientos, contemplando.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxii{Reconocerás en sus rostros el resplandor de las bendiciones.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxiii{Les será escanciado un néctar sellado.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxiv{Su sello será almizcle -¡que quienes emulan emulen por ello!-\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxv{mezclado con Tasnim,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxvi{una fuente de la que beberán los cercanos.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxvii{En verdad, los malvados se burlaban de quienes eran creyentes\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxviii{y cuando pasaban junto a ellos se hacían guiños de complicidad\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxix{cuando regresaban a sus gentes regresaban satisfechos y orgullosos de su comportamiento\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxx{y cuando les veían decían: «¡En verdad que están extraviados!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxi{aunque no habían sido enviados a ellos de protectores.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxii{Así pues, hoy los creyentes se reirán de los que no creen,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxiii{reclinados en asientos, contemplando\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxiv{si los que no creían han sido recompensados por lo que hacían.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxv{\basmalahes Cuando el cielo se rompa\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxvi{y escuche la orden de su Señor, como debe ser,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxvii{y cuando la Tierra sea allanada y extendida\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxviii{y arroje cuanto en ella hay y quede vacía\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxix{y escuche la orden de su Señor, como debe ser…\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccxc{Oh, humano! En verdad, te esfuerzas afanosamente hacia tu Señor y te encontrarás con Él.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccxci{Así pues, a quien le sea entregada su escritura en su mano derecha\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcii{pronto será juzgado con benevolencia\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccxciii{y regresará feliz a su gente.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccxciv{Pero a quien le sea entregada su escritura por detrás de su espalda,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcv{pronto suplicará [diciendo]: «¡Estoy perdido!»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcvi{y entrará y arderá en el Fuego llameante.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcvii{¡En verdad, estaba contento entre su gente!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcviii{¡En verdad, creía que no regresaría jamás!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcix{¡Sí! ¡En verdad, su Señor le observaba!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcm{Juro por el rojo del crepúsculo\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmi{y por la noche y lo que reúne\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmii{y por la Luna cuando está llena,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmiii{que os transformaréis gradualmente.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmiv{Así pues, ¿Qué les sucede que no creen\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmv{y que, cuando se les recita el Corán no se prosternan?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmvi{Pero los que no creen lo desmienten.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmvii{Y Dios es quien mejor conoce lo que ocultan.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcmviii{Así pues, infórmales de un castigo doloroso,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcmix{excepto a aquellos que creen y realizan buenas acciones. Para ellos hay una recompensa inacabable.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcmx{\basmalahes Juro por el cielo constelado\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxi{y por el día prometido\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxii{y por un testigo y lo testimoniado:\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxiii{¡Maldita sea la gente del foso\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxiv{de fuego inmenso!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxv{que se sentaron ante él\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmxvi{presenciando lo que hacían a los creyentes.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmxvii{Y sólo se vengaron de ellos porque creían en Dios, el Todopoderoso, el Digno de Alabanza,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmxviii{a Quien pertenece el reino de los cielos y la Tierra. Y Dios es testigo de todas las cosas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmxix{En verdad, quienes persiguen y torturan a los creyentes y a las creyentes y luego no se arrepienten, sufrirán el castigo del Infierno y el castigo del Fuego.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmxx{En verdad, quienes creen y actúan rectamente tendrán Jardines de cuyas profundidades brotan los ríos. Ese es el gran triunfo.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmxxi{En verdad, el castigo de tu Señor será severísimo.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmxxii{En verdad, Él es Quien inicia la creación y Quien la hace regresar a la vida\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmxxiii{y Él es el Perdonador, el Afectuoso,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmxxiv{el Señor del Trono Glorioso.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmxxv{Él hace lo que quiere.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmxxvi{¿Ha llegado a ti la historia de los ejércitos\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmxxvii{del Faraón y de Zamud?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmxxviii{Pero los que no creen persisten en desmentir,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmxxix{aunque Dios les tiene cercados.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmxxx{Por el contrario, es un Corán glorioso\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxi{registrado) en una tabla protegida.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxii{\basmalahes Juro por el cielo y por Tariq.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxiii{¿Y qué te hará saber lo que es Tariq?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxiv{Es la estrella que brilla en la noche.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxv{En verdad, no hay alma que no tenga un guardián sobre ella.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxvi{Así pues, que observe el ser humano de qué ha sido creado.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxvii{Ha sido creado de un líquido eyaculado\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxviii{que sale de entre la columna y las costillas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxix{En verdad, Él tiene poder para hacerle regresar\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmxl{el día en que serán examinados los secretos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmxli{Y él no tendrá fuerza ni quien le auxilie.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmxlii{Juro por el cielo que regresa\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmxliii{y por la Tierra que se abre.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmxliv{En verdad, él es una palabra discriminadora\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmxlv{y no para ser tomada a broma.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmxlvi{En verdad, ellos organizan planes\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmxlvii{y yo organizo planes.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmxlviii{Así pues, da a los que no son creyentes un pequeño plazo.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmxlix{\basmalahes ¡Glorifica el nombre de tu Señor, el Altísimo!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcml{Quien ha creado y ordenado\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmli{y Quien ha determinado y guiado\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmlii{y Quien hace surgir la hierba\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmliii{y la transforma en heno oscuro.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmliv{Te haremos recitar y no olvidarás\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmlv{excepto lo que Dios quiera. En verdad, Él conoce lo manifiesto y lo que se oculta.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmlvi{Y te facilitaremos un camino fácil.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmlvii{Así pues, advierte cuando la advertencia sea beneficiosa.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmlviii{Se dejará amonestar quien sea temeroso\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmlix{y se apartará de ella el infame,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmlx{el cual será arrojado al Fuego Mayor,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmlxi{en el cual no morirá ni vivirá.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmlxii{Con seguridad, triunfará quien se purifique\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmlxiii{y recuerde el nombre de su Señor y rece.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmlxiv{Pero vosotros preferís la vida mundana,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmlxv{aunque la otra es mejor y más permanente.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmlxvi{En verdad, esto está en los escritos primeros.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmlxvii{Los escritos de Abraham y de Moisés.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmlxviii{\basmalahes ¿Ha llegado a ti el relato de la que cubre?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmlxix{Algunos rostros, ese día, estarán sombríos,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmlxx{agitados, fatigados.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxi{Entrarán en el Fuego abrasador.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxii{Se les dará de beber de una fuente hirviente.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxiii{No tendrán más alimento que Dariy,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxiv{que no engorda ni sacia el hambre.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxv{Otros rostros, ese día, resplandecerán\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxvi{satisfechos por su esfuerzo,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxvii{en un Jardín excelso,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxviii{en el que no escucharán palabras vanas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxix{En él hay una fuente que mana.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxx{En él, lechos elevados\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxi{y copas servidas,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxii{filas de cojines en los que recostarse\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxiii{y gruesas alfombras extendidas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxiv{¿Acaso no han observado cómo han sido creados los camellos?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxv{¿Y cómo ha sido elevado el cielo?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxvi{¿Y cómo han sido fijadas las montañas?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxvii{¿Y cómo ha sido extendida la Tierra?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxviii{Así pues ¡Amonesta! En verdad, tú sólo eres un amonestador.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxix{No tienes poder para obligarles.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmxc{Pero a quien dé la espalda y descrea\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcmxci{Dios le castigará con el castigo mayor.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcmxcii{En verdad, regresarán a Nosotros.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcmxciii{Luego, en verdad, a Nosotros nos corresponderá ajustarles las cuentas\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcmxciv{\basmalahes Juro por la aurora\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxcv{y por las diez noches\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxcvi{y por el par y el impar\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxcvii{y por la noche cuando se retira.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxcviii{¿No es esto suficiente juramento para el que posee intelecto?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxcix{¿No has visto lo que hizo tu Señor con la gente de Ad?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmm{¿Con Iram la de las columnas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmi{semejante a la cual no fue creada ninguna otra en la Tierra?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmii{¿Y con Zamud, que excavaron la roca en el valle?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmiii{¿Y con Faraón, el señor de las estacas?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmiv{que se endiosaron en la Tierra\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmv{e incrementaron la corrupción en ella?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmvi{Así, tu Señor descargó con fuerza sobre ellos el látigo del castigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmvii{En verdad, tu Señor está siempre vigilante.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmviii{En cuanto al ser humano, cuando su Señor le pone a prueba honrándole y bendiciéndole, dice: «Mi Señor me ha honrado.»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmix{Pero cuando le pone a prueba ajustándole la provisión, dice: «Mi Señor me ha humillado.»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmx{¡Pero no! Lo que sucede es que no sois generosos con el huérfano,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmxi{ni os estimuláis unos a otros a alimentar al necesitado\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmxii{y devoráis las herencias con un apetito insaciable\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmxiii{y amáis las riquezas con un amor desaforado\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmxiv{¡Pero no! Cuando la Tierra quede totalmente allanada\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmmxv{y venga tu Señor y los ángeles dispuestos en filas sucesivas\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmmxvi{y se haga venir ese día al Infierno… Ese día, recordará el ser humano y de nada le servirá el recuerdo.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmmxvii{Dirá: «¡Ay de mi! ¡Ojalá hubiese enviado por delante algo de bien para mi vida!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmmxviii{Así, ese día nadie castigará con Su castigo\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmmxix{y nadie apresará con Su presa.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmmxx{¡Oh, alma sosegada!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmmxxi{¡Regresa a tu Señor, satisfecha de Él y Él satisfecho de ti!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmmxxii{Entra con Mis siervos,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmmxxiii{y entra en Mi Jardín.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmmxxiv{\basmalahes Juro por esta ciudad,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxxv{por esta ciudad en la que tú resides,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxxvi{y por un padre y lo que engendra:\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxxvii{Ciertamente, hemos creado al ser humano en el esfuerzo y el cansancio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxxviii{¿Cree que nadie tiene poder sobre él?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxxix{Dice: «¡He derrochado una gran fortuna!»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmxxx{¿Cree que nadie le ve?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmxxxi{¿Acaso no le hemos puesto dos ojos?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmxxxii{¿Y una lengua y dos labios?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmxxxiii{¿Y no le hemos indicado las dos vías?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmxxxiv{Sin embargo no se apresura a subir la cuesta.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmxxxv{¿Y qué te hará saber lo que es la cuesta?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmxxxvi{Es liberar a un esclavo\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmxxxvii{o alimentar en días de hambre\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmxxxviii{a un familiar huérfano\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmxxxix{o a un necesitado polvoriento,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmxl{y ser de los que creen y se aconsejan mutuamente la paciencia y se aconsejan mutuamente la misericordia.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmxli{¡Esos son la gente de la derecha!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmxlii{Y aquellos que no creen en Nuestras señales son la gente de la izquierda,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmxliii{a quienes el Fuego rodeará por todos lados.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmxliv{\basmalahes Juro por el Sol y por el esplendor de la mañana\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxlv{y por la Luna cuando le sigue\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxlvi{y por el día cuando la muestra\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxlvii{y por la noche cuando la cubre\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxlviii{y por el cielo y Quien lo construyó\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxlix{y por la Tierra y Quien la extendió\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmml{y por un alma y Quien la creo de forma armoniosa y equilibrada,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmli{inspirándole lo que la corrompe y el temor que la mantiene a salvo:\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlii{Ciertamente, habrá triunfado quien la purifique\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmliii{y habrá fracasado quien la corrompa\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmliv{Tamud, en su rebeldía, desmintió\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmlv{cuando el más miserable de ellos se alzó,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmlvi{a pesar de que el Mensajero de Dios les había dicho: «¡Ésta es la camella de Dios, dejadla beber!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmlvii{Pero le desmintieron y la mataron y su Señor les castigó por su pecado y les aniquiló a todos por igual,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmlviii{sin temer las consecuencias.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmlix{\basmalahes Juro por la noche cuando cubre\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmlx{y por el día cuando se manifiesta\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmlxi{y por Quien ha creado al varón y a la hembra,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmlxii{que, en verdad, vuestros esfuerzos obtienen diferentes resultados.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmlxiii{Así pues, a quien dé y sea temeroso de Dios\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmlxiv{y crea en la buena promesa,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmlxv{le facilitaremos las cosas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmlxvi{Pero a quien sea avaro y se crea autosuficiente\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlxvii{y desmienta la buena promesa,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmlxviii{le haremos difícil las cosas\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmlxix{y no le beneficiará su riqueza cuando muera.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmlxx{En verdad, Nosotros tenemos la guía\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmlxxi{y a Nosotros pertenece la otra vida y la primera\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmlxxii{Y os he advertido del Fuego llameante\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmlxxiii{al cual sólo será arrojado el más descreído,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmlxxiv{que desmiente y se aparta.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmlxxv{Y se librará de él quien sea más temeroso,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmlxxvi{que dé de sus bienes y los purifique,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmlxxvii{y que no hace el bien esperando recompensa,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmlxxviii{sino buscando la satisfacción de su Señor el Altísimo.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmlxxix{Y pronto será satisfecho.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmmlxxx{\basmalahes Juro por la mañana cuando resplandece\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxi{y por la noche cuando todo está en calma,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxii{que tu Señor no te ha abandonado ni está enojado contigo.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxiii{Y, ciertamente, la otra vida será mejor para ti que la primera\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxiv{y pronto te dará tu Señor y estarás satisfecho.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxv{¿Acaso no te encontró huérfano y te amparó?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxvi{¿Y te encontró perdido y te guió?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxvii{¿Y te encontró pobre y te enriqueció?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxviii{Así pues, no oprimas al huérfano\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxix{ni alejes al mendigo\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmxc{y proclama la merced de tu Señor.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmxci{\basmalahes ¿Acaso no hemos abierto tu pecho\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxcii{y te hemos liberado de la carga\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxciii{que pesaba sobre tu espalda?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxciv{¿Y hemos elevado para ti el recuerdo?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxcv{Así, en verdad, con la dificultad, la facilidad.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxcvi{En verdad, junto a la dificultad, la facilidad.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmxcvii{Así pues, cuando hayas acabado tus obligaciones, esfuérzate en tu adoración\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmxcviii{y vuélvete a tu Señor anhelante.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmxcix{\basmalahes Juro por la higuera y el olivo\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmc{y por el monte Sinaí\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmci{y por esta ciudad segura\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcii{que, ciertamente, hemos creado al ser humano en la mejor condición.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmciii{Luego, le hemos relegado a lo más bajo de lo bajo,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmciv{excepto a aquellos que creen y actúan rectamente, pues para ellos hay una recompensa ilimitada.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcv{Así pues, ¿Qué es lo que te hace desmentir la Recompensa?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcvi{¿No es Dios el mejor de los jueces?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcvii{\basmalahes Recita en el nombre de tu Señor, el Cual ha creado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcviii{Ha creado al ser humano a partir de algo que está suspendido.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcix{Recita. Tu Señor es el Más Generoso.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcx{Es Quien ha enseñado por medio de la escritura\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxi{Ha enseñado al ser humano lo que éste no conocía.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxii{¡Pero no! En verdad, el ser humano se rebela\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxiii{cuando se cree autosuficiente.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxiv{En verdad, el regreso es hacia tu Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxv{¿Has visto a quien prohíbe\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmcxvi{a un siervo que rece?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmcxvii{¿Has visto si está sobre la buena guía\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmcxviii{u ordena el temor de Dios?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmcxix{¿Has visto si desmiente y se aparta?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmcxx{¿Acaso no sabe que Dios ve?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmcxxi{¡Pero no! Si no termina con eso le arrastraremos del flequillo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmcxxii{Flequillo mentiroso y pecador.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmcxxiii{Que llame entonces a sus colegas. Nosotros llamaremos\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmcxxiv{a los ángeles guardianes del Infierno.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmcxxv{¡Pero no! No le obedezcas, prostérnate y busca la cercanía de Dios.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmcxxvi{\basmalahes En verdad, lo hemos hecho descender en la Noche del Decreto.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxxvii{¿Y qué te hará entender lo que es la Noche del Decreto?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxxviii{La Noche del Decreto es mejor que mil meses.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxxix{Descienden en ella los ángeles y el Espíritu con el permiso de tu Señor sobre todos los asuntos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxxx{Hay paz en ella hasta la llegada del amanecer.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxi{\basmalahes No fueron separados los que no creían de la gente de la Escritura y los idólatras hasta que no llegó a ellos la prueba clara.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxii{Un Mensajero procedente de Dios que les recita escritos purificados\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxiii{en los que hay mensajes y disposiciones claras y firmes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxiv{Y no se dividieron aquellos a quienes fue dada la Escritura excepto después de haber llegado a ellos la prueba clara.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxv{Y no les fue ordenado sino que adorasen a Dios, con fe en Él únicamente, como verdaderos buscadores de la Verdad, que hicieran la oración y que diesen el impuesto purificador de la riqueza. Y esa es la religión verdadera.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxvi{En verdad, los que no creen de la gente de la Escritura y los idólatras estarán eternamente en el fuego del Infierno. Ellos son lo peor de la Creación.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxvii{En verdad, quienes creen y actúan rectamente son lo mejor de la Creación\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxviii{Su recompensa junto a su Señor serán los Jardines del Edén, de cuyas profundidades brotan los ríos, en los que estarán eternamente, para siempre. Dios estará satisfecho de ellos y ellos lo estarán de Él. Eso será para quien tema a su Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxix{\basmalahes Cuando la Tierra tiemble con su temblor\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxl{y la Tierra expulse su carga\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxli{y diga el ser humano: «¿Qué le sucede?»\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxlii{Ese día, relatará sus crónicas\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxliii{conforme a lo que Dios la inspire.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxliv{Ese día, regresarán los seres humanos en grupos con estados diferentes, para que les sean mostradas sus acciones\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxlv{Así pues, quien haga el peso de un átomo de bien, lo verá\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxlvi{y quien haga el peso de un átomo de mal, lo verá.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxlvii{\basmalahes Juro por los que galopan jadeantes\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxlviii{y hacen saltar chispas (con sus cascos)\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxlix{y atacan al enemigo por sorpresa al amanecer,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcl{levantando una nube de polvo\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcli{e irrumpiendo en grupo entre las filas enemigas\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclii{que, en verdad, el ser humano es muy ingrato con su Señor\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcliii{y, en verdad, él mismo es consciente de ello.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcliv{En verdad, ama en exceso la riqueza.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclv{¿Acaso no sabe que, cuando sea expulsado lo que hay en las tumbas\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclvi{y se manifieste y diferencie lo que hay en los pechos,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmclvii{en verdad, su Señor, ese día, estará bien informado de ello?\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmclviii{\basmalahes La catástrofe.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclix{¿Qué es la catástrofe?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclx{¿Y qué te hará entender lo que es la catástrofe?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxi{Es el día en que los seres humanos estarán como un tumulto de langostas desorientadas y dispersas\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxii{y las montañas como lana de colores deshilachada.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxiii{Entonces, aquel cuya balanza sea pesada\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxiv{disfrutará de una vida satisfactoria\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxv{y aquel cuya balanza sea ligera\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxvi{tendrá por hogar el abismo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclxvii{¿Y qué te hará entender lo que es el abismo?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmclxviii{Es un Fuego abrasador.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmclxix{\basmalahes La rivalidad sin sentido por obtener mayores bienes materiales os mantendrá distraídos\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxx{hasta que os llegue el momento de visitar las tumbas.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxi{¡Pero no! ¡Pronto sabréis!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxii{Otra vez ¡No! ¡Pronto sabréis!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxxiii{¡Pero no! ¡Si supieseis con certeza,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxxiv{os juro que veríais el Fuego!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxxv{Luego, os juro que lo veréis con certeza absoluta.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxxvi{Luego, os juro que, ese día, seréis preguntados por las bendiciones.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxxvii{\basmalahes Juro por la época\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxxviii{que, en verdad, el ser humano va hacia su perdición,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxix{excepto aquellos que creen y realizan buenas acciones y se aconsejan unos a otros la Verdad y se aconsejan unos a otros la paciencia.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxx{\basmalahes ¡Ay de todo difamador murmurador\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxi{que acumula riqueza y la recuenta!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxii{Cree que su riqueza le eternizará.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxiii{¡Pero no! Juro que será arrojado al Hutama.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxiv{¿Y qué te hará entender los que es el Hutama?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxv{Es el fuego abrasador de Dios,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxvi{que llega hasta el fondo del alma.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxvii{En verdad, se cerrará sobre ellos\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxviii{en columnas alargadas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxix{\basmalahes ¿No has visto lo que hizo tu Señor con la gente del elefante?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxc{¿No hizo que fracasasen sus planes\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxci{y envió sobre ellos pájaros en bandadas sucesivas\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxcii{que les lanzaron piedras de barro,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxciii{que les dejaron como heno masticado?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxciv{\basmalahes ¡Juro por la alianza de los Quraysh!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxcv{¡Su alianza para el viaje de las caravanas de invierno y verano!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxcvi{Así pues, que adoren al Señor de esta Casa,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxcvii{el Cual les da de comer en tiempos de hambruna y les da seguridad ante el temor.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxcviii{\basmalahes ¿Has visto a quien desmiente el Día de la Recompensa?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxcix{Es el mismo que aparta de sí violentamente al huérfano\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcc{y que no anima a alimentar al necesitado.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcci{Así pues ¡Ay de los que rezan\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccii{y que son negligentes con su oración!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcciii{Aquellos que la hacen para ser vistos\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcciv{y niegan la ayuda.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmccv{\basmalahes En verdad, te hemos otorgado la abundancia.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccvi{Así pues, reza a tu Señor y ofrece sacrificios\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccvii{En verdad, quien te odia es el que no tendrá descendencia.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccviii{\basmalahes Di: «¡Oh, vosotros que no creéis!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccix{No adoro lo que vosotros adoráis,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccx{ni vosotros sois adoradores de lo que yo adoro.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxi{Y yo no soy adorador de lo que vosotros adorabais\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxii{y vosotros no sois adoradores de lo que yo adoro.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxiii{Para vosotros vuestra religión y para mí mi religión.»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmccxiv{\basmalahes Cuando llegue el auxilio de Dios y la victoria\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxv{y veas a los seres humanos entrando en la religión de Dios en oleadas sucesivas,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxvi{glorifica con alabanzas a tu Señor y busca Su perdón. En verdad, Él acepta al que se arrepiente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxvii{\basmalahes Que perezcan las manos de Abu Lahab y que perezca él.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxviii{No le servirá de nada su riqueza ni todo lo que obtuvo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxix{Entrará en un Fuego llameante\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxx{y también su mujer, la portadora de leña,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxi{con una cuerda de esparto rodeando su cuello.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxii{\basmalahes Di: «Él es Dios, uno.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxiii{Dios, eterno.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxiv{No ha engendrado ni ha sido engendrado\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxv{y no hay otro semejante a Él.»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxvi{\basmalahes Di: «Me refugio en el Señor del alba\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxvii{del mal de lo que Él ha creado\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxviii{y del mal de la oscuridad de la noche cuando se extiende\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxix{y del mal de las sopladoras de nudos\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxx{y del mal del envidioso cuando envidia.»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxi{\basmalahes Di: «Me refugio en el Señor de los seres humanos,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxii{el Rey de los seres humanos,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxiii{el dios de los seres humanos,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxiv{del mal del susurrante tentador,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxv{el que susurra en el pecho de los seres humanos\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxvi{y procede de los genios y de los seres humanos.»\qt@no{6}}
%% End of file `qurantext-esi.translation.def'.
