\qt@newcmd\qurantrans@es@i{En el nombre de Dios, el Compasivo con toda la creación, el Misericordioso con los creyentes.\qt@no{1}}
\qt@newcmd\qurantrans@es@ii{Todas las alabanzas son para Dios, Señor de todo cuanto existe,\qt@no{2}}
\qt@newcmd\qurantrans@es@iii{el Compasivo, el Misericordioso.\qt@no{3}}
\qt@newcmd\qurantrans@es@iv{Soberano absoluto del Día del Juicio Final,\qt@no{4}}
\qt@newcmd\qurantrans@es@v{solo a Ti te adoramos y solo de Ti imploramos ayuda.\qt@no{5}}
\qt@newcmd\qurantrans@es@vi{¡Guíanos por el camino recto!\qt@no{6}}
\qt@newcmd\qurantrans@es@vii{El camino de los que has colmado con Tus favores, no el de los que cayeron en Tu ira, ni el de los que se extraviaron.\qt@no{7}}
\qt@newcmd\qurantrans@es@viii{\basmalahes Álif. Lam. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@ix{Este es el Libro del cual no hay duda, es guía para los que son conscientes de Dios y e temen devocionalmente,\qt@no{2}}
\qt@newcmd\qurantrans@es@x{los que creen en lo oculto, practican la oración, dan caridad de lo que les he proveído,\qt@no{3}}
\qt@newcmd\qurantrans@es@xi{y creen en lo que te ha sido revelado [¡oh, Mujámmad!] y en lo que fue revelado [originalmente a los profetas anteriores], y tienen certeza de la existencia de la otra vida.\qt@no{4}}
\qt@newcmd\qurantrans@es@xii{Esos son los que están en la guía de su Señor y serán los bienaventurados.\qt@no{5}}
\qt@newcmd\qurantrans@es@xiii{A los que niegan la verdad les da lo mismo que les adviertas o no, no creerán.\qt@no{6}}
\qt@newcmd\qurantrans@es@xiv{Dios ha sellado sus corazones y sus oídos, sobre sus ojos hay un velo y recibirán un castigo terrible [en el Infierno].\qt@no{7}}
\qt@newcmd\qurantrans@es@xv{Entre las personas hay [hipócritas] que dicen: ``Creemos en Dios y en el Día de la Resurrección", pero no son creyentes.\qt@no{8}}
\qt@newcmd\qurantrans@es@xvi{Pretenden engañar a Dios y también a los creyentes pero, sin advertirlo, solo se engañan a sí mismos.\qt@no{9}}
\qt@newcmd\qurantrans@es@xvii{Sus corazones tienen una enfermedad y [por su actitud] Dios agrava aún más su enfermedad. Sufrirán un castigo doloroso por haber mentido.\qt@no{10}}
\qt@newcmd\qurantrans@es@xviii{Cuando se les dice: ¡No siembren la corrupción en la Tierra! Responden: ``¡Pero si nosotros somos los que hacemos el bien!"\qt@no{11}}
\qt@newcmd\qurantrans@es@xix{¿Acaso no son ellos los corruptores? [Sí,] pero no se dan cuenta.\qt@no{12}}
\qt@newcmd\qurantrans@es@xx{Cuando se les dice: ``¡Crean como ha creído la gente!" Responden: ``¿Es que vamos a creer como lo hacen los tontos?" ¿Acaso no son ellos los tontos? [Sí,] pero no lo saben.\qt@no{13}}
\qt@newcmd\qurantrans@es@xxi{Cuando se encuentran con los creyentes les dicen: ``¡Somos creyentes!" Pero cuando están a solas con los malvados de entre ellos, les aseguran: ``¡Estamos con ustedes, solo nos burlábamos de ellos!"\qt@no{14}}
\qt@newcmd\qurantrans@es@xxii{[Pero] Dios hará que sus burlas caigan sobre ellos mismos y dejará que permanezcan extraviados, en su ceguera.\qt@no{15}}
\qt@newcmd\qurantrans@es@xxiii{Ellos vendieron la guía, cambiándola por el desvío, y tal negocio no les resultó provechoso, no siendo de los bien guiados.\qt@no{16}}
\qt@newcmd\qurantrans@es@xxiv{Su ejemplo es como el de los que encienden fuego, y cuando les alumbra a su alrededor, [debido a su desvío] Dios les quita la luz dejándolos en tinieblas, por lo que no pueden ver.\qt@no{17}}
\qt@newcmd\qurantrans@es@xxv{Son sordos, mudos y ciegos, y no volverán [al buen camino].\qt@no{18}}
\qt@newcmd\qurantrans@es@xxvi{O [son] como los que al ser azotados por una lluvia torrencial cargada de oscuridad, truenos y relámpagos, se tapan los oídos con sus dedos al caer los rayos por temor a la muerte. Dios asedia a los que niegan la verdad.\qt@no{19}}
\qt@newcmd\qurantrans@es@xxvii{Los relámpagos casi ciegan sus ojos. Cuando los iluminan caminan a su luz, pero cuando la oscuridad vuelve sobre ellos se detienen. Si Dios hubiese querido les habría dejado sordos y ciegos. Dios tiene poder sobre todas las cosas.\qt@no{20}}
\qt@newcmd\qurantrans@es@xxviii{¡Oh, seres humanos! Adoren a su Señor que los creó a ustedes y a quienes los precedieron, para que así alcancen el temor devocional de Dios.\qt@no{21}}
\qt@newcmd\qurantrans@es@xxix{Él hizo para ustedes de la Tierra un lugar habitable y del cielo un techo, e hizo descender la lluvia del cielo con la que hace brotar frutos para su sustento. En consecuencia, no dediquen actos de adoración a otros además de Dios, ahora que saben [que Él es el único Creador].\qt@no{22}}
\qt@newcmd\qurantrans@es@xxx{Si dudan de lo que le he revelado a Mi siervo traigan un capítulo [del Corán] similar, y recurran para ello a quienes toman por socorredores en lugar de Dios, si es verdad lo que afirman.\qt@no{23}}
\qt@newcmd\qurantrans@es@xxxi{Si no lo hacen, y por cierto que no podrán hacerlo, teman al fuego, cuyo combustible serán seres humanos y piedras, [un fuego] que ha sido preparado para los que niegan la verdad.\qt@no{24}}
\qt@newcmd\qurantrans@es@xxxii{Y albricia a los creyentes que obran correctamente que tendrán como recompensa jardines por donde corren los ríos. Cuando allí reciban frutos dirán: ``Esto es similar a lo que recibimos anteriormente", pero solo lo será en apariencia. Allí tendrán esposas puras, donde morarán por toda la eternidad.\qt@no{25}}
\qt@newcmd\qurantrans@es@xxxiii{Dios no se avergüenza de poner como ejemplo a un mosquito o algo aún más pequeño. Los creyentes saben que es la verdad proveniente de su Señor, en cambio los que niegan la verdad dicen: ``¿Qué pretende Dios con este ejemplo?" Así es como Él extravía a muchos y guía a muchos [con este ejemplo], pero no extravía sino a los perversos,\qt@no{26}}
\qt@newcmd\qurantrans@es@xxxiv{los que no cumplen con el pacto establecido con Dios a pesar de haberse comprometido, rompen [los lazos familiares] que Dios ordenó respetar y siembran corrupción en la Tierra. Ésos son los perdedores.\qt@no{27}}
\qt@newcmd\qurantrans@es@xxxv{¿Cómo osan no creer en Dios siendo que no existían y Él les dio la vida, luego los hará morir y finalmente los resucitará y a Él serán retornados [para que los juzgue el Día del Juicio Final]?\qt@no{28}}
\qt@newcmd\qurantrans@es@xxxvi{Él es Quien creó para ustedes todo cuanto hay en la Tierra, luego se volvió hacia el cielo e hizo de éste siete cielos; Él conoce todas las cosas.\qt@no{29}}
\qt@newcmd\qurantrans@es@xxxvii{Y [menciona, oh, Mujámmad] cuando tu Señor le dijo a los ángeles: ``He de establecer en la Tierra a quien la herede", dijeron: ``¿Pondrás en ella a quien la corrompa [devastándola] y derrame sangre siendo que nosotros te glorificamos y santificamos?" Dijo: ``Yo sé lo que ustedes ignoran".\qt@no{30}}
\qt@newcmd\qurantrans@es@xxxviii{Y [Dios] enseñó a Adán los nombres de todas las cosas, luego se las mostró a los ángeles y dijo: ``Díganme sus nombres, si es que dicen la verdad".\qt@no{31}}
\qt@newcmd\qurantrans@es@xxxix{Dijeron: ``¡Glorificado seas! No tenemos más conocimiento que el que Tú nos has concedido, Tú todo lo conoces, todo lo sabes".\qt@no{32}}
\qt@newcmd\qurantrans@es@xl{Dijo: ``¡Oh Adán! Infórmales sobre sus nombres". Y cuando les hubo informado sobre sus nombres, Dios dijo: ``¿Acaso no les dije que conozco lo oculto de los cielos y de la Tierra, y sé lo que manifiestan y lo que ocultan?"\qt@no{33}}
\qt@newcmd\qurantrans@es@xli{Pero cuando dije a los ángeles: ``¡Prostérnense ante Adán!" Todos se prosternaron excepto Iblís, que se negó y fue soberbio, y se convirtió en uno de los incrédulos.\qt@no{34}}
\qt@newcmd\qurantrans@es@xlii{Dije: ``¡Oh, Adán! Habita con tu esposa el Paraíso, y coman de su abundancia cuanto deseen, pero no se acerquen a este árbol, porque si lo hacen se convertirán ambos en transgresores".\qt@no{35}}
\qt@newcmd\qurantrans@es@xliii{Pero el demonio los hizo caer [en la desobediencia] apartándolos de la situación [agradable] en la que se encontraban. Y les dije: ``¡Desciendan! Serán enemigos unos de otros; y en la Tierra encontrarán una morada y deleite temporal".\qt@no{36}}
\qt@newcmd\qurantrans@es@xliv{Pero le fueron inspiradas a Adán unas palabras de su Señor [para que pudiera expresar su arrepentimiento] y Dios aceptó su arrepentimiento, porque Él es el Indulgente, el Misericordioso.\qt@no{37}}
\qt@newcmd\qurantrans@es@xlv{Dije: ``¡Desciendan todos de él! Cuando les llegue de Mí una guía, quienes la sigan no habrán de sentir temor ni tristeza.\qt@no{38}}
\qt@newcmd\qurantrans@es@xlvi{Pero quienes no crean y desmientan Mis signos serán los habitantes del Fuego, donde morarán eternamente.\qt@no{39}}
\qt@newcmd\qurantrans@es@xlvii{¡Oh, Pueblo de Israel! Recuerden los beneficios con los que los agracié, y cumplan con su compromiso que Yo cumpliré con el Mío, pero tengan temor devocional solo de Mí.\qt@no{40}}
\qt@newcmd\qurantrans@es@xlviii{Y crean en lo que he revelado en confirmación de lo que ya habían recibido y no sean los primeros en negarlo. No vendan Mis preceptos por un precio vil, y tengan temor devocional solo de Mí.\qt@no{41}}
\qt@newcmd\qurantrans@es@xlix{Y no mezclen la verdad con falsedades ni oculten la verdad a sabiendas.\qt@no{42}}
\qt@newcmd\qurantrans@es@l{Cumplan con la oración, paguen el zakat y prostérnense con los que se prosternan [adorando a Dios].\qt@no{43}}
\qt@newcmd\qurantrans@es@li{¿Acaso le ordenan a la gente que haga el bien y se olvidan de hacerlo ustedes mismos, siendo que leen el Libro [la Tora]? ¿Acaso no razonan [bien]?\qt@no{44}}
\qt@newcmd\qurantrans@es@lii{Busquen socorro en la paciencia y la oración. El cumplimiento de la oración es difícil, excepto para los que se someten humildemente [a Dios];\qt@no{45}}
\qt@newcmd\qurantrans@es@liii{tienen certeza del encuentro con su Señor y saben que retornarán a Él.\qt@no{46}}
\qt@newcmd\qurantrans@es@liv{¡Oh, Pueblo de Israel! Recuerden los beneficios con que los agracié y cómo los distinguí sobre los demás pueblos [de su época].\qt@no{47}}
\qt@newcmd\qurantrans@es@lv{Y teman el día en que ninguna persona pueda beneficiarse de otra ni se acepte intercesión o compensación alguna, y nadie sea auxiliado.\qt@no{48}}
\qt@newcmd\qurantrans@es@lvi{Y [recuerden] cuando salvé a sus antepasados de las huestes del Faraón, que los sometían a crueles castigos; degollaban a sus hijos varones [recién nacidos] y dejaban con vida a sus hijas mujeres [para sojuzgarlas]. Esto era una prueba difícil de su Señor.\qt@no{49}}
\qt@newcmd\qurantrans@es@lvii{Y [recuerden] cuando dividí el mar y los salvé, ahogando a las huestes del Faraón delante de sus propios ojos.\qt@no{50}}
\qt@newcmd\qurantrans@es@lviii{Y [recuerden que] cité a Moisés durante cuarenta noches, y cuando se ausentó ustedes tomaron el becerro, obrando injustamente.\qt@no{51}}
\qt@newcmd\qurantrans@es@lix{Luego, a pesar de eso, los perdoné para que fueran agradecidos.\qt@no{52}}
\qt@newcmd\qurantrans@es@lx{Y le concedí a Moisés el Libro y el criterio para que siguieran la guía.\qt@no{53}}
\qt@newcmd\qurantrans@es@lxi{Y [recuerden] cuando Moisés dijo a su pueblo: ``¡Oh, pueblo mío! Han sido injustos con ustedes mismos al adorar al becerro. Arrepiéntanse ante su Señor y dense muerte a ustedes mismos. Eso será lo mejor ante su Creador". Luego Él aceptó su arrepentimiento, porque Él es el Indulgente, el Misericordioso.\qt@no{54}}
\qt@newcmd\qurantrans@es@lxii{Y [recuerden] cuando dijeron: ``¡Oh, Moisés! No creeremos en ti hasta que veamos a Dios claramente". Entonces los azotó un rayo mientras miraban.\qt@no{55}}
\qt@newcmd\qurantrans@es@lxiii{Luego de la muerte los resucité para que fueran agradecidos.\qt@no{56}}
\qt@newcmd\qurantrans@es@lxiv{Y extendí nubes sobre ustedes [para que les dieran sombra], y les envié el maná y las codornices [y les dije:] ``Coman de las cosas buenas que les he provisto"; pero no Me causaron perjuicio alguno [con sus transgresiones], sino que fueron injustos consigo mismos.\qt@no{57}}
\qt@newcmd\qurantrans@es@lxv{Y [recuerden] cuando les dije: ``Entren en esta ciudad [Jerusalén] y coman de ella cuanto deseen en abundancia, pero entren por la puerta prosternándose, suplicando: ¡Perdónanos! Que perdonaré sus pecados, y les concederé aún más a los que hacen el bien".\qt@no{58}}
\qt@newcmd\qurantrans@es@lxvi{Pero los injustos cambiaron por otras las palabras que se les había ordenado decir, y [por eso] hice descender sobre los injustos un castigo del cielo por haber obrado con maldad.\qt@no{59}}
\qt@newcmd\qurantrans@es@lxvii{Y [recuerden] cuando Moisés rogó a su Señor agua para que bebiera su pueblo, le dije: ``¡Golpea la roca con tu bastón!" Entonces brotaron de ella doce manantiales, y supo cada tribu en cual debía beber [y les dije] ``Coman y beban del sustento de Dios, y no abusen en la Tierra corrompiéndola".\qt@no{60}}
\qt@newcmd\qurantrans@es@lxviii{Y [recuerden] cuando dijeron: ``¡Oh, Moisés! No podremos seguir tolerando una sola clase de comida, pide a tu Señor para que nos beneficie con lo que brota de la tierra: verduras, pepinos, ajos, lentejas y cebollas". [Moisés les] Dijo: ``¿Es que quieren cambiar lo superior por algo inferior? Vuelvan entonces a [la esclavitud que sufrían] en Egipto, que allí tendrán lo que piden". Pero los azotó la humillación y la miseria, e incurrieron en la ira de Dios por no haber creído en los preceptos de Dios, haber matado injustamente a los Profetas, rebelarse y transgredir la ley.\qt@no{61}}
\qt@newcmd\qurantrans@es@lxix{Quienes creyeron, los judíos, los cristianos y los sabeos que hayan tenido fe en Dios, en el Día del Juicio Final y hayan obrado correctamente, obtendrán su recompensa junto a su Señor, y no temerán ni se entristecerán.\qt@no{62}}
\qt@newcmd\qurantrans@es@lxx{Y [recuerden] cuando celebré un pacto con ustedes y elevé el monte por encima suyo [y les dije:] ``Aférrense con fuerza a lo que les he dado [la Tora] y recuerden lo que hay en ella, que así alcanzarán el temor devocional de Dios.\qt@no{63}}
\qt@newcmd\qurantrans@es@lxxi{Pero luego volvieron sobre sus pasos, y si no fuera por la gracia y misericordia de Dios sobre ustedes, se contarían entre los perdedores.\qt@no{64}}
\qt@newcmd\qurantrans@es@lxxii{Ellos saben lo que ocurrió a los que transgredieron el sábado; [les dije]: ``Sean monos despreciables".\qt@no{65}}
\qt@newcmd\qurantrans@es@lxxiii{Hice de ello un escarmiento para sus contemporáneos y descendientes, y motivo de reflexión para los que temen devocionalmente a Dios.\qt@no{66}}
\qt@newcmd\qurantrans@es@lxxiv{Y [recuerden] cuando Moisés dijo a su pueblo: ``Dios les ordena ofrendar una vaca". Dijeron: ``¿Acaso te burlas de nosotros?" Dijo [Moisés]: ``¡Que Dios me proteja de contarme entre los ignorantes!"\qt@no{67}}
\qt@newcmd\qurantrans@es@lxxv{Dijeron: ``Pide a tu Señor que nos indique cómo es". Dijo [Moisés]: ``Dios dice que la vaca no debe ser vieja ni joven, sino de edad intermedia; cumplan con lo que se les ordena".\qt@no{68}}
\qt@newcmd\qurantrans@es@lxxvi{Dijeron: ``Pide a tu Señor que nos indique de qué color es". Dijo [Moisés]: ``Él dice que es una vaca de color amarillo, intenso, que alegre a quienes la miren".\qt@no{69}}
\qt@newcmd\qurantrans@es@lxxvii{Dijeron: ``Pide a tu Señor para que nos indique cómo es, porque todas las vacas nos parecen iguales; y si Dios quiere seremos de los que siguen la guía".\qt@no{70}}
\qt@newcmd\qurantrans@es@lxxviii{Dijo [Moisés]: ``Él dice que debe ser una vaca que no haya sido utilizada para arar la tierra ni regar los cultivos, sana y sin manchas". Dijeron: ``Por fin has dicho la verdad". Y la degollaron, aunque estuvieron a punto de no hacerlo.\qt@no{71}}
\qt@newcmd\qurantrans@es@lxxix{Y [recuerden] cuando mataron a un hombre y disputaron, Dios reveló lo que [algunos] ocultaban.\qt@no{72}}
\qt@newcmd\qurantrans@es@lxxx{Entonces dije: ``Golpéenlo con una parte de ella". De la misma manera Dios resucita a los muertos y les muestra Sus milagros para que razonen.\qt@no{73}}
\qt@newcmd\qurantrans@es@lxxxi{Luego [a pesar de estos milagros] se endurecieron sus corazones como piedras, o más duros aún, porque de algunas piedras brotan ríos, otras se parten y pasa agua a través de ellas, y otras se derrumban por temor a Dios; pero [sepan que] Dios no está desatento de lo que hacen.\qt@no{74}}
\qt@newcmd\qurantrans@es@lxxxii{¿Acaso pretenden [¡oh, creyentes!] que les crean, siendo que algunos de ellos oían la Palabra de Dios [la Tora] y la alteraban intencionalmente después de haberla comprendido?\qt@no{75}}
\qt@newcmd\qurantrans@es@lxxxiii{Y cuando se encuentran con los creyentes dicen: ``¡Somos creyentes!" Pero cuando están entre ellos se dicen unos a otros: ``¿Acaso van a contarles lo que Dios nos ha revelado para que puedan argumentar con ello contra nosotros ante nuestro Señor?" ¿Es que no razonan?\qt@no{76}}
\qt@newcmd\qurantrans@es@lxxxiv{¿Es que no saben que Dios conoce lo que ocultan y lo que hacen público?\qt@no{77}}
\qt@newcmd\qurantrans@es@lxxxv{Entre ellos hay iletrados sin conocimiento que no conocen el Libro, que siguen solo sus propios deseos y no hacen sino conjeturar.\qt@no{78}}
\qt@newcmd\qurantrans@es@lxxxvi{¡Ay de aquellos que escriben el Libro con sus manos y luego dicen: ``Esto proviene de Dios", para venderlo a vil precio! ¡Ay de ellos por lo que han escrito sus manos! ¡Ay de ellos por lo que obtuvieron!\qt@no{79}}
\qt@newcmd\qurantrans@es@lxxxvii{Dicen [estos hijos de Israel]: ``El fuego no nos quemará sino días contados". Diles: ``¿Acaso tienen una promesa de Dios?" Sepan que Dios no falta a Sus promesas. ¿O acaso están diciendo de Dios algo que no saben?\qt@no{80}}
\qt@newcmd\qurantrans@es@lxxxviii{No cabe duda de que quienes hayan cometido faltas, y estén cercados por sus pecados, serán los moradores del Fuego, en el que permanecerán eternamente.\qt@no{81}}
\qt@newcmd\qurantrans@es@lxxxix{Pero en cambio, quienes hayan creído y obrado rectamente serán los moradores del Paraíso donde vivirán eternamente.\qt@no{82}}
\qt@newcmd\qurantrans@es@xc{Y [recuerden] cuando celebré el pacto con el Pueblo de Israel: ``Adoren solo a Dios, hagan el bien a sus padres y parientes, a los huérfanos y los pobres, hablen a la gente de buenas maneras, cumplan la oración y paguen el zakat"; pero luego volvieron su espalda en rechazo, salvo unos pocos.\qt@no{83}}
\qt@newcmd\qurantrans@es@xci{Y [recuerden] cuando celebré un pacto con ustedes: ``No derramarán su sangre ni se expulsarán de sus hogares", lo aceptaron y fueron testigos de ello.\qt@no{84}}
\qt@newcmd\qurantrans@es@xcii{Pero fueron ustedes mismos quienes mataron y expulsaron a algunos de los suyos de sus hogares, haciendo causa común contra ellos con pecado y violación de la ley. Y si alguno de ellos caía cautivo, pagaban el rescate por él, pero el haberlos expulsado era ya ilícito. ¿Acaso creen en una parte del Libro y descreen de otra? ¿Cuál es la consecuencia de quienes obran así sino la humillación en la vida mundanal y el castigo más severo el Día de la Resurrección? [Sepan que] Dios no está desatento de cuanto hacen.\qt@no{85}}
\qt@newcmd\qurantrans@es@xciii{Esos son quienes compraron la vida mundanal a cambio de la otra. A ellos no se les aliviará el castigo ni tendrán socorredores.\qt@no{86}}
\qt@newcmd\qurantrans@es@xciv{Y revelé a Moisés el Libro, y después de él envié Mensajeros; y concedí a Jesús, el hijo de María, milagros evidentes y lo fortalecí con el Espíritu Santo [el ángel Gabriel]. ¿No es cierto acaso que cada vez que se les presentaba un Mensajero que no satisfacía sus deseos se comportaban con soberbia, desmintiendo a unos y matando a otros?\qt@no{87}}
\qt@newcmd\qurantrans@es@xcv{Decían: ``Nuestros corazones están cerrados [porque ya saben lo necesario]". Pero en realidad, Dios los maldijo por negar la verdad. ¡Poco es lo que creen!\qt@no{88}}
\qt@newcmd\qurantrans@es@xcvi{Y cuando les llegó el Libro de Dios [el Corán] que confirmaba lo que ya tenían [en la Tora], a pesar de que antes oraban [para que llegara el Profeta que los guiase a] la victoria contra los incrédulos, cuando se les presentó [el Mensajero] lo reconocieron [pero como no era judío], no creyeron en él. ¡Que la maldición de Dios caiga sobre los que niegan la verdad!\qt@no{89}}
\qt@newcmd\qurantrans@es@xcvii{¡Qué mal negocio han hecho al no creer en lo que Dios reveló por envidia a que Dios favoreciera a quien quiso de entre Sus siervos, por lo que incurrieron una y otra vez en la ira [de Dios]! Los que niegan la verdad tendrán un castigo degradante.\qt@no{90}}
\qt@newcmd\qurantrans@es@xcviii{Y cuando se les dice: ``Crean en lo que Dios ha revelado", responden: ``Creemos en lo que Dios nos reveló a nosotros", y descreen de lo que vino después, a pesar de ser la Verdad que corrobora [el libro] que tienen. Diles: ``¿Por qué, entonces, asesinaron a los Profetas de Dios, si eran creyentes?"\qt@no{91}}
\qt@newcmd\qurantrans@es@xcix{Se les presentó Moisés con milagros evidentes, pero adoraron el becerro [de oro] obrando injustamente.\qt@no{92}}
\qt@newcmd\qurantrans@es@c{Y [recuerden] cuando celebré con ustedes el pacto y levanté el monte encima suyo [y dije]: ``Aférrense con fuerza a lo que les he dado y obedezcan". Dijeron: ``Oímos, pero desobedecemos". Y como castigo por haber negado la verdad sus corazones quedaron embebidos de amor por el becerro [de oro]. Diles [¡oh, Mujámmad!, a ellos]: ``¡Qué pésimo es lo que su fe les ordena hacer, si en verdad fueran creyentes!"\qt@no{93}}
\qt@newcmd\qurantrans@es@ci{Diles [¡oh, Mujámmad!]: ``Si creen que la morada del más allá junto a Dios es exclusiva para ustedes, entonces deseen la muerte si son veraces".\qt@no{94}}
\qt@newcmd\qurantrans@es@cii{Pero jamás la desearán por lo que han cometido, y Dios bien sabe quiénes son los injustos.\qt@no{95}}
\qt@newcmd\qurantrans@es@ciii{Encontrarás que [los judíos] son los más aferrados a la vida mundanal, más aún que los idólatras. Algunos de ellos quisieran vivir mil años, pero eso no les libraría del castigo, porque Dios sabe cuanto hacen.\qt@no{96}}
\qt@newcmd\qurantrans@es@civ{Dile [¡oh, Mujámmad!] a quien sea enemigo del ángel Gabriel, que él es quien descendió la revelación a tu corazón con la anuencia de Dios, confirmando los Mensajes anteriores, como guía y buena nueva para los creyentes.\qt@no{97}}
\qt@newcmd\qurantrans@es@cv{Quien sea enemigo de Dios, de Sus ángeles, de Sus Mensajeros, del ángel Gabriel y del ángel Miguel, que sepa que Dios es enemigo de los que rechazan el Mensaje.\qt@no{98}}
\qt@newcmd\qurantrans@es@cvi{Y te he revelado [¡oh, Mujámmad!] signos evidentes, que solo los perversos los niegan.\qt@no{99}}
\qt@newcmd\qurantrans@es@cvii{¿No es cierto que cada vez que realizan un pacto, un grupo de ellos lo rompe? La mayoría de ellos no cree.\qt@no{100}}
\qt@newcmd\qurantrans@es@cviii{Cuando se les presentó el Mensajero de Dios corroborando lo que ya se les había revelado [la Tora], algunos se rebelaron contra el Libro de Dios como si no supieran [lo que contenía].\qt@no{101}}
\qt@newcmd\qurantrans@es@cix{Pero sí seguían lo que recitaban los demonios durante el reinado de Salomón. Sepan que Salomón no cayó en la incredulidad sino que fueron los demonios quienes enseñaban a la gente la hechicería y la magia que transmitieron los ángeles Harút y Marút en Babilonia. Ellos no le enseñaban a nadie sin antes advertirle: ``Nosotros somos una tentación, no caigan en la incredulidad". A pesar de la advertencia, aprendieron de ellos cómo separar al hombre de su esposa, aunque no podían perjudicar a nadie sin el permiso de Dios. Lo que aprendían los perjudicaba y no los beneficiaba. Pero los hijos de Israel sabían que quien practicara la hechicería no tendría éxito en la otra vida. ¡Qué mal vendieron sus almas! Si supieran.\qt@no{102}}
\qt@newcmd\qurantrans@es@cx{Si hubieran creído y temido devocionalmente a Dios, la recompensa de Dios hubiera sido [muy] superior, si supieran.\qt@no{103}}
\qt@newcmd\qurantrans@es@cxi{¡Oh, creyentes! No digan [al Mensajero de Dios]: ``Rá‘ina", sino [que digan]: ``Undhurna", y obedezcan [-lo]. Los que rechacen el mensaje recibirán un castigo doloroso.\qt@no{104}}
\qt@newcmd\qurantrans@es@cxii{Los incrédulos de entre la Gente del Libro y los idólatras no desean que su Señor los agracie con alguna bondad, pero Dios distingue con Su misericordia a quien Él quiere; porque Dios es el poseedor del favor inmenso.\qt@no{105}}
\qt@newcmd\qurantrans@es@cxiii{No abrogo ninguna regla [ni versículo] ni la hago olvidar sin traer otra mejor o similar. ¿Acaso no sabes que Dios tiene poder sobre todas las cosas?\qt@no{106}}
\qt@newcmd\qurantrans@es@cxiv{¿No sabes que a Dios pertenece el reino de los cielos y de la Tierra, y que no tienes fuera de Dios protector ni socorredor?\qt@no{107}}
\qt@newcmd\qurantrans@es@cxv{¿Acaso van a exigirle [un milagro] a su Mensajero como [el pueblo de Israel] le exigió a Moisés? Quien cambie la fe por la incredulidad se habrá desviado del camino recto.\qt@no{108}}
\qt@newcmd\qurantrans@es@cxvi{Muchos de entre la Gente del Libro quisieran que renegaran de su fe y volvieran a ser incrédulos por la envidia que les tienen, [incluso] después de habérseles evidenciado a ellos la verdad. Pero perdonen y disculpen hasta que Dios decida sobre ellos. Dios tiene poder sobre todas las cosas.\qt@no{109}}
\qt@newcmd\qurantrans@es@cxvii{Realicen la oración y paguen el zakat, y [sepan que] todo el bien que hagan será para su propio beneficio, y su recompensa la encontrarán junto a Dios. Dios sabe cuanto hacen.\qt@no{110}}
\qt@newcmd\qurantrans@es@cxviii{Y dicen: ``Solo entrará al Paraíso quien sea judío o cristiano". Esos son sus deseos infundados. Diles: ``Traigan pruebas, si es que dicen la verdad".\qt@no{111}}
\qt@newcmd\qurantrans@es@cxix{Pero no es así, porque quienes sometan su voluntad a Dios y hagan el bien obtendrán su recompensa junto a su Señor, y no sentirán temor ni tristeza.\qt@no{112}}
\qt@newcmd\qurantrans@es@cxx{Dicen los judíos: ``Los cristianos no tienen bases", y los cristianos dicen: ``Los judíos no tienen bases", siendo que ambos recitan el [mismo] Libro. Así mismo dijeron los ignorantes [idólatras]. Dios juzgará entre ellos el Día de la Resurrección sobre lo que discrepaban.\qt@no{113}}
\qt@newcmd\qurantrans@es@cxxi{¿Acaso existe alguien más injusto que quien prohíbe que en las casas de Dios se alabe Su nombre, e intentan destruirlas? Ellos deberían entrar en ellas con temor. [Porque finalmente] serán humillados en este mundo y en la otra vida recibirán un castigo terrible.\qt@no{114}}
\qt@newcmd\qurantrans@es@cxxii{A Dios pertenece el oriente y el occidente, y adondequiera que dirijan el rostro [durante la oración], allí se encuentra el rostro de Dios. Dios es Vasto, todo lo conoce.\qt@no{115}}
\qt@newcmd\qurantrans@es@cxxiii{Dicen: ``Dios ha tenido un hijo". ¡Glorificado sea! A Él pertenece cuanto hay en los cielos y en la Tierra, todo se somete a Él.\qt@no{116}}
\qt@newcmd\qurantrans@es@cxxiv{Originador de los cielos y la Tierra, cuando decreta un asunto dice: ``¡Sé!", y es.\qt@no{117}}
\qt@newcmd\qurantrans@es@cxxv{Pero dicen los que no saben: ``¿Por qué Dios no nos habla, o nos envía una señal?" Lo mismo dijeron quienes les precedieron, sus corazones se asemejan. Hemos hecho evidentes los signos para quienes creen con certeza.\qt@no{118}}
\qt@newcmd\qurantrans@es@cxxvi{Te he enviado [oh, Mujámmad] con la verdad, como albriciador y advertidor, pero no serás preguntado sobre los que se condenen al fuego infernal.\qt@no{119}}
\qt@newcmd\qurantrans@es@cxxvii{Ni los judíos ni los cristianos estarán [completamente] satisfechos contigo hasta que sigas su religión. Di: ``La guía de Dios es la guía verdadera". Si siguieras sus deseos luego de haberte llegado el conocimiento [sobre la verdad], no tendrías quién te protegiera ni quién te auxiliara de Dios.\qt@no{120}}
\qt@newcmd\qurantrans@es@cxxviii{Aquellos a quienes he confiado el Libro, si fueran consecuentes con la versión original del mismo, habrían creído [en el Corán]. Pero quienes lo nieguen, ellos serán los perdedores.\qt@no{121}}
\qt@newcmd\qurantrans@es@cxxix{¡Oh, Pueblo de Israel! Recuerden los beneficios con que los favorecí, y que los distinguí sobre los demás pueblos [de su época].\qt@no{122}}
\qt@newcmd\qurantrans@es@cxxx{Teman el día que ningún alma pueda beneficiar otra alma, no se acepte compensación ni intercesión alguna, y no sean auxiliados.\qt@no{123}}
\qt@newcmd\qurantrans@es@cxxxi{Y [recuerda, oh, Mujámmad] cuando Abraham fue puesto a prueba por su Señor con unas órdenes, y las cumplió. Dijo [Dios]: ``Haré de ti un guía para la gente". Preguntó [Abraham]: ``¿Y de mis descendientes?" Dijo [Dios]: ``Mi pacto [la profecía] no incluye a los injustos".\qt@no{124}}
\qt@newcmd\qurantrans@es@cxxxii{Y [recuerden] cuando hice de La Casa [la Ka‘bah] un lugar de reunión y refugio para la gente. ``[Oh creyentes] Tomen el sitial de Abraham como lugar de oración". Y cuando indiqué a Abraham e Ismael: ``Purifiquen Mi Casa para quienes vengan a hacer el rito de la circunvalación y el retiro espiritual, y los que se inclinen y prosternen durante su oración".\qt@no{125}}
\qt@newcmd\qurantrans@es@cxxxiii{Y [recuerden] cuando Abraham dijo: ``¡Señor mío! Haz de esta ciudad [La Meca] un lugar seguro, y beneficia con frutos a los pobladores que creen en Dios y en el Día del Juicio Final". Dijo [Dios]: ``[Pero] al que rechace la verdad lo dejaré disfrutar por un tiempo, y después lo conduciré al castigo del Fuego. ¡Qué pésimo destino!"\qt@no{126}}
\qt@newcmd\qurantrans@es@cxxxiv{Y [recuerden] cuando Abraham e Ismael levantaron los cimientos de La Casa, dijeron: ``¡Oh, Señor! Acepta nuestra obra. Tú eres el que todo lo oye, todo lo sabe".\qt@no{127}}
\qt@newcmd\qurantrans@es@cxxxv{``¡Señor nuestro! Haz que nosotros nos entreguemos a Tu voluntad, y que nuestra descendencia también lo haga [como una nación de musulmanes]. Enséñanos nuestros ritos para la peregrinación y acepta nuestro arrepentimiento; Tú eres el Indulgente, el Misericordioso".\qt@no{128}}
\qt@newcmd\qurantrans@es@cxxxvi{``¡Señor nuestro! Haz surgir de entre nuestra descendencia un Mensajero que les recite Tus palabras y les enseñe el Libro y la sabiduría, y los purifique. Tú eres el Poderoso, el Sabio".\qt@no{129}}
\qt@newcmd\qurantrans@es@cxxxvii{¿Y quién sino el de espíritu necio, puede rechazar la religión [monoteísta] de Abraham? Fue un elegido en este mundo, y en el otro se contará entre los justos.\qt@no{130}}
\qt@newcmd\qurantrans@es@cxxxviii{Y [recuerden] cuando le dijo su Señor: ``Entrégame tu voluntad", respondió: ``Le entrego mi voluntad al Señor del Universo".\qt@no{131}}
\qt@newcmd\qurantrans@es@cxxxix{Y esto fue lo que Abraham y Jacob legaron a sus hijos: ``¡Oh, hijos míos! Dios les ha elegido esta religión, y no mueran sin haber entregado su voluntad [a Dios]".\qt@no{132}}
\qt@newcmd\qurantrans@es@cxl{¿Acaso saben qué le preguntó Jacob a sus hijos cuando le llegó la muerte?: ``¿Qué adorarán después de mí [muerte]?" Dijeron: ``Adoraremos lo que adoraban tú y tus ancestros, Abraham, Ismael e Isaac: la Única divinidad, y a Él entregamos nuestra voluntad".\qt@no{133}}
\qt@newcmd\qurantrans@es@cxli{Aquella nación ya desapareció y recibió lo que merecía, y ustedes recibirán lo que merezcan, y no se les preguntará por lo que ellos hicieron.\qt@no{134}}
\qt@newcmd\qurantrans@es@cxlii{Dijeron [la Gente del Libro]: ``Sean judíos o cristianos, que así estarán en la guía correcta". Diles: ``¡No! Seguimos la religión de Abraham, que era monoteísta puro y no era de los idólatras".\qt@no{135}}
\qt@newcmd\qurantrans@es@cxliii{Digan: ``Creemos en Dios, en lo que nos fue revelado a nosotros, en lo que fue revelado a Abraham, a Ismael, a Isaac, a Jacob y a las tribus, y en lo que Dios reveló a Moisés, a Jesús y a los demás Profetas. No discriminamos entre ellos, y entregamos a Dios nuestra voluntad [siendo musulmanes].\qt@no{136}}
\qt@newcmd\qurantrans@es@cxliv{Si creen en lo mismo que ustedes creen habrán seguido la guía correcta; pero si lo rechazan, estarán en el error. Dios te protegerá de ellos. Él es el que todo lo oye, todo lo sabe.\qt@no{137}}
\qt@newcmd\qurantrans@es@cxlv{[Digan: ``Seguimos] la religión de Dios. ¿Y qué mejor religión que la de Dios? Y nosotros solo Lo adoramos a Él".\qt@no{138}}
\qt@newcmd\qurantrans@es@cxlvi{Di: ``¿Por qué discuten con nosotros acerca de Dios, siendo que Él es el Señor de ambos? Nosotros responderemos por nuestras acciones y ustedes por las suyas. Nosotros Le somos sinceros [adorándolo solo a Él]".\qt@no{139}}
\qt@newcmd\qurantrans@es@cxlvii{¿Acaso van a decir que Abraham, Ismael, Isaac, Jacob y las doce tribus eran judíos o cristianos? Di: ``¿Acaso ustedes saben más que Dios?" ¿Existe alguien más injusto que quien oculta un testimonio que ha recibido de Dios? Dios no está desatento de lo que hacen.\qt@no{140}}
\qt@newcmd\qurantrans@es@cxlviii{Aquella nación ya desapareció y recibió lo que merecía, y ustedes recibirán lo que merezcan, y no se les preguntará por lo que ellos hicieron.\qt@no{141}}
\qt@newcmd\qurantrans@es@cxlix{Dirán algunas personas tontas: ``¿Qué los hizo cambiar la orientación [en la que oraban]?" Diles: ``A Dios pertenece el oriente y el occidente, y Él guía a quien quiere hacia el sendero recto".\qt@no{142}}
\qt@newcmd\qurantrans@es@cl{Hice de ustedes una comunidad moderada y justa, a fin de que fueran testigos ante la humanidad, y fuera el Mensajero testigo de ustedes. Con el cambio del lugar hacia donde te orientabas [para orar], distinguí a los que toman partido por el Mensajero de aquellos que le dan la espalda. [Este cambio] fue algo difícil, salvo para aquellos a quienes Dios guió. Él no dejará de recompensarlos por su fe. Dios es compasivo y misericordioso con la gente.\qt@no{143}}
\qt@newcmd\qurantrans@es@cli{Veo que vuelves tu rostro hacia el cielo. Te orientaré en una dirección que te complazca; oriéntate hacia la Mezquita Sagrada [de La Meca]. Y donde quiera que estén, oriéntense hacia ella. La Gente del Libro sabe que es la verdad proveniente de su Señor. Dios no está desatento de lo que hacen.\qt@no{144}}
\qt@newcmd\qurantrans@es@clii{Pero aunque te presentes ante la Gente del Libro con todas las evidencias, no seguirán tu orientación [al orar] ni tú seguirás la de ellos, ni seguirán los unos la orientación de los otros; y si siguieras sus deseos luego de lo que se te ha revelado del conocimiento, te contarías entre los injustos.\qt@no{145}}
\qt@newcmd\qurantrans@es@cliii{Aquellos a quienes concedí el Libro [judíos y cristianos] lo reconocen como reconocen a sus propios hijos. Algunos de ellos ocultan la verdad a sabiendas.\qt@no{146}}
\qt@newcmd\qurantrans@es@cliv{La verdad proviene de tu Señor, no seas de los indecisos [aun ante las evidencias irrefutables].\qt@no{147}}
\qt@newcmd\qurantrans@es@clv{Todas [las religiones] tienen una dirección a la cual dirigirse [en sus oraciones]. ¡Apresúrense a realizar obras de bien! Dondequiera que estén, Dios los reunirá a todos [el Día del Juicio Final]. Dios es sobre toda cosa Poderoso.\qt@no{148}}
\qt@newcmd\qurantrans@es@clvi{Y hacia donde quiera que salgas [en tus viajes] oriéntate hacia la Mezquita Sagrada, pues ésta es la verdad que proviene de tu Señor, y [sepan que] Dios no está desatento de lo que hacen.\qt@no{149}}
\qt@newcmd\qurantrans@es@clvii{Y hacia donde quiera que salgas oriéntate hacia la Mezquita Sagrada, y dondequiera que estén oriéntense hacia ella, para que la gente no tenga argumento en su contra, excepto los injustos [idólatras de La Meca], pero no les teman a ellos, y témanme solo a Mí. Completaré sobre ustedes Mis gracias para que sean de los bien guiados.\qt@no{150}}
\qt@newcmd\qurantrans@es@clviii{De la misma manera envié un Mensajero de entre ustedes para que les transmitiera Mis preceptos y los purificase y enseñara el Libro y la sabiduría, y les enseñase lo que ignoraban.\qt@no{151}}
\qt@newcmd\qurantrans@es@clix{Recuérdenme que Yo los recordaré; agradézcanme y no sean ingratos.\qt@no{152}}
\qt@newcmd\qurantrans@es@clx{¡Oh, creyentes! Busquen ayuda en la paciencia y la oración; que Dios está con los pacientes.\qt@no{153}}
\qt@newcmd\qurantrans@es@clxi{Y no digan que quienes cayeron por la causa de Dios ``están muertos", sino que están vivos pero ustedes no lo perciben.\qt@no{154}}
\qt@newcmd\qurantrans@es@clxii{Los pondremos a prueba con algo de temor, hambre, pérdida de bienes materiales, vidas y frutos, pero albricia a los pacientes.\qt@no{155}}
\qt@newcmd\qurantrans@es@clxiii{Aquellos que cuando les alcanza una desgracia dicen: ``De Dios provenimos, y a Él retornaremos [para que nos juzgue por nuestras acciones]".\qt@no{156}}
\qt@newcmd\qurantrans@es@clxiv{A ellos su Señor bendecirá con el perdón y la misericordia, y son los [correctamente] guiados.\qt@no{157}}
\qt@newcmd\qurantrans@es@clxv{[El recorrido entre los montes de] As-Safa y Al-Marwah es un rito establecido por Dios. Quien realice la peregrinación mayor o la peregrinación menor a La Casa [Sagrada de La Meca] sepa que no incurre en falta por realizar el recorrido ritual entre ambas. Y quien voluntariamente haga el bien, sepa que Dios se lo recompensará, pues Él premia las buenas intenciones.\qt@no{158}}
\qt@newcmd\qurantrans@es@clxvi{Quienes ocultan a la gente las evidencias y la guía que he revelado luego de haberlas evidenciado en el Libro, serán malditos por Dios y toda la creación,\qt@no{159}}
\qt@newcmd\qurantrans@es@clxvii{Excepto quienes se arrepientan, reparen y aclaren [lo que habían ocultado]. A ellos les aceptaré su arrepentimiento, porque Yo soy el Indulgente, el Misericordioso.\qt@no{160}}
\qt@newcmd\qurantrans@es@clxviii{Aquellos que no crean y mueran negando la verdad, recibirán la maldición de Dios, los ángeles y toda la humanidad.\qt@no{161}}
\qt@newcmd\qurantrans@es@clxix{Por toda la eternidad así estarán. No les será aliviado el castigo ni se les concederá prórroga alguna.\qt@no{162}}
\qt@newcmd\qurantrans@es@clxx{Su Dios es un Dios Único, no hay divinidad [con derecho a ser adorada] salvo Él, el Compasivo, el Misericordioso.\qt@no{163}}
\qt@newcmd\qurantrans@es@clxxi{En la creación de los cielos y de la Tierra, la sucesión de la noche y el día, el barco que surca el mar para provecho de la gente, el agua que Dios hace descender del cielo con la que da vida a la tierra árida, en la que diseminó toda clase de criaturas, y en la dirección de los vientos y el control de las nubes que están entre el cielo y la tierra, en todo ello hay signos para quienes razonan.\qt@no{164}}
\qt@newcmd\qurantrans@es@clxxii{Existen personas que toman en lugar de Dios a otros que consideran iguales [a Dios], y los aman como solo debe amarse a Dios; pero los creyentes aman más a Dios [de lo que éstos aman a sus divinidades]. Ya sabrán los injustos cuando vean el suplicio que les espera, que a Dios pertenece el poder absoluto y que Dios es severo en el castigo.\qt@no{165}}
\qt@newcmd\qurantrans@es@clxxiii{[Ellos deben considerar que el Día del Juicio] se desentenderán los líderes de sus seguidores, y todos verán el castigo y desaparecerá toda alianza entre ellos.\qt@no{166}}
\qt@newcmd\qurantrans@es@clxxiv{Entonces los seguidores dirán: ``Si tuviéramos otra oportunidad [de regresar a la vida mundanal] nos desentenderíamos de ellos, como ellos se han desentendido de nosotros". Así les hará ver Dios sus obras para que sientan remordimiento. Pero nunca saldrán del Fuego.\qt@no{167}}
\qt@newcmd\qurantrans@es@clxxv{¡Oh, seres humanos! Coman de lo bueno y lo lícito que hay en la Tierra, pero no sigan los pasos del demonio. Él es su enemigo declarado.\qt@no{168}}
\qt@newcmd\qurantrans@es@clxxvi{Él los induce a cometer pecados y actos deshonestos, y a que digan de Dios lo que no saben [con certeza si es cierto].\qt@no{169}}
\qt@newcmd\qurantrans@es@clxxvii{Y cuando se les dice: ``Sigan lo que Dios reveló", argumentan: ``No, seguimos la tradición de nuestros padres". ¿Acaso imitan a sus padres a pesar de que ellos no seguían una lógica ni una revelación?\qt@no{170}}
\qt@newcmd\qurantrans@es@clxxviii{El ejemplo de los que niegan la verdad es como el del animal que al escuchar el llamado del pastor, no percibe sino un ruido. Se hacen los sordos, mudos y ciegos, porque se niegan a usar la razón.\qt@no{171}}
\qt@newcmd\qurantrans@es@clxxix{¡Oh, creyentes! Coman de las cosas buenas que les he proveído, y agradezcan a Dios, si es que [verdaderamente] solo a Él adoran.\qt@no{172}}
\qt@newcmd\qurantrans@es@clxxx{Sepan que [Dios] les ha prohibido [consumir] solamente la carne del animal muerto por causa natural, la sangre, la carne de cerdo y la del animal que haya sido sacrificado invocando un nombre distinto al de Dios. Pero quien se ve forzado por la necesidad, no por deseo y sin excederse, no comete pecado al hacerlo. Dios es Absolvedor, Indulgente.\qt@no{173}}
\qt@newcmd\qurantrans@es@clxxxi{Quienes ocultan lo que Dios reveló del Libro y cambian Sus preceptos para obtener una ganancia vil, sepan que el fuego abrasará sus entrañas. Dios no les hablará ni les purificará [de sus pecados] el Día de la Resurrección, donde tendrán un doloroso castigo.\qt@no{174}}
\qt@newcmd\qurantrans@es@clxxxii{Ellos cambiaron la guía por el desvío y el perdón por el castigo. ¡Qué perseverantes son en buscar el [castigo del] Fuego!\qt@no{175}}
\qt@newcmd\qurantrans@es@clxxxiii{Eso [es lo que merecen] porque Dios reveló el Libro con la Verdad, pero quienes enfrentan al Libro con sus opiniones se encuentran en un profundo error.\qt@no{176}}
\qt@newcmd\qurantrans@es@clxxxiv{La verdadera virtud no consiste en orientarse hacia el oriente o el occidente [durante la oración], sino que es piadoso quien cree en Dios, el Día del Juicio, los ángeles, el Libro, los Profetas, hace caridad a pesar del apego [que tiene por los bienes materiales] a los parientes, los huérfanos, los pobres, los viajeros insolventes, los mendigos, y colabora para liberar esclavos y cautivos. [Tiene piedad quien] hace la oración prescrita, paga el zakat, cumple con los compromisos contraídos, es paciente en la estrechez, la adversidad y ante la persecución. Ésos son los veraces en su fe y los verdaderos piadosos.\qt@no{177}}
\qt@newcmd\qurantrans@es@clxxxv{¡Oh, creyentes! Se ha establecido la retribución legal en caso de homicidio [doloso]: sea libre o esclavo, [sea hombre] o mujer. Pero si le es perdonada [al culpable] la pena por su hermano [en la fe], que pague la indemnización correspondiente en el plazo establecido de buena manera. Esto es una facilidad y una misericordia de su Señor. Pero quien después de eso [aceptando la indemnización] transgrediere [tratando de vengarse del homicida] tendrá un castigo doloroso.\qt@no{178}}
\qt@newcmd\qurantrans@es@clxxxvi{En [la aplicación de] la retribución legal está [la preservación de] la vida, ¡oh, dotados de intelecto!, para que alcancen la piedad.\qt@no{179}}
\qt@newcmd\qurantrans@es@clxxxvii{Se ha establecido que cuando sientan la muerte acercarse y dejen bienes materiales, hagan un testamento a favor de sus padres y parientes en forma justa. Esto es una recomendación para los piadosos.\qt@no{180}}
\qt@newcmd\qurantrans@es@clxxxviii{Si los testigos al escuchar [el testamento] lo cambian después de haber oído la voluntad [del testador], ellos son los que habrán cometido un pecado. Dios todo lo oye, todo lo sabe.\qt@no{181}}
\qt@newcmd\qurantrans@es@clxxxix{Pero quien tema que el testador haya cometido un error o una injusticia, y haga una mediación entre las partes, no incurrirá en falta. Dios es Absolvedor, Misericordioso.\qt@no{182}}
\qt@newcmd\qurantrans@es@cxc{¡Oh, creyentes! Se les prescribe el ayuno al igual que fue prescrito a quienes los precedieron, para que alcancen la piedad.\qt@no{183}}
\qt@newcmd\qurantrans@es@cxci{Son días contados [el mes de Ramadán]. Quien esté enfermo o de viaje y no ayune, deberá reponer posteriormente los días no ayunados. Quienes puedan [pero con mucha dificultad por la vejez] y no lo hagan, deberán alimentar a un pobre [por cada día no ayunado]. Pero quien voluntariamente alimente a más de un pobre, será más beneficioso para él. Y ayunar es mejor para ustedes, si supieran.\qt@no{184}}
\qt@newcmd\qurantrans@es@cxcii{En el mes de Ramadán fue revelado el Corán como guía para la humanidad y evidencia de la guía y el criterio. Quien presencie la llegada de [la Luna nueva de] el mes deberá ayunar, pero quien esté enfermo o de viaje [y no ayune] deberá reponer posteriormente los días no ayunados y así completar el mes. Dios desea facilitarles las cosas y no dificultárselas; alaben y agradezcan a Dios por haberlos guiado.\qt@no{185}}
\qt@newcmd\qurantrans@es@cxciii{Y si Mis siervos te preguntan por Mí [¡oh, Mujámmad!, diles] que estoy cerca de ellos. Respondo la súplica de quien Me invoca. [Entonces] que me obedezcan y crean en Mí, que así se encaminarán.\qt@no{186}}
\qt@newcmd\qurantrans@es@cxciv{Durante las noches del mes de ayuno les es lícito mantener relaciones [maritales] con sus mujeres. Ellas son su vestimenta, y ustedes la vestimenta de ellas. Dios sabe que se engañaban a sí mismos, por eso los perdonó y les hizo esta concesión. Ahora pueden mantener relaciones con ellas y aprovechar lo que Dios les ha prescrito. Coman y beban hasta que se distinga el hilo blanco [la luz del alba] del hilo negro [la oscuridad de la noche], y luego completen el ayuno hasta la noche, y no mantengan relaciones con ellas si están haciendo el retiro espiritual en las mezquitas. Éstos son los límites de Dios, no los transgredan. Así aclara Dios Sus signos a la gente para que alcancen la piedad.\qt@no{187}}
\qt@newcmd\qurantrans@es@cxcv{No usurpen injustamente los bienes materiales unos a otros, ni sobornen con ellos a los jueces para conseguir ilegalmente la propiedad ajena a sabiendas.\qt@no{188}}
\qt@newcmd\qurantrans@es@cxcvi{Te preguntan [¡oh, Mujámmad!] acerca de las fases de la luna. Diles: ``Son una señal para que la gente pueda fijar sus fechas y para la peregrinación". No es ninguna virtud entrar en las casas por la puerta trasera, sino que la virtud está en la piedad. [En consecuencia] entren a las casas por la puerta de adelante, y observen las leyes de Dios que así van a prosperar.\qt@no{189}}
\qt@newcmd\qurantrans@es@cxcvii{Y combatan por la causa de Dios a quienes los agredan, pero no se excedan, porque Dios no ama a los agresores.\qt@no{190}}
\qt@newcmd\qurantrans@es@cxcviii{Den muerte [a aquellos que los ataquen] donde quiera que los encuentren, y expúlsenlos de donde los han expulsado a ustedes, porque la opresión [y la restricción de la libertad a la que son sometidos por los agresores] es más grave que combatirlos. No combatan contra ellos en la Mezquita Sagrada, a menos que ellos los ataquen allí; pero si lo hacen combátanlos, ésta es la retribución que recibirán los que rechacen la verdad.\qt@no{191}}
\qt@newcmd\qurantrans@es@cxcix{Pero si ellos cesan de combatirlos, sepan que Dios es Absolvedor, Misericordioso.\qt@no{192}}
\qt@newcmd\qurantrans@es@cc{Combátanlos hasta que cese la opresión y puedan adorar tranquilamente a Dios [sin temer persecución]; pero si ellos cesan de combatir, que no haya más hostilidades, excepto contra los agresores.\qt@no{193}}
\qt@newcmd\qurantrans@es@cci{Solo se puede combatir en un mes sagrado si son atacados durante el mismo, y para las violaciones [que hayan cometido] apliquen el principio de retribución igualitaria; así que si son agredidos, agredan tal como los agredieron [sin excederse]. Sigan las enseñanzas de Dios, y sepan que Dios está con los piadosos.\qt@no{194}}
\qt@newcmd\qurantrans@es@ccii{Contribuyan a la causa de Dios [de buen grado] y no sean avaros, sino que hagan el bien, porque Dios ama a los que hacen el bien.\qt@no{195}}
\qt@newcmd\qurantrans@es@cciii{Completen la peregrinación mayor y menor en honor a Dios. Pero en caso de que algo les impida completarla, sacrifiquen el animal que puedan como ofrenda. No se rasuren la cabeza hasta que la ofrenda llegue al lugar de sacrificio. Si alguien está enfermo o sufre una dolencia en su cabeza [y se rasura] deberá expiar ayunando o dando limosna o sacrificando. Si hay seguridad [en el camino], entonces quien haga la peregrinación menor [durante los meses de la peregrinación mayor] y luego la peregrinación mayor, que sacrifique la ofrenda según sus posibilidades, y si no encuentra qué sacrificar o no dispone de medios, deberá ayunar tres días durante la peregrinación y siete a su regreso [a su lugar de origen]: en total diez días. Esto es para quienes no viven en las proximidades de la Mezquita Sagrada. Cumplan con los ritos y sepan que Dios es severo en el castigo.\qt@no{196}}
\qt@newcmd\qurantrans@es@cciv{La peregrinación se realiza en unos meses específicos, y quien se consagrara para hacerla, deberá abstenerse [durante ella] de las relaciones maritales, los pecados y las discusiones. Todo lo que hagan de bien Dios lo sabe. Tomen provisiones para el viaje, pero [sepan que] la mejor provisión es la piedad. ¡Oh, dotados de buen discernimiento! Cumplan correctamente Conmigo.\qt@no{197}}
\qt@newcmd\qurantrans@es@ccv{No cometen ninguna falta si buscan el sustento de su Señor [comerciando]. Cuando salgan en multitudes de [el valle de] ‘Arafat, y se encuentren en Al-Mash’ar Al-Harám, recuerden a Dios. Recuérdenlo en agradecimiento por haberlos guiado siendo que se encontraban extraviados.\qt@no{198}}
\qt@newcmd\qurantrans@es@ccvi{Luego avancen en multitudes por donde lo hace la gente e imploren el perdón de Dios. Dios es Absolvedor, Misericordioso.\qt@no{199}}
\qt@newcmd\qurantrans@es@ccvii{Y cuando hayan terminado con los ritos que deben realizar, celebren el nombre de Dios tal como celebran la memoria de sus padres, y más aún. [Pues] hay gente que dice: ``¡Señor nuestro! Danos bienestar en esta vida"; pero no obtendrán nada en la otra vida.\qt@no{200}}
\qt@newcmd\qurantrans@es@ccviii{Pero entre ellos hay quienes dicen: ``¡Señor nuestro! Danos bienestar en esta vida y en la otra, y presérvanos del tormento del Fuego".\qt@no{201}}
\qt@newcmd\qurantrans@es@ccix{Éstos obtendrán su recompensa por lo que hicieron, y Dios es rápido en ajustar cuentas.\qt@no{202}}
\qt@newcmd\qurantrans@es@ccx{Recuerden a Dios los días determinados. Quien lo haga solo dos días no habrá incurrido en falta alguna, como tampoco quien permanezca más [hasta el tercero], siempre que tengan temor de Dios. Cumplan con lo que Dios les ha ordenado y sepan que serán congregados ante Él.\qt@no{203}}
\qt@newcmd\qurantrans@es@ccxi{Hay un tipo de gente que cuando te habla sobre temas mundanos te causa admiración por su elocuencia, y pone como testigo a Dios de la fe que encierra su corazón, cuando en realidad es un enemigo acérrimo y hábil discutidor.\qt@no{204}}
\qt@newcmd\qurantrans@es@ccxii{Pero cuando se alejan [de ti] van por la Tierra corrompiéndola, destruyendo [todos los frutos del trabajo humano, como] las siembras y los ganados, pero [sepan] que Dios no ama la corrupción.\qt@no{205}}
\qt@newcmd\qurantrans@es@ccxiii{Y cuando se le dice [a uno de ellos]: ``Tengan temor de Dios", su soberbia lo impulsa a hacer el mal. Su retribución será el Infierno. ¡Qué pésimo destino!\qt@no{206}}
\qt@newcmd\qurantrans@es@ccxiv{Aunque entre la gente hay quienes dan su vida anhelando complacer a Dios, y Dios es compasivo con Sus siervos.\qt@no{207}}
\qt@newcmd\qurantrans@es@ccxv{¡Oh, creyentes! Entréguense por completo [a Dios practicando el Islam] y no sigan los pasos del demonio, porque él es su enemigo declarado.\qt@no{208}}
\qt@newcmd\qurantrans@es@ccxvi{Pero si caen en el error después de que se les han presentado las pruebas claras, sepan que Dios es Poderoso, Sabio.\qt@no{209}}
\qt@newcmd\qurantrans@es@ccxvii{¿Acaso esperan que [el Día del Juicio] Dios y los ángeles se les presenten a la sombra de las nubes? Para entonces, su situación estaría ya decidida [y serían condenados]. Todos los asuntos retornan a Dios [para que Él juzgue].\qt@no{210}}
\qt@newcmd\qurantrans@es@ccxviii{Pregunta [¡oh, Mujámmad!] a los hijos de Israel cuántas señales evidentes les envié. Quien cambia la gracia de Dios [por incredulidad] después de haberle sido concedida, [sepa que] Dios es severo en el castigo.\qt@no{211}}
\qt@newcmd\qurantrans@es@ccxix{A los que niegan la verdad los seduce la vida mundanal, y [por eso] se burlan de [la pobreza de] los creyentes; pero los que temen a Dios [en este mundo] estarán sobre ellos el Día de la Resurrección, y Dios provee a quien desea sin límite.\qt@no{212}}
\qt@newcmd\qurantrans@es@ccxx{La humanidad era una sola comunidad [y porque comenzaron a desviarse del monoteísmo y discrepar sobre la verdad], Dios envió a los Profetas con albricias y advertencias, y les reveló los Libros Sagrados con la Verdad para que juzgaran entre la gente acerca de lo que discrepaban. Pero [los que habían recibido los Libros Sagrados] no discreparon sino después de que les llegaron las pruebas evidentes, por envidia y rivalidad entre ellos. Dios guió con Su voluntad a los creyentes a la verdad respecto a lo que discrepaban quienes los precedieron. Dios guía a quien Le place por el sendero recto.\qt@no{213}}
\qt@newcmd\qurantrans@es@ccxxi{¿Acaso creen que van a entrar al Paraíso sin sufrir las mismas pruebas que quienes los precedieron? Padecieron pobreza e infortunios, y una conmoción tal que hasta el Mensajero y los creyentes que estaban con él imploraron: ``¿Cuándo llegará el auxilio de Dios?" Pero el auxilio de Dios estaba cercano.\qt@no{214}}
\qt@newcmd\qurantrans@es@ccxxii{Te preguntan [¡oh, Mujámmad!] a quién dar caridad. Diles: ``Den a sus padres, parientes, huérfanos, pobres y viajeros insolventes". Todos los actos de bien que hagan Dios lo sabe.\qt@no{215}}
\qt@newcmd\qurantrans@es@ccxxiii{Se les ha prescrito combatir aunque les desagrade. Es posible que les disguste algo y sea un bien para ustedes, y es posible que amen algo y sea un mal para ustedes. Dios conoce [todo] pero ustedes no.\qt@no{216}}
\qt@newcmd\qurantrans@es@ccxxiv{Te preguntan si es lícito combatir en los meses sagrados. Diles: ``Combatir en los meses sagrados es un sacrilegio, pero ante Dios es más grave aún apartar a la gente del sendero de Dios, negar Su verdad y expulsar a la gente de la Mezquita Sagrada". [Sepan] que la opresión es peor que matar [en un mes sagrado]. Y [sepan que los incrédulos] no dejarán de combatirlos, si pueden, hasta apartarlos de su religión. Y quien reniegue de su religión y muera en la incredulidad, sus obras habrán sido en vano, en esta vida y en el más allá. Ellos son los moradores del Fuego, donde permanecerán eternamente.\qt@no{217}}
\qt@newcmd\qurantrans@es@ccxxv{Aquellos que creyeron, emigraron y se esforzaron por la causa de Dios son quienes pueden esperar con certeza la misericordia de Dios, y Dios es Absolvedor, Misericordioso.\qt@no{218}}
\qt@newcmd\qurantrans@es@ccxxvi{Te preguntan acerca de los embriagantes y las apuestas. Diles: ``Son de gran perjuicio, a pesar de que también hay en ellos algún beneficio para la gente, pero su perjuicio es mayor que su beneficio". Y te preguntan qué dar en caridad. Diles: ``Lo que puedan permitirse". Así aclara Dios los preceptos para que reflexionen\qt@no{219}}
\qt@newcmd\qurantrans@es@ccxxvii{sobre esta vida y el más allá. Y te preguntan acerca de cómo deben obrar quienes tienen huérfanos bajo su responsabilidad. Diles: ``Invertir sus bienes materiales para procurar incrementárselos es lo mejor, pero si [consideran más fructífero] unir su riqueza con la de ellos [para gestionarla conjuntamente], trátenlos como a sus hermanos. Dios sabe quién es corrupto y quién hace el bien. Y si Dios hubiera querido les habría hecho las cosas más difíciles; Dios es Poderoso, Sabio.\qt@no{220}}
\qt@newcmd\qurantrans@es@ccxxviii{No se casen con [mujeres] idólatras a menos que ellas crean [en el monoteísmo], ya que una sierva [de Dios] creyente es mejor que una idólatra, aunque esta les atraiga más; y no casen a los idólatras con las mujeres a su cargo hasta que ellos crean [en el monoteísmo], un siervo [de Dios] creyente es mejor que un idólatra, aunque este les parezca mejor partido. Ellos [los idólatras] invitan al Infierno [a través de la idolatría], mientras que Dios les promete el Paraíso, con Su consentimiento, y el perdón, pero aclara Sus preceptos a la gente para que recapaciten.\qt@no{221}}
\qt@newcmd\qurantrans@es@ccxxix{Y te preguntan acerca de la menstruación. Di: ``Es una impureza"; absténganse de mantener relaciones maritales con sus mujeres durante el menstruo, y no mantengan relaciones con ellas hasta que se purifiquen, pero cuando se hayan purificado mantengan relaciones como Dios les ha permitido [por la vía natural]. Dios ama a los que se arrepienten y a los que se purifican.\qt@no{222}}
\qt@newcmd\qurantrans@es@ccxxx{Sus mujeres son para ustedes como un campo de labranza, por tanto, siembren en su campo cuando [y como] quieran. Hagan obras de bien para que se beneficien, y tengan temor de Dios ya que se encontrarán con Él; y albricia a los creyentes [que obtendrán una hermosa recompensa].\qt@no{223}}
\qt@newcmd\qurantrans@es@ccxxxi{No hagan de un juramento por Dios, prestado con anterioridad, un pretexto para no hacer el bien, no cumplir con la fe ni dejar de ayudar a la gente a reconciliarse. Dios todo lo oye, todo lo sabe.\qt@no{224}}
\qt@newcmd\qurantrans@es@ccxxxii{Dios no tomará en cuenta los juramentos que hacen sin pensar, pero sí tomará en cuenta aquellos que hagan de corazón, Dios es Absolvedor, Indulgente.\qt@no{225}}
\qt@newcmd\qurantrans@es@ccxxxiii{Quienes juren no mantener relaciones sexuales con sus esposas tendrán un plazo [máximo] de cuatro meses; pero si se retractan [de su juramento], [sepan que] Dios es Absolvedor, Misericordioso.\qt@no{226}}
\qt@newcmd\qurantrans@es@ccxxxiv{Y si se deciden por el divorcio, Dios todo lo oye, todo lo sabe.\qt@no{227}}
\qt@newcmd\qurantrans@es@ccxxxv{Las divorciadas deberán esperar tres menstruos [para poder volverse a casar], y no les es lícito ocultar lo que Dios creó en sus vientres, si es que creen en Dios y el Día del Juicio. Sus maridos tienen más derecho a volver con ellas durante ese plazo, si desean reconciliarse. Ellas tienen tanto el derecho al buen trato como la obligación de tratar bien a sus maridos. Y los hombres tienen un grado superior [de responsabilidad] al de ellas; Dios es Poderoso, Sabio.\qt@no{228}}
\qt@newcmd\qurantrans@es@ccxxxvi{El divorcio puede revocarse dos veces. Luego de lo cual no cabe sino convivir dignamente o separarse definitivamente con decoro. No es permitido [a los hombres] tomar nada de lo que hayan dado [como dote]. Pero si no existe una voluntad de convivencia y temen que no se cumpla con lo que Dios ha ordenado [sobre el buen trato], no incurrirá en falta ninguno de los dos [esposos] en que la mujer llegue a un acuerdo económico con su marido para la disolución del matrimonio. Éstas son las leyes de Dios, no las quebranten. Quienes las quebrantan son los opresores.\qt@no{229}}
\qt@newcmd\qurantrans@es@ccxxxvii{Si el marido se divorcia de ella [por tercera vez], no podrá tomarla como esposa de nuevo hasta que ella se case con otro hombre y este último la divorcie también. Entonces, no incurrirán en falta si vuelven a casarse, si creen que podrán cumplir con lo que Dios ha establecido [sobre el buen trato]. Éstas son las leyes de Dios, las cuales aclara a gente que razona.\qt@no{230}}
\qt@newcmd\qurantrans@es@ccxxxviii{Pero si expresan la voluntad de divorcio a sus mujeres y están cerca de cumplir el plazo de espera, reconcíliense en buenos términos o sepárense con decoro. No las retengan para molestarlas y obligarlas [a que cedan parte de su derecho], pues quien obre de esa manera se condena a sí mismo. No tomen las leyes de Dios a la ligera, y recuerden la gracia que Dios les concedió [el Islam], y el Libro y la sabiduría que reveló [el Corán] para exhortarlos. Tengan temor de Dios y sepan que Dios todo lo conoce.\qt@no{231}}
\qt@newcmd\qurantrans@es@ccxxxix{Si expresan la voluntad de divorcio a sus mujeres y éstas cumplen con el plazo de espera, no pueden impedirles que se casen, si lo han convenido mutuamente [sobre bases] correctas. Así exhorta [Dios] a quienes realmente creen en Dios y en el Día del Juicio. Esto es mejor y más sano. Dios sabe [todo] y ustedes no.\qt@no{232}}
\qt@newcmd\qurantrans@es@ccxl{Las madres [divorciadas] podrán amamantar a sus hijos dos años si desean completar la lactancia. El padre tiene la obligación de sustentar y vestir a la madre [de su hijo] de acuerdo a sus recursos, a nadie se le impone más allá de sus posibilidades. Que ni la madre ni el padre utilicen a su hijo para perjudicarse mutuamente. Los familiares directos heredan esta obligación. Pero no incurren en falta si ambos [el padre y la madre], de común acuerdo, y tras consultarlo entre ellos, deciden destetar [al niño]. Si toman una nodriza para completar la lactancia no hay mal en ello, a condición de que le paguen lo correcto. Tengan temor de Dios, y sepan que Dios ve todo cuanto hacen.\qt@no{233}}
\qt@newcmd\qurantrans@es@ccxli{Las viudas deberán esperar cuatro meses y diez días. Luego de ese plazo no serán reprochadas por lo que dispongan hacer consigo mismas [siempre que sea] de manera correcta, y Dios sabe lo que hacen.\qt@no{234}}
\qt@newcmd\qurantrans@es@ccxlii{No incurren en falta si les insinúan a esas mujeres la intención de casarse con ellas o si callan sus intenciones; Dios sabe lo que piensan de ellas. No concierten con ellas acuerdos secretos de matrimonio, sino que háblenles con respeto. Pero no contraigan matrimonio hasta que se cumpla el plazo de espera. Sepan que Dios conoce lo que hay en sus corazones, así que tengan cuidado. Y sepan que Dios es Absolvedor, Indulgente.\qt@no{235}}
\qt@newcmd\qurantrans@es@ccxliii{No incurren en falta si se divorcian de sus esposas antes de consumar el matrimonio o haber convenido la dote. Pero denles un regalo acorde a sus posibilidades, el rico según pueda y el pobre según pueda. Esto es un deber para los que obran correctamente.\qt@no{236}}
\qt@newcmd\qurantrans@es@ccxliv{Pero si se divorcian antes de consumar el matrimonio y ya han convenido la dote, deben darles la mitad de lo acordado, a menos que la mujer renuncie a su parte, o que el hombre renuncie a darle la mitad y se lo dé completo, y esto es lo más próximo a la piedad. Y no olviden lo bueno que hubo entre ustedes; Dios ve todo lo que hacen.\qt@no{237}}
\qt@newcmd\qurantrans@es@ccxlv{Cumplan con la oración prescrita, y especialmente la oración de la tarde, y preséntense ante Dios con total devoción.\qt@no{238}}
\qt@newcmd\qurantrans@es@ccxlvi{Si tienen temor [en una situación de peligro], pueden orar de pie o montados, pero cuando cese el temor recuerden a Dios [en oración], que les enseñó lo que no sabían.\qt@no{239}}
\qt@newcmd\qurantrans@es@ccxlvii{Los casados, al morir, dejan a su viuda un legado que consiste en un año de manutención y que no sean obligadas a abandonar el domicilio conyugal; pero si lo abandonaran antes, no serán reprochados de lo que ellas dispongan hacer consigo mismas [rehaciendo sus vidas siempre que sea] de manera correcta. Dios es Poderoso, Sabio.\qt@no{240}}
\qt@newcmd\qurantrans@es@ccxlviii{Quienes divorcien a su esposa deben mantenerla de manera honorable. Esto es un deber para los piadosos.\qt@no{241}}
\qt@newcmd\qurantrans@es@ccxlix{Así es como Dios evidencia Sus preceptos para que usen la razón.\qt@no{242}}
\qt@newcmd\qurantrans@es@ccl{¿Acaso no reparan en los que dejaron de a miles sus hogares por temor a la muerte? Pero Dios les dijo: ``¡Mueran igual!" Y luego los resucitó. Dios favorece a la gente, pero la mayoría no Le agradece.\qt@no{243}}
\qt@newcmd\qurantrans@es@ccli{Combatan [en defensa propia] por la causa de Dios, y sepan que Dios todo lo oye, todo lo sabe.\qt@no{244}}
\qt@newcmd\qurantrans@es@cclii{¿Quién hará a Dios un préstamo generoso? Dios se lo devolverá multiplicado. Dios restringe y prodiga [el sustento], y a Él volverán [para ser recompensados por sus acciones].\qt@no{245}}
\qt@newcmd\qurantrans@es@ccliii{¿Acaso no reparas en los nobles de los hijos de Israel después de la muerte de Moisés? Cuando le dijeron a su Profeta: ``Desígnanos un rey para que combatamos junto a él por la causa de Dios". Dijo: ``¿Acaso prometen que si se les prescribe el combate no huirán?" Dijeron: ``¿Cómo no vamos a combatir por la causa de Dios si fuimos expulsados de nuestros hogares y apartados de nuestros hijos?" Pero cuando se les ordenó el combate le dieron la espalda, excepto unos pocos, y Dios conoce bien a los opresores.\qt@no{246}}
\qt@newcmd\qurantrans@es@ccliv{Su Profeta les dijo: ``Dios les ha enviado a Saúl para que sea su rey". Exclamaron: ``¿Por qué será él nuestro rey, si nosotros tenemos más derecho que él y ni siquiera es rico?" Dijo: ``Dios lo ha elegido para ustedes y lo ha dotado de gran capacidad intelectual y física". Dios concede el reino a quien Él quiere, porque Dios es Vasto, todo lo sabe.\qt@no{247}}
\qt@newcmd\qurantrans@es@cclv{Su Profeta les dijo también: ``La prueba de su reino será que los ángeles traerán el arca, en la que encontrarán sosiego proveniente de su Señor y una reliquia que dejó la familia de Moisés y de Aarón. En esto hay una señal, si es que son creyentes".\qt@no{248}}
\qt@newcmd\qurantrans@es@cclvi{Pero cuando Saúl partió con sus soldados, les dijo: ``Dios los pondrá a prueba con un río; quien beba de él hasta saciarse no será de los míos, pero quien no beba más que un sorbo en el cuenco de su mano o se abstenga, será de los míos". Pero se saciaron de él, salvo unos pocos. Y cuando él y los que creían cruzaron el río, algunos dijeron: ``Hoy no podremos contra Goliat y sus soldados". En cambio, quienes tenían certeza de que comparecerían ante Dios exclamaron: ``¡Cuántas veces, con el permiso de Dios, un grupo pequeño ha derrotado a grandes ejércitos!" Porque Dios está con los pacientes.\qt@no{249}}
\qt@newcmd\qurantrans@es@cclvii{Al enfrentarse a Goliat y sus soldados suplicaban: ``¡Oh, Señor nuestro! Danos paciencia, mantennos firmes y concédenos la victoria sobre los que niegan la verdad".\qt@no{250}}
\qt@newcmd\qurantrans@es@cclviii{Los derrotaron con el permiso de Dios, y David mató a Goliat. Dios le concedió [a David] el reino y la sabiduría, y le enseñó cuanto Él quiso. Si Dios no hubiera permitido que la gente se defendiera, la Tierra estaría llena de corrupción, pero Dios concede Sus gracias a todos los seres.\qt@no{251}}
\qt@newcmd\qurantrans@es@cclix{Éstos son los signos de Dios que te revelo con la Verdad. Ten certeza que tú [¡oh, Mujámmad!] eres uno de los Mensajeros.\qt@no{252}}
\qt@newcmd\qurantrans@es@cclx{Entre los Mensajeros, distinguí a cada uno con un favor. Entre ellos hay a quienes Dios habló directamente, y otros a quienes elevó en grados. Y concedí a Jesús, hijo de María, las pruebas evidentes y lo fortalecí con el Espíritu Santo [el ángel Gabriel]. Pero si Dios hubiera querido, las naciones que los siguieron no hubiesen combatido entre ellas tras habérseles presentado los Profetas y las evidencias; pero discreparon, y hubo entre ellos quienes creyeron y quienes negaron la verdad. Si Dios hubiera querido no se habrían combatido los unos a los otros, pero Dios obra según Su designio.\qt@no{253}}
\qt@newcmd\qurantrans@es@cclxi{¡Oh, creyentes! Den en caridad parte de los beneficios que les he otorgado antes de que llegue el día en el cual no se aceptará rescate, amistad ni intercesión. Los [verdaderos] injustos son los que rechazan la verdad.\qt@no{254}}
\qt@newcmd\qurantrans@es@cclxii{¡Dios! No existe nada ni nadie con derecho a ser adorado excepto Él, el Viviente [Eterno], el Sustentador [y Gobernador de toda la creación]. No Lo afectan somnolencia ni sueño. Suyo es cuanto hay en los cielos y la Tierra. ¿Quién podrá interceder ante Él si no es con Su permiso? Conoce el pasado y el futuro [lo manifiesto y lo oculto] y nadie abarca de Su conocimiento salvo lo que Él quiere. El escabel de Su Trono abarca los cielos y la Tierra, y la custodia [y mantenimiento] de ambos no Lo agobia. Y Él es el Sublime, el Grandioso.\qt@no{255}}
\qt@newcmd\qurantrans@es@cclxiii{Una vez establecida la diferencia entre la guía correcta y el desvío no se puede forzar a nadie a creer. Quien descrea de las falsas divinidades y crea en Dios, se habrá aferrado al asidero más firme [el Islam], que es irrompible. Dios todo lo oye, todo lo sabe.\qt@no{256}}
\qt@newcmd\qurantrans@es@cclxiv{Dios es el protector de los creyentes, los saca de las tinieblas hacia la luz. En cambio, los que rechazan la verdad tienen como protector a las falsas divinidades, que los sacan de la luz hacia las tinieblas. Ellos serán los moradores del Fuego, en el que permanecerán eternamente.\qt@no{257}}
\qt@newcmd\qurantrans@es@cclxv{¿Acaso no has reparado en quien discutió con Abraham acerca de su Señor valiéndose del reinado que Dios le había concedido? Dijo Abraham: ``Mi Señor es Quien da la vida y da la muerte". Le replicó: ``Yo también doy la vida y la muerte". Dijo Abraham: ``Dios hace que el Sol salga por el oriente, haz tú que salga por el occidente". Entonces, el que había rechazado la verdad quedó confundido, porque Dios no guía a los injustos.\qt@no{258}}
\qt@newcmd\qurantrans@es@cclxvi{[No has reparado] en aquel [‘Uzeir] que pasó por una ciudad en ruinas [Jerusalén], y exclamó: ``¿Cómo va Dios a darle vida ahora que está en ruinas?" Y entonces, Dios lo hizo morir por cien años y después lo resucitó. Le preguntó [Dios]: ``¿Cuánto tiempo has permanecido así?" Respondió: ``Un día o menos aún". Dijo [Dios]: ``No, has permanecido así cien años, observa tu comida y tu bebida, no se han podrido, pero mira tu asno [del que por el contrario solo quedan sus huesos]. Haremos de ti un signo para la gente. Mira los huesos [de tu asno] cómo los reuní y luego los cubrí de carne [resucitándolo]". Y cuando lo vio con claridad dijo: ``Ahora sé que Dios es sobre toda cosa Poderoso".\qt@no{259}}
\qt@newcmd\qurantrans@es@cclxvii{Y [menciona a la gente] cuando Abraham dijo: ``¡Señor mío! Muéstrame cómo das vida a los muertos". Dijo [Dios]: ``¿Es que acaso no crees?" Respondió: ``Claro que sí, pero esto es para fortalecer la fe que hay en mi corazón". Dijo [Dios]: ``Toma cuatro pájaros distintos y córtalos en pedazos, luego pon un pedazo de cada uno sobre la cima de una montaña y llámalos, vendrán a ti deprisa [con vida nuevamente]; y sabe que Dios es Poderoso, Sabio".\qt@no{260}}
\qt@newcmd\qurantrans@es@cclxviii{El ejemplo de quienes contribuyen con su dinero por la causa de Dios es como el de un grano que produce siete espigas, cada espiga contiene cien granos. Así Dios multiplica [la recompensa] de quien Él quiere. Dios es el Más Generoso, todo lo sabe.\qt@no{261}}
\qt@newcmd\qurantrans@es@cclxix{Quienes contribuyan por la causa de Dios, y luego no malogren sus obras con alardes o agravios, obtendrán su recompensa en la otra vida, donde no sentirán temor ni tristeza.\qt@no{262}}
\qt@newcmd\qurantrans@es@cclxx{Una palabra amable y perdonar es mejor que una caridad seguida de un agravio. Dios es Opulento, Indulgente.\qt@no{263}}
\qt@newcmd\qurantrans@es@cclxxi{¡Oh, creyentes! No malogren sus caridades haciendo alarde de ellas u ofendiendo, como aquel que contribuye para que la gente lo vea, pero [en realidad] no cree en Dios ni en el Día del Juicio Final. Su ejemplo es como el de una roca cubierta de tierra, a la cual le cae un aguacero que la deja al descubierto. Esas personas no obtendrán recompensa alguna por sus [buenas] obras, porque Dios no guía a la gente que se niega a reconocer la verdad.\qt@no{264}}
\qt@newcmd\qurantrans@es@cclxxii{El ejemplo de quienes contribuyen con sus bienes materiales anhelando complacer a Dios y por la certeza de ser recompensados, es como el de una huerta que se encuentra sobre una colina [alta y fértil], a la que le cae una lluvia copiosa y duplica sus frutos. Y si no, una llovizna le basta [para dar frutos]. Sepan que Dios ve lo que hacen.\qt@no{265}}
\qt@newcmd\qurantrans@es@cclxxiii{¿A quién complacería tener un huerto de palmeras datileras y vides por donde corren ríos, donde hay toda clase de frutos, y al alcanzar la vejez y con hijos de corta edad, ver sorprendido [su huerto] por un huracán con fuego que lo incendie reduciéndolo a cenizas? Así es como Dios les aclara Sus signos para que reflexionen.\qt@no{266}}
\qt@newcmd\qurantrans@es@cclxxiv{¡Oh, creyentes! Den en caridad de las cosas buenas que hayan adquirido y [también] de lo que les he hecho brotar de la tierra, pero no elijan lo deteriorado para dar caridad así como tampoco lo tomarían para ustedes mismos, salvo que fuera con los ojos cerrados. Sepan que Dios es Opulento, Loable.\qt@no{267}}
\qt@newcmd\qurantrans@es@cclxxv{El demonio los atemoriza con la pobreza y les ordena hacer lo que es inmoral, mientras que Dios les promete Su perdón y Su generosidad. Dios es el Más Generoso, todo lo sabe.\qt@no{268}}
\qt@newcmd\qurantrans@es@cclxxvi{Dios concede la sabiduría a quien quiere, y sepan que a quien le haya sido concedido este don ha recibido una gracia inmensa. Solo reflexionan los dotados de intelecto.\qt@no{269}}
\qt@newcmd\qurantrans@es@cclxxvii{Los pagos de tus obligaciones o las promesas que hagas, Dios los conoce; pero quienes incumplan no tendrán quién los auxilie [el Día del Juicio].\qt@no{270}}
\qt@newcmd\qurantrans@es@cclxxviii{Hacer caridad públicamente es una obra de bien, pero si lo hacen en privado y se la llevan a los pobres será mejor aún. A causa de esto Dios perdonará algunos de sus pecados. Dios sabe todo lo que hacen.\qt@no{271}}
\qt@newcmd\qurantrans@es@cclxxix{No es tu responsabilidad [oh, Mujámmad] que la gente decida seguir la guía [una vez que se la has enseñado], porque Dios guía a quien quiere. Toda caridad que den es en su propio beneficio, pero no den caridad a menos que sea anhelando el rostro de Dios. Lo que hagan de bien les será recompensado sin mengua alguna.\qt@no{272}}
\qt@newcmd\qurantrans@es@cclxxx{[Den caridad a] los pobres que padecen necesidad [por dedicarse] a la causa de Dios y no pueden viajar por la tierra [para trabajar y ganar su sustento]. Quien ignora [la realidad de] su situación los cree ricos, ya que por dignidad no mendigan. Pero los reconocerás por su conducta, no piden inoportunamente. Lo que sea que des en caridad, Dios lo sabe.\qt@no{273}}
\qt@newcmd\qurantrans@es@cclxxxi{Quienes hagan caridad con sus bienes materiales, de noche o de día, en privado o en público, su Señor los recompensará, y no sentirán temor ni tristeza.\qt@no{274}}
\qt@newcmd\qurantrans@es@cclxxxii{Los que lucran con la usura saldrán [de sus tumban el Día del Juicio Final] como un loco poseído por el demonio. Esto es porque dicen que el comercio es igual que la usura, pero [no, porque] Dios permitió el comercio y prohibió la usura. A quien le haya llegado de su Señor [el conocimiento de] la prohibición [de la usura] y se haya abstenido arrepintiéndose, podrá conservar lo que obtuvo en el pasado, y su asunto será juzgado por Dios. Mas si reincide, se contará entre los moradores del Fuego, en el que sufrirá eternamente.\qt@no{275}}
\qt@newcmd\qurantrans@es@cclxxxiii{Dios quita a las ganancias de la usura toda bendición, pero bendice los actos de caridad con un incremento multiplicado. Dios no ama a los que niegan la verdad y transgreden [la prohibición de la usura].\qt@no{276}}
\qt@newcmd\qurantrans@es@cclxxxiv{Los creyentes que obran correctamente, cumplen la oración prescrita y pagan el zakat, serán recompensados por su Señor, y no sentirán temor ni tristeza.\qt@no{277}}
\qt@newcmd\qurantrans@es@cclxxxv{¡Oh, creyentes! Tengan temor de Dios y renuncien a los intereses que les adeuden por usura, si es que son realmente creyentes.\qt@no{278}}
\qt@newcmd\qurantrans@es@cclxxxvi{Pero si no abandonan el lucro a través de la usura, sepan que Dios y Su Mensajero les declaran la guerra. Quien abandona la usura tiene derecho al capital original, de esta forma no oprimirán ni serán oprimidos.\qt@no{279}}
\qt@newcmd\qurantrans@es@cclxxxvii{Si [quien les debe un préstamo] atraviesa una situación difícil, concédanle un nuevo plazo de pago hasta que esté en condición de saldar la deuda. Aunque si supieran la recompensa que tiene, harían algo mejor aún para ustedes: que es condonarle la deuda.\qt@no{280}}
\qt@newcmd\qurantrans@es@cclxxxviii{Teman el día en que serán retornados a Dios, y en que cada persona reciba lo que merezca sin ser oprimido.\qt@no{281}}
\qt@newcmd\qurantrans@es@cclxxxix{¡Oh, creyentes! Si contraen una deuda por un plazo estipulado, pónganlo por escrito ante un escribano. Ningún escribano [creyente] debe negarse a levantar esa acta conforme a lo que Dios le ha enseñado: el escribano debe registrar y el deudor debe dictar fielmente lo que adeuda, con temor de Dios. En caso de que el deudor sea declarado incompetente o sea incapaz de expresar su deuda, que lo haga en su lugar su apoderado con fidelidad. Dos hombres confiables deben ser testigos; pero si no cuentan con dos hombres, recurran a un hombre y dos mujeres, de manera que si una de ellas se olvida la otra lo recuerde. Nadie debe negarse a ser testigo ni rehusarse si son citados a atestiguar. No sean reacios a documentar las deudas, sean pequeñas o grandes, así como su vencimiento. Esto es, para Dios, lo más justo, la mejor evidencia [si existiera una disputa] y da menos lugar a dudas. A menos que se trate de una operación al contado; entonces, no hay inconveniente en que no lo pongan por escrito. Pero [es recomendable] que lo hagan ante testigos en [operaciones de] compraventa. No se debe presionar ni coartar al escribano ni al testigo, porque hacerlo es un delito. Tengan temor de Dios, que Él los agracia con el conocimiento, porque Dios es conocedor de todas las cosas.\qt@no{282}}
\qt@newcmd\qurantrans@es@ccxc{Si estuvieran de viaje y no encontraran un escribano, pueden tomar algo en garantía. Pero si existe una confianza mutua, no hacen mal en no poner por escrito la deuda ni tomar una garantía, y tengan temor de Dios. Que nadie se niegue a prestar testimonio cuando sea convocado, porque quien lo oculta tiene un corazón malvado. Y Dios sabe cuanto hacen.\qt@no{283}}
\qt@newcmd\qurantrans@es@ccxci{A Dios pertenece cuanto hay en los cielos y la Tierra. Lo que manifiesten en público y lo que oculten en privado, Dios les pedirá cuenta por ello; Dios perdona a quien Él quiere y castiga a quien Él quiere. Dios es sobre toda cosa Poderoso.\qt@no{284}}
\qt@newcmd\qurantrans@es@ccxcii{El Mensajero y sus seguidores creen en lo que le fue revelado por su Señor [al Mensajero]. Todos creen en Dios, en Sus ángeles, en Sus Libros y en Sus Mensajeros [diciendo:] ``No hacemos diferencia entre ninguno de Sus Mensajeros". Y dicen: ``Oímos y obedecemos. Perdónanos Señor nuestro, que ante Ti retornaremos [para ser juzgados]".\qt@no{285}}
\qt@newcmd\qurantrans@es@ccxciii{Dios no exige a nadie por encima de sus posibilidades, a su favor tendrá el bien que haga, y en su contra tendrá el mal que haga. ``¡Señor nuestro! No nos castigues si olvidamos o cometemos un error. ¡Señor nuestro! No nos impongas una carga como la que impusiste a quienes nos precedieron. ¡Señor nuestro! No nos impongas algo superior a lo que podamos soportar. Perdónanos, absuélvenos y ten misericordia de nosotros. Tú eres nuestro Protector, concédenos el triunfo sobre los que niegan la verdad".\qt@no{286}}
\qt@newcmd\qurantrans@es@ccxciv{\basmalahes Álif. Lam. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@ccxcv{Dios, no hay otra divinidad que Él, el Viviente, se basta a Sí mismo y se ocupa de toda la creación.\qt@no{2}}
\qt@newcmd\qurantrans@es@ccxcvi{Él te reveló [¡oh, Mujámmad!] el Libro con la Verdad, para confirmar los mensajes anteriores, y ya había revelado la Tora y el Evangelio\qt@no{3}}
\qt@newcmd\qurantrans@es@ccxcvii{como guía para la gente, y reveló el criterio por el cual se discierne lo verdadero de lo falso. Quienes no crean en la palabra de Dios tendrán un castigo severo. Dios es Poderoso y Señor de la retribución Justa.\qt@no{4}}
\qt@newcmd\qurantrans@es@ccxcviii{No hay nada en la Tierra ni en el cielo que pueda esconderse de Dios.\qt@no{5}}
\qt@newcmd\qurantrans@es@ccxcix{Él es Quien, acorde a Su voluntad, les da forma en el útero. No hay otra divinidad salvo Él, el Poderoso, el Sabio.\qt@no{6}}
\qt@newcmd\qurantrans@es@ccc{Él es Quien te ha revelado el Libro [¡oh, Mujámmad!]. En él hay versículos categóricos de significado evidente, que son la base del Libro, y otros que aceptan interpretaciones. Los que tienen el corazón extraviado siguen solo los interpretables con el fin de sembrar la discordia y hacer una interpretación interesada. Pero Dios conoce su verdadero significado. Los que tienen un conocimiento afirmado, dicen: ``Creemos en todos los versículos por igual, todos proceden de nuestro Señor. Aunque solo los dotados de intelecto tienen esto presente.\qt@no{7}}
\qt@newcmd\qurantrans@es@ccci{¡Señor nuestro! No permitas que nuestros corazones se desvíen después de habernos guiado. Concédenos Tu misericordia, Tú eres el Dadivoso.\qt@no{8}}
\qt@newcmd\qurantrans@es@cccii{¡Señor nuestro! [Atestiguamos que] Tú reunirás a los seres humanos para un Día ineludible. Dios no falta jamás a Su promesa".\qt@no{9}}
\qt@newcmd\qurantrans@es@ccciii{A los que rechacen la verdad, de nada les servirán sus bienes materiales ni sus hijos ante Dios. Serán combustible del Fuego.\qt@no{10}}
\qt@newcmd\qurantrans@es@ccciv{Les sucederá lo mismo que a la gente del Faraón y quienes les precedieron. Ellos desmintieron Mis signos. Pero Dios los castigó por sus pecados. Dios es severo en el castigo.\qt@no{11}}
\qt@newcmd\qurantrans@es@cccv{Di a los que rechazan la verdad: ``Serán vencidos y congregados en el Infierno". ¡Qué pésima morada!\qt@no{12}}
\qt@newcmd\qurantrans@es@cccvi{Ya fue una clara evidencia los dos grupos que se enfrentaron [en la batalla de Bader]: uno combatía por la causa de Dios y el otro la rechazaba. Este último, al ver el grupo de creyentes le pareció [milagrosamente] que era dos veces más numeroso de lo real. Dios fortalece con Su auxilio a quien Él quiere. En ello hay una enseñanza para quienes observan con atención.\qt@no{13}}
\qt@newcmd\qurantrans@es@cccvii{Se encuentra en el corazón de las personas la inclinación por los placeres: las mujeres, los hijos, la acumulación de riquezas en oro y plata, los caballos de raza, los ganados y los campos de cultivo. Ese es el breve goce de esta vida, pero lo más hermoso se encuentra junto a Dios.\qt@no{14}}
\qt@newcmd\qurantrans@es@cccviii{Di: ¿Quieren que les informe sobre algo mejor que los placeres mundanos? Aquellos que tengan temor de Dios encontrarán junto a su Señor jardines por donde corren los ríos, con esposas inmaculadas, donde obtendrán la complacencia de Dios por toda la eternidad. Dios conoce a Sus siervos,\qt@no{15}}
\qt@newcmd\qurantrans@es@cccix{quienes dicen: ``¡Señor nuestro! Creemos en Ti. Perdónanos nuestros pecados y líbranos del castigo del Fuego".\qt@no{16}}
\qt@newcmd\qurantrans@es@cccx{[Los creyentes] son los pacientes, los que cumplen su palabra, los piadosos, los caritativos y los que hasta el alba imploran el perdón.\qt@no{17}}
\qt@newcmd\qurantrans@es@cccxi{Dios atestigua, y con Él los ángeles y los dotados de cono-cimiento, que no existe más divinidad que Él, y que Él vela por la justicia [y mantiene el equilibrio]. No hay otra divinidad salvo Él, el Poderoso, el Sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@cccxii{Para Dios la verdadera religión es el Islam. Los que habían recibido el libro anteriormente discreparon por soberbia a pesar de haberles llegado la revelación. Quienes rechacen los signos de Dios, sepan que Dios es rápido en ajustar cuentas.\qt@no{19}}
\qt@newcmd\qurantrans@es@cccxiii{Si te discuten [¡oh, Mujámmad! acerca de tu mensaje], diles: ``Me entrego sinceramente a Dios y así hacen quienes me siguen". Y pregúntales a quienes recibieron el Libro y a los analfabetos [árabes paganos]: ``¿Han aceptado el Islam [sometiéndose a Dios]?" Si lo aceptan habrán seguido la guía, pero si lo rechazan, tú solo tienes la obligación de transmitirles el mensaje. Dios conoce a Sus siervos.\qt@no{20}}
\qt@newcmd\qurantrans@es@cccxiv{Anuncia un castigo severo a quienes rechazan los preceptos de Dios, asesinan a los Profetas y matan a las personas que luchan por la justicia.\qt@no{21}}
\qt@newcmd\qurantrans@es@cccxv{Sus obras serán vanas en esta vida y en la otra, y no tendrán quién los auxilie.\qt@no{22}}
\qt@newcmd\qurantrans@es@cccxvi{¿No te sorprende que quienes recibieron parte del Libro [judíos y cristianos] rechazan juzgar sus asuntos según el Libro de Dios?\qt@no{23}}
\qt@newcmd\qurantrans@es@cccxvii{Eso es porque dicen: ``El fuego no nos tocará más que por días contados". Las falsas creencias que ellos mismos inventaron terminaron apartándolos de su religión.\qt@no{24}}
\qt@newcmd\qurantrans@es@cccxviii{¿Qué será de ellos cuando los reunamos el Día inevitable, en el que cada individuo reciba lo que merece de acuerdo a sus acciones? No serán tratados injustamente.\qt@no{25}}
\qt@newcmd\qurantrans@es@cccxix{Di: ``¡Oh, Dios, Soberano Absoluto! Tú concedes el poder a quien quieres y se lo quitas a quien quieres, fortaleces a quien quieres y humillas a quien quieres. Todo el bien descansa en Tus manos. Tú tienes poder sobre todas las cosas.\qt@no{26}}
\qt@newcmd\qurantrans@es@cccxx{Tú haces que la noche entre en el día y el día en la noche. Tú haces surgir lo vivo de lo muerto y lo muerto de lo vivo. Tú sustentas sin medida a quien quieres".\qt@no{27}}
\qt@newcmd\qurantrans@es@cccxxi{Que los creyentes no tomen como aliados a los que niegan la verdad en lugar de a los creyentes. Quien así lo haga no tendrá nada que ver con Dios, a menos que lo haga para preservar la vida. Dios los exhorta a que Le teman a Él. Ante Dios comparecerán.\qt@no{28}}
\qt@newcmd\qurantrans@es@cccxxii{Di: ``Tanto si ocultan cuanto hay en sus corazones como si lo manifiestan, Dios lo sabe". Él conoce todo lo que hay en los cielos y en la Tierra. Dios tiene poder sobre todas las cosas.\qt@no{29}}
\qt@newcmd\qurantrans@es@cccxxiii{El día que cada ser vea el registro de todo bien y de todo mal que haya producido, deseará que se interponga una gran distancia entre sí y ese momento. Dios los exhorta a que Le teman a Él. Dios es Compasivo con Sus siervos.\qt@no{30}}
\qt@newcmd\qurantrans@es@cccxxiv{Di: ``Si verdaderamente aman a Dios, ¡síganme!, que Dios los amará y perdonará sus pecados". Dios es Absolvedor, Misericordioso.\qt@no{31}}
\qt@newcmd\qurantrans@es@cccxxv{Di: ``¡Obedezcan a Dios y al Mensajero!" Pero si se niegan, sabe que Dios no ama a los que rechazan la verdad.\qt@no{32}}
\qt@newcmd\qurantrans@es@cccxxvi{Dios escogió a Adán, a Noé, a la familia de Abraham y a la de ‘Imrán de entre todos los seres.\qt@no{33}}
\qt@newcmd\qurantrans@es@cccxxvii{Familias descendientes unas de otras. Dios todo lo oye, todo lo sabe.\qt@no{34}}
\qt@newcmd\qurantrans@es@cccxxviii{Cuando la esposa de ‘Imrán dijo: ``¡Señor mío! He realizado el voto de entregar a Tu exclusivo servicio lo que hay en mi vientre. ¡Acéptalo de mí! Tú todo lo oyes, todo lo sabes".\qt@no{35}}
\qt@newcmd\qurantrans@es@cccxxix{Y cuando dio a luz dijo: ``¡Señor mío! He tenido una hija", y Dios bien sabía lo que había concebido. ``No puede servirte una mujer [en el templo] como lo habría hecho un varón. La he llamado María, y Te imploro que la protejas a ella y a su descendencia del maldito demonio".\qt@no{36}}
\qt@newcmd\qurantrans@es@cccxxx{El Señor la aceptó complacido, e hizo que se educase correctamente y la confió a Zacarías. Cada vez que Zacarías ingresaba al templo la encontraba provista de alimentos, y le preguntaba: ``¡María! ¿De dónde obtuviste eso?" Ella respondía: ``Proviene de Dios, porque Dios sustenta sin medida a quien quiere".\qt@no{37}}
\qt@newcmd\qurantrans@es@cccxxxi{En el templo, Zacarías invocó a su Señor diciendo: ``¡Señor mío! Concédeme una descendencia piadosa, Tú escuchas los ruegos".\qt@no{38}}
\qt@newcmd\qurantrans@es@cccxxxii{Entonces los ángeles lo llamaron cuando oraba en el templo diciendo: ``Dios te anuncia el nacimiento de Juan, quien corroborará la Palabra de Dios, será noble, casto y un Profeta virtuoso".\qt@no{39}}
\qt@newcmd\qurantrans@es@cccxxxiii{Exclamó: ``¡Señor mío! ¿Cómo podré tener un hijo si soy anciano y mi mujer estéril?" Le respondió [el ángel]: ``¡Así será! Porque Dios hace lo que quiere".\qt@no{40}}
\qt@newcmd\qurantrans@es@cccxxxiv{Dijo [Zacarías]: ``¡Señor mío! Dame una señal [de que me has concedido un hijo]". Dijo Dios: ``La señal será que durante tres días, no podrás hablar con la gente salvo por señas. Adora mucho a tu Señor y glorifícalo al anochecer y al alba".\qt@no{41}}
\qt@newcmd\qurantrans@es@cccxxxv{Y [recuerda] cuando los ángeles dijeron: ``¡María! Dios te ha elegido por tus virtudes y te ha purificado. Te ha elegido entre todas las mujeres del mundo.\qt@no{42}}
\qt@newcmd\qurantrans@es@cccxxxvi{¡María! Conságrate a tu Señor, prostérnate e inclínate con los orantes".\qt@no{43}}
\qt@newcmd\qurantrans@es@cccxxxvii{[¡Oh, Mujámmad!] Éstas son historias que te he revelado porque no eran conocidas [por tu gente]. Tú no estabas presente cuando sorteaban con sus plumas [de escritura] quién de ellos sería el tutor de María, ni tampoco cuando se lo disputaban.\qt@no{44}}
\qt@newcmd\qurantrans@es@cccxxxviii{Entonces los ángeles dijeron: ``¡María! Dios te albricia con Su Palabra [¡Sea!] será conocido como el Mesías Jesús, hijo de María. Será noble en esta vida y en la otra, y se contará entre los próximos a Dios.\qt@no{45}}
\qt@newcmd\qurantrans@es@cccxxxix{Hablará [milagrosamente] a la gente desde la cuna, y predicará siendo adulto. Será de los virtuosos".\qt@no{46}}
\qt@newcmd\qurantrans@es@cccxl{Dijo [María]: ``¡Señor mío! ¿Cómo he de tener un hijo si no me ha tocado hombre?" Le respondió: ``¡Así será! Dios crea lo que quiere. Cuando decide algo, solo dice: ¡Sea!, y es.\qt@no{47}}
\qt@newcmd\qurantrans@es@cccxli{Él le enseñará la escritura, le concederá la sabiduría, le enseñará la Tora y el Evangelio.\qt@no{48}}
\qt@newcmd\qurantrans@es@cccxlii{Y será Profeta para los hijos de Israel, a quienes dirá: ``Les he traído un milagro de su Señor. Modelaré para ustedes un pájaro de barro. Luego soplaré en él y, con el permiso de Dios, tendrá vida. Con la anuencia de Dios, curaré al que nació ciego y al leproso, y resucitaré a los muertos. Les revelaré lo que comen y guardan dentro de sus casas. Esos milagros son suficientes para que crean en mí, si es que son creyentes.\qt@no{49}}
\qt@newcmd\qurantrans@es@cccxliii{He venido para confirmar [las enseñanzas originales de] la Tora y para permitirles algunas de las cosas que les estaban prohibidas. He venido con un milagro de su Señor. Tengan temor de Dios y obedezcan.\qt@no{50}}
\qt@newcmd\qurantrans@es@cccxliv{Dios es mi Señor y el de ustedes. ¡Adórenlo! Ese es el sendero recto"."\qt@no{51}}
\qt@newcmd\qurantrans@es@cccxlv{Pero cuando Jesús advirtió que su pueblo rechazaba la verdad, dijo: ``¿Quiénes me ayudarán en mi misión de transmitir el Mensaje de Dios?" Dijeron los discípulos: ``Nosotros te ayudaremos. Creemos en Dios. Atestigua [¡oh, Jesús!] que solo a Él adoramos.\qt@no{52}}
\qt@newcmd\qurantrans@es@cccxlvi{¡Señor nuestro! Creemos en lo que has revelado y seguimos a Tu Profeta. Cuéntanos entre los que dan testimonio de fe".\qt@no{53}}
\qt@newcmd\qurantrans@es@cccxlvii{Cuando [los conspiradores] maquinaron planes contra Jesús, Dios desbarató sus planes, porque Dios es el sumo planificador.\qt@no{54}}
\qt@newcmd\qurantrans@es@cccxlviii{Cuando Dios dijo: ``¡Oh, Jesús! Te haré morir [algún día como a todos, pero ahora] te ascenderé a Mí. Te libraré de los que rechazan la verdad y haré prevalecer a los que te han seguido por sobre los incrédulos hasta el Día de la Resurrección. Luego, todos volverán a Mí para que juzgue entre ustedes sobre lo que discrepaban.\qt@no{55}}
\qt@newcmd\qurantrans@es@cccxlix{A los que se obstinan en negar la verdad los castigaré severamente en este mundo y el otro, y no tendrán quién los auxilie".\qt@no{56}}
\qt@newcmd\qurantrans@es@cccl{Mientras que a los creyentes que obren rectamente Dios les dará su recompensa con generosidad. Dios no ama a los injustos.\qt@no{57}}
\qt@newcmd\qurantrans@es@cccli{Esta historia te la he revelado como parte de los milagros y de la sabia amonestación del Corán.\qt@no{58}}
\qt@newcmd\qurantrans@es@ccclii{El ejemplo [de la creación] de Jesús ante Dios es como el de Adán, a quien creó del barro y luego le dijo: ``¡Sea!", y fue.\qt@no{59}}
\qt@newcmd\qurantrans@es@cccliii{Ésta es la verdad que proviene de tu Señor [sobre la historia de Jesús]. No seas de los indecisos.\qt@no{60}}
\qt@newcmd\qurantrans@es@cccliv{Si te disputan acerca de esta verdad [la historia de Jesús] después de haberte llegado el conocimiento, diles: ``¡Vengan! Convoquemos a nuestros hijos y a los suyos, a nuestras mujeres y a las suyas, y presentémonos todos. Luego invoquemos que la maldición de Dios caiga sobre los que mienten".\qt@no{61}}
\qt@newcmd\qurantrans@es@ccclv{Ésta es la verdadera historia. No hay otra divinidad más que Dios. Dios es el Poderoso, el Sabio.\qt@no{62}}
\qt@newcmd\qurantrans@es@ccclvi{Pero si la niegan, Dios sabe quiénes son los que siembran la desviación.\qt@no{63}}
\qt@newcmd\qurantrans@es@ccclvii{Di: ``¡Oh, Gente del Libro! Convengamos en una creencia común: No adoraremos sino a Dios, no Le asociaremos nada y no tomaremos a nadie como divinidad fuera de Dios". Pero si no aceptan digan: ``Sean testigos de que nosotros solo adoramos a Dios".\qt@no{64}}
\qt@newcmd\qurantrans@es@ccclviii{¡Oh, Gente del Libro! ¿Por qué se disputan a Abraham, siendo que la Tora y el Evangelio fueron revelados después de él? ¿Es que no razonan?\qt@no{65}}
\qt@newcmd\qurantrans@es@ccclix{Ustedes discuten sobre los asuntos de los que tienen conocimiento, aun teniendo la revelación. Pero ahora discuten sobre lo que no conocen siquiera. Dios sabe y ustedes no.\qt@no{66}}
\qt@newcmd\qurantrans@es@ccclx{Abraham no fue judío ni cristiano, sino que fue un monoteísta creyente en Dios, y no fue jamás de los idólatras.\qt@no{67}}
\qt@newcmd\qurantrans@es@ccclxi{Los más cercanos a Abraham son los que siguen sus enseñanzas, así como el Profeta y los creyentes [musulmanes]. Dios es el Protector de los creyentes.\qt@no{68}}
\qt@newcmd\qurantrans@es@ccclxii{Un grupo de la Gente del Libro desea extraviarlos, pero sin darse cuenta, solo se extravían a sí mismos.\qt@no{69}}
\qt@newcmd\qurantrans@es@ccclxiii{¡Oh, Gente del Libro! ¿Por qué no creen en la palabra de Dios, siendo que creyeron en ella anteriormente?\qt@no{70}}
\qt@newcmd\qurantrans@es@ccclxiv{¡Oh, Gente del Libro! ¿Por qué, a sabiendas, mezclan la verdad con lo falso y ocultan la verdad?\qt@no{71}}
\qt@newcmd\qurantrans@es@ccclxv{Miembros de un grupo de la Gente del Libro se dicen entre sí: ``Al comenzar el día finjan creer en lo que se le ha revelado a los creyentes [el Islam], pero desacredítenlo al anochecer; tal vez así les sembremos dudas y renuncien a su fe".\qt@no{72}}
\qt@newcmd\qurantrans@es@ccclxvi{Y [dicen:] ``no confíen sino en quienes siguen su religión". Diles [¡oh, Mujámmad!]: ``La verdadera guía es la de Dios". [Y dicen:] ``No enseñen lo que han recibido para que nadie sea bendecido como ustedes, ni para que puedan argumentar en contra suya ante su Señor". Diles [¡oh, Mujámmad!]: ``La gracia está en manos de Dios, y se la concede a quien Él quiere". Dios es Inconmensurable, todo lo sabe.\qt@no{73}}
\qt@newcmd\qurantrans@es@ccclxvii{Favorece con Su misericordia a quien Él quiere. Dios es poseedor del favor inmenso.\qt@no{74}}
\qt@newcmd\qurantrans@es@ccclxviii{Entre la Gente del Libro hay quienes, si les confías un gran tesoro te lo devuelven, y quienes si les confías una moneda te la devuelven solo después de pedírsela con insistencia. Eso es porque dicen: ``No seremos recriminados por no cumplir con quienes no han recibido ninguna revelación". Ellos inventan mentiras acerca de Dios a sabiendas.\qt@no{75}}
\qt@newcmd\qurantrans@es@ccclxix{Por el contrario, quien cumpla su promesa y tenga temor de Dios, sepa que Dios ama a los piadosos.\qt@no{76}}
\qt@newcmd\qurantrans@es@ccclxx{Quienes vendieron por vil precio el compromiso que tomaron con Dios y faltaron a sus juramentos, no tendrán recompensa en la otra vida. Dios no les dirigirá la palabra ni los mirará ni los purificará el Día de la Resurrección, y tendrán un castigo doloroso.\qt@no{77}}
\qt@newcmd\qurantrans@es@ccclxxi{Entre ellos hay quienes tergiversan el Libro cuando lo recitan para que ustedes crean que es parte de él, cuando en realidad no pertenece al Libro. Y dicen que proviene de Dios, cuando en realidad no proviene de Dios. Inventan mentiras acerca de Dios a sabiendas.\qt@no{78}}
\qt@newcmd\qurantrans@es@ccclxxii{No es concebible que una persona a quien Dios concede el Libro, la sabiduría y la profecía, diga a la gente: ``Ríndanme culto a mí, no a Dios"; [una persona así] dirá: ``Sean gente de Dios ilustrados en su religión, que [practican y] enseñan el Libro tal como lo han aprendido".\qt@no{79}}
\qt@newcmd\qurantrans@es@ccclxxiii{Tampoco les ordenaría que tomen como dioses a los ángeles y a los Profetas. ¿Acaso iba a ordenarles que fueran incrédulos siendo ustedes creyentes monoteístas?\qt@no{80}}
\qt@newcmd\qurantrans@es@ccclxxiv{Dios celebró un pacto con la gente del Libro a través de los Profetas, diciéndoles: ``Les concedo el Libro y la sabiduría, pero cuando se les presente un Mensajero que confirme lo que se les ha revelado, crean en él y préstenle auxilio. ¿Asumen tal compromiso?" Respondieron: ``Sí, nos comprometemos". Dijo Dios: ``Entonces, sean testigos que yo también atestiguaré con ustedes".\qt@no{81}}
\qt@newcmd\qurantrans@es@ccclxxv{Quienes después se desentiendan [y no cumplan con el pacto], serán los descarriados.\qt@no{82}}
\qt@newcmd\qurantrans@es@ccclxxvi{¿Acaso desean una religión diferente a la de Dios, siendo que quienes están en los cielos y en la Tierra se someten a Él por libre voluntad o por la fuerza? Y ante Él [todos] comparecerán.\qt@no{83}}
\qt@newcmd\qurantrans@es@ccclxxvii{Di: ``Creemos en Dios y en lo que nos ha revelado, en lo que fue revelado a Abraham, a Ismael, a Isaac, a Jacob y a las doce Tribus, y en lo que de su Señor recibieron Moisés, Jesús y los Profetas. No hacemos distinción entre ninguno de ellos y somos creyentes monoteístas".\qt@no{84}}
\qt@newcmd\qurantrans@es@ccclxxviii{Quien profese una religión diferente al Islam no le será aceptada, y en la otra vida se contará entre los perdedores.\qt@no{85}}
\qt@newcmd\qurantrans@es@ccclxxix{¿Cómo habría Dios de guiar a quienes abandonan la fe luego de ser creyentes, siendo que fueron testigos de la veracidad del Mensajero y vieron las evidencias? Dios no guía a los injustos.\qt@no{86}}
\qt@newcmd\qurantrans@es@ccclxxx{Ellos tendrán como retribución la maldición de Dios, de los ángeles y de toda la humanidad.\qt@no{87}}
\qt@newcmd\qurantrans@es@ccclxxxi{En ese estado se mantendrán eternamente. Tendrán un castigo sin tregua ni alivio.\qt@no{88}}
\qt@newcmd\qurantrans@es@ccclxxxii{Salvo quienes se arrepientan y enmienden, porque Dios es Absolvedor, Misericordioso.\qt@no{89}}
\qt@newcmd\qurantrans@es@ccclxxxiii{A quienes reniegan de la fe luego de haber creído y se obstinan en su incredulidad, no se les aceptará el arrepentimiento. Ésos son los desviados.\qt@no{90}}
\qt@newcmd\qurantrans@es@ccclxxxiv{A los que rechazaron la verdad y los tomó la muerte siendo aún incrédulos, aunque ofrecieran como rescate todo el oro que hubiere en la Tierra, no les será aceptado. Ellos recibirán un castigo doloroso y no tendrán quién pueda socorrerlos.\qt@no{91}}
\qt@newcmd\qurantrans@es@ccclxxxv{[Los creyentes] no alcanzarán la piedad auténtica hasta que den [en caridad] lo que más aman. Todo lo que den en caridad Dios lo sabe.\qt@no{92}}
\qt@newcmd\qurantrans@es@ccclxxxvi{Antes que fuera revelada la Tora, todos los alimentos eran lícitos para el pueblo de Israel, salvo lo que ellos mismos se habían vedado. Diles: ``Traigan la Tora y léanla, si es verdad lo que dicen".\qt@no{93}}
\qt@newcmd\qurantrans@es@ccclxxxvii{Serán unos injustos quienes después de todas estas evidencias inventen mentiras y se las atribuyan a Dios.\qt@no{94}}
\qt@newcmd\qurantrans@es@ccclxxxviii{Di: ``Dios dice la verdad. Sigan la religión de Abraham, que fue monoteísta y no se contó entre los que dedicaban actos de adoración a otros además de Dios".\qt@no{95}}
\qt@newcmd\qurantrans@es@ccclxxxix{El primer templo erigido para los seres humanos es el de Bakkah [la Ka‘bah], en él hay bendición y guía para la humanidad.\qt@no{96}}
\qt@newcmd\qurantrans@es@cccxc{Allí hay signos evidentes, como el sitial de Abraham. Quien ingrese en él estará a salvo. Es obligatorio para las personas peregrinar a este templo si se encuentran en condiciones [físicas y económicas] de hacerlo. Pero quien niegue lo que Dios ha prescrito, sepa que Dios no necesita de Sus criaturas.\qt@no{97}}
\qt@newcmd\qurantrans@es@cccxci{Di: ``¡Oh, Gente del Libro! ¿Por qué no creen en los signos de Dios? Dios es testigo de lo que hacen".\qt@no{98}}
\qt@newcmd\qurantrans@es@cccxcii{Di: ``¡Oh, Gente del Libro! ¿Por qué intentan conscientemente dificultar el camino al Islam a los que quieren abrazarlo, desfigurando su imagen real, haciéndolo pasar por tortuoso?" Dios no está desatento a lo que hacen.\qt@no{99}}
\qt@newcmd\qurantrans@es@cccxciii{¡Oh, creyentes! Si se someten a algunos de la Gente del Libro, ellos lograrán sacarlos a ustedes de la fe a la incredulidad.\qt@no{100}}
\qt@newcmd\qurantrans@es@cccxciv{¿Cómo podrían ustedes abandonar la fe cuando se les recitan los preceptos de Dios, y Su Mensajero se encuentra entre ustedes? Quien se aferre a Dios será guiado al camino recto.\qt@no{101}}
\qt@newcmd\qurantrans@es@cccxcv{¡Oh, creyentes! Tengan temor de Dios como es debido, y no mueran sino como creyentes monoteístas.\qt@no{102}}
\qt@newcmd\qurantrans@es@cccxcvi{Aférrense todos a la religión de Dios y no se dividan en sectas. Recuerden la gracia de Dios cuando los hermanó uniendo sus corazones siendo que eran rivales unos de otros, y cuando se encontraban al borde de un abismo de fuego, los salvó de caer en él. Así les explica Dios Sus signos para que sigan la verdadera guía.\qt@no{103}}
\qt@newcmd\qurantrans@es@cccxcvii{Que siempre haya entre ustedes un grupo que invite al bien, ordenando lo bueno y prohibiendo lo malo. Ésos serán los bienaventurados.\qt@no{104}}
\qt@newcmd\qurantrans@es@cccxcviii{No sean como aquellos que después de haber recibido las pruebas claras, discreparon y se dividieron en sectas. Ésos tendrán un castigo severo.\qt@no{105}}
\qt@newcmd\qurantrans@es@cccxcix{El Día del Juicio unos rostros estarán radiantes y otros ensombrecidos. A aquellos cuyos rostros estén ensombrecidos se les dirá: ``¿Han rechazado la verdad luego de haber creído? Sufran el castigo como consecuencia de su incredulidad".\qt@no{106}}
\qt@newcmd\qurantrans@es@cd{En cuanto a aquellos cuyos rostros estén radiantes, estarán en la misericordia de Dios eternamente.\qt@no{107}}
\qt@newcmd\qurantrans@es@cdi{Éstos son los signos de Dios que te revelo con la verdad, para que adviertas que Dios no oprime a ninguna de Sus criaturas.\qt@no{108}}
\qt@newcmd\qurantrans@es@cdii{A Dios pertenece todo cuanto hay en los cielos y en la Tierra. Y a Dios retornan todos los asuntos.\qt@no{109}}
\qt@newcmd\qurantrans@es@cdiii{[¡Musulmanes!] Son la mejor nación que haya surgido de la humanidad porque ordenan el bien, prohíben el mal y creen en Dios. Si la Gente del Libro creyera, sería mejor para ellos; algunos de ellos son creyentes, pero la mayoría son desviados.\qt@no{110}}
\qt@newcmd\qurantrans@es@cdiv{Ellos solo podrán perjudicarlos levemente, y cada vez que los combatan huirán atemorizados, y no serán socorridos.\qt@no{111}}
\qt@newcmd\qurantrans@es@cdv{Dondequiera que se encuentren deberán soportar la humillación, excepto amparados según lo establecido por Dios o por un pacto con los hombres. Cayeron en la condena de Dios y la miseria se ha abatido sobre ellos por no haber creído en los signos de Dios y por haber matado injustamente a los Profetas, por haber desobedecido y violado la ley.\qt@no{112}}
\qt@newcmd\qurantrans@es@cdvi{Pero no todos los de la Gente del Libro son iguales. Entre ellos hay quienes se mantienen fieles a las enseñanzas originales, y al conocerlo siguen el Islam, pasan la noche recitando los versículos de Dios y se prosternan.\qt@no{113}}
\qt@newcmd\qurantrans@es@cdvii{Creen en Dios y en el Día del Juicio Final, ordenan el bien, prohíben el mal y se apresuran a realizar buenas obras. Ésos se contarán entre los virtuosos.\qt@no{114}}
\qt@newcmd\qurantrans@es@cdviii{El bien que hayan hecho antes de adoptar el Islam no será desmerecido. Dios conoce bien a los piadosos.\qt@no{115}}
\qt@newcmd\qurantrans@es@cdix{En cambio, a los que rechacen la verdad, ni sus riquezas ni sus hijos les servirán de nada ante Dios. Serán condenados al Infierno, donde morarán eternamente.\qt@no{116}}
\qt@newcmd\qurantrans@es@cdx{[De nada les servirán] las caridades que ellos hacen en esta vida mundanal [porque la incredulidad las destruye] como un viento frío que azota una cosecha de gente que ha sido injusta, y la destruye. Pero Dios no ha sido injusto con ellos, sino que ellos lo han sido consigo mismos.\qt@no{117}}
\qt@newcmd\qurantrans@es@cdxi{¡Oh, creyentes! No tomen por confidentes a quienes no sean como ustedes, porque los que rechazan la verdad se esforzarán para corromperlos, porque desean verlos en la ruina. Ya han manifestado su odio con palabras, pero lo que ocultan sus corazones es peor aún. Les he mostrado las evidencias de su enemistad, para que reflexionen.\qt@no{118}}
\qt@newcmd\qurantrans@es@cdxii{Ustedes los aman a ellos, porque creen en todas las revelaciones, pero ellos no los aman a ustedes. Cuando se encuentran con ustedes dicen: ``¡Somos creyentes!" Pero cuando están a solas se muerden los dedos por la rabia que sienten contra ustedes. Di: ``Muéranse de rabia". Dios sabe bien lo que encierran los corazones.\qt@no{119}}
\qt@newcmd\qurantrans@es@cdxiii{Cuando ustedes prosperan, ellos se afligen; pero cuando les sobreviene un mal, se alegran. Si ustedes son pacientes y tienen temor de Dios, sus intrigas no les harán ningún daño. Dios sabe bien lo que ellos hacen.\qt@no{120}}
\qt@newcmd\qurantrans@es@cdxiv{Y recuerda [¡oh, Mujámmad!] cuando al alba saliste de tu hogar para asignar a los creyentes sus posiciones en el campo de batalla. Dios todo lo oye, todo lo sabe.\qt@no{121}}
\qt@newcmd\qurantrans@es@cdxv{Cuando dos de tus tropas estuvieron a punto de perder el coraje, pero Dios era su Protector y es a Dios que los creyentes deben encomendarse.\qt@no{122}}
\qt@newcmd\qurantrans@es@cdxvi{Dios los socorrió en Bader cuando estaban en inferioridad de condiciones. Tengan temor de Dios, en señal de agradecimiento.\qt@no{123}}
\qt@newcmd\qurantrans@es@cdxvii{Cuando decías a los creyentes: ``¿No les basta que su Señor los socorriera descendiendo tres mil ángeles?"\qt@no{124}}
\qt@newcmd\qurantrans@es@cdxviii{[Dijeron:] ``¡Sí!" Y si son pacientes y tienen temor de Dios, cuando intenten atacarlos sorpresivamente, su Señor los fortalecerá con cinco mil ángeles con distintivos.\qt@no{125}}
\qt@newcmd\qurantrans@es@cdxix{Dios lo hizo para albriciarlos y tranquilizar sus corazones. La victoria proviene de Dios, el Poderoso, el Sabio.\qt@no{126}}
\qt@newcmd\qurantrans@es@cdxx{[Y lo hizo también] para destruir y humillar a algunos de los que rechazaban la verdad, y que se retiraran derrotados.\qt@no{127}}
\qt@newcmd\qurantrans@es@cdxxi{No es asunto tuyo [oh, Mujámmad] si Dios acepta su arrepentimiento o los castiga, pues ellos han cometido muchas injusticias.\qt@no{128}}
\qt@newcmd\qurantrans@es@cdxxii{A Dios pertenece cuanto hay en los cielos y en la Tierra. Él perdona a quien quiere y castiga a quien quiere. Dios es Absolvedor, Misericordioso.\qt@no{129}}
\qt@newcmd\qurantrans@es@cdxxiii{¡Oh, creyentes! No se beneficien de la usura duplicando y multiplicando los intereses, y tengan temor de Dios, pues solo así tendrán éxito.\qt@no{130}}
\qt@newcmd\qurantrans@es@cdxxiv{Y tengan temor de un fuego que ha sido reservado para los que niegan la verdad.\qt@no{131}}
\qt@newcmd\qurantrans@es@cdxxv{Obedezcan a Dios y al Mensajero, que así alcanzarán la misericordia.\qt@no{132}}
\qt@newcmd\qurantrans@es@cdxxvi{Y apresúrense a buscar el perdón de su Señor y un Paraíso tan vasto como los cielos y la Tierra, que ha sido reservado para los que tienen consciencia de Dios [y cumplen la ley],\qt@no{133}}
\qt@newcmd\qurantrans@es@cdxxvii{[que son] aquellos que hacen caridad, tanto en momentos de holgura como de estrechez, controlan su enojo y perdonan a las personas, y Dios ama a los que hacen el bien.\qt@no{134}}
\qt@newcmd\qurantrans@es@cdxxviii{Aquellos que al cometer una obscenidad o injusticia invocan a Dios pidiendo perdón por sus pecados, porque saben que solo Dios perdona los pecados, y no reinciden a sabiendas.\qt@no{135}}
\qt@newcmd\qurantrans@es@cdxxix{Su recompensa será el perdón de su Señor y jardines por donde corren ríos, en los que estarán eternamente. ¡Qué hermosa es la recompensa de quienes obran correctamente!\qt@no{136}}
\qt@newcmd\qurantrans@es@cdxxx{En la antigüedad Dios ha escarmentado [a otros pueblos]; viajen por el mundo y observen cómo terminaron aquellos que desmintieron la verdad.\qt@no{137}}
\qt@newcmd\qurantrans@es@cdxxxi{Esto debería ser una lección clara para la humanidad, y es guía y motivo de reflexión para los que tienen temor de Dios.\qt@no{138}}
\qt@newcmd\qurantrans@es@cdxxxii{No se desanimen ni entristezcan, porque los que obtendrán el éxito finalmente serán los creyentes.\qt@no{139}}
\qt@newcmd\qurantrans@es@cdxxxiii{Si sufren una derrota, sepan que ellos también han sufrido derrotas. Se alterna el triunfo y la derrota entre las personas para que Dios ponga a prueba a los creyentes y honre con la muerte dando testimonio [de su fe] a algunos. Dios no ama a los opresores.\qt@no{140}}
\qt@newcmd\qurantrans@es@cdxxxiv{Esto es para que Dios purifique a los creyentes de sus pecados y destruya a los que desmienten la verdad.\qt@no{141}}
\qt@newcmd\qurantrans@es@cdxxxv{¿Acaso creen que van a entrar al Paraíso sin que Dios evidencie quiénes están dispuestos a combatir por Su causa y ser pacientes?\qt@no{142}}
\qt@newcmd\qurantrans@es@cdxxxvi{Anhelaban la muerte antes de salir a su encuentro, y la vieron con sus propios ojos.\qt@no{143}}
\qt@newcmd\qurantrans@es@cdxxxvii{Mujámmad es un Mensajero a quien precedieron otros. ¿Si muriera o le dieran muerte, volverían al paganismo? Quien regrese al paganismo no perjudica a Dios. Dios retribuirá generosamente a los agradecidos.\qt@no{144}}
\qt@newcmd\qurantrans@es@cdxxxviii{Ningún ser puede morir excepto por el designio de Dios, lo que se encuentra escrito con anterioridad. Quien desee el provecho de esta vida mundanal, le concederé parte de ello; pero quien quiera la recompensa de la otra vida, se la otorgaré. Así recompensaré a los agradecidos.\qt@no{145}}
\qt@newcmd\qurantrans@es@cdxxxix{¡Cuántos Profetas han tenido que combatir junto a multitudes de seguidores devotos! No perdieron la fe por los reveses en la causa de Dios, no flaquearon ni se sometieron al enemigo. Dios ama a los perseverantes.\qt@no{146}}
\qt@newcmd\qurantrans@es@cdxl{No pronunciaban otras palabras más que: ``¡Oh, Señor nuestro! Perdona nuestros pecados y nuestros excesos. Afirma nuestros pasos y concédenos el triunfo sobre los que rechazan la verdad".\qt@no{147}}
\qt@newcmd\qurantrans@es@cdxli{Dios les premió en esta vida y les favorecerá con una recompensa mayor en la otra, porque Dios ama a los que hacen el bien.\qt@no{148}}
\qt@newcmd\qurantrans@es@cdxlii{¡Oh, creyentes! Si obedecen a los que rechazan la verdad, los harán renegar de su fe, y serán finalmente de los perdedores.\qt@no{149}}
\qt@newcmd\qurantrans@es@cdxliii{Solo Dios es su Protector, y Él es quien mejor da auxilio.\qt@no{150}}
\qt@newcmd\qurantrans@es@cdxliv{Infundiremos miedo en el corazón de los que rechazan la verdad por haber dedicado actos de adoración a otros además de Dios, sin fundamento lógico ni evidencia revelada. Su morada será el Fuego. ¡Qué pésima será la morada de los opresores!\qt@no{151}}
\qt@newcmd\qurantrans@es@cdxlv{Dios cumplió Su promesa cuando, con Su anuencia, vencían [en la batalla de Uhud]. Pero flaquearon y cuestionaron las órdenes cayendo en la desobediencia. Entre ustedes hubo quienes anhelaron los bienes materiales de esta vida, pero otros anhelaron la recompensa de la otra vida. Entonces Dios los probó con la derrota, pero los perdonó, porque Dios concede Su favor a los creyentes.\qt@no{152}}
\qt@newcmd\qurantrans@es@cdxlvi{Y [recuerden] cuando huían sin reparar en nadie y el Mensajero los convocaba a sus espaldas, pero no lo obedecieron. Entonces, Dios los afligió con una tribulación para que no se lamentaran por lo que habían perdido [del botín] ni padecido [la derrota]. Dios está bien informado de lo que hacen.\qt@no{153}}
\qt@newcmd\qurantrans@es@cdxlvii{Luego de pasada la tribulación, Dios hizo descender sobre ustedes una seguridad y los envolvió en un sueño. Mientras tanto, otro grupo estaba preocupado tan solo por su suerte y pensaban equivocadamente acerca de Dios, a la manera de los paganos, diciendo: ``¿Acaso obtuvimos lo que se nos prometió?" Diles: ``Todo asunto depende de Dios". Ellos ocultan en sus corazones [la incredulidad] que no te manifiestan. Dicen: ``Si nos hubieran consultado, no habría muertos aquí". Respóndeles: ``Aunque hubieran permanecido en sus hogares, la muerte habría sorprendido en sus lechos a aquellos para los que estaba decretada". Dios quiso probarlos para evidenciar sus verdaderos sentimientos y purificar sus corazones. Dios bien sabe lo que encierran los pechos.\qt@no{154}}
\qt@newcmd\qurantrans@es@cdxlviii{Los que huyeron el día que se enfrentaron los dos ejércitos, fue porque el demonio los sedujo a causa de sus pecados. Pero Dios los perdonó, porque Dios es Perdonador, Indulgente.\qt@no{155}}
\qt@newcmd\qurantrans@es@cdxlix{¡Oh, creyentes! No sean como los que niegan la verdad y dicen de sus hermanos cuando éstos salen de viaje o en una expedición militar [y mueren]: ``Si se hubieran quedado no habrían muerto ni caído en batalla", porque Dios hará que eso sea una angustia en sus corazones. Dios es Quien da la vida y la muerte. Dios ve todo lo que hacen.\qt@no{156}}
\qt@newcmd\qurantrans@es@cdl{Pero si los matan o mueren por la causa de Dios, sepan que el perdón de Dios y Su misericordia son mejores que lo que puedan atesorar.\qt@no{157}}
\qt@newcmd\qurantrans@es@cdli{Tanto si mueren como si caen por la causa de Dios, serán congregados ante Dios.\qt@no{158}}
\qt@newcmd\qurantrans@es@cdlii{[Oh, Mujámmad] Por misericordia de Dios eres compasivo con ellos. Si hubieras sido rudo y de corazón duro se habrían alejado de ti; perdónalos, pide perdón por ellos, y consulta con ellos los asuntos [de interés público]. Pero cuando hayas tomado una decisión encomiéndate a Dios, porque Dios ama a los que se encomiendan a Él.\qt@no{159}}
\qt@newcmd\qurantrans@es@cdliii{Si Dios los auxilia nadie podrá vencerlos. Pero si los abandona, ¿quién podrá auxiliarlos contra Su voluntad? Que a Dios se encomienden los creyentes.\qt@no{160}}
\qt@newcmd\qurantrans@es@cdliv{No es concebible que un Profeta pueda cometer fraude. Quien cometa fraude cargará con ello el Día de la Resurrección. Todos serán retribuidos según sus obras y no serán tratados injustamente.\qt@no{161}}
\qt@newcmd\qurantrans@es@cdlv{¿Acaso es igual quien busca la complacencia de Dios a quien incurre en Su ira? Su destino será el Infierno y qué pésimo fin.\qt@no{162}}
\qt@newcmd\qurantrans@es@cdlvi{Son diferentes ante Dios. Dios ve todo cuanto obran.\qt@no{163}}
\qt@newcmd\qurantrans@es@cdlvii{Dios ha dado Su favor a los creyentes al enviarles un Mensajero de entre ellos mismos que les recita Sus versículos, los purifica y les enseña el Corán y la sabiduría [de la Sunnah]. Porque antes se encontraban en un claro extravío.\qt@no{164}}
\qt@newcmd\qurantrans@es@cdlviii{Ahora que les sobrevino una desgracia, y a pesar de haber causado a sus enemigos el doble, se preguntan a sí mismos: ``¿Por qué fuimos vencidos?" Diles: ``Por su comportamiento". Dios es sobre toda cosa Poderoso.\qt@no{165}}
\qt@newcmd\qurantrans@es@cdlix{Recuerden lo que les aconteció el día que se enfrentaron los dos ejércitos por voluntad de Dios, para distinguir quiénes eran los verdaderos creyentes\qt@no{166}}
\qt@newcmd\qurantrans@es@cdlx{y quiénes los hipócritas, a quienes se les dijo: ``Combatan por la causa de Dios o al menos defiéndanse". Respondieron [mintiendo]: ``Si hubiéramos sabido que habría combate, los hubiéramos seguido". Ese día estuvieron más cerca de la incredulidad que de la fe, porque manifestaban con sus bocas lo que no había en sus corazones. Pero Dios bien sabe lo que ellos ocultaban.\qt@no{167}}
\qt@newcmd\qurantrans@es@cdlxi{Quienes se ausentaron dijeron a sus hermanos: ``Si nos hubieran escuchado, no habrían muerto". Diles: ``Si es verdad lo que dicen, háganse inmunes a la muerte".\qt@no{168}}
\qt@newcmd\qurantrans@es@cdlxii{Pero no crean que quienes han caído defendiendo la causa de Dios están realmente muertos. Por el contrario, están vivos y colmados de gracias junto a su Señor.\qt@no{169}}
\qt@newcmd\qurantrans@es@cdlxiii{Se regocijan por las gracias que Dios les ha concedido y están felices por la recompensa que recibirán quienes todavía no se les han unido, que no sentirán temor ni tristeza.\qt@no{170}}
\qt@newcmd\qurantrans@es@cdlxiv{Se congratulan unos a otros por la gracia y el favor de Dios. Porque Dios recompensa a los creyentes.\qt@no{171}}
\qt@newcmd\qurantrans@es@cdlxv{Quienes acudieron al llamado de Dios y Su Mensajero a pesar de sus heridas [y dificultades], con obediencia y temor a Dios, obtendrán una recompensa magnífica.\qt@no{172}}
\qt@newcmd\qurantrans@es@cdlxvi{A ellos les fue dicho: ``Los enemigos se han agrupado contra ustedes, no podrán con ellos". Pero esto solo les aumentó la fe y dijeron: ``Dios es suficiente para nosotros, porque Él es el mejor protector"\qt@no{173}}
\qt@newcmd\qurantrans@es@cdlxvii{y retornaron ilesos por la gracia y el favor de Dios. Ellos buscaron la complacencia de Dios, y Dios es el poseedor de un favor inmenso.\qt@no{174}}
\qt@newcmd\qurantrans@es@cdlxviii{Así [es la estrategia del] demonio, que intenta atemorizar a quienes lo siguen. Pero no le teman a él, sino que témanme a Mí, si son verdaderamente creyentes.\qt@no{175}}
\qt@newcmd\qurantrans@es@cdlxix{Que no te cause tristeza ver a quienes se precipitan a negar la verdad, porque no perjudican a Dios. Es voluntad de Dios que en la otra vida no obtengan bendición alguna, y sí tengan un castigo terrible.\qt@no{176}}
\qt@newcmd\qurantrans@es@cdlxx{Quienes abandonen la fe y nieguen la verdad, no perjudicarán en nada a Dios, sino que tendrán un castigo doloroso.\qt@no{177}}
\qt@newcmd\qurantrans@es@cdlxxi{Que no piensen los que niegan la verdad que la tolerancia de permitirles seguir con vida significa un bien para ellos. Por el contrario, es para que aumenten sus pecados y luego sufran un castigo humillante.\qt@no{178}}
\qt@newcmd\qurantrans@es@cdlxxii{No es propio de la sabiduría de Dios dejar a los creyentes en la situación en que se encuentran sin distinguir al perverso [hipócrita] del virtuoso [creyente]. Ni es propio de la sabiduría de Dios revelarles el conocimiento oculto [de quiénes son los hipócritas]. Dios elige entre Sus Mensajeros a quien Le place [para revelárselo], así que crean en Dios y Sus Mensajeros, porque si creen y obran rectamente obtendrán una magnífica recompensa.\qt@no{179}}
\qt@newcmd\qurantrans@es@cdlxxiii{Los que mezquinan lo que Dios les ha concedido, que no crean que es un bien para ellos ser avaros. Por el contrario, es un mal. El Día del Juicio Final llevarán colgando de su cuello aquello a lo que con tanta avaricia se aferraron. A Dios pertenece la herencia de cuanto hay en los cielos y la Tierra. Dios está bien informado de lo que hacen.\qt@no{180}}
\qt@newcmd\qurantrans@es@cdlxxiv{Dios ha oído las palabras de quienes dijeron: ``Dios es pobre, mientras que nosotros somos ricos". Registraremos lo que dijeron y también que hayan matado injustamente a los Profetas. Y les diré: ``Sufran el castigo del fuego del Infierno".\qt@no{181}}
\qt@newcmd\qurantrans@es@cdlxxv{Es lo que merecen en retribución por sus obras, porque Dios no es injusto con Sus siervos.\qt@no{182}}
\qt@newcmd\qurantrans@es@cdlxxvi{Ellos mismos son los que dijeron: ``Dios pactó con nosotros que no creyéramos en ningún Mensajero hasta que nos trajera una ofrenda que el fuego consumiera". Diles: ``Antes de mí, otros Mensajeros se les presentaron con las pruebas claras y todas sus exigencias; ¿por qué los mataron entonces, si es cierto lo que dicen?"\qt@no{183}}
\qt@newcmd\qurantrans@es@cdlxxvii{Si te desmienten, también fueron desmentidos anteriormente otros Mensajeros, a pesar de haber traído pruebas claras, Escrituras y Libros Luminosos.\qt@no{184}}
\qt@newcmd\qurantrans@es@cdlxxviii{Todo ser probará el sabor de la muerte, y cada uno recibirá su recompensa íntegra el Día de la Resurrección. Quien sea salvado del Fuego e ingresado al Paraíso habrá realmente triunfado, porque la vida mundanal es solo un placer ilusorio.\qt@no{185}}
\qt@newcmd\qurantrans@es@cdlxxix{Van a ser probados en sus bienes materiales y en sus personas. Oirán ofensas de aquellos que han recibido el Libro antes que ustedes y de los idólatras. Pero tengan paciencia, temor de Dios, y sepan que esto requiere entereza.\qt@no{186}}
\qt@newcmd\qurantrans@es@cdlxxx{[Sabe que] Dios celebró este pacto con la Gente del Libro: ``Deberán explicar el Libro claramente a la gente y jamás ocultarlo". Pero traicionaron el pacto y lo vendieron por vil precio. ¡Qué mal actuaron!\qt@no{187}}
\qt@newcmd\qurantrans@es@cdlxxxi{No creas que quienes se vanaglorian de lo que hacen y aman el elogio por lo que ni siquiera han hecho se salvarán del castigo. Tendrán un castigo doloroso.\qt@no{188}}
\qt@newcmd\qurantrans@es@cdlxxxii{A Dios pertenece el reino de los cielos y de la Tierra. Dios es sobre toda cosa Poderoso.\qt@no{189}}
\qt@newcmd\qurantrans@es@cdlxxxiii{En la creación de los cielos y de la Tierra, y en la sucesión de la noche y el día, hay signos para los dotados de intelecto,\qt@no{190}}
\qt@newcmd\qurantrans@es@cdlxxxiv{que invocan a Dios de pie, sentados o recostados, que meditan en la creación de los cielos y la Tierra y dicen: ``¡Señor nuestro! No has creado todo esto sin un sentido. ¡Glorificado seas! Presérvanos del castigo del Fuego.\qt@no{191}}
\qt@newcmd\qurantrans@es@cdlxxxv{¡Señor nuestro! A quien condenes al Fuego lo habrás deshonrado, porque los opresores no tendrán quién los auxilie.\qt@no{192}}
\qt@newcmd\qurantrans@es@cdlxxxvi{¡Señor nuestro! Hemos oído a quien convocaba a la fe, diciendo: ‘Crean en su Señor’, y creímos. ¡Señor nuestro! Perdona nuestros pecados, borra nuestras malas acciones y, al morir, reúnenos con los piadosos.\qt@no{193}}
\qt@newcmd\qurantrans@es@cdlxxxvii{¡Señor nuestro! Concédenos lo que has prometido a través de Tus Mensajeros y no nos humilles el Día de la Resurrección. Tú no faltas a Tu promesa".\qt@no{194}}
\qt@newcmd\qurantrans@es@cdlxxxviii{Su Señor les respondió sus súplicas diciendo: ``No dejaré de recompensar ninguna de sus obras, sean hombres o mujeres, descienden el uno del otro. A los que emigraron, fueron expulsados de sus hogares, padecieron dificultades por Mi causa, lucharon y cayeron, les perdonaré sus faltas y los introduciré en jardines por donde corren ríos". Ésta es la recompensa que Dios les concederá. Dios posee la más hermosa recompensa.\qt@no{195}}
\qt@newcmd\qurantrans@es@cdlxxxix{No te dejes engañar por la opulencia y los viajes de negocios de los que niegan la verdad,\qt@no{196}}
\qt@newcmd\qurantrans@es@cdxc{porque es solo un disfrute temporal. Pero finalmente su destino será el Infierno. ¡Qué pésima morada!\qt@no{197}}
\qt@newcmd\qurantrans@es@cdxci{En cambio, quienes hayan tenido temor de su Señor vivirán eternamente en jardines por donde corren ríos, es la acogida que Dios les ha preparado. Lo que Dios tiene reservado para los virtuosos es superior al éxito de los incrédulos en esta vida.\qt@no{198}}
\qt@newcmd\qurantrans@es@cdxcii{Entre la Gente del Libro hay quienes creen en Dios y en lo que ha sido revelado a ustedes y a ellos. Son humildes ante Dios, y no venden la palabra de Dios a vil precio. Ellos serán recompensados por su Señor. Dios es rápido en ajustar cuentas.\qt@no{199}}
\qt@newcmd\qurantrans@es@cdxciii{¡Oh, creyentes! Tengan paciencia, perseverancia, defiéndanse y tengan temor de Dios, que así tendrán éxito.\qt@no{200}}
\qt@newcmd\qurantrans@es@cdxciv{\basmalahes ¡Oh, seres humanos! Tengan temor de su Señor, Quien los ha creado de un solo ser, del que creó a su cónyuge e hizo descender de ambos muchos hombres y mujeres. Tengan temor de Dios, en Cuyo nombre se reclaman sus derechos, y respeten los lazos familiares. Dios los observa.\qt@no{1}}
\qt@newcmd\qurantrans@es@cdxcv{Reintegren los bienes materiales a los huérfanos [cuando alcancen la pubertad]. No les cambien lo bueno de ellos por lo malo de ustedes, ni se apropien de los bienes materiales de ellos agregándolos a los de ustedes, porque es un gran pecado.\qt@no{2}}
\qt@newcmd\qurantrans@es@cdxcvi{No se casen con las huérfanas que han criado si temen no ser equitativos [con sus dotes], mejor cásense con otras mujeres que les gusten: dos, tres o cuatro. Pero si temen no ser justos, cásense con una sola o con una esclava, porque es lo mejor para evitar cometer alguna injusticia.\qt@no{3}}
\qt@newcmd\qurantrans@es@cdxcvii{Den a las mujeres la dote con buena predisposición. Pero si ellas renuncian a parte de ella en favor de ustedes, dispongan de ésta como les plazca.\qt@no{4}}
\qt@newcmd\qurantrans@es@cdxcviii{No confíen a los [huérfanos menores de edad que sean] derrochadores los bienes materiales cuya administración Dios les ha confiado. Denles alimentación y vestimenta, y háblenles con cariño.\qt@no{5}}
\qt@newcmd\qurantrans@es@cdxcix{Pongan a prueba la madurez de los huérfanos cuando alcancen la pubertad, y si los consideran maduros y capaces, entréguenles sus bienes. No los derrochen antes de que alcancen la mayoría de edad. El [administrador] que sea rico, que se abstenga [de cobrar honorarios por su administración]; y el pobre que cobre lo mínimo. Cuando les entreguen su patrimonio, háganlo ante testigos. Es suficiente con que Dios les pedirá cuentas.\qt@no{6}}
\qt@newcmd\qurantrans@es@d{A los varones les corresponde un porcentaje de la herencia que dejen los padres y parientes más cercanos, y a las mujeres otro porcentaje de lo que los padres y parientes más cercanos dejen. Fuere poco o mucho, les corresponde [por derecho] un porcentaje determinado de la herencia.\qt@no{7}}
\qt@newcmd\qurantrans@es@di{Si algunos [otros] parientes, huérfanos o pobres, asisten al reparto de la herencia, denles algo y trátenlos con amabilidad.\qt@no{8}}
\qt@newcmd\qurantrans@es@dii{Que [los apoderados de los huérfanos] se preocupen [por ellos] igual que si dejasen tras de sí a sus propios hijos menores huérfanos y temiesen por ellos. Que tengan temor de Dios y digan la verdad.\qt@no{9}}
\qt@newcmd\qurantrans@es@diii{Quienes se apropien injustamente de los bienes de los huérfanos, estarán llenando sus entrañas con fuego y arderán en el Infierno.\qt@no{10}}
\qt@newcmd\qurantrans@es@div{Dios prescribe respecto a [la herencia de] sus hijos: Al varón le corresponde lo mismo que a dos mujeres. Si las hermanas son más de dos, les corresponderán dos tercios de la herencia. Si es hija única, le corresponde la mitad. A cada uno de los padres [del difunto] le corresponderá un sexto, si deja hijos; pero si no tiene hijos y le heredan solo sus padres, un tercio es para la madre. Si tiene hermanos, un sexto es lo que corresponde para la madre. Esto luego de cumplir con sus legados y pagar sus deudas. Ustedes ignoran quiénes tienen más derecho al beneficio de la herencia, si sus padres o sus hijos, de ahí este precepto de Dios. Dios es Sabio, todo lo sabe.\qt@no{11}}
\qt@newcmd\qurantrans@es@dv{A los hombres les corresponde la mitad de lo que dejaran sus esposas si no tuvieran hijos. Si tuvieran hijos les corresponde un cuarto, luego de cumplir con sus legados y pagar sus deudas. Si no tuvieran hijos, a las mujeres les corresponde un cuarto de lo que dejaran. Si tuvieran hijos, entonces un octavo de lo que dejaran, luego de cumplir con sus legados y pagar las deudas. Si [el difunto] no tiene padres ni hijos, pero sí un hermano o una hermana, entonces les corresponde a cada uno de ellos un sexto. Si son más, participarán del tercio de la herencia, luego de cumplir con los legados y pagar las deudas, siempre que los legados no causen perjuicio a los herederos. Esto es un precepto de Dios. Dios es Sabio, Generoso.\qt@no{12}}
\qt@newcmd\qurantrans@es@dvi{Estas son las leyes de Dios. A quien obedezca a Dios y a Su Mensajero, Él lo introducirá en jardines donde corren ríos, donde vivirá por toda la eternidad. Éste es el éxito supremo.\qt@no{13}}
\qt@newcmd\qurantrans@es@dvii{Pero a quien desobedezca a Dios y a Su Mensajero y no cumpla con Sus leyes, Él lo introducirá en el Infierno donde morará por toda la eternidad y sufrirá un castigo humillante.\qt@no{14}}
\qt@newcmd\qurantrans@es@dviii{Si una mujer es acusada de fornicación, deben declarar en su contra cuatro testigos [presenciales del acto]. Si los testigos confirman el hecho, condénenlas a reclusión perpetua en sus casas o hasta que Dios les conceda otra salida.\qt@no{15}}
\qt@newcmd\qurantrans@es@dix{El castigo se aplica a los dos que lo cometen [hombre y mujer]. Pero cuando se arrepientan y enmienden, déjenlos en paz. Dios es Indulgente, Misericordioso.\qt@no{16}}
\qt@newcmd\qurantrans@es@dx{Dios solo perdona a quienes cometen el mal por ignorancia y se arrepienten antes de morir. A éstos Dios los absuelve porque es Sabio y todo lo sabe.\qt@no{17}}
\qt@newcmd\qurantrans@es@dxi{Mas no serán perdonados quienes sigan obrando mal [por rebeldía contra Dios] hasta que los sorprenda la muerte y recién entonces digan: ``Ahora me arrepiento". Ni tampoco quienes mueran negando la verdad; a éstos les tenemos reservado un castigo doloroso.\qt@no{18}}
\qt@newcmd\qurantrans@es@dxii{¡Oh, creyentes! Quedan abolidas las costumbres [paganas preislámicas] de heredar a las mujeres como un objeto y de obligarlas a casarse y retenerlas por la fuerza para recuperar parte de lo que les habían dado, a menos que ellas cometan un acto de inmoralidad. En lugar de eso, traten amablemente a las mujeres en la convivencia. Y si algo de ellas les llegara a disgustar [sean tolerantes], puede ser que les desagrade algo en lo que Dios ha puesto un bien para ustedes.\qt@no{19}}
\qt@newcmd\qurantrans@es@dxiii{Y si te decides a divorciarte de tu esposa, a la que has dado una fortuna como dote, para casarte con otra [mujer], no le pidas que te devuelva nada de su dote. ¿Acaso pensabas hacerlo calumniándola, cometiendo un claro delito?\qt@no{20}}
\qt@newcmd\qurantrans@es@dxiv{¿Acaso pretendes que se te devuelva [la dote] después de haberse entregado uno al otro [en la intimidad] a través de un solemne contrato matrimonial?\qt@no{21}}
\qt@newcmd\qurantrans@es@dxv{Salvo hechos consumados, les está prohibido casarse con las exesposas de sus padres, porque es algo obsceno, aborrecible e inmoral.\qt@no{22}}
\qt@newcmd\qurantrans@es@dxvi{Se prohíbe contraer matrimonio con sus madres, hijas, hermanas, tías, sobrinas por parte de hermano o de hermana, madres de leche, hermanas de leche, sus suegras, hijastras que están bajo su tutela nacidas de esposas con las que han consumado el matrimonio; pero si no han consumado el matrimonio, no incurren en falta al casarse con ellas. Salvo en casos consumados, también se prohíbe la nuera y casarse con dos hermanas a la vez. Dios es Perdonador, Misericordioso.\qt@no{23}}
\qt@newcmd\qurantrans@es@dxvii{Las mujeres decentes y honestas son prohibidas, excepto que sea tomando su mano a través de un contrato de matrimonio. Esta es la ley de Dios. Fuera de las prohibiciones, es lícito que busquen casarse pagando la dote correspondiente, pero con intensión de matrimonio y no de fornicar. Es una obligación dar a la mujer la dote convenida una vez consumado el matrimonio. Pero no incurren en falta si después de haber cumplido con esta obligación legal, deciden algo distinto de mutuo acuerdo. Dios es Sabio, todo lo sabe.\qt@no{24}}
\qt@newcmd\qurantrans@es@dxviii{Quien no disponga de los medios necesarios para casarse con una creyente libre, podrá hacerlo con una esclava creyente. Dios conoce bien la fe de ustedes, y todos proceden de un mismo ser. Cásense con ellas con el permiso de sus tutores, y denles la dote legítima y de buen grado. Tómenlas como mujeres honestas, no como fornicadoras o amantes. Si estas mujeres se casan y cometen una deshonestidad, se les aplicará la mitad del castigo que a las mujeres libres. Esto es para los que teman caer en la fornicación, pero tener paciencia es mejor. Dios es Absolvedor, Misericordioso.\qt@no{25}}
\qt@newcmd\qurantrans@es@dxix{Dios quiere aclararles la ley, mostrarles el camino correcto de quienes los precedieron, y perdonarlos. Dios todo lo sabe, es Sabio.\qt@no{26}}
\qt@newcmd\qurantrans@es@dxx{Dios quiere perdonarlos, mientras que quienes siguen sus pasiones solo quieren extraviarlos lejos del camino recto.\qt@no{27}}
\qt@newcmd\qurantrans@es@dxxi{Dios facilita las cosas, ya que el ser humano fue creado con una naturaleza débil.\qt@no{28}}
\qt@newcmd\qurantrans@es@dxxii{¡Oh, creyentes! No estafen ni usurpen injustamente, sino que comercien de mutuo acuerdo. No se maten a ustedes mismos. Dios es Misericordioso con ustedes.\qt@no{29}}
\qt@newcmd\qurantrans@es@dxxiii{Quien quebrante estas leyes agresiva e injustamente, terminará en el Fuego. Eso es fácil para Dios.\qt@no{30}}
\qt@newcmd\qurantrans@es@dxxiv{Si se apartan de los pecados más graves, perdonaré sus faltas menores y los introduciré con honra en el Paraíso.\qt@no{31}}
\qt@newcmd\qurantrans@es@dxxv{No codicien lo que Dios ha concedido a unos más que a otros. Los hombres obtendrán una recompensa conforme a sus méritos, y las mujeres obtendrán una recompensa conforme a sus méritos. Rueguen a Dios para que les conceda de Sus favores. Dios conoce todas las cosas.\qt@no{32}}
\qt@newcmd\qurantrans@es@dxxvi{Cada uno de ustedes tiene derecho a heredar de lo que dejen sus padres y sus parientes más cercanos. Aquellos con quienes hayan celebrado un pacto, también tienen derecho a heredar. Dios es testigo de todas las cosas.\qt@no{33}}
\qt@newcmd\qurantrans@es@dxxvii{Los hombres son responsables del cuidado de las mujeres debido a las diferencias [físicas] que Dios ha puesto entre ellos, y por su obligación de mantenerlas con sus bienes materiales. Las mujeres piadosas e íntegras obedecen a Dios y en ausencia de su marido se mantienen fieles, tal como Dios manda. A aquellas de quienes teman maltrato y animadversión, exhórtenlas, tomen distancia no compartiendo el lecho, y por último pongan un límite físico; si les obedecen [en lo que Dios ordena], no les reclamen ni recriminen más. Dios es Sublime, Grande.\qt@no{34}}
\qt@newcmd\qurantrans@es@dxxviii{Si temen la ruptura del matrimonio, apelen a un mediador de la familia de él y otro de la familia de ella. Si tienen el deseo íntimo de reconciliarse, Dios los ayudará a llegar a un acuerdo. Dios todo lo sabe y está bien informado.\qt@no{35}}
\qt@newcmd\qurantrans@es@dxxix{Adoren solamente a Dios y no dediquen actos de adoración a otros. Hagan el bien a sus padres, a sus familiares, a los huérfanos, a los pobres, a los vecinos parientes y no parientes, al compañero, al viajero insolvente y a quienes están a su servicio. Dios no ama a quien se comporta como un arrogante jactancioso.\qt@no{36}}
\qt@newcmd\qurantrans@es@dxxx{Que los avaros, los que incitan a otros a la avaricia, y los que ocultan el favor que Dios les ha concedido, sepan que Dios ha preparado para los ingratos un castigo humillante.\qt@no{37}}
\qt@newcmd\qurantrans@es@dxxxi{También para los que hacen caridad solo para ser vistos por la gente, y no creen [de corazón] en Dios ni en el Día del Juicio Final. ¡Quien tome al demonio por compañero, qué pésimo es su consejero!\qt@no{38}}
\qt@newcmd\qurantrans@es@dxxxii{¿Qué les habría costado creer en Dios y en el Día del Juicio y dar caridades de aquello que Dios les concedió? Dios los conoce perfectamente.\qt@no{39}}
\qt@newcmd\qurantrans@es@dxxxiii{Dios no es injusto con nadie ni en el peso de la más ínfima partícula. Por el contrario, retribuye generosamente toda obra de bien, y concede de Su parte una recompensa magnánima.\qt@no{40}}
\qt@newcmd\qurantrans@es@dxxxiv{¿Qué pasará cuando traiga a un testigo de cada comunidad y te traiga a ti [¡oh, Mujámmad!] como testigo contra los que niegan la verdad [y las gracias de Dios]?\qt@no{41}}
\qt@newcmd\qurantrans@es@dxxxv{Ese día, los que negaron la verdad y se opusieron al Mensajero, querrán que la tierra se los trague. No podrán ocultar ni una de sus palabras ante Dios.\qt@no{42}}
\qt@newcmd\qurantrans@es@dxxxvi{¡Oh, creyentes! No hagan la oración si están bajo el efecto de embriagantes [o narcóticos] hasta que sepan lo que están diciendo. Tampoco [hagan la oración] si están impuros hasta que se hayan bañado, excepto quien solo necesite pasar por la mezquita. Pero si se encuentran enfermos o de viaje, o si han hecho sus necesidades o han tenido relación sexual con su mujer y no encuentran agua [para la ablución], busquen tierra limpia y pásensela por el rostro y las manos. Dios es Remisorio, Absolvedor.\qt@no{43}}
\qt@newcmd\qurantrans@es@dxxxvii{¿No te asombra el caso de quienes recibieron algo de la revelación pero la cambiaron por el extravío? Ellos anhelan que ustedes también se desvíen del camino recto.\qt@no{44}}
\qt@newcmd\qurantrans@es@dxxxviii{Dios conoce bien a los enemigos de ustedes. Dios es suficiente como Protector y Socorredor.\qt@no{45}}
\qt@newcmd\qurantrans@es@dxxxix{Algunos judíos tergiversan el sentido de las palabras sacándolas de contexto, como cuando dicen: ``Te oímos [y al mismo tiempo les dicen a otros], pero no te seguiremos en nada de lo que digas". [O como cuando dicen:] ``Óyenos tú, que no aceptamos oírte". Te llaman con doble sentido en sus palabras ofendiendo la religión [de Dios]. Si hubieran dicho: ``Te oímos y te seguiremos. Escúchanos y sé paciente con nosotros", sería mejor para ellos y más correcto. Pero Dios los alejó de Su misericordia por negarse a aceptar la verdad, poco es lo que creen.\qt@no{46}}
\qt@newcmd\qurantrans@es@dxl{¡Oh, Gente del Libro! Crean en lo que he revelado ahora, que confirma lo que ya tenían [de la verdad], antes de que borre los rasgos de su identidad y terminen en su propia perdición, o los maldiga como maldije a los que profanaron el sábado. Lo que Dios dispone es ineludible.\qt@no{47}}
\qt@newcmd\qurantrans@es@dxli{Dios no perdona la idolatría, pero fuera de ello perdona a quien Le place. Quien asocie algo a Dios comete un pecado gravísimo.\qt@no{48}}
\qt@newcmd\qurantrans@es@dxlii{¿No has visto a los que se jactan de puritanos? En realidad es Dios Quien concede la pureza [librando del egocentrismo] a quien Le place. Nadie será tratado injustamente [en cuanto a la recompensa que sus obras merezcan].\qt@no{49}}
\qt@newcmd\qurantrans@es@dxliii{Observa cómo inventan mentiras y las atribuyen a Dios. Eso es en sí mismo un pecado evidente.\qt@no{50}}
\qt@newcmd\qurantrans@es@dxliv{¿Acaso no te sorprende que quienes habiendo recibido algo de la revelación, siguen la hechicería y a los demonios y dicen sobre los idólatras: ``Ellos están mejor guiados que los creyentes"?\qt@no{51}}
\qt@newcmd\qurantrans@es@dxlv{Ellos fueron apartados de la misericordia de Dios, y a quien Dios aparta de Su misericordia no tendrá quién lo socorra.\qt@no{52}}
\qt@newcmd\qurantrans@es@dxlvi{¿Acaso comparten [con Dios] la soberanía? [No la tienen, pero] si la tuvieran, no darían lo más mínimo a la gente [debido a su avaricia].\qt@no{53}}
\qt@newcmd\qurantrans@es@dxlvii{¿Es que envidian a la gente porque Dios les ha concedido de Su favor? Porque concedí a la familia de Abraham el Libro y la sabiduría, y les he concedido un dominio inmenso.\qt@no{54}}
\qt@newcmd\qurantrans@es@dxlviii{Entre ellos hay quienes creyeron y quienes los combatieron. [A estos últimos] el Infierno les bastará como castigo.\qt@no{55}}
\qt@newcmd\qurantrans@es@dxlix{A quienes nieguen la revelación los arrojaré al Fuego. Cada vez que se les queme la piel, se la cambiaré por otra nueva para que continúen sufriendo el castigo. Dios es Poderoso, Sabio.\qt@no{56}}
\qt@newcmd\qurantrans@es@dl{[En cambio] los creyentes que obren correctamente estarán en jardines por donde corren ríos, en los que morarán eternamente, donde tendrán esposas purificadas bajo buena sombra.\qt@no{57}}
\qt@newcmd\qurantrans@es@dli{Dios les ordena que restituyan a sus dueños originales lo que se les haya confiado, y que cuando juzguen entre las personas lo hagan con equidad. ¡Qué excelente es aquello a lo que Dios los convoca! Dios todo lo oye, todo lo ve.\qt@no{58}}
\qt@newcmd\qurantrans@es@dlii{¡Oh, creyentes! Obedezcan a Dios, obedezcan al Mensajero y a aquellos de ustedes que tengan autoridad y conocimiento. Si realmente creen en Dios y en el Día del Juicio, cuando tengan discrepancias remítanlas al juicio de Dios y del Mensajero, porque en ello hay bien y es el camino correcto.\qt@no{59}}
\qt@newcmd\qurantrans@es@dliii{¿No te causan asombro quienes dicen creer en lo que se te ha revelado y en lo que había sido revelado anteriormente, y sin embargo recurren a la justicia de quienes gobiernan con principios injustos y paganos, a pesar de que se les ha ordenado no creer en eso? El demonio solo quiere que se pierdan lejos [de la fe monoteísta].\qt@no{60}}
\qt@newcmd\qurantrans@es@dliv{Cuando se les dice: ``Acepten lo que Dios ha revelado y las enseñanzas del Mensajero", ves a los hipócritas apartarse de ti con aversión.\qt@no{61}}
\qt@newcmd\qurantrans@es@dlv{¿Qué será de ellos cuando los aflija una desgracia por lo que hicieron y vengan a ti jurando por Dios: ``Solo intentábamos hacer el bien y ayudar"?\qt@no{62}}
\qt@newcmd\qurantrans@es@dlvi{Dios sabe lo que encierran sus corazones. Apártate de ellos, exhórtalos y amonéstalos sobre la gravedad de lo que hicieron.\qt@no{63}}
\qt@newcmd\qurantrans@es@dlvii{Hemos enviado a los Mensajeros para que sean obedecidos con el permiso de Dios. Si [los hipócritas] después de haber cometido esas injusticias hubieran recurrido a ti, se hubieran arrepentido ante Dios, y el Mensajero hubiera pedido perdón por ellos, habrían comprobado que Dios es Indulgente, Misericordioso.\qt@no{64}}
\qt@newcmd\qurantrans@es@dlviii{Pero no, [juro] por tu Señor que no creerán [realmente] a menos que te acepten como juez de sus disputas, y no se resistan a aceptar tu decisión y se sometan completamente.\qt@no{65}}
\qt@newcmd\qurantrans@es@dlix{Si les hubiera prescrito que sacrificaran sus vidas o que abandonaran sus hogares, no lo habrían hecho, salvo unos pocos. Pero si hubieran cumplido con lo que se les ordenó, habría sido mejor para ellos y les habría fortalecido la fe,\qt@no{66}}
\qt@newcmd\qurantrans@es@dlx{les habría concedido una magnífica recompensa,\qt@no{67}}
\qt@newcmd\qurantrans@es@dlxi{y los habría guiado por el sendero recto.\qt@no{68}}
\qt@newcmd\qurantrans@es@dlxii{Los que obedezcan a Dios y al Mensajero estarán con los bienaventurados: los Profetas, los veraces, los que murieron dando testimonio [de su fe] y los justos. ¡Qué excelentes compañeros!\qt@no{69}}
\qt@newcmd\qurantrans@es@dlxiii{Esa es la generosidad de Dios. Y Dios es el único que todo lo sabe.\qt@no{70}}
\qt@newcmd\qurantrans@es@dlxiv{¡Oh, creyentes! Tomen precaución. Salgan en grupos o todos juntos [en defensa del Islam y la verdad].\qt@no{71}}
\qt@newcmd\qurantrans@es@dlxv{Habrá entre ustedes quien se rezague, y si sufren un revés dirá: ``Dios me ha concedido la gracia de no estar con ellos".\qt@no{72}}
\qt@newcmd\qurantrans@es@dlxvi{Pero si por la gracia de Dios alcanzan la victoria, dirá como si no hubiera amistad entre ustedes: ``¡Ojalá hubiera estado con ellos!, así habría obtenido un éxito grandioso".\qt@no{73}}
\qt@newcmd\qurantrans@es@dlxvii{Que luchen por la causa de Dios quienes son capaces de sacrificar la vida mundanal por la otra. Pues a quien luche por la causa de Dios, sea que caiga abatido o que obtenga la victoria, le daré una magnífica recompensa.\qt@no{74}}
\qt@newcmd\qurantrans@es@dlxviii{¿Qué les impide combatir por la causa de Dios, siendo que hay hombres, mujeres y niños oprimidos que imploran: ``¡Señor nuestro! Sácanos de esta ciudad de opresores. Concédenos, por Tu gracia, quién nos proteja y socorra"?\qt@no{75}}
\qt@newcmd\qurantrans@es@dlxix{Los creyentes combaten por la causa de Dios. Los incrédulos, en cambio, combaten por la de los ídolos y la injusticia. ¡Combatan a los secuaces del demonio, y [sepan que] las artimañas del demonio son débiles!\qt@no{76}}
\qt@newcmd\qurantrans@es@dlxx{¿Acaso no te sorprende la actitud de aquellos a quienes se les dijo: ``No tienen permiso para combatir ahora, sino que cumplan la oración y hagan caridades?" Pero cuando se les llamó a combatir, algunos de ellos temieron a la gente como se debe temer a Dios o aún más, y dijeron: ``¡Señor nuestro! ¿Por qué nos llamas a combatir? Si lo dejaras para más tarde…". Diles: ``El goce de la vida mundanal es pasajero; en cambio, la otra vida es superior para los piadosos, en la que no serán tratados injustamente en lo más mínimo.\qt@no{77}}
\qt@newcmd\qurantrans@es@dlxxi{La muerte los alcanzará donde quiera que se encuentren, aunque se refugien en fortalezas inexpugnables. Si les acontece algo bueno dicen: ``Esto proviene de Dios". Pero si los alcanza un perjuicio dicen: ``Esto es a causa de ti [¡oh, Mujámmad!]". Diles: ``Todo proviene de Dios". ¿Qué le sucede a esta gente que no comprenden lo que se les dice?\qt@no{78}}
\qt@newcmd\qurantrans@es@dlxxii{Todo bien que te alcance proviene de Dios, mientras que todo mal que te aflija es consecuencia de tus propias obras. Te he enviado [¡oh, Mujámmad!] como Mensajero a todas las personas. Dios es suficiente testigo.\qt@no{79}}
\qt@newcmd\qurantrans@es@dlxxiii{Quien obedezca al Mensajero obedece a Dios. Pero no te he enviado como custodio de quien te rechace.\qt@no{80}}
\qt@newcmd\qurantrans@es@dlxxiv{[Los hipócritas] te juran obediencia, pero cuando salen de tu presencia, un grupo de ellos pasa la noche tramando contradecirte. Dios registra lo que traman. Aléjate de ellos y encomiéndate a Dios, porque Dios te es suficiente como protector.\qt@no{81}}
\qt@newcmd\qurantrans@es@dlxxv{¿Acaso no reflexionan en el Corán y sus significados? Si no procediera de Dios encontrarían en él numerosas contradicciones.\qt@no{82}}
\qt@newcmd\qurantrans@es@dlxxvi{Cuando escuchan un rumor que pudiere atentar contra la seguridad y sembrar el temor, lo divulgan inmediatamente. Pero lo que debían hacer era remitirlo al Mensajero y a quienes tienen autoridad y conocimiento, que son quienes pueden investigar la información y comprender su magnitud, y sabrían qué hacer. Si no fuera por el favor y la misericordia de Dios para con ustedes, habrían seguido la voluntad del demonio, salvo algunos pocos.\qt@no{83}}
\qt@newcmd\qurantrans@es@dlxxvii{Lucha por la causa de Dios, tú solo eres responsable por ti mismo. Exhorta a los creyentes a combatir; puede que Dios detenga el hostigamiento de los que niegan la verdad, pues Dios tiene mayor poderío y fuerza de disuasión.\qt@no{84}}
\qt@newcmd\qurantrans@es@dlxxviii{Quien interceda por una causa justa obtendrá parte de la recompensa [de Dios], y quien interceda por una causa injusta obtendrá parte del pecado [que implica]. Dios tiene poder sobre todas las cosas.\qt@no{85}}
\qt@newcmd\qurantrans@es@dlxxix{Si los saludan respondan con un saludo igual o mejor. Dios tiene en cuenta todas las cosas.\qt@no{86}}
\qt@newcmd\qurantrans@es@dlxxx{Dios, nadie merece ser adorado sino Él. [Dios] los reunirá el Día del Juicio sobre el cual no hay duda que sucederá. ¿Y qué es más veraz que la palabra de Dios?\qt@no{87}}
\qt@newcmd\qurantrans@es@dlxxxi{[Creyentes,] ¿Por qué se dividen respecto a los hipócritas? Dios ha designado Su desvío a causa de su desobediencia. ¿Acaso intentan guiar a quien Dios extravió? Quien ha sido desviado por Dios no tiene salvación.\qt@no{88}}
\qt@newcmd\qurantrans@es@dlxxxii{[Los hipócritas] quieren que ustedes rechacen la verdad, tal como ellos hicieron. No se alíen con ellos hasta que hayan emigrado por la causa de Dios [demostrando su fe]. Pero si se vuelven [abiertamente] hostiles, aprésenlos y ajustícienlos donde quiera que los encuentren. No los tomen jamás por aliados ni confidentes\qt@no{89}}
\qt@newcmd\qurantrans@es@dlxxxiii{salvo a quienes busquen asilo en un pueblo con el que tengan un pacto [de no agresión], o con aquellos que están apesadumbrados por tener que combatirlos o combatir a su propia gente. [A ellos no los combatan porque] si Dios hubiera querido, les habría otorgado valor de combatir contra ustedes. Si ellos los dejan tranquilos y no los combaten y proponen la paz, sepan que Dios no los autoriza a agredirlos.\qt@no{90}}
\qt@newcmd\qurantrans@es@dlxxxiv{Pero encontrarán a otro grupo que desea estar a salvo de ustedes [aparentando ser creyentes] y a salvo de su gente [manifestando la incredulidad que hay en sus corazones]. Cada vez que su pueblo los incita a combatir contra ustedes se precipitan a agredirlos. A estos, si no dan la palabra de que no combatirán contra ustedes, proponen la paz y contienen la agresión, aprésenlos y ajustícienlos [en el curso del combate] donde quiera que los encuentren. A ellos se les permite combatirlos.\qt@no{91}}
\qt@newcmd\qurantrans@es@dlxxxv{No es propio de un creyente matar a otro creyente, salvo que sea por accidente. Quien mate a un creyente accidentalmente deberá liberar a un esclavo creyente y pagar una indemnización a la familia de la víctima, a menos que ésta la condone. Si [quien muere accidentalmente] era creyente y pertenecía a un pueblo enemigo, [el que causó la muerte accidental] deberá liberar un esclavo creyente. Pero si pertenecía a un pueblo con el que se tiene un pacto [de no agresión], deberá pagarle la indemnización a la familia de la víctima y liberar a un esclavo creyente. Y quien no esté en condiciones [económicas] de hacerlo [o no encuentre,] deberá ayunar dos meses consecutivos para alcanzar el perdón de Dios. Dios todo lo sabe, es Sabio.\qt@no{92}}
\qt@newcmd\qurantrans@es@dlxxxvi{Quien asesine a un creyente con premeditación será condenado a permanecer eternamente en el Infierno, además caerá en la ira de Dios, y recibirá Su maldición y un castigo terrible.\qt@no{93}}
\qt@newcmd\qurantrans@es@dlxxxvii{¡Oh, creyentes! Cuando salgan a combatir por la causa de Dios, asegúrense de no combatir contra los creyentes, y no digan a quien los saluda con la paz [expresando su Islam]: ``¡Tú no eres creyente!", para así combatirlo y conseguir algo de los bienes perecederos de la vida mundanal, pues junto a Dios hay grandes botines. Ustedes eran así [en la época pagana], pero Dios los agració [con el Islam]. Usen su discernimiento, porque Dios está bien informado de lo que hacen.\qt@no{94}}
\qt@newcmd\qurantrans@es@dlxxxviii{Los creyentes que permanecieron pasivos [ante la llamada a luchar por la justicia y la seguridad] no pueden ser equiparados con quienes combatieron por la causa de Dios con sus bienes y sus vidas, excepto los que tengan excusa válida. Dios considera superiores a quienes combaten [por la justicia] con sus bienes y sus vidas, por sobre quienes permanecen pasivos [ante la injusticia]. Pero a todos Dios ha prometido un buen fin [el Paraíso], aunque Dios ha preferido conceder una recompensa más grandiosa a quienes lucharon que a quienes no lo hicieron.\qt@no{95}}
\qt@newcmd\qurantrans@es@dlxxxix{Son grados que Él concede, junto con Su perdón y misericordia. Dios es Indulgente y Misericordioso.\qt@no{96}}
\qt@newcmd\qurantrans@es@dxc{Aquellos que mueran siendo injustos consigo mismos [cometiendo pecados influenciados por la sociedad pagana], los ángeles al tomar sus almas les preguntaran: ``¿Qué les pasó?" Responderán: ``Nos sentíamos débiles y oprimidos [por los incrédulos]". Les dirán: ``¿Acaso la tierra de Dios no era suficientemente vasta como para que emigraran [a otra sociedad]?" Su morada será el Infierno. ¡Qué mal fin!\qt@no{97}}
\qt@newcmd\qurantrans@es@dxci{Excepto los hombres, mujeres y niños débiles que no eran capaces [de emigrar] ni les fue mostrado el camino recto.\qt@no{98}}
\qt@newcmd\qurantrans@es@dxcii{A ellos Dios los perdonará, porque Dios es Remisorio, Indulgente.\qt@no{99}}
\qt@newcmd\qurantrans@es@dxciii{Quien emigre por la causa de Dios encontrará en la Tierra muchos lugares para refugiarse y también sustento. A quien emigre de su hogar por la causa de Dios y la de Su Mensajero, pero lo sorprenda la muerte [antes de llegar a su destino], sepa que Dios le garantiza Su recompensa. Dios es Absolvedor, Misericordioso.\qt@no{100}}
\qt@newcmd\qurantrans@es@dxciv{Cuando estén de viaje o si temen que los agredan los que niegan la verdad, que son sus enemigos, no incurren en falta si abrevian la oración.\qt@no{101}}
\qt@newcmd\qurantrans@es@dxcv{Cuando estés con ellos [¡oh, Mujámmad! en el campo de batalla] y establezcas la oración, que un grupo permanezca de pie contigo tomando las armas. Cuando hagan la prosternación, que ellos se pongan detrás; luego el grupo que aún no haya orado se adelante y ore contigo, tomando precauciones y portando sus armas. Los [enemigos] que niegan la verdad desean que descuiden sus armas para atacarlos sorpresivamente. No cometen falta alguna si la lluvia los molesta o están enfermos y dejan las armas [mientras rezan], pero tomen precauciones. Dios ha reservado un castigo denigrante para los que niegan la verdad.\qt@no{102}}
\qt@newcmd\qurantrans@es@dxcvi{Cuando hayan terminado la oración recuerden a Dios de pie, sentados o recostados. Y cuando estén fuera de peligro hagan la oración [normalmente]. La oración ha sido prescrita a los creyentes para ser realizada en horarios específicos.\qt@no{103}}
\qt@newcmd\qurantrans@es@dxcvii{No se desanimen en la lucha contra ese pueblo [de opresores], porque así como ustedes tienen dificultades, ellos también las tienen. Pero ustedes anhelan [una recompensa] de Dios que ellos no pueden esperar. Dios todo lo sabe, es Sabio.\qt@no{104}}
\qt@newcmd\qurantrans@es@dxcviii{Te he revelado el Libro que contiene la verdad para que juzgues entre la gente con lo que Dios te ha enseñado. No seas abogado de los hipócritas.\qt@no{105}}
\qt@newcmd\qurantrans@es@dxcix{Pide perdón a Dios, porque Dios es Perdonador, Misericordioso.\qt@no{106}}
\qt@newcmd\qurantrans@es@dc{Pero no intentes justificar la conducta de quienes son desleales consigo mismos. Dios no ama a quien traiciona y comete injusticias.\qt@no{107}}
\qt@newcmd\qurantrans@es@dci{[Los hipócritas] pueden engañar a la gente, pero no pueden engañar a Dios, porque Él está con ellos cuando pasan la noche tramando lo que no Le complace. Dios bien sabe cuanto hacen.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcii{[Creyentes,] pueden defenderlos en esta vida; pero, ¿quién los defenderá de Dios el Día de la Resurrección? Y, ¿quién abogará por ellos?\qt@no{109}}
\qt@newcmd\qurantrans@es@dciii{Quien obre mal o sea injusto consigo mismo, pero pida perdón a Dios, encontrará que Dios es Perdonador, Misericordioso.\qt@no{110}}
\qt@newcmd\qurantrans@es@dciv{Quien cometa una falta, en realidad lo hace en su propio perjuicio. Dios todo lo sabe, es Sabio.\qt@no{111}}
\qt@newcmd\qurantrans@es@dcv{Quien cometa una falta o un delito y acuse de ello a un inocente, cargará con su calumnia y con un pecado manifiesto.\qt@no{112}}
\qt@newcmd\qurantrans@es@dcvi{Si no fuera por el favor [de la infalibilidad] y la misericordia de Dios contigo [oh, Mujámmad], un grupo [de los hipócritas] te habría extraviado; pero solo se extravían a sí mismos y en nada pueden perjudicarte. Dios te ha revelado el Libro [el Corán] y la sabiduría [la Sunnah] y te ha enseñado lo que no sabías. ¡El favor de Dios sobre ti es inmenso!\qt@no{113}}
\qt@newcmd\qurantrans@es@dcvii{En la mayoría de las conversaciones secretas no hay ningún bien, excepto las que sean para coordinar una ayuda social, hacer una buena acción o reconciliar entre las personas. A quien lo haga anhelando complacer a Dios, lo agraciaré con una grandiosa recompensa.\qt@no{114}}
\qt@newcmd\qurantrans@es@dcviii{Quien se aparte de las enseñanzas del Mensajero después de habérsele evidenciado la guía, y siga otro camino distinto al de los creyentes, lo abandonaré y lo ingresaré al Infierno. ¡Y qué mal destino!\qt@no{115}}
\qt@newcmd\qurantrans@es@dcix{Dios no perdona la idolatría, pero perdona, fuera de ello, a quien Le place. Quien atribuya actos de adoración a otros además de Dios se habrá desviado profundamente [del camino de los Profetas].\qt@no{116}}
\qt@newcmd\qurantrans@es@dcx{[Los paganos] invocan en vez de Dios a deidades femeninas. En realidad solo invocan a un demonio rebelde.\qt@no{117}}
\qt@newcmd\qurantrans@es@dcxi{Dios maldijo al demonio, pero éste replicó: ``Seduciré a la mayoría de Tus siervos,\qt@no{118}}
\qt@newcmd\qurantrans@es@dcxii{los desviaré, les daré falsas expectativas, les ordenaré cortar las orejas del ganado [marcándolas como ofrenda para los ídolos] y que alteren la naturaleza de la creación de Dios". Quien tome al demonio como aliado en lugar de Dios estará evidentemente perdido.\qt@no{119}}
\qt@newcmd\qurantrans@es@dcxiii{Les hará falsas promesas y les dará esperanzas; el demonio no hace sino engañar.\qt@no{120}}
\qt@newcmd\qurantrans@es@dcxiv{Su morada será el Infierno del que no encontrarán escapatoria.\qt@no{121}}
\qt@newcmd\qurantrans@es@dcxv{[En cambio] a los creyentes que obren rectamente los ingresaré en jardines donde corren ríos, en los que vivirán por toda la eternidad. La promesa de Dios es auténtica. ¿Qué palabra es más verídica que la palabra de Dios?\qt@no{122}}
\qt@newcmd\qurantrans@es@dcxvi{No se trata de lo que ustedes deseen o lo que desee la Gente del Libro. Quien haya obrado mal será retribuido por ello, y no encontrará fuera de Dios protector ni socorredor.\qt@no{123}}
\qt@newcmd\qurantrans@es@dcxvii{Al creyente que haga obras de bien, sea hombre o mujer, lo ingresaré al Paraíso y no será privado de su recompensa en lo más mínimo.\qt@no{124}}
\qt@newcmd\qurantrans@es@dcxviii{¿Quién practica una religión mejor que aquel que entrega su voluntad a Dios, hace el bien y sigue la creencia monoteísta de Abraham? Dios tomó a Abraham como uno de Sus siervos más amados.\qt@no{125}}
\qt@newcmd\qurantrans@es@dcxix{A Dios pertenece cuanto hay en los cielos y en la Tierra. El conocimiento de Dios todo lo abarca.\qt@no{126}}
\qt@newcmd\qurantrans@es@dcxx{Te preguntan acerca de las mujeres. Diles: ``Dios les responde y explica lo que se encuentra mencionado en el Libro [el Corán] sobre las huérfanas a las que no han dado lo que les corresponde [como dote] siendo que les gustaría casarse con ellas, [así como les informa] acerca de los menores indefensos y [la obligación de] ser equitativos con los huérfanos. Sepan que toda obra de bien que hagan Dios la conoce.\qt@no{127}}
\qt@newcmd\qurantrans@es@dcxxi{Si una mujer teme de su marido maltrato o rechazo, no incurrirán en falta si ambos llegan a un acuerdo, pues un acuerdo [justo] es lo mejor. El alma es propensa a la avaricia, pero si hacen el bien y tienen temor de Dios, sepan que Dios sabe bien cuanto hacen.\qt@no{128}}
\qt@newcmd\qurantrans@es@dcxxii{No podrán ser [completamente] equitativos con sus esposas por mucho que lo intenten. Pero no por eso vulneren los derechos [de una de ellas] dejándola como abandonada. Si se rectifican y tienen temor de Dios, Dios es Perdonador, Misericordioso.\qt@no{129}}
\qt@newcmd\qurantrans@es@dcxxiii{Pero si se divorcian, Dios proveerá a cada uno de Su abundancia. Dios es Vasto, Sabio.\qt@no{130}}
\qt@newcmd\qurantrans@es@dcxxiv{A Dios pertenece cuanto hay en los cielos y en la Tierra. He ordenado a quienes recibieron el Libro anteriormente y también a ustedes tener temor de Dios, pero si se rehúsan, a Dios pertenece cuanto hay en los cielos y en la Tierra. Dios es Opulento, Loable.\qt@no{131}}
\qt@newcmd\qurantrans@es@dcxxv{A Dios pertenece cuanto hay en los cielos y en la Tierra. Dios es Quien vela por ellos.\qt@no{132}}
\qt@newcmd\qurantrans@es@dcxxvi{¡Oh, gente! Si Él hubiera querido los habría exterminado y remplazado por otros. Dios tiene el poder para hacerlo.\qt@no{133}}
\qt@newcmd\qurantrans@es@dcxxvii{Quien anhele la recompensa de esta vida mundanal, sepa que Dios dispone de la recompensa de esta vida y de la otra. Dios todo lo oye, todo lo ve.\qt@no{134}}
\qt@newcmd\qurantrans@es@dcxxviii{¡Oh, creyentes! Sean responsablemente equitativos cuando den testimonio por Dios, aunque sea en contra de ustedes mismos, de sus padres o parientes cercanos, no importa si [el acusado es] rico o pobre: Dios está por encima de ellos. Que los sentimientos no los hagan ser injustos. Si dan falso testimonio o rechazan prestar testimonio [ocultando la verdad], sepan que Dios está bien informado de cuanto hacen.\qt@no{135}}
\qt@newcmd\qurantrans@es@dcxxix{¡Oh, creyentes! Crean en Dios, en Su Mensajero, en el Libro que fue revelado a Su Mensajero y en los Libros que fueron revelados en el pasado. Quien no crea en Dios, en Sus ángeles, en Sus Libros, en Sus Mensajeros y en el Día del Juicio, habrá caído en un desvío profundo.\qt@no{136}}
\qt@newcmd\qurantrans@es@dcxxx{A quienes crean y luego renieguen, después vuelvan a creer y luego renieguen nuevamente, aferrándose tercamente en su rechazo de la verdad [hasta su muerte], Dios no ha de perdonarlos ni guiarlos [por la senda al Paraíso].\qt@no{137}}
\qt@newcmd\qurantrans@es@dcxxxi{Anuncia a los hipócritas que recibirán un castigo doloroso.\qt@no{138}}
\qt@newcmd\qurantrans@es@dcxxxii{Los que toman a los incrédulos como aliados en vez de tomar a los creyentes, ¿pretenden acaso así alcanzar poder y gloria? Sepan que el poder y la gloria pertenecen solamente a Dios.\qt@no{139}}
\qt@newcmd\qurantrans@es@dcxxxiii{[Musulmanes:] Se les informa en el Libro revelado que cuando escuchen que se blasfema o que se burlan de la revelación de Dios, no se queden en esa reunión con quienes lo hagan, a menos que cambien de tema, porque de lo contrario serán iguales a ellos. Dios se encargará de congregar a los hipócritas y los que niegan la verdad en el Infierno.\qt@no{140}}
\qt@newcmd\qurantrans@es@dcxxxiv{[Los hipócritas] siempre especulan. Si ustedes obtienen una victoria con la ayuda de Dios, les dicen: ``¿Acaso no estábamos de su lado?" Pero si los que niegan la verdad logran un triunfo parcial, les dicen a ellos: ``¿Acaso no los ayudamos a vencer y los defendimos de los creyentes?" Dios los juzgará el Día de la Resurrección. Dios no ha de conceder a los que rechazan el mensaje la supremacía absoluta sobre los creyentes.\qt@no{141}}
\qt@newcmd\qurantrans@es@dcxxxv{Los hipócritas pretenden engañar a Dios, pero Él hace que ellos se engañen a sí mismos. Cuando se levantan para hacer la oración lo hacen con desgano, solo para ser vistos por la gente, sin apenas acordarse de Dios.\qt@no{142}}
\qt@newcmd\qurantrans@es@dcxxxvi{[Los hipócritas] vacilan entre los creyentes y los incrédulos, no se inclinan por unos ni por otros. A quien Dios desvíe no encontrará camino.\qt@no{143}}
\qt@newcmd\qurantrans@es@dcxxxvii{¡Oh, creyentes! No tomen a los que niegan la verdad como aliados en vez de a los creyentes. ¿Acaso pretenden darle a Dios una prueba en contra de ustedes mismos?\qt@no{144}}
\qt@newcmd\qurantrans@es@dcxxxviii{Los hipócritas estarán en el abismo más profundo del Fuego y no encontrarán quién los socorra.\qt@no{145}}
\qt@newcmd\qurantrans@es@dcxxxix{Excepto aquellos [hipócritas] que se arrepientan, rectifiquen, se aferren a Dios y practiquen la fe sinceramente. Ellos estarán junto a los creyentes, y Dios tiene preparado para los creyentes una recompensa grandiosa.\qt@no{146}}
\qt@newcmd\qurantrans@es@dcxl{¿Para qué iba Dios a castigarlos [por sus ofensas pasadas] si son [ahora] agradecidos y creyentes? Dios es Agradecido, todo lo sabe.\qt@no{147}}
\qt@newcmd\qurantrans@es@dcxli{A Dios no Le complace que se hagan públicos los errores de otros, excepto que sea para denunciar o detener una injusticia. Dios todo lo oye, todo lo sabe.\qt@no{148}}
\qt@newcmd\qurantrans@es@dcxlii{Si hacen públicas sus buenas obras o si las esconden, o si perdonan una ofensa, sepan que Dios es Perdonador, Poderoso.\qt@no{149}}
\qt@newcmd\qurantrans@es@dcxliii{Quienes no creen en Dios ni en Sus Mensajeros y pretenden hacer distinción entre [la fe en] Dios y [la fe en] Sus Mensajeros diciendo: ``Creemos en algunos, pero en otros no", pretendiendo tomar un camino intermedio,\qt@no{150}}
\qt@newcmd\qurantrans@es@dcxliv{ellos son auténticos incrédulos. Y a los que nieguen la verdad les tenemos reservado un castigo denigrante.\qt@no{151}}
\qt@newcmd\qurantrans@es@dcxlv{Pero quienes crean [realmente] en Dios y en Sus Mensajeros sin hacer distinciones entre ellos, Él les concederá Sus recompensas. Dios es Perdonador, Misericordioso.\qt@no{152}}
\qt@newcmd\qurantrans@es@dcxlvi{[Los judíos entre] la Gente del Libro te piden que les hagas descender un Libro del cielo. Ya le habían pedido a Moisés algo peor cuando dijeron: ``Haz que podamos ver a Dios con los ojos". Pero fueron fulminados por un rayo debido a las injusticias que cometían. Luego comenzaron a adorar al becerro [de oro] a pesar de haber recibido las evidencias [del monoteísmo]. Pero les perdoné [esa ofensa] y concedí a Moisés un milagro evidente.\qt@no{153}}
\qt@newcmd\qurantrans@es@dcxlvii{Para que respetaran el pacto [de seguir la Tora] elevé la montaña por encima de ellos y les dije: ``Ingresen por la puerta [principal de la ciudad], prostérnense [en señal de humildad] y no quebranten el sábado". Celebré con ellos un pacto solemne.\qt@no{154}}
\qt@newcmd\qurantrans@es@dcxlviii{[Y no te sorprendas, ¡oh, Mujámmad! de que te pidan que hagas descender un Libro del cielo, cuando ellos] Quebrantaron el pacto, no creyeron en los signos de Dios, mataron a los Profetas injustamente, y [además] dicen: ``No podemos comprender tus palabras". No es eso, sino que Dios endureció sus corazones porque negaron la verdad evidente, y no van a creer sino unos pocos de ellos.\qt@no{155}}
\qt@newcmd\qurantrans@es@dcxlix{Tampoco creyeron [en el Mesías] y manifestaron contra María una calumnia gravísima [acusándola de fornicadora].\qt@no{156}}
\qt@newcmd\qurantrans@es@dcl{Y dijeron: ``Hemos matado al Mesías, Jesús hijo de María, el Mensajero de Dios". Pero, aunque así lo creyeron, no lo mataron ni lo crucificaron. Quienes discrepan sobre él [Jesús] tienen dudas al respecto. No tienen conocimiento certero sino que siguen suposiciones, pero en la realidad no lo mataron.\qt@no{157}}
\qt@newcmd\qurantrans@es@dcli{Dios lo ascendió al cielo [en cuerpo y alma]. Dios es Poderoso, Sabio.\qt@no{158}}
\qt@newcmd\qurantrans@es@dclii{La Gente del Libro comprenderá, antes de la muerte, la verdad sobre Jesús, y el Día del Juicio él testificará en contra [de quienes lo negaron y de quienes lo adoraron].\qt@no{159}}
\qt@newcmd\qurantrans@es@dcliii{Debido a las injusticias que cometían los judíos, y porque constantemente obstaculizaban el camino de Dios, les prohibí cosas buenas que antes les eran permitidas.\qt@no{160}}
\qt@newcmd\qurantrans@es@dcliv{Lucraban con la usura siendo que les estaba prohibido, y estafaban engañando a la gente. Les tenemos reservado un castigo doloroso a quienes de entre ellos negaron la verdad [a pesar de conocerla].\qt@no{161}}
\qt@newcmd\qurantrans@es@dclv{Pero a los que están afianzados en el conocimiento y creen en lo que te fue revelado y lo que fue revelado anteriormente, hacen la oración prescrita, pagan el zakat, creen en Dios y en el Día del Juicio Final, les daremos una recompensa grandiosa.\qt@no{162}}
\qt@newcmd\qurantrans@es@dclvi{Te he descendido la revelación como lo hice con Noé y con los Profetas que le sucedieron, con Abraham, Ismael, Isaac, Jacob, las doce tribus, Jesús, Job, Jonás, Aarón y Salomón. A David le he revelado los Salmos.\qt@no{163}}
\qt@newcmd\qurantrans@es@dclvii{Te he mencionado [¡oh, Mujámmad!] algunos de los Mensajeros que envié [a la humanidad] y otros no. Y sabe que Dios habló con Moisés directamente.\qt@no{164}}
\qt@newcmd\qurantrans@es@dclviii{A los Mensajeros los envié como anunciadores de albricias y como amonestadores, para que [la humanidad] no tuviera argumento alguno ante Dios [por haber rechazado el mensaje]. Dios es Poderoso, Sabio.\qt@no{165}}
\qt@newcmd\qurantrans@es@dclix{[Si te acusan de mentiroso, ¡oh, Mujámmad! sabe que] Dios mismo atestigua que lo que te reveló es con Su sabiduría, y los ángeles también lo atestiguan, aunque es suficiente con Dios como testigo.\qt@no{166}}
\qt@newcmd\qurantrans@es@dclx{Los que negaron la verdad y además impidieron a la gente seguir la guía de Dios, están profundamente extraviados.\qt@no{167}}
\qt@newcmd\qurantrans@es@dclxi{A los que negaron la verdad y cometieron injusticias, Dios no ha de perdonarlos ni guiarlos por el buen camino,\qt@no{168}}
\qt@newcmd\qurantrans@es@dclxii{Excepto por el camino que conduce al Infierno, en donde morarán eternamente. Eso es fácil para Dios.\qt@no{169}}
\qt@newcmd\qurantrans@es@dclxiii{¡Oh, seres humanos! Les ha llegado un Mensajero con la Verdad sobre su Señor. Crean [en Dios y sigan el Islam], eso es lo mejor para ustedes. Pero si no creen, sepan que a Dios pertenece cuanto hay en los cielos y en la Tierra. Dios todo lo sabe y es Sabio.\qt@no{170}}
\qt@newcmd\qurantrans@es@dclxiv{¡Oh, Gente del Libro! No se extralimiten en las creencias de su religión. No digan acerca de Dios sino la verdad: Porque el Mesías, Jesús hijo de María, es un Mensajero de Dios y Su palabra [¡Sé!] que depositó en María; un espíritu creado por Él. Crean en [la unicidad de] Dios y en Sus Mensajeros. No digan que [Dios] es una parte de la trinidad, abandonen esa idea, es lo mejor para ustedes. Dios es una única divinidad. Lejos está, Glorificado sea, de tener un hijo. A Él pertenece cuanto hay en los cielos y en la Tierra. Dios es suficiente como protector.\qt@no{171}}
\qt@newcmd\qurantrans@es@dclxv{Ni el Mesías ni los ángeles allegados menosprecian ser siervos de Dios. Quien desdeñe adorar a Dios y se comporte con soberbia, sepa que todos serán resucitados y congregados ante Él [para ser juzgados por sus actitudes].\qt@no{172}}
\qt@newcmd\qurantrans@es@dclxvi{Los creyentes que hayan obrado correctamente serán retribuidos con generosidad y se les concederá aún más de Su favor. Pero quienes hayan rechazado adorarlo [solo a Él] y hayan sido soberbios, sufrirán un castigo doloroso, y no encontrarán, fuera de Dios, protector ni socorredor.\qt@no{173}}
\qt@newcmd\qurantrans@es@dclxvii{¡Oh, seres humanos! Les ha llegado una prueba de su Señor [el Profeta], y les he hecho descender una luz que ilumina [el Corán].\qt@no{174}}
\qt@newcmd\qurantrans@es@dclxviii{A quienes creyeron y se aferraron a Dios, Él tendrá compasión de ellos, los agraciará y los guiará por el camino recto.\qt@no{175}}
\qt@newcmd\qurantrans@es@dclxix{Te piden una respuesta [sobre la herencia]. Diles: ``Dios dictamina sobre quien no tiene padre ni hijo. Si un hombre muere sin dejar hijos, pero sí una hermana, ésta heredará la mitad de lo que dejare, y si ella muere sin dejar hijos, él la heredará. Si el difunto deja dos hermanas, éstas heredarán dos tercios de lo que dejare. Si tiene hermanos, varones y mujeres, a cada varón le corresponderá lo mismo que a dos mujeres. Dios se los aclara para que no se desvíen [de lo que es justo]. Dios todo lo sabe.\qt@no{176}}
\qt@newcmd\qurantrans@es@dclxx{\basmalahes ¡Oh, creyentes! Cumplan con sus compromisos. Les es lícito comer del ganado excepto lo que esté expresamente prohibido. La caza no está permitida mientras estén consagrados a la peregrinación. Dios legisla lo que Le place [según su sabiduría divina].\qt@no{1}}
\qt@newcmd\qurantrans@es@dclxxi{¡Oh, creyentes! No profanen los ritos de Dios ni los meses sagrados ni los animales ofrendados ni los animales marcados para ofrenda ni perjudiquen a quienes se dirigen a la Casa Sagrada buscando el favor y la complacencia de su Señor. [Solo] cuando hayan finalizado la peregrinación podrán cazar. Que el descontento que tengan hacia quienes les impedían el acceso a la Mezquita Sagrada no los lleve a transgredir [la ley], sino que cooperen con ellos a obrar el bien e impedir el mal, pero no cooperen en el pecado y la enemistad. Y tengan temor de Dios; Dios es severo en el castigo.\qt@no{2}}
\qt@newcmd\qurantrans@es@dclxxii{Les es prohibido [comer] la carne del animal muerto por causa natural, la sangre, la carne de cerdo, el animal que haya sido sacrificado invocando otro en lugar de Dios, la del animal muerto por asfixia, golpe, caída, cornada o herido por las fieras, a menos que alcancen a degollarlo [antes de que muera], y lo que es inmolado en altares [en honor a un ídolo]. [También es prohibido] consultar la suerte echando flechas. [Violar alguna de estas leyes] es un pecado. Quienes se empeñan en negar la verdad han perdido la esperanza de [hacerlos renunciar a] su religión. No tengan temor de ellos, sino que tengan temor de Mí. Hoy les he perfeccionado su forma de adoración, he completado Mi gracia sobre ustedes y he dispuesto que el Islam sea su religión. Pero quien, [en caso extremo] por hambre, se vea forzado [y coma de lo prohibido] pero sin intención de transgredir la ley ni excederse, Dios es Perdonador, Misericordioso.\qt@no{3}}
\qt@newcmd\qurantrans@es@dclxxiii{Te preguntan qué es lícito [comer]. Responde: ``Se les permite comer todas las cosas buenas [y sanas]. Pueden comer lo que hayan atrapado los animales de caza que han entrenado, conforme a lo que Dios les ha enseñado. Coman de lo que cacen para ustedes, pero mencionen el nombre de Dios sobre esos alimentos, y tengan temor de Dios, porque Dios es rápido en ajustar cuentas.\qt@no{4}}
\qt@newcmd\qurantrans@es@dclxxiv{De hoy en adelante les es permitido todo [alimento] bueno. La carne de los [animales sacrificados] de quienes recibieron el Libro [la Tora y el Evangelio] es lícita, y la carne [de los animales que ustedes sacrifican] es lícita para ellos. También es permitido [para ustedes] casarse con las mujeres creyentes que sean recatadas y las mujeres recatadas que recibieron el Libro anteriormente [judías y cristianas], siempre que cumplan la condición de darle su dote, con intensión [seria] de casarse, no para fornicar o tomarlas como amantes secretas. Pero quien rechace la creencia [monoteísta de Dios], sus obras [en este mundo] habrán sido en vano, y en la otra vida se contará entre los perdedores.\qt@no{5}}
\qt@newcmd\qurantrans@es@dclxxv{¡Oh, creyentes! Cuando se dispongan a hacer la oración lávense el rostro y los brazos hasta los codos, pasen las manos [húmedas] por la cabeza y [laven] los pies hasta los tobillos. Si están en estado de impureza mayor, tomen un baño [completo]. Si están enfermos o de viaje o han hecho sus necesidades [biológicas] o han cohabitado con su mujer y no encuentran agua, usen [para la ablución virtual] tierra limpia y pásenla por el rostro y las manos. Dios no quiere imponerles dificultades, solo quiere purificarlos y completar Su favor sobre ustedes para que sean agradecidos.\qt@no{6}}
\qt@newcmd\qurantrans@es@dclxxvi{Recuerden la bendición que Dios les concedió, y [recuerden] el pacto que hizo con ustedes cuando dijeron: ``Oímos y obedecemos". Tengan temor de Dios, porque Dios bien sabe lo que encierran los corazones.\qt@no{7}}
\qt@newcmd\qurantrans@es@dclxxvii{¡Oh, creyentes! Sean responsables con [los preceptos de] Dios. Sean justos cuando den testimonio. Que el rencor que sienten no les conduzca a obrar injustamente. Sean justos y equitativos, porque eso es lo más cercano a la piedad. Y tengan temor de Dios, porque Dios está bien informado de lo que hacen.\qt@no{8}}
\qt@newcmd\qurantrans@es@dclxxviii{A los creyentes que obren correctamente Dios les ha prometido el perdón [de sus pecados] y una recompensa generosa.\qt@no{9}}
\qt@newcmd\qurantrans@es@dclxxix{Pero [en cambio] los que niegan la verdad y rechazan Mi palabra serán los habitantes del fuego del Infierno.\qt@no{10}}
\qt@newcmd\qurantrans@es@dclxxx{¡Oh, creyentes! Recuerden las bendiciones que Dios les concedió cuando sus enemigos intentaron agredirlos pero Dios los protegió. Tengan temor de Dios, y que los creyentes solo se encomienden a Dios.\qt@no{11}}
\qt@newcmd\qurantrans@es@dclxxxi{Dios celebró un pacto con los Hijos de Israel y designó de entre ellos doce jefes. Pero Dios les dijo: ``Estaré con ustedes siempre que cumplan con la oración, paguen el zakat, crean y apoyen a [todos] Mis Mensajeros, gasten generosamente en Mi causa; entonces perdonaré sus ofensas y los introduciré en jardines en los que corren ríos. Pero quien [después de todo esto] niegue la verdad, se habrá extraviado del camino recto".\qt@no{12}}
\qt@newcmd\qurantrans@es@dclxxxii{Pero por haber violado el pacto los maldije y sus corazones se volvieron insensibles y duros. [Por eso] tergiversan el sentido de las palabras [de la Tora] sacándolas de contexto, y dejan de lado parte de lo que les fue mencionado [en ella]. Descubrirás que la mayoría de ellos, salvo unos pocos, traicionan [a la gente]; pero tu discúlpalos y sé tolerante con ellos, porque Dios ama a los que hacen el bien.\qt@no{13}}
\qt@newcmd\qurantrans@es@dclxxxiii{[Dios también tomó un compromiso] con quienes dicen: ``Somos cristianos", pero ellos dejaron de lado parte de lo que les había mencionado [en el Evangelio]. Y [por eso] sembré entre ellos la discordia y el odio hasta el Día de la Resurrección, cuando Dios les hará saber el [gran] nivel de desvío que alcanzaron.\qt@no{14}}
\qt@newcmd\qurantrans@es@dclxxxiv{¡Oh, Gente del Libro! Les ha llegado un Mensajero enviado por Mí, cuya misión es traerles a la luz los preceptos más importantes que ocultaron de la Biblia, y facilitar muchos otros preceptos. Dios les ha enviado una luz y un Libro claro [el Corán],\qt@no{15}}
\qt@newcmd\qurantrans@es@dclxxxv{con el cual Dios guía a quienes buscan Su complacencia hacia los caminos de la salvación, los extrae por Su voluntad de las tinieblas hacia la luz, y los dirige por el camino recto.\qt@no{16}}
\qt@newcmd\qurantrans@es@dclxxxvi{Son incrédulos quienes dicen: ``Jesús hijo de María es Dios". Diles: ``¿Quién podría impedir que Dios exterminara al Mesías hijo de María, a su madre y a todo cuanto existe en la Tierra, si así lo quisiera?" A Dios pertenece el reino de los cielos y de la Tierra, y todo lo que existe entre ambos. Dios crea lo que Le place, porque Él tiene poder sobre todas las cosas.\qt@no{17}}
\qt@newcmd\qurantrans@es@dclxxxvii{Dicen judíos y cristianos: ``Somos hijos de Dios y sus predilectos". Diles: ``Si así fuera, ¿por qué los castigará por los pecados que cometen? No son sino como el resto de la humanidad, seres creados por Él. Dios perdona a quien quiere y castiga a quien quiere. A Dios pertenece el reino de los cielos y de la Tierra, y todo lo que existe entre ambos, y ante Él compareceremos [para que nos juzgue por nuestras acciones]".\qt@no{18}}
\qt@newcmd\qurantrans@es@dclxxxviii{¡Oh, Gente del Libro! Luego de que pasara un tiempo desde el último Mensajero, les ha llegado Mi Mensajero para aclararles la verdad, y que no puedan decir [el Día del Juicio Final]: ``No se nos presentó nadie que nos albriciara [con el monoteísmo] y nos advirtiera [contra la idolatría]". Pues ahora sí tienen quien les albricia y les advierte, porque Dios es sobre toda cosa Poderoso.\qt@no{19}}
\qt@newcmd\qurantrans@es@dclxxxix{[Recuerda] cuando Moisés dijo a su pueblo: ``¡Oh, pueblo mío! Recuerden las bendiciones que Dios les concedió al hacer que surgieran entre ustedes Profetas y poderosos, y los bendijo con gracias que no concedió a nadie de sus contemporáneos.\qt@no{20}}
\qt@newcmd\qurantrans@es@dcxc{¡Oh, pueblo mío! Entren en la Tierra Santa que Dios destinó para ustedes y no renieguen [de su fe], porque se convertirían en perdedores".\qt@no{21}}
\qt@newcmd\qurantrans@es@dcxci{Respondieron: ``¡Oh, Moisés! Allí hay gente poderosa, así que no entraremos hasta que ellos se marchen. Solo cuando abandonen la ciudad entraremos".\qt@no{22}}
\qt@newcmd\qurantrans@es@dcxcii{Dos hombres que tenían temor de Dios, que habían sido bendecidos [con una fe sólida], dijeron: ``Ingresen sorpresivamente por la puerta, porque si lo hacen obtendrán la victoria. Pero encomiéndense solo a Dios, si es que verdaderamente son creyentes".\qt@no{23}}
\qt@newcmd\qurantrans@es@dcxciii{Dijeron: ``¡Oh, Moisés! No ingresaremos mientras ellos permanezcan dentro. Ve tú con tu Señor y combátelos, que nosotros nos quedaremos aquí".\qt@no{24}}
\qt@newcmd\qurantrans@es@dcxciv{Dijo [Moisés]: ``¡Señor mío! Solo tengo control de mis actos y autoridad sobre mi hermano [Aarón], decide Tú entre ellos y nosotros".\qt@no{25}}
\qt@newcmd\qurantrans@es@dcxcv{Dijo [Dios a Moisés]: ``Les estará prohibida [la entrada en Tierra Santa]. Vagarán por la tierra durante cuarenta años. No te aflijas por la gente perversa".\qt@no{26}}
\qt@newcmd\qurantrans@es@dcxcvi{[Oh, Mujámmad:] Cuéntales la auténtica historia de los hijos de Adán, cuando presentaron una ofrenda y le fue aceptada a uno y rechazada al otro. Dijo [Caín]: ``Te mataré". Dijo [Abel]: ``Dios solo acepta las obras de los que obran con fe sincera.\qt@no{27}}
\qt@newcmd\qurantrans@es@dcxcvii{Aunque levantaras tu mano para matarme, yo no levantaría la mía para matarte, porque yo tengo temor de Dios, Señor del Universo.\qt@no{28}}
\qt@newcmd\qurantrans@es@dcxcviii{Prefiero que seas tú quien cargue con mis pecados y los tuyos, [y si me matas] serás de los moradores del Fuego, porque ese es el castigo para los que cometen esa injusticia".\qt@no{29}}
\qt@newcmd\qurantrans@es@dcxcix{Pero su ego lo llevó [a Caín] a matar a su hermano, por lo que se arruinó a sí mismo.\qt@no{30}}
\qt@newcmd\qurantrans@es@dcc{Entonces Dios envió un cuervo para que escarbase la tierra y le mostrara cómo enterrar el cadáver de su hermano. Dijo [Caín]: ``¡Ay de mí! ¿Acaso no soy capaz de hacer como este cuervo y enterrar el cadáver de mi hermano?" Y sintió un profundo arrepentimiento.\qt@no{31}}
\qt@newcmd\qurantrans@es@dcci{Como consecuencia [de este asesinato], legislé para los Hijos de Israel que: ``Quien mata a una persona sin que ésta haya cometido un crimen o sembrado la corrupción en la Tierra, es como si matase a toda la humanidad. Pero quien salva una vida es como si salvase a toda la humanidad". Mis Mensajeros se presentaron ante ellos con pruebas claras [de la ley], pero muchos de ellos siguen cometiendo graves excesos en el mundo.\qt@no{32}}
\qt@newcmd\qurantrans@es@dccii{El castigo para quienes hacen la guerra a [un pueblo que se gobierna por la ley de] Dios y Su Mensajero y siembran en la Tierra la corrupción es que [luego de un juicio justo] se los condene a muerte, se los crucifique, se les ampute una mano y el pie del lado opuesto, o se los condene al exilio. Esto es para que sean denigrados en esta vida, y en la otra tendrán un castigo terrible.\qt@no{33}}
\qt@newcmd\qurantrans@es@dcciii{Pero quienes se arrepientan antes de ser apresados [y se entreguen voluntariamente] sepan que Dios es Perdonador, Misericordioso.\qt@no{34}}
\qt@newcmd\qurantrans@es@dcciv{¡Oh, creyentes! Tengan temor de Dios, busquen acercarse a Él [realizando obras de bien] y luchen por Su causa, que así tendrán éxito.\qt@no{35}}
\qt@newcmd\qurantrans@es@dccv{Los que niegan la verdad, aunque tuvieran todo cuanto existe en la Tierra y aún el doble para ofrecerlo como rescate y salvarse del castigo del Día de la Resurrección, no se les aceptará, y recibirán un castigo doloroso.\qt@no{36}}
\qt@newcmd\qurantrans@es@dccvi{Querrán salir del Fuego pero nunca lo conseguirán, y tendrán un castigo perpetuo.\qt@no{37}}
\qt@newcmd\qurantrans@es@dccvii{Al ladrón y a la ladrona [luego de un juicio justo] córtenles la mano en compensación por su delito. Esta es una sentencia disuasoria dictada por Dios. Dios es Poderoso, Sabio.\qt@no{38}}
\qt@newcmd\qurantrans@es@dccviii{Pero a quien se arrepienta luego de cometer un delito o injusticia y enmiende, Dios lo perdonará, porque Dios es Perdonador, Misericordioso.\qt@no{39}}
\qt@newcmd\qurantrans@es@dccix{¿Acaso no sabes que a Dios pertenece el reino de los cielos y de la Tierra? Castiga a quien quiere y perdona a quien quiere. Dios es sobre toda cosa Poderoso.\qt@no{40}}
\qt@newcmd\qurantrans@es@dccx{¡Oh, Mensajero! No te entristezcas por quienes se precipitan a negar la verdad, como quienes dicen: ``Creemos", pero sus corazones no creen. Entre los judíos hay quienes prestan oídos a cualquier falsedad que se diga, escuchan ávidamente sin venir a pedirte aclaración. Tergiversan el sentido de las palabras [reveladas] sacándolas de su contexto, y dicen: ``Si se les dice así [acorde a su tergiversación] acéptenlo; caso contrario, rechácenlo". A quien Dios pone a prueba con una tentación, no podrás hacer nada para salvarlo. Dios no ha querido purificar sus corazones. Ellos serán denigrados en esta vida, y en la otra tendrán un castigo terrible.\qt@no{41}}
\qt@newcmd\qurantrans@es@dccxi{Prestan oídos a la mentira y se benefician vorazmente del soborno. Si se presentan ante ti [para que juzgues] sobre un pleito entre ellos, puedes juzgar o abstenerte. Si te abstienes no podrán perjudicarte en nada; pero si juzgas entre ellos, hazlo con equidad y justicia, porque Dios ama a los justos.\qt@no{42}}
\qt@newcmd\qurantrans@es@dccxii{¿Y por qué necesitan pedirte a ti que juzgues entre ellos si tienen la Tora en la que se encuentra el juicio de Dios? Si tu veredicto no les agrada lo rechazan [a pesar de que coincide con la Tora], esos de verdad no son creyentes [en Dios ni en la Tora].\qt@no{43}}
\qt@newcmd\qurantrans@es@dccxiii{He revelado la Tora, en la que hay guía y luz. Los Profetas entregados [a la voluntad de Dios] juzgaban entre los judíos. Lo mismo hicieron los rabinos y juristas en cumplimiento de su misión de custodiar el Libro de Dios y ser testigos de él [en sus enseñanzas]. No teman a la gente sino que tengan temor de Mí. No vendan Mis preceptos por un precio vil. Quienes no juzgan conforme a lo que Dios ha revelado [por considerarlo inferior], ésos son los verdaderos incrédulos.\qt@no{44}}
\qt@newcmd\qurantrans@es@dccxiv{He prescrito en ella [la Tora, la justicia retributiva]: Vida por vida, ojo por ojo, nariz por nariz, oreja por oreja, diente por diente, y con las heridas una similar. Pero si la víctima perdona [que se aplique la pena al culpable] esto le servirá de expiación. Quienes no juzgan conforme a lo que Dios ha revelado [por considerarlo inferior], ésos son los verdaderos ofensores.\qt@no{45}}
\qt@newcmd\qurantrans@es@dccxv{Hice que Jesús hijo de María siguiera [el ejemplo de los Profetas anteriores], en confirmación de la verdad que aún quedaba en la Tora. A él le he revelado el Evangelio en el que había guía y luz, como confirmación de lo que aun quedaba de la Tora, y como guía y exhortación para los que tienen temor de Dios y piedad.\qt@no{46}}
\qt@newcmd\qurantrans@es@dccxvi{Que los seguidores del Evangelio juzguen según lo que Dios ha revelado en él, porque los que no juzgan conforme a lo que Dios ha revelado, ésos son los verdaderos perversos.\qt@no{47}}
\qt@newcmd\qurantrans@es@dccxvii{[Y a ti, ¡oh, Mujámmad!] Te he revelado el Libro que contiene la verdad definitiva [el Corán], que corrobora los Libros revelados anteriormente y es juez de lo que es verdadero en ellos. Juzga conforme a lo que Dios ha revelado y no te sometas a sus deseos transgrediendo la Verdad que has recibido. A cada [comunidad religiosa] le he dado una legislación y una metodología [norma]. Si Dios hubiera querido habría hecho de ustedes una sola comunidad, pero quiso probar su fe en lo que les reveló. Apresúrense a realizar obras de bien, porque todos comparecerán ante Dios, y Él les informará acerca de lo que discrepaban.\qt@no{48}}
\qt@newcmd\qurantrans@es@dccxviii{Juzga entre ellos conforme a lo que Dios ha revelado, no te sometas a sus deseos y ten cuidado con ellos, no sea que te aparten con engaños de lo que Dios te ha revelado. Si ellos se rehúsan [a seguir lo que has dictaminado], sabe que Dios, a causa de sus pecados, quiere afligirlos. Pero muchas personas [a pesar de las advertencias] son perversas.\qt@no{49}}
\qt@newcmd\qurantrans@es@dccxix{¿Acaso prefieren un juicio según las leyes paganas? Pero, ¿qué mejor juicio que el de Dios para quienes están convencidos de su fe?\qt@no{50}}
\qt@newcmd\qurantrans@es@dccxx{¡Oh, creyentes! No tomen a los judíos ni a los cristianos por aliados, porque ellos son aliados entre sí. Quien les dé lealtad se convierte en uno de ellos. Dios no guía a un pueblo opresor.\qt@no{51}}
\qt@newcmd\qurantrans@es@dccxxi{Verás que quienes tienen una enfermedad en sus corazones [la hipocresía] se apresuran buscando su complacencia y dicen: ``Tenemos miedo de que nos sorprenda una derrota". Pero puede que Dios les tenga deparada la victoria o algún otro decreto, y entonces tengan que arrepentirse de lo que pensaban.\qt@no{52}}
\qt@newcmd\qurantrans@es@dccxxii{Los creyentes dirán entonces: ``¿Son éstos quienes juraban solemnemente por Dios que nos apoyaban?" Sus obras habrán sido en vano y se contarán entre los fracasados.\qt@no{53}}
\qt@newcmd\qurantrans@es@dccxxiii{¡Oh, creyentes! Si apostatan de su religión, Dios los suplantará por otros a quienes amará y ellos Lo amarán, que serán compasivos con los creyentes, severos con los que niegan la verdad, y combatirán por la causa de Dios sin temor a los reproches. Esas son las cualidades de quienes Dios ha bendecido. Dios es Vasto, todo lo sabe.\qt@no{54}}
\qt@newcmd\qurantrans@es@dccxxiv{Sus únicos aliados deben ser Dios, Su Mensajero y los creyentes que hacen la oración prescrita, pagan el zakat y se inclinan [ante Dios en la oración].\qt@no{55}}
\qt@newcmd\qurantrans@es@dccxxv{Quienes tomen por aliados a Dios, a Su Mensajero y a los creyentes, son de la comunidad de Dios, quienes serán en definitiva los vencedores.\qt@no{56}}
\qt@newcmd\qurantrans@es@dccxxvi{¡Oh, creyentes! No tomen por aliados a quienes toman a burla y broma su religión, sean gente del Libro o de los que niegan la verdad. Tengan temor de Dios si es que son creyentes.\qt@no{57}}
\qt@newcmd\qurantrans@es@dccxxvii{Cuando ustedes convocan a la oración, ellos se burlan y la toman a broma, porque son gente que no razona.\qt@no{58}}
\qt@newcmd\qurantrans@es@dccxxviii{Di: ``¡Oh, Gente del Libro! ¿Acaso nos reprochan que creamos en Dios, en la revelación que nos fue enviada y lo que fue revelado anteriormente, o lo hacen solamente porque la mayoría de ustedes son perversos?"\qt@no{59}}
\qt@newcmd\qurantrans@es@dccxxix{Di: ``¿No quieren acaso que les informe quiénes tendrán peor retribución que éstos ante Dios? Son quienes maldijo Dios, los que incurrieron en Su ira, los que convirtió en monos y cerdos, y los que adoran a los falsos dioses. Esos son los que se encuentran en una situación peor y son los más extraviados del camino recto.\qt@no{60}}
\qt@newcmd\qurantrans@es@dccxxx{Cuando se encuentran con ustedes dicen: ``Creemos", pero cuando entraron [al Islam en apariencia] traían la incredulidad consigo, y al abandonarlo [al Islam] salieron igual. Dios sabe bien lo que ocultan.\qt@no{61}}
\qt@newcmd\qurantrans@es@dccxxxi{Verás a muchos de ellos precipitarse en el pecado, la injusticia y apoderarse de los bienes ajenos. ¡Qué mal está lo que hacen!\qt@no{62}}
\qt@newcmd\qurantrans@es@dccxxxii{¿Por qué sus maestros y rabinos no les prohíben mentir y usurpar los bienes ajenos? ¡Qué mal está lo que hacen!\qt@no{63}}
\qt@newcmd\qurantrans@es@dccxxxiii{Estos judíos dijeron: ``La mano de Dios está cerrada". Son sus manos las que se cerraron, y cayeron en la maldición de Dios por su blasfemia. Por el contrario, Sus dos manos están extendidas y dispensa [generosamente] según Su voluntad. Lo que te ha sido revelado por tu Señor acrecentará en muchos de ellos la arrogancia y la negación de la verdad. Hemos previsto entre ellos la enemistad y el odio hasta el Día de la Resurrección. Siempre que enciendan el fuego de la guerra [contra ustedes], Dios lo apagará. Ellos se esfuerzan por sembrar la corrupción en la Tierra, pero Dios no ama a los que siembran la corrupción.\qt@no{64}}
\qt@newcmd\qurantrans@es@dccxxxiv{Pero si la Gente del Libro creyera y tuviera temor de Dios, Yo les borraría sus pecados y los introduciría en los Jardines de las Delicias.\qt@no{65}}
\qt@newcmd\qurantrans@es@dccxxxv{Si se hubiesen atenido a la Tora, el Evangelio y lo [último] que les ha sido revelado por su Señor [el Corán], recibirían las bendiciones que caen del cielo y las que brotan de la tierra. Entre ellos hay quienes son moderados, pero la mayoría obra de forma perversa.\qt@no{66}}
\qt@newcmd\qurantrans@es@dccxxxvi{¡Oh, Mensajero! Comunica [completamente] lo que te ha sido revelado por tu Señor. Si no lo haces, no habrás hecho llegar Su Mensaje. Dios te protegerá de la gente [que intenta impedir que cumplas con tu misión]. Dios no guía a un pueblo que niega la verdad.\qt@no{67}}
\qt@newcmd\qurantrans@es@dccxxxvii{Di: ``¡Oh, Gente del Libro! No tendrán fundamento alguno mientras no se atengan a [la ley de] la Tora, el Evangelio y lo que les ha sido revelado por su Señor". Lo que te ha sido revelado por tu Señor acrecentará en muchos de ellos la arrogancia y la negación a reconocer la verdad, pero no te aflijas por un pueblo que se niega a reconocer la verdad.\qt@no{68}}
\qt@newcmd\qurantrans@es@dccxxxviii{Los creyentes [en el Islam], los judíos, los sabeos y los cristianos, quienes crean en Dios [sin asociarle nada] y en el Día del Juicio y obren rectamente, no deben sentir temor ni tristeza [por su futuro].\qt@no{69}}
\qt@newcmd\qurantrans@es@dccxxxix{Celebré un pacto solemne con los Hijos de Israel y les envié Mensajeros. Siempre que un Mensajero se presentaba ante ellos con algo que no les gustaba, lo desmentían o lo mataban.\qt@no{70}}
\qt@newcmd\qurantrans@es@dccxl{Creían que no les alcanzaría ninguna calamidad [por sus crímenes] y se volvieron ciegos y sordos [de corazón], pero Dios los perdonó, aunque muchos de ellos reincidieron. Dios ve todo lo que hacen.\qt@no{71}}
\qt@newcmd\qurantrans@es@dccxli{Quienes dicen: ``Dios y el Mesías hijo de María son una misma persona" niegan la verdad, porque el mismo Mesías dijo: ``¡Oh, Hijos de Israel! Adoren solo a Dios, que es mi Señor y el suyo". A quien atribuya actos de adoración a otros además de Dios, Él le vedará el Paraíso y su morada será el Infierno. Los injustos no tendrán quién los socorra.\qt@no{72}}
\qt@newcmd\qurantrans@es@dccxlii{Quienes dicen: ``Dios es una de las tres personas de la trinidad", niegan la verdad, porque no hay más que una sola divinidad. Si no desisten de sus palabras, un castigo doloroso azotará a quienes se obstinan en negar la verdad.\qt@no{73}}
\qt@newcmd\qurantrans@es@dccxliii{¿Acaso no van a arrepentirse y pedir perdón a Dios? Dios es Perdonador, Misericordioso.\qt@no{74}}
\qt@newcmd\qurantrans@es@dccxliv{El Mesías hijo de María es solo un Mensajero, como los otros Mensajeros que le precedieron. Su madre fue una creyente devota. Ambos necesitaban alimentos [como el resto de los seres humanos]. Observa cómo les aclaré las evidencias, y cómo [a pesar de eso] rechazan la verdad.\qt@no{75}}
\qt@newcmd\qurantrans@es@dccxlv{Di: ``¿Acaso van a adorar, en lugar de Dios, lo que no puede causarles perjuicio ni beneficio? Dios todo lo oye, todo lo sabe".\qt@no{76}}
\qt@newcmd\qurantrans@es@dccxlvi{Di: ``¡Oh, Gente del Libro! No se excedan en sus creencias tergiversando la verdad, y no sigan ideas personales de gentes que se desviaron en el pasado, que hicieron que muchos se extraviaran y se desviaran del camino recto.\qt@no{77}}
\qt@newcmd\qurantrans@es@dccxlvii{Los Hijos de Israel que se obstinaban en negar la verdad ya fueron maldecidos por David y por Jesús hijo de María, porque transgredían los límites de la ley y se rebelaban [contra Dios].\qt@no{78}}
\qt@newcmd\qurantrans@es@dccxlviii{No se reprochaban unos a otros los pecados que cometían. ¡Qué perversa era su forma de actuar!\qt@no{79}}
\qt@newcmd\qurantrans@es@dccxlix{Verás que muchos de ellos toman a los que rechazan la verdad por aliados. ¡Qué perverso es a lo que les indujo su ego! La ira de Dios cayó sobre ellos, y sufrirán eternamente en el castigo.\qt@no{80}}
\qt@newcmd\qurantrans@es@dccl{Si realmente hubieran creído en Dios, en el Profeta y en lo que le fue revelado, no los hubieran tomado por aliados, pero muchos de ellos son perversos.\qt@no{81}}
\qt@newcmd\qurantrans@es@dccli{Verás que los peores enemigos de los creyentes son los judíos y los idólatras, y los más amistosos son quienes dicen: ``Somos cristianos". Esto es porque entre ellos hay sacerdotes y monjes que no se comportan con soberbia.\qt@no{82}}
\qt@newcmd\qurantrans@es@dcclii{Cuando escuchan lo que le ha sido revelado al Mensajero, ves que sus ojos se inundan de lágrimas porque reconocen la verdad, y entonces dicen: ``¡Señor nuestro! Creemos, cuéntanos entre quienes dan testimonio [de la verdad del Islam].\qt@no{83}}
\qt@newcmd\qurantrans@es@dccliii{¿Y por qué no íbamos a creer en Dios y en lo que nos ha llegado de la verdad? Esperamos que nuestro Señor nos introduzca [al Paraíso] junto a los justos".\qt@no{84}}
\qt@newcmd\qurantrans@es@dccliv{Dios les recompensará por su testimonio con jardines por los que corren ríos, en los que estarán por toda la eternidad. Ésa es la recompensa de los que hacen el bien.\qt@no{85}}
\qt@newcmd\qurantrans@es@dcclv{Pero quienes rechacen la verdad y desmientan Mi mensaje morarán en el fuego del Infierno.\qt@no{86}}
\qt@newcmd\qurantrans@es@dcclvi{¡Oh, creyentes! No prohíban las cosas buenas que Dios les ha permitido, pero tampoco se excedan. Dios no ama a los que cometen excesos.\qt@no{87}}
\qt@newcmd\qurantrans@es@dcclvii{Coman de lo lícito y bueno que Dios les ha proveído, y tengan temor de Dios, en Quien creen.\qt@no{88}}
\qt@newcmd\qurantrans@es@dcclviii{Dios no va a pedirles cuentas por los juramentos [que hagan] sin intención, pero sí [va a preguntarles] por los que hayan pronunciado reflexionando sobre su implicancia. En estos casos deberán expiarlos alimentando a diez pobres como alimentan a su familia, o dándoles vestimenta, o liberando a un esclavo. Quien no encuentre los medios [económicos para una de estas tres opciones] deberá ayunar tres días. Ésta es la expiación de los juramentos [si no los cumplen]. Sean cuidadosos con sus juramentos, pero cuando los hagan deben cumplirlos. Así es cómo Dios explica Su mensaje, para que sean agradecidos.\qt@no{89}}
\qt@newcmd\qurantrans@es@dcclix{¡Oh, creyentes! Los embriagantes, las apuestas, los altares [sobre los cuales eran degollados los animales como ofrenda para los ídolos] y consultar la suerte [por ejemplo] con flechas, son una obra inmunda del demonio. Aléjense de todo ello, que así tendrán éxito [en esta vida y en la próxima].\qt@no{90}}
\qt@newcmd\qurantrans@es@dcclx{El demonio pretende [con esas cosas] sembrar entre la gente la discordia y el odio, y apartarlos del recuerdo de Dios y la oración valiéndose de los embriagantes y las apuestas. ¿No van a dejarlo ya?\qt@no{91}}
\qt@newcmd\qurantrans@es@dcclxi{Deben obediencia absoluta a Dios y a Su Mensajero, y tengan cuidado [de desobedecerlos]. Pero quien se rehúse, sepa que Mi Mensajero solo tiene la obligación de transmitir [el Mensaje] con claridad.\qt@no{92}}
\qt@newcmd\qurantrans@es@dcclxii{Quienes creen y hacen buenas obras no serán reprochados por lo que disfrutaron [de lo que era lícito] antes [de su prohibición] siempre que tengan temor de Dios, crean y obren rectamente, luego tengan temor de Dios y crean [en las leyes], luego tengan temor de Dios y hagan el bien [manteniéndose firmes], porque Dios ama a los que hacen el bien.\qt@no{93}}
\qt@newcmd\qurantrans@es@dcclxiii{¡Oh, creyentes! Dios los pone a prueba prohibiendo la caza que puedan obtener con las manos o lanzas [mientras estén consagrados a la peregrinación] para distinguir quién Le teme en secreto. Quien transgreda [las leyes] tendrá un doloroso castigo.\qt@no{94}}
\qt@newcmd\qurantrans@es@dcclxiv{¡Oh, creyentes! No cacen mientras estén consagrados a la peregrinación. Quien lo haga deliberadamente deberá compensarlo sacrificando una res de ganado equivalente a la que mató, la que será determinada por dos personas justas y será ofrendada [a Dios] ante la Ka‘bah [y repartida entre los necesitados], o deberá hacer una expiación alimentando a pobres o ayunando un plazo equivalente, para que sufra y comprenda las consecuencias de sus ofensas. Dios no les pedirá cuentas por lo que hayan hecho antes de descender la legislación. Pero quien reincida, sepa que Dios lo retribuirá con lo que se merece. Dios es Poderoso, Dueño de la retribución.\qt@no{95}}
\qt@newcmd\qurantrans@es@dcclxv{Es permitido [durante la peregrinación comer de] lo que pesquen en el mar, para los residentes y los viajeros. Pero está prohibida la caza mientras estén consagrados a la peregrinación. Tengan temor de Dios, ante Quien serán congregados [para ser juzgados por sus obras].\qt@no{96}}
\qt@newcmd\qurantrans@es@dcclxvi{Dios designó a la Ka‘bah, la Casa Sagrada, como un lugar de devoción y adoración. Los meses sagrados, las ofrendas y los animales marcados para ofrenda son sagrados. Esto para que sepan que Dios conoce cuanto hay en los cielos y la Tierra, y que Dios todo lo sabe.\qt@no{97}}
\qt@newcmd\qurantrans@es@dcclxvii{Sepan que Dios es severo en el castigo, pero también es Perdonador, Misericordioso.\qt@no{98}}
\qt@newcmd\qurantrans@es@dcclxviii{El Mensajero solo tiene la obligación de transmitir el Mensaje, Dios es Quien sabe lo que manifiestan y lo que ocultan.\qt@no{99}}
\qt@newcmd\qurantrans@es@dcclxix{Di: ``No se puede equiparar lo malo y lo bueno, así que no te dejes engañar por la abundancia de lo malo. Tengan temor de Dios, ¡oh, gente que reflexiona!, que así tendrán éxito".\qt@no{100}}
\qt@newcmd\qurantrans@es@dcclxx{¡Oh, creyentes! No ahonden en asuntos que si fueran revelados [en forma de ley] les causarían dificultad [en la práctica de la religión]. Pero si los indagan cuando hayan sido revelados en el Corán, les serán explicados. Dios los perdona por sus indagaciones [fuera de lugar] porque es Perdonador, Tolerante.\qt@no{101}}
\qt@newcmd\qurantrans@es@dcclxxi{Estas mismas indagaciones fueron hechas por otros pueblos en la antigüedad, y [cuando les fueron reveladas como leyes] las rechazaron.\qt@no{102}}
\qt@newcmd\qurantrans@es@dcclxxii{No es prescripción de Dios que ciertas clases de ganado sean marcadas por superstición y costumbres paganas, como la camella que se consagra a los ídolos por lo que no debe ser ordeñada, ni la que también es consagrada a los ídolos y se la deja pastar libremente, ni la oveja que si en su séptimo parto pare un macho y una hembra se la consagra a los ídolos y no se la debe sacrificar, ni el camello semental que luego de servir diez veces se consagra a los ídolos por lo que no se lo utiliza para montura. Son los paganos supersticiosos quienes han inventaron estos ritos, mintiendo acerca de Dios. La mayoría de ellos no usa el razonamiento.\qt@no{103}}
\qt@newcmd\qurantrans@es@dcclxxiii{Cuando se les dice: ``Tomen lo que Dios ha revelado y sigan al Mensajero", dicen: ``Nos basta con lo que nos transmitieron nuestros padres", a pesar de que sus padres eran ignorantes y no estaban bien encaminados.\qt@no{104}}
\qt@newcmd\qurantrans@es@dcclxxiv{¡Oh, creyentes! Ustedes son responsables por sus almas en el cumplimento de sus deberes para con Dios. Nos les perjudica quien elige el camino del desvío si ustedes están en el camino recto. A Dios regresarán y Él les informará el resultado de sus obras.\qt@no{105}}
\qt@newcmd\qurantrans@es@dcclxxv{¡Oh, creyentes! Ante la inminencia de la muerte deben declarar su testamento ante dos testigos confiables conocidos, o bien dos extraños si están de viaje y les sobreviene la [agonía de la] muerte. Si dudan [del testimonio] de los testigos, reténganlos hasta después de la oración para que juren por Dios: ``No pretendemos, con nuestro testimonio, ningún provecho personal ni beneficiar a un pariente. No ocultamos el testimonio que Dios nos ordenó declarar, porque de hacerlo nos contaríamos entre los pecadores".\qt@no{106}}
\qt@newcmd\qurantrans@es@dcclxxvi{Si se descubre que cometieron un pecado [al mentir sobre los términos del testamento], otros dos los sustituirán, y éstos serán [elegidos] de entre los parientes con más derecho [a su herencia] y jurarán por Dios: ``Nuestro testimonio es más digno de ser creído que el de ellos y no los agredimos [al acusarlos de falso testimonio], porque de hacerlo nos contaríamos entre los injustos".\qt@no{107}}
\qt@newcmd\qurantrans@es@dcclxxvii{Esto es lo más adecuado para lograr que presten un testimonio exacto o que teman que se refuten su juramento con un juramento contrario. Tengan temor de Dios y obedezcan [Sus leyes], porque Dios no guía a los perversos.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcclxxviii{[Teman] el día que Dios reúna a los Mensajeros y diga: ``¿Cómo respondieron [aquellos a quienes fueron enviados]?" Dirán: ``No sabemos, Tú eres Quien conoce lo oculto".\qt@no{109}}
\qt@newcmd\qurantrans@es@dcclxxix{Dios dirá: ``¡Oh, Jesús hijo de María! Recuerda las bendiciones que te concedí a ti y a tu madre, cuando te fortalecí con el Espíritu Santo para que pudieras hablar a la gente desde la cuna y de adulto, y te enseñé la escritura, la sabiduría, la Tora y el Evangelio. Cuando modelaste con arcilla un pájaro con Mi anuencia, y luego soplaste en él y se convirtió en un pájaro real con Mi permiso, y curaste al ciego de nacimiento y al leproso con Mi permiso, y resucitaste al muerto con Mi permiso. Te protegí de los Hijos de Israel cuando te presentaste ante ellos con las evidencias, y los que negaron la verdad dijeron: ``Esto es hechicería pura".\qt@no{110}}
\qt@newcmd\qurantrans@es@dcclxxx{[Recuerda] cuando inspiré a los discípulos para que creyeran en Mí y en Mi Mensajero. Ellos dijeron: ``¡Creemos! Sé testigo de que somos musulmanes [en sumisión a Dios]".\qt@no{111}}
\qt@newcmd\qurantrans@es@dcclxxxi{Cuando los discípulos de Jesús dijeron: ``¡Oh, Jesús hijo de María! ¿Tu Señor podría hacernos descender del cielo una mesa servida?" Dijo: ``Tengan temor de Dios, si es que son verdaderos creyentes".\qt@no{112}}
\qt@newcmd\qurantrans@es@dcclxxxii{Dijeron [los discípulos]: ``Queremos comer de ella para que nuestros corazones se sosieguen, saber [con certeza] que nos has dicho la verdad y dar testimonio de ella".\qt@no{113}}
\qt@newcmd\qurantrans@es@dcclxxxiii{Jesús hijo de María rezó: ``¡Oh Dios, nuestro señor! Haz que descienda una mesa servida del cielo que sea para nosotros un acontecimiento festivo, tanto para los primeros como para los últimos [de nuestra nación], y un milagro proveniente de Ti. Concédenos Tu favor, pues Tú eres el mejor de los sustentadores".\qt@no{114}}
\qt@newcmd\qurantrans@es@dcclxxxiv{Respondió Dios: ``La haré descender; pero si después alguno de ustedes reniega [de su fe], lo castigaré como no he castigado a nadie en el mundo".\qt@no{115}}
\qt@newcmd\qurantrans@es@dcclxxxv{[El Día del Juicio Final] Dios dirá: ``¡Oh, Jesús hijo de María! ¿Acaso tú dijiste a la gente: ``Adórenme a mí y a mi madre como divinidades junto con Dios?" Dirá [Jesús]: ``¡Glorificado seas! No me corresponde decir algo a lo que no tengo derecho. Si lo hubiera dicho Tú lo sabrías. Tú conoces lo que encierra mi alma, mientras que yo ignoro lo que encierra la Tuya. Tú eres Quien conoce lo oculto.\qt@no{116}}
\qt@newcmd\qurantrans@es@dcclxxxvi{No les transmití sino lo que Tú me has ordenado: ‘Adoren solo a Dios, mi Señor y el suyo’. Fui testigo de sus acciones mientras estuve con ellos; pero después de que me elevaste, fuiste Tú Quien los vigiló. Tú eres testigo de todas las cosas.\qt@no{117}}
\qt@newcmd\qurantrans@es@dcclxxxvii{Si los castigas, lo haces con derecho, pues son Tus siervos; pero si los perdonas, Tú eres el Poderoso, el Sabio".\qt@no{118}}
\qt@newcmd\qurantrans@es@dcclxxxviii{Dios dirá [el Día del Juicio]: ``Este es el día en que los sinceros disfrutarán su sinceridad. Tendrán jardines por donde corren ríos, en los que estarán por toda la eternidad. Dios estará complacido de ellos y ellos con Él. Esa será la bienaventuranza.\qt@no{119}}
\qt@newcmd\qurantrans@es@dcclxxxix{A Dios pertenece el reino de los cielos y de la tierra, y cuanto existe entre ambos. Él tiene poder sobre todas las cosas.\qt@no{120}}
\qt@newcmd\qurantrans@es@dccxc{\basmalahes Alabado sea Dios que creó los cielos y la Tierra, y originó las tinieblas y la luz. Pero los que se niegan a creer igualan [sus ídolos] a su Señor.\qt@no{1}}
\qt@newcmd\qurantrans@es@dccxci{Él es Quien los creó de barro y luego decretó el término de cada vida, y también el término que solo Él conoce [sobre el fin del mundo], pero a pesar de eso todavía están indecisos.\qt@no{2}}
\qt@newcmd\qurantrans@es@dccxcii{Él es Al-lah, el adorado en los cielos y en la Tierra. Sabe lo que esconden y lo que manifiestan, y sabe lo que obtienen [con sus obras].\qt@no{3}}
\qt@newcmd\qurantrans@es@dccxciii{Cada vez que les llega una prueba de su Señor, se niegan a creer en ella.\qt@no{4}}
\qt@newcmd\qurantrans@es@dccxciv{Antes ya habían desmentido la Verdad cuando les llegó, pero ya verán el resultado de sus burlas.\qt@no{5}}
\qt@newcmd\qurantrans@es@dccxcv{¿Acaso no ven cuántas generaciones anteriores a ellos he destruido? Les había concedido a ellos más poder en la Tierra que el que ustedes tienen, pero hice que las lluvias del cielo se desplomaran sobre ellos y los ríos los anegaron bajo sus pies, y les hice perecer a causa de sus pecados, e hice surgir después de ellos nuevas generaciones.\qt@no{6}}
\qt@newcmd\qurantrans@es@dccxcvi{Y aunque te hubiera hecho descender un libro escrito en un pergamino y lo hubieran podido palpar con sus manos, los que se niegan a creer habrían dicho: ``Esto no es más que hechicería".\qt@no{7}}
\qt@newcmd\qurantrans@es@dccxcvii{Ellos dicen: ``¿Por qué no hizo descender un ángel junto a él?" Pero si hubiese enviado un ángel el asunto habría quedado decidido, y no se les habría dado ningún plazo de espera [para creer].\qt@no{8}}
\qt@newcmd\qurantrans@es@dccxcviii{Y si hubiera enviado a un ángel [en lugar de un hombre], le habría dado apariencia humana y estarían en una confusión similar a la que tienen contigo.\qt@no{9}}
\qt@newcmd\qurantrans@es@dccxcix{Pero también se burlaron de otros Mensajeros anteriores a ti en la antigüedad. A los que se burlaron, les llegó el castigo del que se habían burlado.\qt@no{10}}
\qt@newcmd\qurantrans@es@dccc{Diles [¡oh, Mujámmad!]: ``Viajen por el mundo y reflexionen sobre cuál fue el destino de los que desmintieron [a los Mensajeros de Dios]".\qt@no{11}}
\qt@newcmd\qurantrans@es@dccci{Pregúntales [a los idólatras]: ``¿A quién pertenece cuanto hay en los cielos y en la Tierra?" Diles: ``A Dios". Él ha prescrito para Sí mismo la misericordia. Él los reunirá el Día indubitable de la Resurrección, en el que solo serán desventurados quienes se hayan negado a creer.\qt@no{12}}
\qt@newcmd\qurantrans@es@dcccii{A Él pertenece lo que habita la noche y el día. Él todo lo oye, todo lo sabe.\qt@no{13}}
\qt@newcmd\qurantrans@es@dccciii{Diles: ``¿Acaso voy a tomar como protector a otro en lugar de Dios, [siendo que Él es el] Originador de los cielos y la de Tierra, y Quien alimenta y no necesita ser alimentado?" Di: ``Se me ha ordenado ser el primero en entregarse a la voluntad de Dios. No sean ustedes de los que dedican actos de adoración a otros [además de Dios]".\qt@no{14}}
\qt@newcmd\qurantrans@es@dccciv{Di: ``Temo el castigo de un día terrible si desobedezco a mi Señor".\qt@no{15}}
\qt@newcmd\qurantrans@es@dcccv{Quien sea eximido [del castigo] ese día será porque Dios se apiadó de él, y ese será un triunfo evidente.\qt@no{16}}
\qt@newcmd\qurantrans@es@dcccvi{Si Dios te aflige con una desgracia, nadie excepto Él podrá librarte de ella. Pero si te agracia con una bendición, Él tiene poder sobre todas las cosas.\qt@no{17}}
\qt@newcmd\qurantrans@es@dcccvii{Él tiene total dominio sobre Sus siervos, y Él es el Sabio, el Conocedor.\qt@no{18}}
\qt@newcmd\qurantrans@es@dcccviii{Pregúntales: ``¿Quién es el testigo más creíble?" Di: ``Dios es testigo [de la diferencia] entre ustedes y yo. Me ha sido revelado este Corán para advertirles con él a todos aquellos que les llegue el Mensaje. ¿Acaso darían testimonio de que existen otras divinidades junto con Dios?" Diles: ``Yo no lo haré". Diles: ``Él es la única divinidad, y soy inocente de lo que ustedes Le asocian cometiendo idolatría".\qt@no{19}}
\qt@newcmd\qurantrans@es@dcccix{Aquellos a quienes les envié anteriormente el Libro [judíos y cristianos] reconocen [la profecía de Mujámmad] como reconocen a sus propios hijos, pero los que se han desviado a sí mismos se niegan a creer.\qt@no{20}}
\qt@newcmd\qurantrans@es@dcccx{¿Acaso existe alguien más injusto que quien atribuye a Dios sus falsos inventos, o quien desmiente Su Palabra? Los injustos jamás prosperarán.\qt@no{21}}
\qt@newcmd\qurantrans@es@dcccxi{El día que los resucitemos a todos y le sea dicho a quienes asociaron divinidades a Dios: ``¿Dónde están ahora aquellos que en sus fantasías eran socios de Dios en la divinidad?"\qt@no{22}}
\qt@newcmd\qurantrans@es@dcccxii{Entonces en su confusión dirán: ``¡Juramos por Dios, nuestro Señor, que no Le atribuíamos divinidad a nada junto con Él!"\qt@no{23}}
\qt@newcmd\qurantrans@es@dcccxiii{Mira cómo se desmienten a sí mismos, finalmente los desvió aquello que inventaron.\qt@no{24}}
\qt@newcmd\qurantrans@es@dcccxiv{Hay entre ellos quienes [parece] que te prestan atención [cuando recitas el Corán], pero [a causa de su incredulidad] he puesto sobre sus corazones un velo y he ensordecido sus oídos, por ello no pueden comprenderlo. Aunque vieran toda clase de signos, no creerían. Se presentan ante ti solo para debatirte, y dicen: ``Esto no es más que una fábula de los antiguos".\qt@no{25}}
\qt@newcmd\qurantrans@es@dcccxv{Le prohíben a la gente [seguir el mensaje] y se apartan ellos mismos, pero sin darse cuenta solo se perjudican a sí mismos.\qt@no{26}}
\qt@newcmd\qurantrans@es@dcccxvi{Si los vieras cuando sean detenidos ante el Fuego y digan: ``¡Ojalá pudiéramos volver [a la vida mundanal], para no desmentir la palabra de nuestro Señor y ser de los creyentes!"\qt@no{27}}
\qt@newcmd\qurantrans@es@dcccxvii{¡Pero no! Dirán eso porque saldrá a la luz lo que antes ocultaban. Y si se les diera la oportunidad de regresar [a la vida mundanal] volverían a [cometer] lo que se les había prohibido [asociándole divinidades a Dios]. La verdad es que son mentirosos.\qt@no{28}}
\qt@newcmd\qurantrans@es@dcccxviii{Y dicen: ``No hay vida después de la muerte, jamás seremos resucitados".\qt@no{29}}
\qt@newcmd\qurantrans@es@dcccxix{Si los vieras cuando sean llevados ante su Señor y se les diga: ``¿Acaso no es ahora verdad [la Resurrección y el Juicio Final]?" Responderán: ``¡Sí, por Dios!" Pero entonces se les dirá: ``Sufran el castigo por haber negado la verdad".\qt@no{30}}
\qt@newcmd\qurantrans@es@dcccxx{Los desventurados serán quienes hayan desmentido el encuentro con Dios. Y cuando les llegue por sorpresa la hora [de la Resurrección] dirán: ``¡Qué desventurados! ¡Cómo desperdiciamos nuestra vida!" Cargarán con sus pecados sobre sus espaldas. ¡Con que pésima carga irán [al Juicio]!\qt@no{31}}
\qt@newcmd\qurantrans@es@dcccxxi{Esta vida mundanal no es más que juego y disfrute pasajero, pero la otra vida es mejor para los piadosos. ¿Acaso no van a razonar?\qt@no{32}}
\qt@newcmd\qurantrans@es@dcccxxii{Sé muy bien que te apena lo que dicen [sobre ti]. Pero no es a ti a quien desmienten, sino que lo que los injustos rechazan es la palabra de Dios.\qt@no{33}}
\qt@newcmd\qurantrans@es@dcccxxiii{Antes de ti [también] fueron desmentidos otros Mensajeros. Ellos soportaron con paciencia que los desmintieran y hostigaran hasta que les llegó Mi auxilio. Porque no hay poder que pueda alterar [el cumplimiento de] las promesas de Dios. Te he relatado las historias de los Mensajeros [para consolar tu corazón].\qt@no{34}}
\qt@newcmd\qurantrans@es@dcccxxiv{Te entristece que se nieguen a creer, pues aunque buscaras una entrada a [las profundidades de] la Tierra o una escalera al cielo para traer una señal, no podrías hacerlos creer. Si Dios hubiese querido los habría guiado a todos. No te deprimas a causa de los que no creen.\qt@no{35}}
\qt@newcmd\qurantrans@es@dcccxxv{Solo responden [a tu llamado] los que escuchan, pero a los muertos [de corazón] Dios los resucitará y ante Él comparecerán.\qt@no{36}}
\qt@newcmd\qurantrans@es@dcccxxvi{Dijeron: ``¿Por qué su Señor no le ha concedido un milagro?" Diles [¡oh, Mujámmad!]: ``Dios es capaz de enviar un milagro". Pero la mayoría de ellos no son conscientes [que Dios envía Sus milagros por una sabiduría].\qt@no{37}}
\qt@newcmd\qurantrans@es@dcccxxvii{[Y es un milagro de la creación que] no hay criatura que camine en la tierra o vuele con sus dos alas que no forme una comunidad igual que ustedes. No he omitido nada en el Libro. Todos [los seres humanos] serán resucitados ante su Señor [el Día del Juicio].\qt@no{38}}
\qt@newcmd\qurantrans@es@dcccxxviii{Quienes desmienten Mis milagros son sordos, mudos y caminan en las tinieblas [de la incredulidad]. Dios extravía a quien quiere, y a quien quiere lo conduce por el sendero recto.\qt@no{39}}
\qt@newcmd\qurantrans@es@dcccxxix{Diles: ``Si les llegara el castigo de Dios o los sorprendiera la Hora [del comienzo del fin del mundo], ¿invocarían a otro en lugar de Dios? Respondan con sinceridad".\qt@no{40}}
\qt@newcmd\qurantrans@es@dcccxxx{Es Él a Quien invocan cuando los azota un mal, ahí se olvidan de las divinidades que Le asocian. Y Dios, si Él quiere, es Quien puede librarlos del mal.\qt@no{41}}
\qt@newcmd\qurantrans@es@dcccxxxi{Ya había enviado Mensajeros anteriores a ti a otras comunidades, pero [por haberles desmentido] las castigué con miseria y enfermedades, para que así fueran humildes.\qt@no{42}}
\qt@newcmd\qurantrans@es@dcccxxxii{Hubiera sido mejor para ellos mostrar humildad e invocarme cuando les llegó Mi castigo. Pero sus corazones se endurecieron y el demonio les hizo parecer bello lo que hacían.\qt@no{43}}
\qt@newcmd\qurantrans@es@dcccxxxiii{Cuando olvidaron lo que les ocurrió a quienes los precedieron [la miseria y las enfermedades que los azotaron] les abrí las puertas de la fortuna, y cuando estuvieron felices con lo que tenían los sorprendí con el castigo, y fueron presa de la desesperación.\qt@no{44}}
\qt@newcmd\qurantrans@es@dcccxxxiv{Así fueron destruidos los injustos. ¡Alabado sea Dios, Señor del universo!\qt@no{45}}
\qt@newcmd\qurantrans@es@dcccxxxv{Pregúntales: ``Si Dios los privara de la audición y la visión, y sellara sus corazones, ¿qué otra divinidad en lugar de Dios se los podría devolver?" Observa cómo les evidencio los signos, pero aun así se apartan con desdén.\qt@no{46}}
\qt@newcmd\qurantrans@es@dcccxxxvi{Pregúntales: ``Si el castigo de Dios llegara repentina o gradualmente, ¿acaso no serían destruidos los injustos?"\qt@no{47}}
\qt@newcmd\qurantrans@es@dcccxxxvii{He enviado a los Mensajeros para que albricien y adviertan a la gente. Quienes crean y se enmienden no tendrán razón para temer ni estar tristes [el Día del Juicio].\qt@no{48}}
\qt@newcmd\qurantrans@es@dcccxxxviii{Pero a quienes desmientan Mis signos, los alcanzará el castigo por su perversidad.\qt@no{49}}
\qt@newcmd\qurantrans@es@dcccxxxix{Diles: ``No les digo que poseo los tesoros de Dios ni que conozco lo oculto, ni tampoco afirmo ser un ángel, solo sigo lo que me fue revelado". Diles: ``¿Acaso pueden equipararse el ciego y el vidente? ¿Acaso no van a reflexionar?"\qt@no{50}}
\qt@newcmd\qurantrans@es@dcccxl{Advierte con el Corán a aquellos que tienen temor del día en que serán congregados ante su Señor, cuando no tendrán fuera de Él protector ni intercesor alguno, para que así tengan temor de Dios.\qt@no{51}}
\qt@newcmd\qurantrans@es@dcccxli{No rechaces a quienes invocan a su Señor por la mañana y por la tarde anhelando Su rostro. A ti no te corresponde pedirles cuentas de sus obras ni a ellos tampoco pedirte cuenta de las tuyas, porque serías de los injustos.\qt@no{52}}
\qt@newcmd\qurantrans@es@dcccxlii{Así es como los puse a prueba unos con otros, para que [opulentos y arrogantes] dijesen: ``¿Son estos [pobres insignificantes] a quienes Dios ha agraciado de entre nosotros?" Pero Dios sabe mejor que nadie quiénes son los agradecidos.\qt@no{53}}
\qt@newcmd\qurantrans@es@dcccxliii{Cuando se presenten ante ti aquellos que creen en Mis signos, diles: ``¡La paz sea con ustedes! Su Señor ha prescrito para Sí mismo la misericordia. Quien cometa una falta por ignorancia, y luego se arrepienta y enmiende, sepa que Dios es Absolvedor, Misericordioso.\qt@no{54}}
\qt@newcmd\qurantrans@es@dcccxliv{Así es como evidencio los signos para que puedan distinguir claramente el camino de los pecadores.\qt@no{55}}
\qt@newcmd\qurantrans@es@dcccxlv{Diles: ``Me fue prohibido adorar aquello que invocan en lugar de Dios". Diles: ``No voy a ceder a sus pasiones, porque [de hacerlo] me extraviaría y no sería de los bien guiados".\qt@no{56}}
\qt@newcmd\qurantrans@es@dcccxlvi{Diles: ``Yo sigo la palabra que proviene de mi Señor, que ustedes desmienten. Lo que piden que suceda pronto, no está en mis manos. La decisión pertenece solo a Dios. Él juzga con la verdad y es el mejor de los jueces".\qt@no{57}}
\qt@newcmd\qurantrans@es@dcccxlvii{Diles: ``Si estuviera en mis manos acelerar lo que ustedes me piden, ya todo estaría juzgado entre ustedes y yo. Pero Dios conoce mejor que nadie quiénes son los injustos.\qt@no{58}}
\qt@newcmd\qurantrans@es@dcccxlviii{Él posee las llaves de lo oculto y nadie más que Él las conoce. Él sabe lo que hay en la costa y en el mar. No hay hoja de árbol que caiga sin que Él lo sepa, ni grano en el seno de la tierra, o algo que esté verde o seco, sin que se encuentre registrado en un libro evidente.\qt@no{59}}
\qt@newcmd\qurantrans@es@dcccxlix{Él es Quien toma sus almas por la noche, sabe lo que han hecho durante el día, y les devuelve el alma al despertar, hasta que se cumpla el plazo prefijado para su muerte. Luego volverán a Él y les informará sobre lo que hacían".\qt@no{60}}
\qt@newcmd\qurantrans@es@dcccl{Él tiene total dominio sobre Sus siervos. Les envía ángeles custodios hasta que, cuando les llega la muerte, los ángeles toman sus almas y no pasan por alto a nadie.\qt@no{61}}
\qt@newcmd\qurantrans@es@dcccli{Luego serán devueltos a Dios, su verdadero Señor. ¿Acaso no es Él Quien los va a juzgar? ¡Él es el más rápido en ajustar cuentas!\qt@no{62}}
\qt@newcmd\qurantrans@es@dccclii{Pregúntales: ``¿Quién podrá salvarlos de las tinieblas de la tierra y del mar [cuando viajan] y Lo invocan en público y en secreto, diciendo: ‘Si nos salvas de esta, estaremos agradecidos’?"\qt@no{63}}
\qt@newcmd\qurantrans@es@dcccliii{Diles: ``Solo Dios los puede librar de esas situaciones y de toda otra aflicción. Pero a pesar de eso, luego [cuando se sienten a salvo] vuelven a adorar otras divinidades junto a Él".\qt@no{64}}
\qt@newcmd\qurantrans@es@dcccliv{Diles: ``Él tiene el poder para enviarles un castigo que caiga del cielo o salga de la tierra bajo sus pies, o puede dividirlos en partidos y hacer que se persigan unos a otros con violencia". Observa cómo evidencio los signos para que entiendan.\qt@no{65}}
\qt@newcmd\qurantrans@es@dccclv{Pero tu pueblo lo ha negado, siendo que es la verdad. Diles: ``Yo no soy responsable de lo que hacen".\qt@no{66}}
\qt@newcmd\qurantrans@es@dccclvi{Todo lo que he profetizado ocurrirá a su debido tiempo. ¡Ya lo verán!\qt@no{67}}
\qt@newcmd\qurantrans@es@dccclvii{Cuando veas a los que se burlan de Mis signos, aléjate de ellos hasta que cambien de conversación. Pero si el demonio te hace olvidar, cuando lo recuerdes no permanezcas reunido con los injustos.\qt@no{68}}
\qt@newcmd\qurantrans@es@dccclviii{A los que tienen temor de Dios no les corresponde pedirles cuentas [a quienes se burlan] por lo que hacen, pero sí exhortarlos [llamándolos a la reflexión] para que tengan temor de Dios.\qt@no{69}}
\qt@newcmd\qurantrans@es@dccclix{Pero apártate de quienes toman su vida y sus creencias a la ligera y se dedican a la diversión seducidos por los gozos transitorios de esta vida. Exhorta con el Corán para que comprendan que toda alma responderá por sus obras, y que nadie tendrá fuera de Dios protector ni intercesor. Y aunque ofrezcan toda clase de rescate [para salvarse del castigo] no se les aceptará. Esos serán quienes sufrirán las consecuencias por lo que cometieron, donde se les dará de beber un líquido hirviendo, y tendrán un castigo doloroso por haber negado la verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@dccclx{Di: ``¿Acaso debemos invocar en lugar de Dios algo que no puede beneficiarnos ni perjudicarnos? ¿Debemos dar marcha atrás luego de que Dios nos ha guiado? Seríamos como aquel a quien los demonios han seducido y camina desorientado por las pasiones terrenales, a pesar de tener amigos que lo llaman a la guía diciéndole: ‘Ven con nosotros’." Di: ``La guía de Dios es la verdadera guía, y nos ha sido ordenado entregarnos libremente al Señor del universo,\qt@no{71}}
\qt@newcmd\qurantrans@es@dccclxi{hacer la oración y tener temor de Él, porque es ante Él que seremos resucitados".\qt@no{72}}
\qt@newcmd\qurantrans@es@dccclxii{Él es Quien creó el cosmos y el planeta Tierra con un fin justo y verdadero. En cualquier momento que diga: ``¡Sé!", es. Su palabra es la Verdad. Suya será la soberanía el día que se sople la trompeta [para dar comienzo a la resurrección]. Él es el conocedor de lo oculto y de lo manifiesto, Él es el Sabio y el Conocedor.\qt@no{73}}
\qt@newcmd\qurantrans@es@dccclxiii{Y recuerda cuando Abraham le dijo a su padre Ázar: ``¿Tomas a los ídolos por divinidades? Creo que tú y tu pueblo están en un claro extravío".\qt@no{74}}
\qt@newcmd\qurantrans@es@dccclxiv{Así fue que le mostré a Abraham los milagros de los cielos y de la Tierra, para que fuera de los que creen con certeza.\qt@no{75}}
\qt@newcmd\qurantrans@es@dccclxv{Al llegar la noche vio una estrella y le dijo [a su pueblo]: ``¡Este es mi Señor!" Pero cuando desapareció dijo: ``No adoro lo que se ausenta".\qt@no{76}}
\qt@newcmd\qurantrans@es@dccclxvi{Luego, al ver la Luna aparecer dijo: ``¡Este es mi Señor!" Pero cuando desapareció dijo: ``Si no me guía mi Señor, seré de los pueblos extraviados".\qt@no{77}}
\qt@newcmd\qurantrans@es@dccclxvii{Y cuando vio salir el Sol dijo: ``¡Este es mi Señor, este es el más grande [de los astros]!" Pero cuando desapareció dijo: ``¡Pueblo mío! Yo estoy libre de asociarle, como ustedes, divinidades a Dios.\qt@no{78}}
\qt@newcmd\qurantrans@es@dccclxviii{Me consagro a Quien creó los cielos y la Tierra, soy monoteísta puro. No soy de los que Le asocian divinidades a Dios [en la adoración]".\qt@no{79}}
\qt@newcmd\qurantrans@es@dccclxix{Pero su pueblo lo desmintió. Él les dijo: ``¿Me discuten acerca de Dios siendo que Él me ha guiado? No tengo miedo a sus ídolos, [solo podrá ocurrirme] lo que mi Señor quiera. Mi Señor abarca con Su conocimiento todas las cosas. ¿No van a recapacitar?\qt@no{80}}
\qt@newcmd\qurantrans@es@dccclxx{¿Por qué iba a tener temor de sus ídolos siendo que ustedes no tienen temor de Dios y Le asocian divinidades sin que se les haya revelado ningún fundamento para ello? ¿Quién entre ustedes y yo tiene más motivo para sentirse seguro [de Dios]? Respondan, si es que saben".\qt@no{81}}
\qt@newcmd\qurantrans@es@dccclxxi{Quienes crean y no desacrediten su fe cometiendo la injusticia de asociar divinidades a Dios, estarán a salvo, porque son los bien guiados.\qt@no{82}}
\qt@newcmd\qurantrans@es@dccclxxii{Esa es Mi prueba, la que concedí a Abraham para que argumentara contra su pueblo. Así elevo la condición de quien quiero; tu Señor es Sabio, Conocedor.\qt@no{83}}
\qt@newcmd\qurantrans@es@dccclxxiii{Lo agracié [a Abraham] con Isaac y [a este con] Jacob, a quienes concedí la guía. A Noé también lo había guiado en la antigüedad. Y de sus descendientes [también guie] a David, Salomón, Job, José, Moisés y Aarón. Así es como recompenso a los que hacen el bien.\qt@no{84}}
\qt@newcmd\qurantrans@es@dccclxxiv{Y a Zacarías, Juan, Jesús y Elías; todos ellos se contaron entre los piadosos.\qt@no{85}}
\qt@newcmd\qurantrans@es@dccclxxv{Y a Ismael, Eliseo, Jonás y Lot; a todos ellos los distinguí entre la gente.\qt@no{86}}
\qt@newcmd\qurantrans@es@dccclxxvi{También distinguí a algunos de sus antepasados, descendientes y hermanos. Los elegí y los guie por el sendero recto.\qt@no{87}}
\qt@newcmd\qurantrans@es@dccclxxvii{Esa es la guía de Dios, guía con ella a quien Él quiere de entre Sus siervos. Pero si Le hubieran asociado divinidades [en la adoración] a Dios, todas sus obras no habrían valido de nada.\qt@no{88}}
\qt@newcmd\qurantrans@es@dccclxxviii{A ellos les revelé los Libros y los agracié con la sabiduría y la profecía. Pero si algunos no creen, [sepan que] he enviado este mensaje a otro pueblo que no dejará de creer en él.\qt@no{89}}
\qt@newcmd\qurantrans@es@dccclxxix{Ellos son los que Dios ha guiado, sigue su ejemplo. Y diles [a los que te rechazan]: ``No les pido remuneración alguna a cambio, este es un Mensaje para todo el universo".\qt@no{90}}
\qt@newcmd\qurantrans@es@dccclxxx{[Algunas personas] No valoraron ni enaltecieron a Dios como Él merece, y dijeron: ``Dios no ha revelado nada a ningún hombre". Pregúntales: ``¿Quién ha revelado el Libro que trajo Moisés como luz y guía para la gente, el cual copian en pergaminos y dan a conocer en parte, pero del que ocultan una gran parte? Se les enseñó allí lo que ni ustedes ni sus padres sabían". Di: ``Fue Dios [Quien lo reveló]". Luego déjales que sigan jugando con sus palabrerías.\qt@no{91}}
\qt@newcmd\qurantrans@es@dccclxxxi{Este es un Libro bendito que he revelado en confirmación de los Libros anteriores, y para que adviertas a la Madre de las Ciudades y a quienes viven en sus alrededores [el resto de la humanidad]. Los que creen en la otra vida creen en él y observan la oración.\qt@no{92}}
\qt@newcmd\qurantrans@es@dccclxxxii{No hay nadie más injusto que quien inventa mentiras acerca de Dios o dice: ``He recibido una revelación", cuando en realidad no se le ha revelado nada, o dice: ``Revelaré algo similar a lo que Dios ha revelado". Si pudieras ver [lo terrible que será] cuando los opresores estén en la agonía de su muerte y los ángeles extiendan las manos [para atormentarlos, y les digan]: ``Entreguen sus almas. Hoy se les retribuirá con un castigo denigrante por haber inventado mentiras acerca de Dios y por despreciar con arrogancia Su mensaje".\qt@no{93}}
\qt@newcmd\qurantrans@es@dccclxxxiii{Han venido ante Mí solos, tal como los creé por primera vez. Han dejado atrás [en la vida mundanal] lo que les concedí [de bienes materiales], y no veo junto a ustedes los intercesores que pretendían eran socios [de Dios en la divinidad]. Se ha roto su vínculo [con ellos] y desvanecido aquello que creían.\qt@no{94}}
\qt@newcmd\qurantrans@es@dccclxxxiv{Dios hace que germinen el grano y la semilla, y hace surgir lo vivo de lo muerto y lo muerto de lo vivo. ¡Ese es Dios! ¡Cómo pueden desviarse tanto [de la verdad]!\qt@no{95}}
\qt@newcmd\qurantrans@es@dccclxxxv{Hace que el alba despunte, dispuso que la noche sea para descansar, e hizo que el Sol y la Luna sigan una órbita precisa para que puedan llevar el cómputo [del tiempo]. Esto fue establecido por el Poderoso, el que todo lo sabe.\qt@no{96}}
\qt@newcmd\qurantrans@es@dccclxxxvi{Él es Quien ha creado las estrellas para que puedan guiarse por ellas en la oscuridad de la tierra y del mar. Dios ha evidenciado los signos para quienes reflexionan.\qt@no{97}}
\qt@newcmd\qurantrans@es@dccclxxxvii{Y Él es Quien los ha creado [a partir] de un solo ser, y les ha dado un lugar de estancia y otro de destino. Así ha evidenciado los signos para quienes comprenden.\qt@no{98}}
\qt@newcmd\qurantrans@es@dccclxxxviii{He hecho descender agua del cielo con la cual hago brotar toda clase de vegetación, y de ella resulta la cosecha de la cual saco semillas. De los brotes de la palmera hago salir racimos de dátiles al alcance de la mano. Y [también hago brotar] plantaciones de vides, olivos y granados, [todos de aspecto] similar pero [de frutos con sabores] diferentes. Observen cómo es su fruto cuando aparece y luego cuando madura, en todo ello hay signos para quienes creen.\qt@no{99}}
\qt@newcmd\qurantrans@es@dccclxxxix{[Pero los idólatras] asocian a los yinn con Dios [en la divinidad], siendo que Él es Quien ha creado [a los yinn]. Y Le atribuyen [a Dios], en su ignorancia, hijos e hijas. ¡Glorificado y Exaltado sea! Dios está por encima de ser como Lo describen.\qt@no{100}}
\qt@newcmd\qurantrans@es@dcccxc{Originador de los cielos y de la Tierra. ¿Cómo podría tener un hijo si no tiene compañera y Él es Quien ha creado todo? Él tiene conocimiento de todas las cosas.\qt@no{101}}
\qt@newcmd\qurantrans@es@dcccxci{¡Ese es Dios, su Señor! No hay más divinidad que Él, Creador de todas las cosas. Adórenlo solo a Él. Él es el Protector de todas las cosas.\qt@no{102}}
\qt@newcmd\qurantrans@es@dcccxcii{La vista [de los seres humanos] no puede abarcarlo, pero Él sí ve [a todos Sus siervos]. Él es el Sutil y el Conocedor.\qt@no{103}}
\qt@newcmd\qurantrans@es@dcccxciii{Han recibido evidencias de su Señor. Quien las comprenda será en beneficio propio, pero quien se enceguezca lo hará en detrimento propio. [Diles:] ``Yo no soy su custodio".\qt@no{104}}
\qt@newcmd\qurantrans@es@dcccxciv{Así es como evidencio los signos, aunque [los que se niegan a creer] dicen: ``Lo has aprendido de otros". Pero lo hago claro para la gente que tiene conocimiento.\qt@no{105}}
\qt@newcmd\qurantrans@es@dcccxcv{Sigue lo que te ha sido revelado por tu Señor, no hay más divinidad que Él, y apártate de los idólatras que dedican actos de adoración a otros además de Dios.\qt@no{106}}
\qt@newcmd\qurantrans@es@dcccxcvi{Si Dios hubiera querido no Le hubieran asociado nada. Pero no eres responsable de sus actos ni eres su protector.\qt@no{107}}
\qt@newcmd\qurantrans@es@dcccxcvii{Pero no insulten a quienes son invocados en lugar de Dios, porque insultarán a Dios con hostilidad sin tener real conocimiento [acerca de lo que dicen], pues he hecho que a cada pueblo le parezcan buenas sus obras, pero finalmente todos comparecerán ante su Señor, Quien les informará lo que hacían.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcccxcviii{[Los que se niegan a creer] juran seriamente por Dios que si se cumpliera uno de los milagros [que solicitaron] creerían. Diles: ``Solo Dios dispone de los milagros". ¿Y qué les hará entender, que aun cuando se cumpliera [el milagro que pedían] no creerían?\qt@no{109}}
\qt@newcmd\qurantrans@es@dcccxcix{Desviaré sus corazones y sus ojos [de la verdad], ya que se negaron a creer desde la primera vez. Los dejaré vagar ciegos en su extravío.\qt@no{110}}
\qt@newcmd\qurantrans@es@cm{Aunque les hubiera enviado ángeles o hecho que los muertos les hablaran, o hubiera reunido ante ellos a todas las naciones, no habrían creído a menos que Dios lo hubiera querido. Sin embargo, la mayoría de ellos lo ignora.\qt@no{111}}
\qt@newcmd\qurantrans@es@cmi{Todos los Profetas tuvieron enemigos que eran demonios de entre los seres humanos y los yinn, que se susurraban mutuamente palabras adornadas con seducción. Pero si tu Señor hubiera querido no lo habrían hecho. Apártate de ellos y sus mentiras.\qt@no{112}}
\qt@newcmd\qurantrans@es@cmii{Para que los corazones de quienes no creen en la otra vida se inclinen hacia esos engaños, para que se complazcan de eso y así obtengan su merecido.\qt@no{113}}
\qt@newcmd\qurantrans@es@cmiii{¿Acaso debo buscar otro juez en lugar de Dios, siendo que Él es Quien ha revelado el Libro donde se detallan todas las cosas? Aquellos a quienes les concedí el Libro anteriormente saben que el Corán ha sido revelado por tu Señor con la Verdad. No seas de los indecisos.\qt@no{114}}
\qt@newcmd\qurantrans@es@cmiv{La Palabra de tu Señor es de una veracidad y justicia absolutas. Nadie puede alterar la Palabra de Dios, Él todo lo oye, todo lo sabe.\qt@no{115}}
\qt@newcmd\qurantrans@es@cmv{Si obedecieras a la mayoría [de las personas] en la Tierra, te extraviarían del sendero de Dios, porque siguen solo conjeturas y no hacen más que especular.\qt@no{116}}
\qt@newcmd\qurantrans@es@cmvi{Tu Señor bien sabe quién se extravía de Su camino y quiénes siguen la guía.\qt@no{117}}
\qt@newcmd\qurantrans@es@cmvii{Coman de aquello sobre lo que se ha mencionado el nombre de Dios, si creen en Su mensaje.\qt@no{118}}
\qt@newcmd\qurantrans@es@cmviii{¿Por qué no habrían de comer de aquello sobre lo que se ha mencionado el nombre de Dios, siendo que Él ya les ha detallado lo que les es prohibido [comer], salvo en caso de extrema necesidad? Muchos se extravían al seguir sus pasiones por ignorancia, pero Dios conoce mejor que nadie a los transgresores.\qt@no{119}}
\qt@newcmd\qurantrans@es@cmix{Eviten el pecado, tanto en público como en privado. Quienes cometan pecados serán retribuidos por lo que hicieron.\qt@no{120}}
\qt@newcmd\qurantrans@es@cmx{No coman sobre lo que no se ha mencionado el nombre de Dios, pues hacerlo es un pecado. Los demonios inspiran a sus aliados para que discutan con ustedes, pero si los siguen se contarán entre quienes les atribuyen divinidad a otros junto a Dios.\qt@no{121}}
\qt@newcmd\qurantrans@es@cmxi{¿Acaso quien estaba muerto [de corazón] y le di vida [guiándolo], y le proporcioné una luz con la cual transita entre la gente, es igual a aquel que se encuentra entre tinieblas y no puede salir de ellas? Por eso es que a los que se niegan a creer les parece bueno lo que hacen.\qt@no{122}}
\qt@newcmd\qurantrans@es@cmxii{De igual manera dispuse en cada ciudad que los peores criminales maquinaran intrigas [contra su propia gente]. Pero sin darse cuenta, lo único que logran con sus intrigas es causarse daño a sí mismos.\qt@no{123}}
\qt@newcmd\qurantrans@es@cmxiii{Cuando se les presenta un milagro dicen: ``No creeremos hasta que se nos conceda lo mismo que les ha sido concedido a los Mensajeros de Dios". Pero Dios sabe bien en quién confiar Su Mensaje. Los criminales serán humillados ante Dios y castigados severamente a causa de sus intrigas.\qt@no{124}}
\qt@newcmd\qurantrans@es@cmxiv{A quien Dios quiere guiar le abre el corazón para que acepte el Islam. En cambio, a quien Él quiere extraviar le oprime fuertemente el pecho como si subiera a un lugar muy elevado. Así es como Dios humilla a quienes se niegan a creer.\qt@no{125}}
\qt@newcmd\qurantrans@es@cmxv{Este es el sendero recto de tu Señor. He hecho claro el mensaje para quienes reflexionan.\qt@no{126}}
\qt@newcmd\qurantrans@es@cmxvi{Ellos tendrán una morada de paz junto a su Señor, Quien es su Protector, como recompensa por sus obras.\qt@no{127}}
\qt@newcmd\qurantrans@es@cmxvii{El día que los congregue a todos y les diga: ``¡Oh, yinnes! Han extraviado a muchos seres humanos", y sus aliados de entre los seres humanos exclamen: ``¡Señor nuestro! Nos hemos beneficiado unos de otros y se ha cumplido el plazo que fijaste [para nuestra muerte]". Les dirá: ``El Fuego será su morada por toda la eternidad, salvo que Dios disponga otra cosa". Tu Señor es Sabio, todo lo sabe.\qt@no{128}}
\qt@newcmd\qurantrans@es@cmxviii{Y así es como hago que los injustos sean unos aliados de otros.\qt@no{129}}
\qt@newcmd\qurantrans@es@cmxix{[Y se les preguntará:] ``¡Oh, comunidad de yinnes y de seres humanos! ¿Acaso no se les presentaron Mensajeros para transmitirles Mi mensaje y advertirles de este día?" Responderán: ``Sí, y atestiguamos en contra nuestra". Los sedujo la vida mundanal y atestiguarán en su propia contra que se negaron a creer.\qt@no{130}}
\qt@newcmd\qurantrans@es@cmxx{Esto es porque tu Señor jamás destruiría un pueblo que haya obrado injustamente sin antes haberles advertido.\qt@no{131}}
\qt@newcmd\qurantrans@es@cmxxi{Cada uno será retribuido conforme a lo que hizo, tu Señor no está desatento a lo que hacen.\qt@no{132}}
\qt@newcmd\qurantrans@es@cmxxii{Tu Señor es Opulento y Misericordioso. Si quisiera, los exterminaría y los remplazaría, del mismo modo que los hizo surgir a ustedes como descendencia de otro pueblo.\qt@no{133}}
\qt@newcmd\qurantrans@es@cmxxiii{Lo que se les ha prometido ocurrirá [con toda certeza], y no podrán escapar de ello.\qt@no{134}}
\qt@newcmd\qurantrans@es@cmxxiv{Diles: ``¡Oh, pueblo mío! Obren como les plazca, que yo también obraré [pero acorde a lo que Dios ordena]. Pronto sabrán quién recibirá el mejor destino. Dios no concede el éxito a los opresores.\qt@no{135}}
\qt@newcmd\qurantrans@es@cmxxv{Y destinaron para Dios una parte de la cosecha y del ganado, que Él mismo ha creado [y otra parte para sus ídolos], y decían: ``Esto es para Dios y esto para nuestros ídolos". Pero lo que ellos destinaban para sus ídolos no los acercaba a la complacencia de Dios, y lo que habían destinado para Dios, sí los acercaba más a sus ídolos. ¡Con qué mal criterio juzgaban!\qt@no{136}}
\qt@newcmd\qurantrans@es@cmxxvi{Así es como a muchos de los idólatras, sus falsas divinidades les hicieron creer que era bueno que mataran a sus propios hijos, para así llevarlos a la perdición y confundirles su religión. Pero si Dios hubiera querido no lo habrían hecho; aléjate de ellos y de sus mentiras.\qt@no{137}}
\qt@newcmd\qurantrans@es@cmxxvii{Y decían, inventando: ``Este ganado y esta cosecha están consagrados [a los ídolos] y nadie, excepto quien nosotros queramos, puede comer de ello; y este otro ganado está consagrado y no puede usarse para la carga". Y también había otros ganados sobre los que no mencionaban el nombre de Dios [sino el de sus ídolos], pero todo era una mentira que atribuían a Dios. Pronto Él los castigará por las mentiras que inventaron.\qt@no{138}}
\qt@newcmd\qurantrans@es@cmxxviii{Y decían: ``La cría que se encuentra en el vientre de estos ganados es exclusivamente para nuestros varones y está vedada para nuestras esposas. Pero si una de sus crías nace muerta, entonces ambos [hombres y mujeres] pueden comer de ella". Dios los castigará por sus mentiras, Él es Sabio, lo sabe todo.\qt@no{139}}
\qt@newcmd\qurantrans@es@cmxxix{Están perdidos quienes maten a sus hijos por necedad e ignorancia, y prohíban lo que Dios les ha proveído como sustento, atribuyendo [esas prohibiciones] a Dios. Se han extraviado y no encuentran la guía.\qt@no{140}}
\qt@newcmd\qurantrans@es@cmxxx{Él es Quien ha creado huertos, unos cultivados y otros silvestres, [y ha creado también] las palmeras, las plantas de diferentes frutos, los olivos y los granados, [todos de aspecto] similar pero distintos. Coman de sus frutos cuando maduren, pero el día de la cosecha den la parte que corresponde [a los pobres] y no derrochen, porque Dios no ama a los derrochadores.\qt@no{141}}
\qt@newcmd\qurantrans@es@cmxxxi{De los ganados [Dios creó] algunos para la carga y otros para su consumo. Coman de lo que Dios les ha proveído y no sigan los pasos del demonio, porque él es su enemigo declarado.\qt@no{142}}
\qt@newcmd\qurantrans@es@cmxxxii{[Ellos alegan falsamente que] Ocho reses en parejas [están prohibidas]: del ovino dos y del cabrío dos. Pregúntales entonces: ``¿Qué les ha prohibido [Dios], los dos machos, las dos hembras, o lo que se encuentra en el vientre de las dos hembras? Fundamenten lo que afirman, si es que son sinceros".\qt@no{143}}
\qt@newcmd\qurantrans@es@cmxxxiii{Y de los camélidos dos y del bovino dos. Pregúntales: ``¿Qué les ha prohibido [Dios], los dos machos, las dos hembras, o lo que se encuentra en el vientre de las dos hembras? ¿Acaso estuvieron presentes cuando Dios les prescribió eso?" No hay nadie más injusto que aquél que inventa mentiras acerca de Dios sin fundamentos, para desviar a la gente. Dios no guía a los opresores.\qt@no{144}}
\qt@newcmd\qurantrans@es@cmxxxiv{Di: ``No encuentro en lo que me ha sido revelado otra cosa que se prohíba comer excepto la carne del animal muerto por causa natural, la sangre derramada, la carne de cerdo porque es una inmundicia, y lo que haya sido ofrendado invocando otro nombre que no sea el de Dios, porque es un pecado. Pero quien [en caso de extrema necesidad] se vea forzado [a ingerir algo de lo vedado] sin intención de pecar o excederse, debe saber que tu Señor es Absolvedor, Misericordioso".\qt@no{145}}
\qt@newcmd\qurantrans@es@cmxxxv{A los que practican el judaísmo les prohibí los animales de pezuñas partidas, y la grasa de ganado bovino y ovino, excepto la que tengan en los lomos, en las entrañas o adheridas a los huesos. Así los retribuí por su maldad. Esto es en castigo a su rebeldía, y soy fiel a Mi promesa.\qt@no{146}}
\qt@newcmd\qurantrans@es@cmxxxvi{Y si te desmienten diles: ``Su Señor es inmensamente Misericordioso, pero Su castigo caerá con toda certeza sobre los que se hunden en el pecado".\qt@no{147}}
\qt@newcmd\qurantrans@es@cmxxxvii{Quienes Le asociaron divinidades a Dios dirán: ``Si Dios hubiera querido no Le habríamos asociado nada y no habríamos vedado nada, ni nosotros ni nuestros padres". Así es como desmintieron quienes los precedieron, hasta que sufrieron Mi castigo. Pregúntales: ``¿Acaso tienen algún conocimiento que puedan presentar?" Solo siguen conjeturas, y no hacen más que especular.\qt@no{148}}
\qt@newcmd\qurantrans@es@cmxxxviii{Di: ``Dios posee la Verdad absoluta, y si hubiera querido los habría guiado a todos".\qt@no{149}}
\qt@newcmd\qurantrans@es@cmxxxix{Di: ``Traigan a sus testigos, que atestiguan que Dios les ha prohibido [esas cosas]". Si atestiguan, no testifiques tú con ellos ni sigas las pasiones de quienes desmintieron Mi mensaje, no creen en la otra vida y asocian divinidades a su Señor.\qt@no{150}}
\qt@newcmd\qurantrans@es@cmxl{Diles: ``Vengan, que les informaré lo que su Señor les ha prohibido: No deben asociarle nada, deben hacer el bien a sus padres, no matarán a sus hijos por temor a la pobreza, Yo me encargo de su sustento y el de ellos, no deben acercarse al pecado, ni en público ni en privado, y no matarán a nadie que Dios prohibió matar, salvo que sea con justo derecho. Esto es lo que les ha ordenado para que usen el razonamiento.\qt@no{151}}
\qt@newcmd\qurantrans@es@cmxli{No toquen los bienes del huérfano, a menos que sea para acrecentarlos, hasta que alcance la madurez. Deben medir y pesar con equidad. No impongo a nadie una carga mayor de la que puede soportar. Cuando hablen deben hablar con justicia, aunque sea en contra de un pariente. Deben cumplir sus compromisos con Dios. Esto es lo que les ha ordenado para que Lo recuerden.\qt@no{152}}
\qt@newcmd\qurantrans@es@cmxlii{Este es mi sendero recto, síganlo. Pero no sigan otros caminos, porque si lo hacen, estos los dividirán y los desviarán de Su camino. Esto es lo que les ha ordenado para que tengan temor de Él".\qt@no{153}}
\qt@newcmd\qurantrans@es@cmxliii{También le he revelado el Libro a Moisés para completar Mi gracia sobre los que obran correctamente, y para que sirva de aclaración de todas las cosas, sea guía y misericordia, y para que creyeran en el encuentro con su Señor.\qt@no{154}}
\qt@newcmd\qurantrans@es@cmxliv{Este es un Libro bendito que he revelado para que lo sigan, quizás así se les tenga misericordia.\qt@no{155}}
\qt@newcmd\qurantrans@es@cmxlv{Y para que no digan: ``Solo dos comunidades en la antigüedad recibieron la revelación, pero ignorábamos sus enseñanzas".\qt@no{156}}
\qt@newcmd\qurantrans@es@cmxlvi{O digan: ``Si hubiéramos recibido la revelación, habríamos seguido la guía mejor que ellos". Pero ya les llegó de su Señor la evidencia [el Corán], como guía y misericordia. ¿Acaso hay alguien más injusto que quien desmiente los mensajes de Dios y se aparta de ellos? Retribuiré a quienes se apartan de Mi mensaje con el más severo castigo.\qt@no{157}}
\qt@newcmd\qurantrans@es@cmxlvii{¿Acaso esperan que se presenten ante ellos los ángeles o su Señor mismo o se presente un signo de su Señor? El día que vean el signo de tu Señor, a ningún alma le servirá creer o arrepentirse si no lo ha hecho anteriormente. Diles: ``Sigan esperando, que nosotros también lo hacemos".\qt@no{158}}
\qt@newcmd\qurantrans@es@cmxlviii{Tú no eres responsable de quienes dividieron su religión y formaron sectas. Dios se hará cargo de ellos, y Él les hará saber lo que hicieron.\qt@no{159}}
\qt@newcmd\qurantrans@es@cmxlix{Quienes realicen una buena obra serán recompensados como si hubieran hecho diez obras buenas. En cambio, la mala obra será computada como una sola, y nadie será tratado injustamente.\qt@no{160}}
\qt@newcmd\qurantrans@es@cml{Diles: ``Mi Señor me ha guiado por el camino recto, que es el de la verdadera adoración y el de la religión monoteísta de Abraham, quien no era de los que asociaban divinidades a Dios".\qt@no{161}}
\qt@newcmd\qurantrans@es@cmli{Diles: ``Mi oración, mi ofrenda, mi vida y mi muerte pertenecen a Dios, Señor del universo,\qt@no{162}}
\qt@newcmd\qurantrans@es@cmlii{Quien no tiene iguales. Esto es lo que se me ha ordenado creer, y soy el primero en someterse a Dios".\qt@no{163}}
\qt@newcmd\qurantrans@es@cmliii{Diles: ``¿Acaso debería adorar a otro que no fuese Dios, cuando es Él el Creador de todo? Quien cometa un pecado lo hace en detrimento propio, y nadie cargará con los pecados ajenos. Finalmente volverán a su Señor, Quien les informará acerca de lo que solían discrepar.\qt@no{164}}
\qt@newcmd\qurantrans@es@cmliv{Él es Quien los ha hecho responsables de la Tierra, y ha agraciado a unos más que a otros para probarlos con ello. Tu Señor es rápido en castigar, pero también es Absolvedor, Misericordioso".\qt@no{165}}
\qt@newcmd\qurantrans@es@cmlv{\basmalahes Álif. Lam. Mim. Sad.\qt@no{1}}
\qt@newcmd\qurantrans@es@cmlvi{Éste es el Libro que te ha sido revelado, no tengas duda en tu corazón sobre ello, para que adviertas con él y como recuerdo para los creyentes.\qt@no{2}}
\qt@newcmd\qurantrans@es@cmlvii{[Oh, creyentes] Sigan lo que les ha sido revelado por su Señor, y no sigan fuera de Él a ningún aliado-protector. ¡Qué poco reflexionan!\qt@no{3}}
\qt@newcmd\qurantrans@es@cmlviii{Cuántas ciudades he destruido [en el pasado]. Mi castigo los azotó sorpresivamente mientras dormían por la noche o durante la siesta.\qt@no{4}}
\qt@newcmd\qurantrans@es@cmlix{Cuando los alcanzó Mi castigo dijeron: ``Éramos de los que cometían injusticias".\qt@no{5}}
\qt@newcmd\qurantrans@es@cmlx{He de preguntar a los Mensajeros y a los pueblos donde fueron enviados,\qt@no{6}}
\qt@newcmd\qurantrans@es@cmlxi{y les informaré acerca de todos sus actos con conocimiento, pues nunca estuve ausente.\qt@no{7}}
\qt@newcmd\qurantrans@es@cmlxii{Ese día se pesarán las obras con la verdad. Aquellos cuyas [buenas] obras pesen más [en la balanza] serán los bienaventurados.\qt@no{8}}
\qt@newcmd\qurantrans@es@cmlxiii{Pero aquellos cuyas [buenas] obras sean las livianas serán los perdedores, porque fueron injustos con Mis signos.\qt@no{9}}
\qt@newcmd\qurantrans@es@cmlxiv{Les he concedido poder en la Tierra y he dispuesto los medios para que vivan en ella. Pero, ¡qué poco agradecen!\qt@no{10}}
\qt@newcmd\qurantrans@es@cmlxv{Creé [al ser humano] y le di forma [armoniosa]. Luego dije a los ángeles: ``¡Hagan una reverencia ante Adán!" Todos se prosternaron excepto el demonio, que se negó a obedecer.\qt@no{11}}
\qt@newcmd\qurantrans@es@cmlxvi{[Dios] le preguntó: ``¿Qué te impidió prosternarte cuando te lo ordené?" Respondió: ``Yo soy superior a él, pues a mí me creaste de fuego, mientras que a él lo creaste del barro".\qt@no{12}}
\qt@newcmd\qurantrans@es@cmlxvii{Dijo [Dios]: ``¡Sal de aquí! En este lugar no se permite la soberbia. ¡Vete, pues [a partir de ahora] serás de los humillados!"\qt@no{13}}
\qt@newcmd\qurantrans@es@cmlxviii{Dijo [el Demonio]: ``Permíteme vivir hasta el Día de la Resurrección".\qt@no{14}}
\qt@newcmd\qurantrans@es@cmlxix{Dijo [Dios]: ``Serás de los que esperen [con vida hasta ese día]".\qt@no{15}}
\qt@newcmd\qurantrans@es@cmlxx{Dijo [el Demonio]: ``Por haberme descarriado los acecharé para apartarlos de Tu sendero recto.\qt@no{16}}
\qt@newcmd\qurantrans@es@cmlxxi{Los abordaré por delante, por detrás, por la derecha y por la izquierda; encontrarás que la mayoría de ellos no serán agradecidos".\qt@no{17}}
\qt@newcmd\qurantrans@es@cmlxxii{Dijo [Dios]: ``¡Sal de aquí degradado y despreciado! Llenaré el Infierno con todos aquellos que te sigan.\qt@no{18}}
\qt@newcmd\qurantrans@es@cmlxxiii{¡Oh, Adán! Habita el Paraíso con tu esposa. Coman cuanto deseen de lo que hay en él, pero no se acerquen a este árbol, pues de hacerlo se contarían entre los injustos".\qt@no{19}}
\qt@newcmd\qurantrans@es@cmlxxiv{Pero el demonio les susurró con el fin de que [desobedecieran a Dios y así] se les hiciera evidente lo que antes estaba oculto [de su desnudez] para ellos, diciéndoles: ``Su Señor les prohibió acercarse a este árbol para que no se conviertan en ángeles o en seres inmortales".\qt@no{20}}
\qt@newcmd\qurantrans@es@cmlxxv{Y les juró: ``Yo solo soy un consejero [sincero]".\qt@no{21}}
\qt@newcmd\qurantrans@es@cmlxxvi{Los sedujo con engaños. Cuando ambos comieron del árbol se les hizo manifiesta su desnudez y comenzaron a cubrirse con hojas del Jardín, entonces su Señor los llamó: ``¿No les había prohibido comer de este árbol? ¿No les había advertido que el demonio era su enemigo declarado?"\qt@no{22}}
\qt@newcmd\qurantrans@es@cmlxxvii{Ellos dijeron [arrepentidos]: ``¡Señor nuestro! Hemos sido injustos con nosotros mismos; si no nos perdonas y nos tienes misericordia, seremos de los perdidos".\qt@no{23}}
\qt@newcmd\qurantrans@es@cmlxxviii{Dijo [Dios]: ``¡Desciendan [del Paraíso]! Serán enemigos unos de otros. En la Tierra tendrán morada y deleite por un tiempo".\qt@no{24}}
\qt@newcmd\qurantrans@es@cmlxxix{Dijo [Dios]: ``En ella vivirán y morirán, y de ella serán resucitados".\qt@no{25}}
\qt@newcmd\qurantrans@es@cmlxxx{¡Oh, hijos de Adán! Los he provisto con vestimentas para que cubran sus vergüenzas y para que se vistan con elegancia. Pero vestirse con la piedad es la mejor [vestimenta]. Eso es un signo de Dios para que puedan recapacitar.\qt@no{26}}
\qt@newcmd\qurantrans@es@cmlxxxi{¡Oh, hijos de Adán! Que no los seduzca el demonio como lo hizo con sus padres [Adán y Eva] haciendo que salieran del Paraíso y fueran despojados de lo que los cubría. El demonio y sus secuaces los acechan desde donde no los ven. Hice que los demonios fueran aliados de los que se niegan a creer,\qt@no{27}}
\qt@newcmd\qurantrans@es@cmlxxxii{que cuando cometen una obscenidad se excusan diciendo: ``Nuestros padres lo hacían y Dios así nos lo ordenó". Diles: ``Dios no ordena la inmoralidad. ¿Afirman sobre Dios algo que en realidad ignoran?"\qt@no{28}}
\qt@newcmd\qurantrans@es@cmlxxxiii{Diles: ``Mi Señor solo ordena la justicia, que se mantengan en adoración en las mezquitas, y que Lo invoquen solo a Él practicando sinceramente Su religión". Así como los creó [por primera vez] los hará volver [a la vida].\qt@no{29}}
\qt@newcmd\qurantrans@es@cmlxxxiv{Un grupo siguió la guía, pero otro grupo se confirmó en su extravío, porque tomaron a los demonios como aliados-protectores en vez de Dios, mientras creían estar en la guía [correcta].\qt@no{30}}
\qt@newcmd\qurantrans@es@cmlxxxv{¡Oh, hijos de Adán! Vistan con elegancia cuando acudan a las mezquitas. Coman y beban con mesura, porque Dios no ama a los derrochadores.\qt@no{31}}
\qt@newcmd\qurantrans@es@cmlxxxvi{Diles: ``¿Quién les ha prohibido vestir con las prendas elegantes que Dios les ha concedido a Sus siervos y beneficiarse de todo lo bueno que Dios les ha proveído?" Diles: ``Pero de todo eso, el Día de la Resurrección, se beneficiarán exclusivamente quienes hayan sido creyentes durante la vida mundanal". Así es como aclaro Mis signos para un pueblo que comprende.\qt@no{32}}
\qt@newcmd\qurantrans@es@cmlxxxvii{Diles: ``Lo que realmente ha prohibido mi Señor son las obscenidades, tanto en público como en privado, la maldad, la opresión sin causa, que Le asocien en la adoración y que afirmen acerca de Él lo que ignoran".\qt@no{33}}
\qt@newcmd\qurantrans@es@cmlxxxviii{Cada nación tiene un plazo determinado, y cuando éste se cumpla no podrán retrasarlo ni adelantarlo, ni por un instante.\qt@no{34}}
\qt@newcmd\qurantrans@es@cmlxxxix{¡Oh, hijos de Adán! Cuando se les presenten Mensajeros que les transmitan Mis signos, tengan temor [de Dios] y rectifiquen [sus obras], que nada tendrán que temer ni estarán tristes [el Día del Juicio Final].\qt@no{35}}
\qt@newcmd\qurantrans@es@cmxc{Pero quienes desmientan Mis signos y tengan una actitud soberbia, esos serán la gente del Fuego, donde morarán por toda la eternidad.\qt@no{36}}
\qt@newcmd\qurantrans@es@cmxci{¿Acaso hay alguien más injusto que quien inventa mentiras acerca de Dios o desmiente Sus signos? A ellos los alcanzará lo que estaba escrito [en la predestinación]. Cuando se les presenten Mis [ángeles] Enviados para tomar sus almas les dirán: ``¿Dónde están aquellos [ídolos] que invocaban en vez de Dios?" Ellos responderán: ``Nos han abandonado", y atestiguarán contra sí mismos haber sido incrédulos.\qt@no{37}}
\qt@newcmd\qurantrans@es@cmxcii{Les dirá [Dios]: ``Entren al Infierno junto a las comunidades de seres humanos y yinnes que los precedieron". Cada vez que entre una comunidad, maldecirá a su hermana; y cuando todos hayan ingresado, dirán los últimos sobre los primeros: ``¡Señor nuestro! Ellos son quienes nos desviaron, duplícales el castigo del Fuego". Pero dirá [Dios]: ``A todos les será duplicado, aunque no lo sepan".\qt@no{38}}
\qt@newcmd\qurantrans@es@cmxciii{Los primeros dirán a los últimos: ``Ustedes no son mejores que nosotros", [pero Dios dirá a ambos grupos]: ``Sufran todos el castigo que merecen [por sus obras]".\qt@no{39}}
\qt@newcmd\qurantrans@es@cmxciv{A quienes hayan desmentido Mis signos con soberbia no se les abrirán las puertas del cielo ni entrarán en el Paraíso hasta que un camello pase por el ojo de una aguja. Así castigo a los pecadores.\qt@no{40}}
\qt@newcmd\qurantrans@es@cmxcv{Ellos tendrán allí lechos envolventes de fuego. Así es como castigo a los que cometen injusticias.\qt@no{41}}
\qt@newcmd\qurantrans@es@cmxcvi{Pero quienes hayan creído y realizado obras de bien, y a nadie le exijo una carga mayor a la que puede soportar, serán la gente del Paraíso donde morarán por toda la eternidad.\qt@no{42}}
\qt@newcmd\qurantrans@es@cmxcvii{Purificaré sus corazones del rencor que hubiere entre ellos. Vivirán donde corren ríos y dirán [en agradecimiento]: ``¡Alabado sea Dios, Quien nos guió!, y no hubiéramos podido encaminarnos de no haber sido por Él. La promesa con la que vinieron los Mensajeros de nuestro Señor era verdad". Se les dirá: ``Éste es el Paraíso que han heredado [en recompensa] por lo que solían obrar".\qt@no{43}}
\qt@newcmd\qurantrans@es@cmxcviii{La gente del Paraíso dirá a la gente del Fuego: ``Hemos encontrado lo que nuestro Señor nos había prometido. ¿Acaso no están ustedes padeciendo el castigo que su Señor les había advertido?" Responderán: ``¡Sí!" Entonces se oirá a un pregonero decir: ``¡Qué la maldición de Dios pese sobre los opresores!",\qt@no{44}}
\qt@newcmd\qurantrans@es@cmxcix{Los que apartan [a la gente] del sendero de Dios, tratando de complicarlo, y desmienten el Día del Juicio.\qt@no{45}}
\qt@newcmd\qurantrans@es@m{Entre ambos [grupos] habrá una separación, y en los lugares elevados habrá personas que serán reconocidas por su aspecto [por la gente del Paraíso y la gente del Infierno], y llamarán a la gente del Paraíso saludándolos: ``¡La paz sea con ustedes!" Ellos no han ingresado en él, pero están ansiosos por hacerlo.\qt@no{46}}
\qt@newcmd\qurantrans@es@mi{Cuando dirijan sus miradas hacia los habitantes del Fuego dirán: ``¡Señor nuestro! No nos juntes con la gente que cometió injusticias".\qt@no{47}}
\qt@newcmd\qurantrans@es@mii{La gente de los lugares elevados llamarán a unas personas [habitantes del Fuego] que serán reconocidas por su aspecto, diciéndoles: ``De nada les valieron sus riquezas ni su soberbia.\qt@no{48}}
\qt@newcmd\qurantrans@es@miii{Observen a quienes ustedes juraban que la misericordia de Dios no los alcanzaría, y [contrario a lo que creían] se les dijo: ‘Ingresen al Paraíso, donde no tendrán nada que temer ni sentirán tristezas’".\qt@no{49}}
\qt@newcmd\qurantrans@es@miv{La gente del Fuego implorará a la gente del Paraíso: ``Dennos un poco de agua o algo [para comer] de lo que Dios les ha proveído". Responderán: ``Dios ha vedado esas cosas a los que se negaron a creer".\qt@no{50}}
\qt@newcmd\qurantrans@es@mv{Aquellos que tomaron su religión como juego y diversión, y les sedujo la vida mundanal, hoy los olvidaré así como ellos olvidaron que se encontrarían con este día, y por haber negado Mis signos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mvi{Les envié el Libro, en el que detallé todas las cosas con sabiduría, como guía y misericordia para la gente que cree.\qt@no{52}}
\qt@newcmd\qurantrans@es@mvii{¿Acaso esperan que suceda lo que se les ha advertido [en el Libro]? El día que llegue [la advertencia] dirán quienes lo ignoraron: ``Reconocemos que los Mensajeros de nuestro Señor se presentaron con la Verdad. ¿Acaso habrá quién pueda interceder por nosotros [para salvarnos del castigo] o nos conceda otra oportunidad para volver a la vida mundanal y así poder obrar distinto a lo que hicimos antes?" Se perdieron a sí mismos y no podrán encontrar [a las divinidades] que inventaron.\qt@no{53}}
\qt@newcmd\qurantrans@es@mviii{Su Señor es Dios, Quien creó los cielos y la Tierra en seis eras, y luego se estableció sobre el Trono. Hace que la noche y el día se sucedan. Creó el Sol, la Luna y las estrellas sometiéndolas a Su voluntad. ¿Acaso no Le pertenece la creación y Él es Quien dictamina las órdenes según Él quiere? ¡Bendito sea Dios, Señor del universo!\qt@no{54}}
\qt@newcmd\qurantrans@es@mix{Invoquen a su Señor con humildad en privado. Él no ama a los transgresores.\qt@no{55}}
\qt@newcmd\qurantrans@es@mx{No siembren corrupción en la Tierra después de que se haya establecido en ella el orden, e invóquenlo con temor y esperanza. La misericordia de Dios está cerca de los que hacen el bien.\qt@no{56}}
\qt@newcmd\qurantrans@es@mxi{Él es Quien envía los vientos que albrician la llegada de Su misericordia. Cuando éstos reúnen a las nubes, las conduzco hacia una tierra azotada por la sequía donde hago descender la lluvia con la que hago brotar toda clase de frutos. De la misma manera haré resucitar a los muertos; ¡reflexionen!\qt@no{57}}
\qt@newcmd\qurantrans@es@mxii{En una buena tierra crece vegetación abundante por voluntad de su Señor, mientras que en un territorio desértico no brota sino poco. Así explico los signos a la gente agradecida.\qt@no{58}}
\qt@newcmd\qurantrans@es@mxiii{Envié a Noé a su pueblo. Les dijo: ``¡Oh, pueblo mío! Adoren solamente a Dios, pues no existe otra divinidad salvo Él. Temo que los azote un castigo terrible [si continúan en la idolatría].\qt@no{59}}
\qt@newcmd\qurantrans@es@mxiv{Los nobles de su pueblo dijeron [con soberbia]: ``Vemos que estás en un error evidente".\qt@no{60}}
\qt@newcmd\qurantrans@es@mxv{Dijo [Noé]: ``¡Oh, pueblo mío! No hay en mí extravío alguno, sino que soy un Mensajero del Señor del universo.\qt@no{61}}
\qt@newcmd\qurantrans@es@mxvi{Les transmito el Mensaje de mi Señor y les aconsejo para su bien, puesto que sé acerca de Dios lo que ustedes ignoran".\qt@no{62}}
\qt@newcmd\qurantrans@es@mxvii{¿Se asombran de que les llegue el Mensaje de su Señor por intermedio de un hombre igual a ustedes, que les advierte para que tengan temor de Dios y quizás así alcancen la misericordia?\qt@no{63}}
\qt@newcmd\qurantrans@es@mxviii{Pero lo desmintieron. Entonces lo salvé junto a quienes estaban con él en el arca, y ahogué a quienes habían desmentido Mis signos. Ellos fueron gente ciega.\qt@no{64}}
\qt@newcmd\qurantrans@es@mxix{Al pueblo ‘Ad le envié a su hermano Hud [como Profeta]. Les dijo: ``¡Oh, pueblo mío! Adoren a Dios, pues no existe otra divinidad salvo Él. ¿Acaso no van a tener temor [de Dios]?"\qt@no{65}}
\qt@newcmd\qurantrans@es@mxx{Los nobles que no creyeron de su pueblo le dijeron: ``Te vemos en una insensatez, y creemos que eres un mentiroso".\qt@no{66}}
\qt@newcmd\qurantrans@es@mxxi{Dijo [Hud]: ``¡Oh, pueblo mío! No estoy en ninguna insensatez, solo soy un Mensajero enviado por el Señor del universo,\qt@no{67}}
\qt@newcmd\qurantrans@es@mxxii{que les transmito el Mensaje de mi Señor. Yo soy un consejero leal".\qt@no{68}}
\qt@newcmd\qurantrans@es@mxxiii{¿Se asombran de que les haya llegado un Mensaje de su Señor a través de un hombre de los suyos para advertirles? Recuerden cuando Dios hizo que sucedieran al pueblo [destruido] de Noé, y les concedió mayor fortaleza física. Recuerden las gracias de Dios para que así tengan éxito.\qt@no{69}}
\qt@newcmd\qurantrans@es@mxxiv{Dijeron: ``¿Acaso has venido para que adoremos a Dios solamente y abandonemos lo que adoraban nuestros padres? Haz que se cumpla el castigo con que nos amenazas si es que dices la verdad".\qt@no{70}}
\qt@newcmd\qurantrans@es@mxxv{Dijo: ``Los azotará un castigo terrible [por lo que dicen] y habrán caído en la ira de su Señor. ¿Me van a discutir por [ídolos de piedra] a los que han denominado divinidades ustedes y sus padres? Dios no les dio autoridad alguna [para ello], aguarden [el castigo], que yo aguardaré [el socorro de Dios]".\qt@no{71}}
\qt@newcmd\qurantrans@es@mxxvi{Lo salvé por Mi misericordia junto a los que creyeron, pero destruí a todos los que habían desmentido Mis signos porque se negaron a creer.\qt@no{72}}
\qt@newcmd\qurantrans@es@mxxvii{A Zamud le envié a su hermano [el Profeta] Sálih. Les dijo: ``¡Oh, pueblo mío! Adoren a Dios, pues no existe otra divinidad salvo Él. Ésta es la camella de Dios, es un milagro enviado por su Señor, déjenla comer en la tierra de Dios y no le causen ningún daño, porque si lo hacen los azotará un castigo doloroso.\qt@no{73}}
\qt@newcmd\qurantrans@es@mxxviii{Recuerden que [Dios] los hizo sucesores después de ‘Ad, y los estableció en su tierra. Ustedes construían palacios en sus llanuras y esculpían casas en las montañas. Recuerden las gracias de Dios, y no siembren maldad en la tierra como los corruptos".\qt@no{74}}
\qt@newcmd\qurantrans@es@mxxix{Dijeron los nobles soberbios de su pueblo a los más débiles que habían creído: ``¿Acaso piensan que Sálih es un Mensajero de su Señor?" Les respondieron: ``Creemos en el Mensaje que nos transmite".\qt@no{75}}
\qt@newcmd\qurantrans@es@mxxx{Los soberbios dijeron: ``Nosotros rechazamos lo que ustedes creen".\qt@no{76}}
\qt@newcmd\qurantrans@es@mxxxi{Y mataron a la camella, desobedeciendo la orden de su Señor, y dijeron: ``¡Oh, Sálih! Haz que se desencadene el castigo con el que nos adviertes, si realmente eres uno de los Mensajeros [de Dios]".\qt@no{77}}
\qt@newcmd\qurantrans@es@mxxxii{[Como consecuencia] los destruyó un temblor, y amanecieron en sus casas [muertos] caídos de bruces.\qt@no{78}}
\qt@newcmd\qurantrans@es@mxxxiii{[Sálih] se apartó de ellos diciendo: ``¡Oh, pueblo mío! Les transmití el Mensaje de mi Señor y les aconsejé para su bien, pero ustedes no aprecian a quienes los aconsejan".\qt@no{79}}
\qt@newcmd\qurantrans@es@mxxxiv{[Envié a] Lot [a Sodoma], le dijo a su pueblo: ``¿Cometen una inmoralidad de la que no hay precedentes en la humanidad?\qt@no{80}}
\qt@newcmd\qurantrans@es@mxxxv{Satisfacen sus deseos con hombres en vez de hacerlo con mujeres, son trasgresores".\qt@no{81}}
\qt@newcmd\qurantrans@es@mxxxvi{Pero la respuesta de su pueblo no fue otra que: ``Expúlsenlos de la ciudad, pues son gente que mantiene su pureza [negándose a actuar como nosotros]".\qt@no{82}}
\qt@newcmd\qurantrans@es@mxxxvii{Lo salvé junto a su familia, excepto a su esposa, que se quedó atrás [y no salió de la ciudad].\qt@no{83}}
\qt@newcmd\qurantrans@es@mxxxviii{Envié sobre ellos una lluvia. Observa cómo es el final de los que cometen crímenes [morales].\qt@no{84}}
\qt@newcmd\qurantrans@es@mxxxix{A Madián le envié [como Profeta] a su hermano Jetró, quien les dijo: ``¡Oh, pueblo mío! Adoren a Dios, pues no existe otra divinidad salvo Él. Les ha llegado un milagro de su Señor [que corrobora mi profecía]. Midan y pesen con equidad, no se apropien de los bienes del prójimo, y no siembren mal en la Tierra, corrompiéndola luego de haberse establecido la justicia. Esto es mejor para ustedes, si es que son creyentes.\qt@no{85}}
\qt@newcmd\qurantrans@es@mxl{No embosquen en los caminos a los creyentes para intimidarlos y apartarlos del sendero de Dios con el fin de desviarlos. Recuerden que ustedes eran pocos y Él los multiplicó. Observen cuál fue el destino de los que sembraron la corrupción".\qt@no{86}}
\qt@newcmd\qurantrans@es@mxli{[Jetró dijo:] ``Entre ustedes hay quienes creen en el Mensaje con el que fui enviado y quienes no, tengan paciencia hasta que Dios juzgue entre ustedes; y sepan que Él es el mejor de los jueces".\qt@no{87}}
\qt@newcmd\qurantrans@es@mxlii{Dijeron los nobles de su pueblo con soberbia: ``Te expulsaremos de nuestra ciudad, a ti, ¡oh, Jetró!, y también a los creyentes, a menos que vuelvan a nuestra religión". [Jetró] replicó: ``¿Aunque sea en contra de nuestra voluntad?\qt@no{88}}
\qt@newcmd\qurantrans@es@mxliii{Estaríamos mintiendo acerca de Dios si volviéramos a su religión después de que Dios nos ha salvado de ella, y no volveremos a ella salvo que fuera la voluntad de Dios, nuestro Señor. Su conocimiento lo abarca todo y a Dios nos encomendamos. ¡Oh, Señor nuestro! Juzga entre nosotros y nuestro pueblo, Tú eres el mejor de los jueces".\qt@no{89}}
\qt@newcmd\qurantrans@es@mxliv{Los nobles de su pueblo que rechazaron la verdad dijeron: ``Si siguen a Jetró serán de los perdedores".\qt@no{90}}
\qt@newcmd\qurantrans@es@mxlv{Entonces los sorprendió un temblor y amanecieron en sus casas [muertos], caídos de bruces.\qt@no{91}}
\qt@newcmd\qurantrans@es@mxlvi{[Las casas de] quienes desmintieron a Jetró quedaron como si jamás hubieran sido habitadas. Quienes desmintieron a Jetró fueron [realmente] los perdedores.\qt@no{92}}
\qt@newcmd\qurantrans@es@mxlvii{[Jetró] se alejó de ellos y dijo: ``¡Oh, pueblo mío! Les transmití el Mensaje de mi Señor y los aconsejé para su bien. ¿Por qué iba a sentir pena por un pueblo que persistió en la incredulidad?"\qt@no{93}}
\qt@newcmd\qurantrans@es@mxlviii{Cada vez que envié un Profeta a una ciudad [y lo desmintieron], los azoté con la miseria y los padecimientos para que se volvieran humildes.\qt@no{94}}
\qt@newcmd\qurantrans@es@mxlix{Luego les cambié sus dificultades por bienestar. Pero cuando prosperaron, dijeron: ``Era común que nuestros padres atravesaran épocas de adversidad y prosperidad"; entonces los castigué sorpresivamente, sin que se dieran cuenta.\qt@no{95}}
\qt@newcmd\qurantrans@es@ml{Pero si la gente de esas ciudades hubiera creído y tenido temor [de Dios], les habría abierto las bendiciones del cielo y de la Tierra. Pero desmintieron [a Mis Profetas] y los castigué por lo que habían cometido.\qt@no{96}}
\qt@newcmd\qurantrans@es@mli{¿Acaso la gente de esas ciudades se sentían seguros de que Mi ira no podría alcanzarlos por la noche, mientras dormían?\qt@no{97}}
\qt@newcmd\qurantrans@es@mlii{¿O acaso la gente de esas ciudades se sentían seguros de que no podría llegarles Mi castigo por la mañana, cuando estuvieran distraídos?\qt@no{98}}
\qt@newcmd\qurantrans@es@mliii{¿Acaso se sentían a salvo del plan de Dios? Solo se sienten a salvo del plan de Dios los que están perdidos.\qt@no{99}}
\qt@newcmd\qurantrans@es@mliv{¿Es que no se les ha evidenciado a quienes les sucedieron, que si quisiera los castigaría por sus pecados, sellando sus corazones para que no escucharan?\qt@no{100}}
\qt@newcmd\qurantrans@es@mlv{[¡Oh, Mujámmad!] Te he relatado acerca de la gente de aquellas ciudades a las que se les presentaron sus Profetas con milagros y no les creyeron, al igual que no creían antes. Así es como Dios sella los corazones de los que rechazan la verdad.\qt@no{101}}
\qt@newcmd\qurantrans@es@mlvi{La mayoría de ellos no cumplían sus compromisos y eran perversos.\qt@no{102}}
\qt@newcmd\qurantrans@es@mlvii{Envié, después de ellos, a Moisés con Mis milagros al Faraón y su nobleza, pero los negaron injustamente. Observa cuál fue el final de los corruptos.\qt@no{103}}
\qt@newcmd\qurantrans@es@mlviii{Dijo Moisés: ``¡Oh, Faraón! Soy un Mensajero del Señor del universo.\qt@no{104}}
\qt@newcmd\qurantrans@es@mlix{Es un deber para mí transmitirte la verdad acerca de Dios. Te traigo milagros evidentes de tu Señor. Deja ir conmigo a los Hijos de Israel".\qt@no{105}}
\qt@newcmd\qurantrans@es@mlx{Dijo [el Faraón]: ``Si has traído un milagro, muéstramelo si eres sincero".\qt@no{106}}
\qt@newcmd\qurantrans@es@mlxi{Entonces arrojó su vara, y esta se convirtió en una serpiente real.\qt@no{107}}
\qt@newcmd\qurantrans@es@mlxii{Luego introdujo su mano por el cuello de su túnica y, al retirarla ante todos los presentes, estaba blanca y resplandeciente.\qt@no{108}}
\qt@newcmd\qurantrans@es@mlxiii{Dijo la nobleza del pueblo del Faraón: ``Él es un hechicero experto.\qt@no{109}}
\qt@newcmd\qurantrans@es@mlxiv{[En realidad lo que] quiere es expulsarlos de su tierra". [Les preguntó el Faraón:] ``¿Cuál es su consejo?"\qt@no{110}}
\qt@newcmd\qurantrans@es@mlxv{Dijeron [los nobles]: ``Retenlos a él y a su hermano, y envía reclutadores a las ciudades\qt@no{111}}
\qt@newcmd\qurantrans@es@mlxvi{para que te traigan a todo hechicero experto".\qt@no{112}}
\qt@newcmd\qurantrans@es@mlxvii{Los hechiceros se presentaron ante el Faraón y dijeron: ``Exigimos una recompensa si somos los vencedores".\qt@no{113}}
\qt@newcmd\qurantrans@es@mlxviii{Dijo el Faraón: ``¡Sí! Se los recompensará y serán de mis allegados".\qt@no{114}}
\qt@newcmd\qurantrans@es@mlxix{Dijeron [los hechiceros]: ``¡Oh, Moisés! Arroja tú o lo hacemos nosotros".\qt@no{115}}
\qt@newcmd\qurantrans@es@mlxx{Dijo: ``¡Arrojen ustedes!" Cuando los hechiceros arrojaron [sus varas], hechizaron los ojos de la gente y los aterrorizaron. Su hechizo era poderoso.\qt@no{116}}
\qt@newcmd\qurantrans@es@mlxxi{Pero le revelé a Moisés: ``Arroja tu vara", y [al transformarse en serpiente] se tragó [la ilusión que los hechiceros] habían hecho.\qt@no{117}}
\qt@newcmd\qurantrans@es@mlxxii{Entonces quedó en evidencia la verdad y la falsedad de lo que [los hechiceros] habían hecho.\qt@no{118}}
\qt@newcmd\qurantrans@es@mlxxiii{Y fueron vencidos [los hechiceros] quedando humillados.\qt@no{119}}
\qt@newcmd\qurantrans@es@mlxxiv{Pero los hechiceros se prosternaron.\qt@no{120}}
\qt@newcmd\qurantrans@es@mlxxv{Dijeron: ``Creemos en el Señor del universo,\qt@no{121}}
\qt@newcmd\qurantrans@es@mlxxvi{el Señor de Moisés y de Aarón".\qt@no{122}}
\qt@newcmd\qurantrans@es@mlxxvii{Dijo el Faraón: ``¿Acaso van a creer en él sin que yo se los haya autorizado? Esto se trata de una conspiración para expulsar [de Egipto] a sus habitantes, pero ya verán.\qt@no{123}}
\qt@newcmd\qurantrans@es@mlxxviii{Haré que les amputen una mano y el pie del lado opuesto, luego los haré clavar sobre un madero".\qt@no{124}}
\qt@newcmd\qurantrans@es@mlxxix{Dijeron [los hechiceros]: ``A nuestro Señor hemos de retornar.\qt@no{125}}
\qt@newcmd\qurantrans@es@mlxxx{Solo te vengas de nosotros porque hemos creído cuando llegaron los milagros de nuestro Señor. ¡Señor nuestro! Danos paciencia y haznos morir musulmanes, sometidos a Ti".\qt@no{126}}
\qt@newcmd\qurantrans@es@mlxxxi{Pero la nobleza del pueblo del Faraón dijo: ``¿Dejarás a Moisés y a su pueblo sembrar la corrupción en la Tierra, que te abandonen a ti y a tus dioses?" Dijo [el Faraón]: ``Mataremos a sus hijos varones y dejaremos con vida a las mujeres, así los subyugaremos".\qt@no{127}}
\qt@newcmd\qurantrans@es@mlxxxii{Moisés dijo a su pueblo: ``Busquen la ayuda de Dios y sean pacientes [ante esta prueba]. La Tierra es de Dios, y la dará en herencia a quien quiera de Sus siervos. El buen fin es para los que tienen temor [de Dios]".\qt@no{128}}
\qt@newcmd\qurantrans@es@mlxxxiii{Dijeron [sus seguidores]: ``Hemos sufrido antes de ti y también ahora que tú has venido". Dijo [Moisés]: ``Quiera Dios aniquilar a sus enemigos y hacer que ustedes los sucedan en la Tierra, que Él observará cómo obran ustedes".\qt@no{129}}
\qt@newcmd\qurantrans@es@mlxxxiv{Entonces azoté a la gente del Faraón con años de sequía y escasez de frutos, para que reflexionaran.\qt@no{130}}
\qt@newcmd\qurantrans@es@mlxxxv{Pero cuando les llegó nuevamente una época de prosperidad dijeron: ``Esto es lo que merecemos". Cuando les acontecía un mal le echaban la culpa a Moisés y a sus seguidores [por considerarlos de mal agüero]; pero cuanto les ocurría era porque Dios así lo decretaba, aunque la mayoría de ellos lo ignoraba.\qt@no{131}}
\qt@newcmd\qurantrans@es@mlxxxvi{Dijeron: ``Cualquiera que sea el milagro que nos presentes para hechizarnos con él, no creeremos en ti".\qt@no{132}}
\qt@newcmd\qurantrans@es@mlxxxvii{Envié entonces contra ellos [las plagas de] la inundación, las langostas, los piojos, las ranas y la sangre, como signos claros, pero se llenaron de soberbia y actuaron como criminales.\qt@no{133}}
\qt@newcmd\qurantrans@es@mlxxxviii{Cuando les llegó el castigo, dijeron: ``¡Oh, Moisés! Ruega por nosotros a tu Señor, puesto que ha realizado un pacto contigo. Si logras apartar este castigo creeremos en ti y dejaremos ir contigo a los Hijos de Israel".\qt@no{134}}
\qt@newcmd\qurantrans@es@mlxxxix{Pero cuando aparté de ellos el castigo hasta el tiempo fijado, no cumplieron.\qt@no{135}}
\qt@newcmd\qurantrans@es@mxc{Entonces los castigué con justicia e hice que se ahogaran en el mar, porque habían desmentido Mis signos y habían sido indiferentes [ante los milagros].\qt@no{136}}
\qt@newcmd\qurantrans@es@mxci{Le di a los Hijos de Israel, luego de que fueran humillados, las tierras que bendije al este y al oeste [de Egipto], y se cumplió así la promesa de tu Señor con los Hijos de Israel porque fueron pacientes, pero destruí cuanto habían construido el Faraón y su pueblo.\qt@no{137}}
\qt@newcmd\qurantrans@es@mxcii{Hice que los Hijos de Israel cruzaran el mar, pero cuando llegaron a un pueblo que se prosternaba ante los ídolos dijeron: ``¡Oh, Moisés! Queremos que nos hagas un ídolo similar a los que tienen ellos". Dijo [Moisés]: ``Ustedes son gente ignorante.\qt@no{138}}
\qt@newcmd\qurantrans@es@mxciii{Ellos serán destruidos por lo que hacen, y sus obras serán en vano".\qt@no{139}}
\qt@newcmd\qurantrans@es@mxciv{Dijo: ``¿Cómo podría admitir que ustedes adoren ídolos en vez de Dios, siendo que Él los distinguió entre sus contemporáneos?\qt@no{140}}
\qt@newcmd\qurantrans@es@mxcv{Recuerden cuando los salvó del Faraón y su ejército, que los castigaba con el peor de los castigos, matando a sus hijos varones y dejando con vida a las mujeres; esa fue una prueba dura de su Señor".\qt@no{141}}
\qt@newcmd\qurantrans@es@mxcvi{Cité a Moisés durante treinta noches que completé con diez noches más. El encuentro con su Señor duró cuarenta noches. [Antes de partir hacia la cita,] Moisés dijo a su hermano Aarón: ``Ocupa mi lugar ante mi pueblo y ordena el bien, y no sigas el sendero de los corruptos".\qt@no{142}}
\qt@newcmd\qurantrans@es@mxcvii{Cuando Moisés acudió al encuentro y su Señor le habló, [Moisés] le pidió: ``Muéstrate para que pueda verte". Dijo [Dios]: ``No podrías verme. Pero observa la montaña, si permanece firme en su lugar [después de mostrarme a ella], entonces tú también podrás verme". Y cuando su Señor se mostró a la montaña, ésta se convirtió en polvo y Moisés cayó inconsciente. Cuando volvió en sí exclamó: ``¡Glorificado seas! Me arrepiento y soy el primero en creer en Ti".\qt@no{143}}
\qt@newcmd\qurantrans@es@mxcviii{Dijo [Dios]: ``¡Oh, Moisés! Te he distinguido entre las personas con la profecía y por haberte hablado directamente. Aférrate a lo que te he revelado y sé de los agradecidos".\qt@no{144}}
\qt@newcmd\qurantrans@es@mxcix{Escribí para él en las tablas instrucción y explicación de todas las cosas. ``Aférrate a ellas y ordena a tu pueblo que siga todo lo bueno que hay en ellas. Les mostraré [cómo quedaron] las casas de los desviados".\qt@no{145}}
\qt@newcmd\qurantrans@es@mc{Alejaré de Mis signos a quienes actúen con soberbia en la Tierra sin razón. Aunque vean todos los milagros no creerán. Si ven el sendero de la guía no lo seguirán y, por el contrario, cuando vean el sendero del desvío se extraviarán. Esto es por haber desmentido Mis signos y haber sido negligentes.\qt@no{146}}
\qt@newcmd\qurantrans@es@mci{Quienes desmientan Mis signos y no crean en el Día del Juicio sus obras habrán sido en vano. ¿Acaso no se les castigará sino por lo que ellos mismos hicieron?\qt@no{147}}
\qt@newcmd\qurantrans@es@mcii{Cuando [Moisés] partió [hacia el encuentro con su Señor] su pueblo hizo, con las joyas que tenían, un becerro [de oro] que emitía un mugido. ¿Acaso no veían que éste [ídolo] no les podía hablar ni guiarlos? Aun así lo adoraron, cometiendo una injusticia.\qt@no{148}}
\qt@newcmd\qurantrans@es@mciii{Pero cuando se arrepintieron y vieron que se habían desviado, exclamaron: ``Si nuestro Señor no tiene misericordia de nosotros y nos perdona, seremos de los perdedores".\qt@no{149}}
\qt@newcmd\qurantrans@es@mciv{Cuando Moisés volvió a su pueblo, [se sintió] enojado y afligido, y dijo: ``¡Qué mal está lo que hicieron durante mi ausencia! ¿Acaso pretenden que se les precipite el castigo de su Señor?" Y arrojó las tablas, tomando a su hermano por la cabeza y acercándolo a él. Entonces [su hermano Aarón] le dijo: ``¡Oh, hermano mío! Nuestro pueblo me menospreció y por poco me matan. No permitas que los enemigos se regocijen con esta situación y no me consideres de los que cometen injusticias".\qt@no{150}}
\qt@newcmd\qurantrans@es@mcv{Dijo Moisés: ``¡Oh, Señor mío! Perdona a mi hermano y a mí, y ten misericordia de nosotros. Tú eres el más Misericordioso".\qt@no{151}}
\qt@newcmd\qurantrans@es@mcvi{La ira de Dios azotará a aquellos que adoraron el becerro, y serán humillados en esta vida mundanal. Así es como castigo a quienes inventan mentiras.\qt@no{152}}
\qt@newcmd\qurantrans@es@mcvii{Quienes obren mal pero luego se arrepientan y crean, sepan que tu Señor, a pesar de lo que hicieron, es Absolvedor, Misericordioso.\qt@no{153}}
\qt@newcmd\qurantrans@es@mcviii{Cuando Moisés calmó su ira recogió las tablas. En ellas hay guía y misericordia para quienes tienen temor de su Señor.\qt@no{154}}
\qt@newcmd\qurantrans@es@mcix{Moisés eligió entre su pueblo a setenta hombres para una cita conmigo, y cuando les azotó un violento temblor, [Moisés] exclamó: ``¡Señor mío! Si hubieras querido los habrías aniquilado antes y a mí también. ¿Acaso nos aniquilarás por lo que han cometido los necios que hay entre nosotros? [El becerro] no es sino una prueba con la que extravías y guías a quien quieres. Tú eres nuestro protector, perdónanos y ten misericordia de nosotros. Tú eres el más Indulgente.\qt@no{155}}
\qt@newcmd\qurantrans@es@mcx{Concédenos bienestar en esta vida y en la otra; nos hemos vuelto a Ti arrepentidos". Dijo [Dios]: ``Azoto con Mi castigo a quien quiero, pero sepan que Mi misericordia lo abarca todo, y se la concederé a los piadosos que pagan el zakat y creen en Mis signos,\qt@no{156}}
\qt@newcmd\qurantrans@es@mcxi{aquellos que sigan al Mensajero y Profeta iletrado [Mujámmad], quien se encuentra descrito en la Tora y el Evangelio; [el Profeta] que les ordena el bien y les prohíbe el mal, les permite todo lo beneficioso y solo les prohíbe lo perjudicial, y les abroga los preceptos difíciles que pesaban sobre ellos [la Gente del Libro]. Y quienes crean en él, lo secunden, defiendan y sigan la luz que le ha sido revelada, serán los bienaventurados".\qt@no{157}}
\qt@newcmd\qurantrans@es@mcxii{Di [oh, Mujámmad]: ``¡Oh, gente! Soy el Mensajero de Dios para todos ustedes. A Él pertenece el reino de los cielos y de la Tierra, nada ni nadie merece ser adorado salvo Él, da la vida y la muerte". Crean en Dios y en Su Mensajero y Profeta iletrado que cree en Dios y en Sus palabras, síganlo, pues así estarán bien guiados.\qt@no{158}}
\qt@newcmd\qurantrans@es@mcxiii{En el pueblo de Moisés hay una comunidad que se rige por la verdad [revelada] y conforme a ella emiten sus juicios\qt@no{159}}
\qt@newcmd\qurantrans@es@mcxiv{Los dividí en doce tribus, como naciones; y le inspiré a Moisés cuando su pueblo le solicitó [agua para] beber [diciéndole]: ``Golpea la roca con tu vara", y brotaron de ella doce manantiales y cada tribu supo cuál era su abrevadero, y los protegí con la sombra de una nube e hice descender para ellos el maná y las codornices [y les dije]: ``Coman de lo bueno con que los he agraciado". Pero no fue contra Mí que cometieron una injusticia, sino que la cometieron contra ellos mismos.\qt@no{160}}
\qt@newcmd\qurantrans@es@mcxv{Y se les dijo: ``Habiten esta ciudad y coman cuanto quieran de lo que hay en ella, y digan: ``¡Perdónanos!", pero entren sumisos por la puerta prosternados, que perdonaré sus pecados, y a los que hagan el bien les concederé aún más.\qt@no{161}}
\qt@newcmd\qurantrans@es@mcxvi{Pero los injustos de ellos cambiaron la palabra que se les ordenó decir por otra diferente, y entonces envié sobre ellos un castigo del cielo por haber obrado injustamente.\qt@no{162}}
\qt@newcmd\qurantrans@es@mcxvii{Y pregúntales [¡oh, Mujámmad!] por [los habitantes de] la ciudad que estaba a orillas del mar que transgredían el sábado, cuando los peces aparecían el sábado y los demás días no; así es como les puse una prueba por haber sido soberbios.\qt@no{163}}
\qt@newcmd\qurantrans@es@mcxviii{Un grupo de gente justa de entre ellos preguntaron [a quienes exhortaban al bien]: ``¿Por qué exhortan a un pueblo al que Dios aniquilará o castigará duramente?" Respondieron: ``Para que nuestro Señor no nos castigue por no haber ordenado el bien, y para que quizás tengan temor [de Dios]".\qt@no{164}}
\qt@newcmd\qurantrans@es@mcxix{Pero cuando olvidaron lo que se les había prohibido, salvé a quienes se oponían al mal y azoté a los que cometían injusticias con un castigo terrible a causa de su perversión.\qt@no{165}}
\qt@newcmd\qurantrans@es@mcxx{Cuando transgredieron lo que se les había prohibido, les dije: ``Conviértanse en monos despreciables".\qt@no{166}}
\qt@newcmd\qurantrans@es@mcxxi{Tu Señor anunció que les enviaría a quienes les infligieran un castigo severo hasta el Día de la Resurrección. Tu Señor es rápido en aplicar el castigo, pero también es Absolvedor, Misericordioso.\qt@no{167}}
\qt@newcmd\qurantrans@es@mcxxii{Por eso los dividí en comunidades y los dispersé por la Tierra. Entre ellos hay justos y otros que no lo son. Los probaré con tiempos de prosperidad y otros de adversidad para que recapaciten.\qt@no{168}}
\qt@newcmd\qurantrans@es@mcxxiii{[A ellos] les sucedió una generación que heredó el Libro [la Tora], pero a pesar de eso prefirieron los bienes materiales de este mundo. [Cada vez que cometían un pecado] decían: ``[Dios] nos perdonará". Pero cuando se les presentaba una nueva posibilidad volvían a pecar. ¿Acaso no se comprometieron a cumplir con la Tora y no decir acerca de Dios sino la verdad? Aun habiendo estudiado la Tora [desobedecieron], pero para los piadosos la otra vida es preferible. ¿Es que no reflexionan?\qt@no{169}}
\qt@newcmd\qurantrans@es@mcxxiv{Aquellos que se aferran al Libro y realizan la oración prescrita sepan que jamás dejaré de recompensar a los que hacen el bien.\qt@no{170}}
\qt@newcmd\qurantrans@es@mcxxv{Recuerda cuando elevé la montaña por encima de ellos como si fuese una nube oscura y creyeron que se desplomaría, y [les dije:] ``aférrense a lo que les he concedido [la Tora] y obren según sus preceptos, que así serán piadosos".\qt@no{171}}
\qt@newcmd\qurantrans@es@mcxxvi{Cuando tu Señor sacó de las espaldas de los hijos de Adán a su descendencia y los hizo dar testimonio [preguntándoles]: ``¿Acaso no Soy Yo su Señor?" Respondieron: ``Sí, atestiguamos que así es". Esto es para que el Día de la Resurrección no digan: ``No sabíamos nada de esto".\qt@no{172}}
\qt@newcmd\qurantrans@es@mcxxvii{O digan: ``Nuestros padres eran idólatras, y nosotros solo somos sus descendientes siguiendo lo que ellos hacían. ¿Acaso vas a castigarnos por lo que hicieron los que falsearon [la verdad del monoteísmo]?"\qt@no{173}}
\qt@newcmd\qurantrans@es@mcxxviii{Así es como explico los signos para que recapaciten.\qt@no{174}}
\qt@newcmd\qurantrans@es@mcxxix{Y relátales la historia de aquel a quien habiéndole concedido el conocimiento de Mis preceptos, los descuidó, el demonio lo sedujo y fue de los extraviados.\qt@no{175}}
\qt@newcmd\qurantrans@es@mcxxx{Y si hubiera querido habría elevado su rango [en esta vida y en la otra, preservándolo], pero se inclinó por los placeres de este mundo y siguió sus pasiones. Se comportó como el perro que si lo llamas jadea, y si lo dejas también jadea. Éste es el ejemplo de quienes desmienten Mis signos. Nárrales estas historias a ver si reflexionan.\qt@no{176}}
\qt@newcmd\qurantrans@es@mcxxxi{¡Qué pésimo es el ejemplo de quienes desmienten Mis signos, y son injustos con ellos mismos!\qt@no{177}}
\qt@newcmd\qurantrans@es@mcxxxii{A quien Dios guíe estará encaminado, pero a quien [Dios] extravíe estará perdido.\qt@no{178}}
\qt@newcmd\qurantrans@es@mcxxxiii{He creado muchos yinnes y seres humanos que irán al Infierno [a causa de sus obras]. Tienen corazones pero no pueden comprender, ojos pero no pueden ver y oídos pero no pueden oír. Son como los ganados que no razonan, o peor aún. Ellos son los que se comportan con indiferencia [ante Mis signos].\qt@no{179}}
\qt@newcmd\qurantrans@es@mcxxxiv{A Dios pertenecen los nombres más sublimes, invócalo a través de ellos, y apártate de quienes los niegan. Serán castigados por lo que hicieron.\qt@no{180}}
\qt@newcmd\qurantrans@es@mcxxxv{Algunos de Mi creación guían [a la gente] con la Verdad, y acorde a ella establecen justicia.\qt@no{181}}
\qt@newcmd\qurantrans@es@mcxxxvi{A quienes desmientan Mis signos los degradaré paulatinamente sin que puedan darse cuenta.\qt@no{182}}
\qt@newcmd\qurantrans@es@mcxxxvii{Los toleraré temporalmente [hasta el Día del Juicio], puesto que Mi castigo es una promesa firme.\qt@no{183}}
\qt@newcmd\qurantrans@es@mcxxxviii{¿Acaso no se dieron cuenta de que su Mensajero no es un demente? Él es un claro amonestador.\qt@no{184}}
\qt@newcmd\qurantrans@es@mcxxxix{¿Acaso no reflexionaron en el reino de los cielos y de la Tierra y lo que Dios creó en él, ni tampoco en que el final de sus vidas pudiere estar próximo? Si no creen en este Mensaje, ¿en qué otro iban a creer?\qt@no{185}}
\qt@newcmd\qurantrans@es@mcxl{A quien Dios extravía nadie lo podrá guiar. A éstos Dios los deja que actúen desorientados en su ceguera.\qt@no{186}}
\qt@newcmd\qurantrans@es@mcxli{Te preguntan cuándo llegará la Hora [del Día de la Resurrección]. Diles: ``Solo mi Señor lo sabe, y nadie salvo Él hará que comience en el momento decretado. Los cielos y la Tierra temen su llegada. Cuando llegue los sorprenderá". Te preguntan como si supieras [cuándo ocurrirá]. Diles: ``Su conocimiento solo Le pertenece a Dios, pero la mayoría de la gente no lo sabe".\qt@no{187}}
\qt@newcmd\qurantrans@es@mcxlii{Diles [oh, Mujámmad]: ``No poseo ningún poder para beneficiarme ni perjudicarme a mí mismo, salvo lo que Dios quiera. Si tuviera conocimiento de lo oculto tendría abundantes bienes materiales y no me alcanzaría nunca un mal. Yo solo soy un amonestador y albriciador para la gente que cree".\qt@no{188}}
\qt@newcmd\qurantrans@es@mcxliii{Él es Quien los creó a partir de un solo ser, del cual hizo surgir a su cónyuge para que encontrara en ella sosiego. Y cuando se unió a ella, quedó embarazada y llevó en su vientre una carga liviana con la que podía andar, pero cuando ésta se hizo pesada, ambos invocaron a Dios [diciendo]: ``¡Oh, Señor nuestro! Si nos agracias con un hijo sano y virtuoso seremos agradecidos".\qt@no{189}}
\qt@newcmd\qurantrans@es@mcxliv{Y se les agració con lo que suplicaron, pero [sus descendientes] dedicaron actos de adoración a otros además de Dios; y Dios está por encima de lo que Le asocian.\qt@no{190}}
\qt@newcmd\qurantrans@es@mcxlv{¿Acaso adoran a quienes no pueden crear nada, sino por el contrario, ellos mismos fueron creados?\qt@no{191}}
\qt@newcmd\qurantrans@es@mcxlvi{No pueden auxiliarlos, ni tampoco auxiliarse a sí mismos.\qt@no{192}}
\qt@newcmd\qurantrans@es@mcxlvii{Si ustedes los invitan a seguir la guía, no lo harán. Lo mismo da que los inviten o que se queden callados.\qt@no{193}}
\qt@newcmd\qurantrans@es@mcxlviii{Lo que adoran en vez de Dios son seres creados igual que ustedes. [Los desafío:] Invóquenlos y que les respondan, si es verdad lo que dicen.\qt@no{194}}
\qt@newcmd\qurantrans@es@mcxlix{¿Tienen acaso piernas con las que caminan? ¿O manos con las que toman? ¿U ojos con los que ven? ¿U oídos con los que oyen? Di: ``Invoquen a los que asocian y luego tramen contra mí sin más demora".\qt@no{195}}
\qt@newcmd\qurantrans@es@mcl{Mi protector es Dios, Quien reveló el Libro. Él es Quien protege a los justos.\qt@no{196}}
\qt@newcmd\qurantrans@es@mcli{Los que ustedes invocan en vez de Dios no pueden auxiliarlos ni auxiliarse a ellos mismos.\qt@no{197}}
\qt@newcmd\qurantrans@es@mclii{Cuando ustedes los invocan pidiendo guía, no los oyen. Pareciera que los miran, pero en realidad no los ven.\qt@no{198}}
\qt@newcmd\qurantrans@es@mcliii{[¡Oh, Mujámmad!] Ante todo, elige perdonar, ordena el bien y apártate de quienes se comportan contigo en forma ignorante.\qt@no{199}}
\qt@newcmd\qurantrans@es@mcliv{Si sientes que el demonio te susurra, refúgiate en Dios. Él todo lo oye, todo lo sabe.\qt@no{200}}
\qt@newcmd\qurantrans@es@mclv{Los piadosos, cuando el demonio les susurra, invocan a su Señor y entonces pueden ver con claridad.\qt@no{201}}
\qt@newcmd\qurantrans@es@mclvi{Pero los demonios persisten en mantener a sus secuaces en el extravío, y no se cansan de hacerlo.\qt@no{202}}
\qt@newcmd\qurantrans@es@mclvii{Cuando no se le revela [al Profeta Mujámmad] un nuevo versículo, le dicen [en tono burlón]: ``¿Por qué no has inventado uno?" Diles: ``Solo sigo lo que mi Señor me revela. Éste [Corán] es un milagro de su Señor, guía y misericordia para la gente que cree en él".\qt@no{203}}
\qt@newcmd\qurantrans@es@mclviii{Cuando el Corán sea leído, escúchenlo con atención y guarden silencio para que se les tenga misericordia.\qt@no{204}}
\qt@newcmd\qurantrans@es@mclix{Recuerda a tu Señor en tu interior con sometimiento y temor, e invócalo con voz baja por la mañana y por la tarde. No seas de los indiferentes.\qt@no{205}}
\qt@newcmd\qurantrans@es@mclx{[Los ángeles] que están junto a tu Señor no tienen ninguna soberbia que les impida adorarlo, Lo glorifican y se prosternan ante Él.\qt@no{206}}
\qt@newcmd\qurantrans@es@mclxi{\basmalahes Te preguntan acerca de los botines [de guerra, cómo se distribuyen]. Diles [¡oh, Mujámmad!]: ``Los botines son para Dios y el Mensajero. Tengan temor de Dios, solucionen sus conflictos y obedezcan a Dios y a Su Mensajero, si es que son creyentes".\qt@no{1}}
\qt@newcmd\qurantrans@es@mclxii{Los creyentes son aquellos que cuando les es mencionado el nombre de Dios sus corazones se estremecen, y que cuando les son recitados Sus versículos les aumenta la fe y se encomiendan a su Señor.\qt@no{2}}
\qt@newcmd\qurantrans@es@mclxiii{[Los creyentes] son quienes realizan la oración y dan en caridad parte de lo que les he proveído.\qt@no{3}}
\qt@newcmd\qurantrans@es@mclxiv{Estos son los verdaderos creyentes, que alcanzarán grados elevados ante su Señor, el perdón y un sustento generoso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mclxv{Tu Señor te hizo salir de tu casa [para luchar] por la verdad, pero eso le disgustó a un grupo de los creyentes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mclxvi{Te discuten sobre el verdadero motivo [del enfrentamiento] luego de habérseles evidenciado la verdad, como si fueran arrastrados a la muerte ante sus propios ojos.\qt@no{6}}
\qt@newcmd\qurantrans@es@mclxvii{Pero [recuerda] cuando Dios les prometió [la victoria] sobre uno de los dos grupos. Ustedes deseaban enfrentar al menos poderoso, pero Dios quería hacer prevalecer la verdad con Sus Palabras y erradicar a los que se niegan a creer,\qt@no{7}}
\qt@newcmd\qurantrans@es@mclxviii{para que así prevalezca la Verdad y se desvanezca la falsedad, aunque ello les disguste a los criminales.\qt@no{8}}
\qt@newcmd\qurantrans@es@mclxix{[Recuerden] cuando pedían socorro a su Señor y Él les respondió: ``Los auxiliaré con mil ángeles que descenderán uno tras otro".\qt@no{9}}
\qt@newcmd\qurantrans@es@mclxx{Dios los envió como una albricia y para infundir el sosiego en sus corazones, pero sepan que la victoria depende de Dios. Dios es el Poderoso, el Sabio.\qt@no{10}}
\qt@newcmd\qurantrans@es@mclxxi{[Y recuerden] cuando los envolvió un sueño ligero dándoles una calma interior, e hizo descender una llovizna del cielo para purificarlos con ella y apartar de ustedes la mancha del demonio, afirmar sus corazones y afianzar sus pasos.\qt@no{11}}
\qt@newcmd\qurantrans@es@mclxxii{Y cuando tu Señor inspiró a los ángeles: ``Yo estoy con ustedes, denle valor a los creyentes, infundiré terror en los corazones de los que se niegan a creer. Golpeen sobre sus cuellos y golpeen todos sus dedos".\qt@no{12}}
\qt@newcmd\qurantrans@es@mclxxiii{Esto [es lo que merecen] porque combatieron a Dios y a Su Mensajero. Quien combata a Dios y a Su Mensajero sepa que Dios es severo en el castigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mclxxiv{Eso es lo que merecen recibir, y sepan que los que se niegan a creer recibirán el castigo del Infierno.\qt@no{14}}
\qt@newcmd\qurantrans@es@mclxxv{¡Oh, creyentes! Cuando se enfrenten con los que se niegan a creer, no les den la espalda [para huir].\qt@no{15}}
\qt@newcmd\qurantrans@es@mclxxvi{Pero quien huya, a menos que fuera por una maniobra de batalla o para unirse a otra tropa, incurrirá en la ira de Dios y su morada final será el Infierno. ¡Qué pésimo destino!\qt@no{16}}
\qt@newcmd\qurantrans@es@mclxxvii{No fueron ustedes quienes los mataron [a sus enemigos] sino que fue Dios quien les dio muerte, y no fuiste tú [¡oh, Mujámmad!] quien arrojó [el polvo que llegó a los ojos del enemigo en el combate], sino que fue Dios Quien lo hizo. Dios agracia así a los creyentes. Dios todo lo oye, todo lo sabe.\qt@no{17}}
\qt@newcmd\qurantrans@es@mclxxviii{Eso fue para que Dios desbaratara las confabulaciones de los que se niegan a creer.\qt@no{18}}
\qt@newcmd\qurantrans@es@mclxxix{[¡Oh, incrédulos!] Ustedes pidieron que triunfara quien estuviera en la verdad, y esto fue lo que ocurrió. Sepan que si desisten [de combatir al Islam y a los creyentes] será mejor para ustedes; pero si vuelven a hacerlo volveré [a castigarlos] y de nada les servirán sus ejércitos, aunque fueran numerosos. Porque Dios está con los creyentes.\qt@no{19}}
\qt@newcmd\qurantrans@es@mclxxx{¡Oh, creyentes! Obedezcan a Dios y a Su Mensajero, y no le den la espalda al escuchar [el mensaje].\qt@no{20}}
\qt@newcmd\qurantrans@es@mclxxxi{No sean como quienes dicen: ``Oímos", pero no prestan atención.\qt@no{21}}
\qt@newcmd\qurantrans@es@mclxxxii{Las peores criaturas para Dios son los sordos [que no quieren oír la Verdad] y los mudos [que no quieren atestiguar la Verdad], los que no razonan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mclxxxiii{Si Dios supiera que en ellos hay algún bien los haría oír, pero aun si los hiciera oír le darían la espalda, desentendiéndose.\qt@no{23}}
\qt@newcmd\qurantrans@es@mclxxxiv{¡Oh, creyentes! Obedezcan a Dios y al Mensajero cuando los invitan a practicar aquello que les da vida, y sepan que Dios se interpone entre la persona y [los deseos de] su corazón. Ante Dios comparecerán.\qt@no{24}}
\qt@newcmd\qurantrans@es@mclxxxv{Tengan cuidado de una prueba que afligirá no solamente a los opresores, sino a todos. Dios es severo en el castigo.\qt@no{25}}
\qt@newcmd\qurantrans@es@mclxxxvi{Recuerden cuando eran solo unos pocos, eran perseguidos y oprimidos donde estuvieran, y temían que la gente los apresara. Pero Dios los protegió, los fortaleció con Su auxilio y los agració con un sustento lícito, para que sean agradecidos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mclxxxvii{¡Oh, creyentes! No traicionen a Dios y al Mensajero, ni traicionen la confianza que se depositó en ustedes.\qt@no{27}}
\qt@newcmd\qurantrans@es@mclxxxviii{Sepan que sus posesiones y sus hijos son una prueba. Dios tiene reservada junto a Él una recompensa inmensa.\qt@no{28}}
\qt@newcmd\qurantrans@es@mclxxxix{¡Oh, creyentes! Si tienen temor de Dios, Él les concederá el criterio, perdonará sus faltas y aceptará su arrepentimiento. Dios es el dueño de un favor inmenso.\qt@no{29}}
\qt@newcmd\qurantrans@es@mcxc{Y recuerda [¡oh, Mujámmad!] cuando se confabularon contra ti los incrédulos para capturarte, matarte o expulsarte [de tu ciudad]. Ellos planearon en tu contra, pero Dios desbarató sus planes, porque finalmente Dios es el que mejor planea.\qt@no{30}}
\qt@newcmd\qurantrans@es@mcxci{Cuando se les recitan Mis versículos, dicen [los que se niegan a creer]: ``Oímos, pero si quisiéramos podríamos decir palabras similares. Son fábulas de nuestros ancestros".\qt@no{31}}
\qt@newcmd\qurantrans@es@mcxcii{Y alguien dijo: ``¡Señor nuestro! Si esto [que transmite Mujámmad] es la Verdad que dimana de Ti, te desafío a que hagas llover sobre nosotros piedras del cielo o nos azotes con un castigo doloroso".\qt@no{32}}
\qt@newcmd\qurantrans@es@mcxciii{Pero Dios nunca los castigaría estando tú [¡oh, Mujámmad!] entre ellos, ni tampoco mientras haya quienes Le pidan perdón.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcxciv{¿Por qué no iba Dios a castigarlos si ellos impiden [a los creyentes] el ingreso a la Mezquita Sagrada, sin ser los protectores [legítimos de la Mezquita Sagrada]? Sepan que los [legítimos] protectores son los piadosos. Pero la mayoría de los idólatras no lo sabe.\qt@no{34}}
\qt@newcmd\qurantrans@es@mcxcv{Su oración ante la Casa Sagrada [de La Meca] no era más que silbidos y aplausos. Sufran [¡oh, idólatras!] el castigo por su rechazo obstinado a la verdad.\qt@no{35}}
\qt@newcmd\qurantrans@es@mcxcvi{Los que se niegan a creer gastan su dinero para apartar a la gente del sendero de Dios. Seguirán gastando hasta que lo lamentarán, y finalmente serán vencidos. Los que se niegan a creer serán finalmente congregados en el Infierno.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcxcvii{Así Dios diferenciará al corrupto del honesto, y reunirá a los perversos unos con otros y los congregará en el Infierno. Esos serán los perdedores.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcxcviii{Diles a los que se niegan a creer que si desisten [y abrazan el Islam] les será perdonado cuanto cometieron en el pasado; pero si persisten, tendrán el mismo destino de los pueblos que los precedieron.\qt@no{38}}
\qt@newcmd\qurantrans@es@mcxcix{Combatan [a los criminales] hasta que cese la opresión y todos puedan adorar libremente a Dios. Pero si ellos desisten [de perseguir a los creyentes] Dios bien ve lo que hacen.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcc{Pero si ellos se niegan [y prefieren seguir persiguiendo a los creyentes], sepan ustedes que Dios es su Protector. ¡Qué excelente Protector y qué excelente Defensor!\qt@no{40}}
\qt@newcmd\qurantrans@es@mcci{Sepan que un quinto del botín Le corresponde a Dios, al Mensajero, a sus familiares, a los huérfanos, a los pobres y a los viajeros insolventes [y el resto a los soldados], si es que creen en Dios y en lo que le he revelado a Mi siervo el día que se evidenció la verdad de la falsedad: el día que se enfrentaron los dos ejércitos. Dios tiene poder sobre todas las cosas.\qt@no{41}}
\qt@newcmd\qurantrans@es@mccii{[Recuerda] cuando se encontraban en el valle más cercano [a Medina] y el ejército de los idólatras en el más lejano, y la caravana de camellos más abajo [en dirección al mar]. Y si ustedes hubieran sabido que se habría de producir una batalla, se habrían negado a aceptar el desafío. Pero [la batalla fue provocada aun así] para que Dios llevara a cabo algo [que Él había dispuesto] que ocurriera, y para que quien hubiera de perecer [en ese día], pereciera ante una prueba clara de la verdad; y quien hubiera de sobrevivir, sobreviviera ante una prueba clara de la verdad. Dios todo lo oye, todo lo sabe.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcciii{Dios hizo que en un sueño vieras a los enemigos como si fueran pocos, pues si se los hubiera mostrado como un ejército numeroso se habrían acobardado, dudando sobre combatir o no. Pero Dios los protegió. Él bien sabe lo que hay en los corazones.\qt@no{43}}
\qt@newcmd\qurantrans@es@mcciv{Cuando estuvieron frente a frente, Dios hizo que ustedes los vieran poco numerosos, e hizo que ellos los vieran poco numerosos a ustedes, de manera que sucediese lo que Dios había decretado. A Dios se remiten todos los asuntos.\qt@no{44}}
\qt@newcmd\qurantrans@es@mccv{¡Oh, creyentes! Cuando se enfrenten a un ejército [de incrédulos] manténganse firmes y recuerden permanentemente a Dios, que así alcanzarán el triunfo.\qt@no{45}}
\qt@newcmd\qurantrans@es@mccvi{Obedezcan a Dios y a Su Mensajero y no discrepen, porque se debilitarían y serían derrotados. Sean pacientes, porque Dios está con los pacientes.\qt@no{46}}
\qt@newcmd\qurantrans@es@mccvii{Pero no sean como aquellos [incrédulos] que salieron de sus hogares con arrogancia y ostentación ante su gente, para apartar a las personas del sendero de Dios. Dios está bien enterado de lo que hacen.\qt@no{47}}
\qt@newcmd\qurantrans@es@mccviii{El demonio les hizo ver que lo que hacían era lo correcto, y les dijo: ``Hoy nadie los podrá vencer, yo estoy junto a ustedes". Pero cuando los dos bandos se divisaron, [el demonio] huyó diciendo: ``Yo no soy responsable de lo que hacen, pues veo lo que ustedes no pueden ver, yo tengo temor de Dios, y Dios es severo en el castigo".\qt@no{48}}
\qt@newcmd\qurantrans@es@mccix{En ese momento los hipócritas y quienes tenían el corazón enfermo [con incertidumbre] dijeron [acerca de los creyentes]: ``Estos están enceguecidos por su religión". Quienes se encomienden a Dios sepan que Él es Poderoso, Sabio.\qt@no{49}}
\qt@newcmd\qurantrans@es@mccx{Si vieras [qué terrible es] cuando los ángeles toman las almas de los que mueren habiéndose negado a creer, y les golpean sus rostros y sus espaldas, y les dicen: ``Sufran el tormento del Infierno.\qt@no{50}}
\qt@newcmd\qurantrans@es@mccxi{Este es el castigo que merecieron por sus obras. Dios no es injusto con Sus siervos".\qt@no{51}}
\qt@newcmd\qurantrans@es@mccxii{El pueblo del Faraón y quienes los precedieron fueron castigados, pues tampoco creyeron en los signos de Dios, y Dios los condenó por sus pecados. Dios tiene poder sobre todas las cosas y es severo en el castigo.\qt@no{52}}
\qt@newcmd\qurantrans@es@mccxiii{Dios no quita a ningún pueblo las gracias con las que lo ha bendecido, a menos que este se pervierta. Dios todo lo oye, todo lo sabe.\qt@no{53}}
\qt@newcmd\qurantrans@es@mccxiv{Por lo mismo castigué a la gente del Faraón y a quienes los precedieron, pues desmintieron los signos de su Señor y entonces los aniquilé por sus pecados: por eso ahogué a la gente del Faraón. Sepan que todos [estos pueblos] eran opresores.\qt@no{54}}
\qt@newcmd\qurantrans@es@mccxv{Las peores criaturas ante Dios son los incrédulos, pues se negaron a creer,\qt@no{55}}
\qt@newcmd\qurantrans@es@mccxvi{aquellos que siempre quebrantan los pactos que tú [¡oh, Mujámmad!] celebras con ellos y no tienen temor [del castigo de Dios].\qt@no{56}}
\qt@newcmd\qurantrans@es@mccxvii{Si enfrentas a algunos de ellos durante la guerra, dales un escarmiento que sirva de ejemplo a quienes sigan sus pasos. Puede que así reconsideren.\qt@no{57}}
\qt@newcmd\qurantrans@es@mccxviii{Si te traiciona un pueblo, hazles saber que rompes el pacto igual que ellos. Dios no ama a los traidores.\qt@no{58}}
\qt@newcmd\qurantrans@es@mccxix{Que no piensen los incrédulos que podrán huir de Mi castigo. No tienen salvación.\qt@no{59}}
\qt@newcmd\qurantrans@es@mccxx{Preparen contra ellos cuanto puedan de fuerzas [de combate] y caballería, para que así amedrenten a los enemigos de Dios que también son los suyos, y a otros enemigos que aún no conocen, pero Dios los conoce bien. Sepan que aquello con lo que contribuyan en la causa de Dios les será recompensado generosamente, y no serán jamás tratados injustamente.\qt@no{60}}
\qt@newcmd\qurantrans@es@mccxxi{Si [los incrédulos] se inclinan por la paz, acéptala tú también y encomiéndate a Dios. Él todo lo oye, todo lo sabe.\qt@no{61}}
\qt@newcmd\qurantrans@es@mccxxii{Pero si quieren engañarte, sabe que la protección de Dios es suficiente. Él es Quien te ha fortalecido con Su auxilio y con los creyentes,\qt@no{62}}
\qt@newcmd\qurantrans@es@mccxxiii{Él es Quien unió sus corazones, y tú no habrías podido hacerlo aunque hubieras gastado todo lo que hay en la Tierra, pero Dios los reconcilió. Él es Poderoso, Sabio.\qt@no{63}}
\qt@newcmd\qurantrans@es@mccxxiv{¡Oh, Profeta! La protección de Dios es suficiente para ti y para los creyentes que te sigan.\qt@no{64}}
\qt@newcmd\qurantrans@es@mccxxv{¡Oh, Profeta! Exhorta a los creyentes a combatir [por la causa de Dios]. Por cada veinte pacientes y perseverantes de entre ustedes, vencerán a doscientos; y si hubiere cien, vencerán a mil de los que se negaron a creer, porque ellos no razonan.\qt@no{65}}
\qt@newcmd\qurantrans@es@mccxxvi{Pero Dios les alivia la carga, por compasión ante su debilidad: Por cada cien pacientes vencerán a doscientos enemigos, y si hubiere mil vencerán a dos mil, con el permiso de Dios. Dios está con los pacientes.\qt@no{66}}
\qt@newcmd\qurantrans@es@mccxxvii{No le es permitido al Profeta [ni a los creyentes] tomar prisioneros si antes no combaten en la Tierra. Pretenden algunos obtener un beneficio mundanal, mientras Dios quiere para ustedes la recompensa de la otra vida. Dios es Poderoso, Sabio.\qt@no{67}}
\qt@newcmd\qurantrans@es@mccxxviii{Si Dios no hubiera prescrito que el botín de guerra fuera lícito, habrían sufrido un terrible castigo por lo que tomaron de él.\qt@no{68}}
\qt@newcmd\qurantrans@es@mccxxix{Disfruten de todo lo lícito y bueno que han ganado como botín de guerra, y tengan temor de Dios. Dios es Absolvedor, Misericordioso.\qt@no{69}}
\qt@newcmd\qurantrans@es@mccxxx{¡Oh, Profeta! Diles a los prisioneros que hayan capturado: ``Si Dios encuentra en sus corazones algo de bien, les concederá algo mejor que los bienes que se les han quitado y los perdonará. Dios es Absolvedor, Misericordioso".\qt@no{70}}
\qt@newcmd\qurantrans@es@mccxxxi{Pero si quieren engañarte aduciendo que son creyentes, recuerda que ya antes habían traicionado a Dios y Él los sometió ante ustedes. Dios todo lo sabe, es Sabio.\qt@no{71}}
\qt@newcmd\qurantrans@es@mccxxxii{Los creyentes que emigraron, contribuyeron con sus bienes y combatieron por la causa de Dios, son aliados de aquellos que les dieron refugio y socorro. En cambio, a quienes no emigraron no tienen la obligación de socorrerlos hasta que emigren. Pero si piden que los auxilien para preservar su religión, deben hacerlo, salvo que se encuentren en un pueblo con el que ustedes hayan celebrado un pacto. Dios ve bien lo que hacen.\qt@no{72}}
\qt@newcmd\qurantrans@es@mccxxxiii{Los que se niegan a creer son aliados unos de otros. Si no obran de la misma manera [siendo los creyentes aliados unos de otros], se propagarán los conflictos en la Tierra y habrá una gran corrupción.\qt@no{73}}
\qt@newcmd\qurantrans@es@mccxxxiv{Los creyentes que emigraron y lucharon por la causa de Dios, y aquellos que les dieron refugio y los socorrieron, esos son los verdaderos creyentes. A ellos les serán perdonados sus pecados y recibirán una recompensa generosa.\qt@no{74}}
\qt@newcmd\qurantrans@es@mccxxxv{Y aquellos que posteriormente crean [abrazando el Islam], emigren y luchen con ustedes, serán de los suyos. Sepan que Dios ha prescrito en Su Libro que sus parientes tienen más derecho a la herencia que sus hermanos en la fe, y Dios es conocedor de todas las cosas.\qt@no{75}}
\qt@newcmd\qurantrans@es@mccxxxvi{\basmalahes Dios y Su Mensajero están exentos de responsabilidad sobre el pacto que ustedes habían celebrado con los idólatras.\qt@no{1}}
\qt@newcmd\qurantrans@es@mccxxxvii{[Los que combatieron a los musulmanes en la península árabe] pueden transitar [con libertad y seguridad] por la tierra cuatro meses. Sepan que no podrán eludir a Dios, porque será Dios Quien afrente a los que se negaron a creer.\qt@no{2}}
\qt@newcmd\qurantrans@es@mccxxxviii{Dios y Su Mensajero anuncian a toda la gente en el día más importante de la peregrinación, que Dios ya no tiene ningún pacto con los idólatras, ni tampoco Su Mensajero. [¡Oh, idólatras!] Si se arrepienten [y abandonan la incredulidad] será mejor para ustedes, pero si se rehúsan no podrán escapar de Dios. A los que se negaron a creer anúnciales que recibirán un castigo doloroso,\qt@no{3}}
\qt@newcmd\qurantrans@es@mccxxxix{excepto aquellos que no quebrantaron los pactos que ustedes celebraron con ellos ni apoyaron a nadie contra ustedes. Respeten el pacto convenido con ellos hasta su plazo acordado. Dios ama a los piadosos [que respetan los acuerdos].\qt@no{4}}
\qt@newcmd\qurantrans@es@mccxl{Pero cuando hayan pasado los meses sagrados, maten a esos idólatras dondequiera que los encuentren, captúrenlos, sítienlos y acéchenlos en todo lugar. Pero si se arrepienten [y aceptan el Islam], cumplen con la oración prescrita y pagan el zakat, déjenlos en paz. Dios es Absolvedor, Misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mccxli{Si alguno de los idólatras te pidiera protección, dale asilo para que así recapacite y escuche la Palabra de Dios, luego [si no reflexiona] ayúdalo a alcanzar un lugar seguro. Esto es porque son gente que no sabe.\qt@no{6}}
\qt@newcmd\qurantrans@es@mccxlii{¿Cómo podrían Dios y Su Mensajero tener un pacto con los idólatras [siendo que ellos no dudaron en combatirlos]? Pero si aquellos con quienes ustedes pactaron anteriormente junto a la Mezquita Sagrada [en La Meca] cumplen lo pactado, cúmplanlo ustedes también. Dios ama a los piadosos [que respetan los pactos].\qt@no{7}}
\qt@newcmd\qurantrans@es@mccxliii{¿Cómo [podría tenerse un pacto con ellos siendo que] si obtuvieran una victoria sobre ustedes no tendrían compasión ni respetarían lazo familiar? Quieren agradarlos con sus palabras, pero sus corazones los rechazan. La mayoría de ellos son perversos.\qt@no{8}}
\qt@newcmd\qurantrans@es@mccxliv{Han cambiado los signos de Dios por un precio vil y apartan a la gente del sendero de Dios. ¡Qué pésimo es lo que hacen!\qt@no{9}}
\qt@newcmd\qurantrans@es@mccxlv{No respetan pacto ni compromiso con los creyentes. Ellos son los transgresores.\qt@no{10}}
\qt@newcmd\qurantrans@es@mccxlvi{Pero si se arrepienten, cumplen con la oración prescrita y pagan el zakat, entonces [perdónenlos y sepan que ahora] son sus hermanos en la religión. Así es como explico detalladamente los preceptos a quienes los comprenden.\qt@no{11}}
\qt@newcmd\qurantrans@es@mccxlvii{Si quebrantan sus juramentos después de haber celebrado un pacto y se burlan de su religión, combatan a los líderes de la incredulidad, pues ellos no respetan los pactos. Quizás así dejen de agredirlos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mccxlviii{¿Acaso no combatirían a quienes faltan a sus juramentos y planearon expulsar al Mensajero, y fueron ellos los que comenzaron primero [con la agresión]? ¿Acaso les temen? Sepan que Dios es más digno de que Le teman, si es que son creyentes.\qt@no{13}}
\qt@newcmd\qurantrans@es@mccxlix{Combátanlos, pues Dios los castigará a través de sus manos, los humillará, concederá a ustedes el triunfo sobre ellos y curará así los pechos de los creyentes,\qt@no{14}}
\qt@newcmd\qurantrans@es@mccl{removiendo la ira que hay en ellos. Dios acepta el arrepentimiento de quien quiere. Dios lo sabe todo, es Sabio.\qt@no{15}}
\qt@newcmd\qurantrans@es@mccli{¿Acaso creen que no se los pondrá a prueba, cuando Dios quiere que se evidencie quiénes combaten verdaderamente [por Su causa] y solo toman como aliados a Dios, a Su Mensajero y a los creyentes? Dios está bien informado de lo que hacen.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcclii{No es propio que los idólatras construyan y mantengan las mezquitas de Dios, cuando [con sus creencias y acciones] dan testimonio de su incredulidad [en Dios]. Sus obras serán en vano, y sufrirán eternamente en el Infierno.\qt@no{17}}
\qt@newcmd\qurantrans@es@mccliii{Las mezquitas de Dios deben ser construidas y mantenidas por aquellos que creen en Él, en el Día del Juicio, cumplen con la oración, pagan el zakat, y no temen sino a Dios. Porque ellos son los que siguen la guía.\qt@no{18}}
\qt@newcmd\qurantrans@es@mccliv{[¡Oh, incrédulos!] ¿Acaso creen que quienes proveen agua a los peregrinos y quienes se encargan del cuidado de la Mezquita Sagrada son equiparables a aquellos que creen en Dios, en el Día del Juicio y luchan por la causa de Dios? Sepan que no pueden equipararse ante Dios. Dios no guía a los opresores.\qt@no{19}}
\qt@newcmd\qurantrans@es@mcclv{Los creyentes que emigraron y contribuyeron a la causa de Dios con sus bienes materiales y sus personas, tienen un grado muy elevado ante Dios. Ellos son los bienaventurados.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcclvi{Su Señor les albricia [que serán recompensados] con Su misericordia, Su complacencia, y con jardines donde gozarán de delicias inagotables.\qt@no{21}}
\qt@newcmd\qurantrans@es@mcclvii{Vivirán en ellos por toda la eternidad. Dios les tiene reservada una recompensa grandiosa.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcclviii{¡Oh, creyentes! No tomen a sus padres y hermanos como aliados si estos prefieren la incredulidad a la fe; quien de ustedes los tome a ellos por aliados será de los opresores.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcclix{Diles [¡oh, Mujámmad!]: ``Si sus padres, hijos, hermanos, cónyuges y familiares, los bienes materiales que hayan adquirido, los negocios que teman perder, y las propiedades que posean y les agraden, son más amados para ustedes que Dios, Su Mensajero y la lucha por Su causa, esperen que les sobrevenga el castigo de Dios [que pronto llegará]. Dios no guía a los corruptos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mcclx{[Recuerden que] Dios los socorrió en muchas ocasiones, como el día de [la batalla de] Hunain, cuando ustedes se vanagloriaban de su superioridad numérica, pero de nada les valió y les resultó estrecha la Tierra [para escapar cuando los atacaron los idólatras] a pesar de su vastedad, y huyeron.\qt@no{25}}
\qt@newcmd\qurantrans@es@mcclxi{Pero Dios hizo descender el sosiego sobre Su Mensajero y sobre los creyentes, e hizo descender tropas [de ángeles] que ustedes no pudieron ver y castigó a los que se negaban a creer [con una derrota]. Así es como Dios castiga a los que se niegan a creer.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcclxii{Luego, Dios perdonó a quienes se arrepintieron [y abrazaron el Islam]. Dios es Absolvedor, Misericordioso.\qt@no{27}}
\qt@newcmd\qurantrans@es@mcclxiii{¡Oh, creyentes! Los idólatras son impuros, que no se acerquen a la Mezquita Sagrada después de este año. No teman padecer por ello pobreza o necesidad alguna, que si Dios quiere los proveerá con Su gracia. Dios todo lo sabe, es Sabio.\qt@no{28}}
\qt@newcmd\qurantrans@es@mcclxiv{Luchen contra quienes no creen en Dios ni en el Día del Juicio, no respetan lo que Dios y Su Mensajero han vedado y no siguen la verdadera religión [el Islam] de entre aquellos de la Gente del Libro [que los hayan agredido], a menos que acepten pagar un impuesto con humildad.\qt@no{29}}
\qt@newcmd\qurantrans@es@mcclxv{Dicen [algunos] judíos: ``‘Uzeir es el hijo de Dios", y los cristianos dicen: ``El Mesías es el hijo de Dios". Estas son solo palabras [sin fundamento] que salen de sus bocas, asemejándose por ello a los incrédulos que los precedieron. ¡Que Dios los destruya! ¡Cómo pueden ser tan desviados!\qt@no{30}}
\qt@newcmd\qurantrans@es@mcclxvi{Tomaron [los judíos] a sus rabinos y [los cristianos] a sus monjes y al Mesías, hijo de María, por divinidades en lugar de Dios. Pero solo se les había ordenado [en la Tora y el Evangelio] adorar a Dios, la única divinidad. No existe nada ni nadie con derecho a ser adorado salvo Él. ¡Glorificado sea! ¡Cómo pueden dedicar actos de adoración a otros!\qt@no{31}}
\qt@newcmd\qurantrans@es@mcclxvii{Pretenden extinguir la luz de Dios con sus palabras, pero Dios hará que Su luz prevalezca aunque esto desagrade a los que se niegan a creer.\qt@no{32}}
\qt@newcmd\qurantrans@es@mcclxviii{Él es Quien envió a Su Mensajero con la guía y la religión verdadera para que llegue a prevalecer sobre toda religión [falsa], aunque esto disguste a los idólatras.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcclxix{¡Oh, creyentes! Muchos de los rabinos y monjes se apropian del dinero ajeno sin derecho, y desvían [a la gente] del sendero de Dios. A aquellos que atesoren el oro y la plata y no contribuyan por la causa de Dios, anúnciales un castigo doloroso.\qt@no{34}}
\qt@newcmd\qurantrans@es@mcclxx{El Día del Juicio, lo que atesoraron se tornará incandescente por el fuego del Infierno, y sus frentes, sus costados y sus espaldas serán marcados con ello. [Se les dirá:] ``Esto es lo que atesoraron, sufran ahora su castigo".\qt@no{35}}
\qt@newcmd\qurantrans@es@mcclxxi{El número de meses para Dios es doce, porque así Él lo decretó el día que creó los cielos y la Tierra. De ellos, cuatro son sagrados. Así es en la religión verdadera. No obren en contra de ustedes mismos durante estos meses. Combatan a los idólatras tal como ellos los combaten a ustedes, y sepan que Dios está con los piadosos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcclxxii{Cambiar los meses sagrados es acrecentar aún más la incredulidad. Así se extraviaron los que se negaron a creer, unos años lo declaraban [al combate] lícito durante determinados meses, mientras que otros años lo declaraban ilícito [durante esos mismos meses], pero siempre hacían que el número de meses sagrados fuera cuatro para que de esta manera coincidiera con el número de meses que Dios había decretado que fueran sagrados. Declaraban lícito lo que Dios había prohibido. [El demonio] les hizo ver sus malas obras como buenas. Sepan que Dios no guía a la gente que se niega a creer.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcclxxiii{¡Oh, creyentes! ¿Por qué cuando se los convoca a combatir por la causa de Dios, responden con desgano? ¿Acaso prefieren la vida mundanal a la otra? Los placeres mundanos son insignificantes respecto a los de la otra vida.\qt@no{38}}
\qt@newcmd\qurantrans@es@mcclxxiv{Si no responden al llamado a combatir los azotará un castigo doloroso, y Dios los sustituirá por otro pueblo [que socorrerá al Profeta y combatirá por Su causa]. Sepan que no perjudicarán a Dios en nada [si se niegan a combatir]. Dios tiene poder sobre todas las cosas.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcclxxv{Si no lo socorren [al Mensajero], sepan que Dios [no necesita de ustedes, pues ya] lo auxilió aquella vez que los incrédulos lo expulsaron [de La Meca], cuando estando en la caverna con su compañero [Abu Bakr], le dijo: ``No te entristezcas, pues Dios está con nosotros". Entonces, Dios hizo descender Su sosiego sobre él [Abu Bakr], los socorrió con un ejército [de ángeles] que ellos no veían, y dispuso que la palabra de los incrédulos se desvaneciera, y que la palabra de Dios sea la que prevalezca. Dios es Poderoso, Sabio.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcclxxvi{Salgan a combatir, sea que tengan una situación fácil o difícil. Contribuyan por la causa de Dios con sus bienes y luchen, porque es lo mejor para ustedes, si supieran.\qt@no{41}}
\qt@newcmd\qurantrans@es@mcclxxvii{Si hubiera sido por algo mundano fácil de conseguir o un viaje breve, te habrían seguido, pero la distancia [en la batalla de Tabuk] era muy larga [y por ello se negaron a salir a combatir]. Juraron por Dios que si hubieran podido, habrían salido con ustedes. Se destruyeron a sí mismos [con sus excusas falsas], pero Dios sabe que mienten.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcclxxviii{¡Que Dios te disculpe [¡oh, Mujámmad!]! ¿Por qué los has eximido sin antes corroborar quiénes decían la verdad y quiénes estaban mintiendo?\qt@no{43}}
\qt@newcmd\qurantrans@es@mcclxxix{En cambio, aquellos que creen en Dios y en el Día del Juicio no se excusan para que los eximas de la obligación de contribuir con sus bienes materiales y combatir. Dios sabe bien quiénes son los piadosos.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcclxxx{Los que te presentan excusas para no alistarse [en el ejército] no creen en Dios ni en el Día del Juicio, sus corazones están llenos de dudas, y por sus dudas vacilan.\qt@no{45}}
\qt@newcmd\qurantrans@es@mcclxxxi{Si [los hipócritas] hubieran querido realmente combatir, se habrían preparado para tal fin; pero Dios no quiso que salieran [con ustedes] y les infundió desgano, y se les dijo: ``Permanezcan con quienes se quedan [por estar verdaderamente eximidos]".\qt@no{46}}
\qt@newcmd\qurantrans@es@mcclxxxii{Si hubieran salido a combatir, los habrían confundido sembrando la discordia, pues entre ustedes hay quienes prestan oído a lo que dicen, pero Dios conoce bien a los injustos.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcclxxxiii{Ya antes pretendieron sembrar la sedición [cuando arribaste a Medina, ¡oh, Mujámmad!] creando conflictos [entre los creyentes], hasta que la verdad fue revelada y se hizo manifiesta la voluntad de Dios, a pesar de que ellos lo detestaban.\qt@no{48}}
\qt@newcmd\qurantrans@es@mcclxxxiv{Entre los hipócritas hubo quien te dijo: ``[¡Oh, Mujámmad!] Permíteme quedarme y no me expongas a la tentación". ¿Acaso no cayeron en la tentación [del demonio al negarse a combatir]? El Infierno rodeará a los que se niegan a creer.\qt@no{49}}
\qt@newcmd\qurantrans@es@mcclxxxv{Si obtienes un éxito se disgustan, pero si recibes un revés dicen: ``Ya habíamos tomado nuestras precauciones", y se marchan alegres.\qt@no{50}}
\qt@newcmd\qurantrans@es@mcclxxxvi{Diles [¡oh, Mujámmad!]: ``Solo nos sucede lo que Dios decretó para nosotros. Él es nuestro Protector, y a Dios se encomiendan los creyentes".\qt@no{51}}
\qt@newcmd\qurantrans@es@mcclxxxvii{Diles [a los hipócritas]: ``Sepan que solo puede sucedernos una de dos cosas buenas, en cambio a ustedes, o bien Dios les enviará un castigo o hará que nosotros los derrotemos. Aguarden su destino, que nosotros aguardamos el nuestro".\qt@no{52}}
\qt@newcmd\qurantrans@es@mcclxxxviii{Diles: ``[¡Oh, hipócritas!] Lo que donen, de buena voluntad o por compromiso, no les será aceptado, porque son gente perversa".\qt@no{53}}
\qt@newcmd\qurantrans@es@mcclxxxix{Sepan que sus donaciones no son aceptadas porque no creen en Dios ni en Su Mensajero. Ellos realizan la oración con desgano y hacen donaciones con desgano.\qt@no{54}}
\qt@newcmd\qurantrans@es@mccxc{Que no te maravillen [¡oh, Mujámmad!] sus bienes materiales ni sus hijos, porque Dios decretó que les sirvan de sufrimiento en esta vida, y que sus almas mueran mientras están hundidos en la incredulidad.\qt@no{55}}
\qt@newcmd\qurantrans@es@mccxci{Les juran a ustedes por Dios que son de los suyos, cuando en realidad no lo son, solo actúan por temor:\qt@no{56}}
\qt@newcmd\qurantrans@es@mccxcii{Si encontraran un refugio, una caverna o algún escondite, se dirigirían hacia allí presurosamente [para ocultarse y no combatir].\qt@no{57}}
\qt@newcmd\qurantrans@es@mccxciii{De entre ellos hay quienes te critican por cómo repartes las caridades [¡oh, Mujámmad!]. Si les das de ellas [todo lo que pretenden] quedan satisfechos, pero si no lo haces se molestan.\qt@no{58}}
\qt@newcmd\qurantrans@es@mccxciv{[Sería mejor para ellos] que se conformaran con el reparto de Dios y Su Mensajero, y dijeran: ``Nos basta con Dios, y Dios nos concederá de Su favor y [repartirá entre nosotros] Su Mensajero. De Dios anhelamos que nos conceda bendiciones".\qt@no{59}}
\qt@newcmd\qurantrans@es@mccxcv{El zakat debe ser distribuido entre los pobres, los menesterosos, los que trabajan en su recaudación y distribución, aquellos de los que se desea ganar sus corazones, la liberación de los prisioneros, los endeudados, la causa de Dios y el viajero insolvente. Esto es un deber prescrito por Dios, y Dios lo sabe todo, es Sabio.\qt@no{60}}
\qt@newcmd\qurantrans@es@mccxcvi{Entre ellos hay [hipócritas] quienes critican al Profeta y dicen: ``Escucha todo lo que le dicen", pero ello es para su bien. Él cree en Dios, confía en [la palabra de] los creyentes y es una misericordia para quienes de ustedes [realmente] han llegado a creer. Quienes calumnien al Mensajero de Dios recibirán un castigo doloroso.\qt@no{61}}
\qt@newcmd\qurantrans@es@mccxcvii{[Un grupo de hipócritas] les juran por Dios con el fin de que ustedes se complazcan con ellos. Pero es de Dios y Su Mensajero de quienes deberían buscar su complacencia, si es que realmente son creyentes.\qt@no{62}}
\qt@newcmd\qurantrans@es@mccxcviii{¿No saben acaso que quien se enfrente a Dios y a Su Mensajero estará perpetuamente en el fuego del Infierno? Esa es la humillación más terrible.\qt@no{63}}
\qt@newcmd\qurantrans@es@mccxcix{Los hipócritas temían que un capítulo [del Corán] como este fuera revelado y pusiera en evidencia lo que [realmente] hay en sus corazones. Diles [¡oh, Mujámmad!]: ``Búrlense [de la religión], que Dios pondrá al descubierto lo que tanto temen".\qt@no{64}}
\qt@newcmd\qurantrans@es@mccc{Pero si les preguntas, te dicen: ``Solo bromeábamos y nos entreteníamos". Diles: ``¿Acaso se burlaban de Dios, de Sus preceptos y de Su Mensajero?\qt@no{65}}
\qt@newcmd\qurantrans@es@mccci{No se excusen, han demostrado ahora su incredulidad a pesar de haber expresado su testimonio de fe anteriormente". Perdonaré a un grupo de ustedes, pero castigaré a otro grupo por haber sido transgresor.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcccii{Los hipócritas y las hipócritas son aliados unos de otros, incitan al mal y prohíben hacer el bien, y se niegan a hacer caridades. Se olvidaron de Dios y por eso Él se olvidó de ellos [dejándolos fuera de Su misericordia]. Los hipócritas están en el desvío.\qt@no{67}}
\qt@newcmd\qurantrans@es@mccciii{Dios ha prometido a los hipócritas, a las hipócritas y a los que se niegan a creer que serán castigados con el fuego del Infierno donde sufrirán eternamente; eso será suficiente [castigo] para ellos. Dios los maldecirá y recibirán un castigo incesante.\qt@no{68}}
\qt@newcmd\qurantrans@es@mccciv{De la misma manera Dios castigó a otros pueblos del pasado que eran más fuertes que ustedes, tenían más riquezas y más hijos, y disfrutaban de lo que Dios les había concedido. Ahora ustedes disfrutan [de lo que Dios les concedió], pero se sumergen en la injusticia tal como ellos lo hicieron. Sus obras no les servirán en esta vida ni en la otra. Ellos son los verdaderos perdedores.\qt@no{69}}
\qt@newcmd\qurantrans@es@mcccv{¿Acaso no les fueron relatadas las historias de otros pueblos del pasado, como el pueblo de Noé, ‘Ad, Zamud, el pueblo de Abraham, la gente de Madián y las dos ciudades que fueron destruidas? Se les presentaron sus Mensajeros con las pruebas evidentes [pero los rechazaron]. Dios no fue injusto con ellos [al castigarlos], sino que ellos fueron injustos consigo mismos.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcccvi{Los creyentes y las creyentes son aliados unos de otros, ordenan el bien y prohíben el mal, cumplen con la oración prescrita, pagan el zakat y obedecen a Dios y a Su Mensajero. De ellos Dios tendrá misericordia. Dios es Poderoso, Sabio.\qt@no{71}}
\qt@newcmd\qurantrans@es@mcccvii{A los creyentes y a las creyentes Dios prometió jardines [en el Paraíso] por donde corren ríos, en los que disfrutarán por toda la eternidad, y hermosas moradas en los jardines del Edén. Pero alcanzar la complacencia de Dios es aún superior. ¡Ese es el éxito grandioso!\qt@no{72}}
\qt@newcmd\qurantrans@es@mcccviii{¡Oh, Profeta! Lucha contra los incrédulos y los hipócritas [que te ataquen], y sé severo con ellos. Su morada será el Infierno. ¡Qué pésimo destino!\qt@no{73}}
\qt@newcmd\qurantrans@es@mcccix{[Los hipócritas] juran por Dios que no dijeron nada [en contra de la religión de Dios y de Su Mensajero], y he aquí que sí dijeron palabras que evidenciaban su incredulidad, y así renegaron después de haber aceptado el Islam [exteriormente]. También se complotaron para algo que finalmente no pudieron conseguir. ¡Y nada pueden objetar [a la Fe] excepto que Dios los ha enriquecido y [ha hecho que] Su Mensajero [los enriquezca] de Su favor! Mejor sería que se arrepintieran, porque si no lo hacen, Dios les infligirá un castigo doloroso en esta vida y en la otra, y no tendrán en la Tierra protector ni defensor alguno.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcccx{Entre ellos hay quienes hacen una promesa a Dios diciendo: ``Si Dios nos agracia haremos caridades y seremos de los virtuosos".\qt@no{75}}
\qt@newcmd\qurantrans@es@mcccxi{Pero cuando Dios los bendijo con bienes materiales, se mostraron avaros y le dieron la espalda con desdén.\qt@no{76}}
\qt@newcmd\qurantrans@es@mcccxii{Dios les infundió la hipocresía en sus corazones, que perdurará hasta el día en que se encontrarán con Él. Eso fue por no cumplir su promesa con Dios y por haber mentido.\qt@no{77}}
\qt@newcmd\qurantrans@es@mcccxiii{¿Acaso no saben que Dios conoce sus intenciones y sus conspiraciones? Dios conoce bien lo oculto.\qt@no{78}}
\qt@newcmd\qurantrans@es@mcccxiv{Ellos critican a los creyentes que hacen obras voluntarias dando donaciones generosas, y se burlan también de quienes no encuentran qué dar, salvo con un gran esfuerzo. Dios los pondrá a ellos en ridículo y recibirán un castigo doloroso.\qt@no{79}}
\qt@newcmd\qurantrans@es@mcccxv{Es igual [¡oh, Mujámmad!] que pidas perdón por ellos o que no lo hagas. Aunque pidieras perdón por ellos setenta veces, Dios no los perdonaría, porque no creyeron en Dios ni en Su Mensajero, y Dios no guía a los perversos.\qt@no{80}}
\qt@newcmd\qurantrans@es@mcccxvi{Los que no participaron [en la batalla de Tabuk] se alegraron por rezagarse contrariando las órdenes del Mensajero. Se negaron a contribuir y luchar por la causa de Dios, y dijeron: ``No marchen [a combatir] con este calor". Diles [¡oh, Mujámmad!]: ``El calor del fuego del Infierno es más intenso aún". Si comprendieran.\qt@no{81}}
\qt@newcmd\qurantrans@es@mcccxvii{Que rían un poco [en este mundo], porque llorarán mucho [en el Infierno] como retribución por lo que cometieron.\qt@no{82}}
\qt@newcmd\qurantrans@es@mcccxviii{Si Dios te trae nuevamente [luego de la batalla de Tabuk] ante un grupo de ellos [los hipócritas], y ellos te piden permiso para salir a combatir [en otra batalla], diles: ``No marcharán ni combatirán conmigo contra un enemigo jamás, porque se complacieron en rezagarse la primera vez; quédense entonces con los que se rezagan".\qt@no{83}}
\qt@newcmd\qurantrans@es@mcccxix{Cuando alguno de ellos muera, no ores ni te detengas junto a su tumba [para rogar por él], porque no creyeron en Dios ni en Su Mensajero, y murieron en la desobediencia [a Dios].\qt@no{84}}
\qt@newcmd\qurantrans@es@mcccxx{Que no te maravillen sus bienes materiales ni sus hijos, pues Dios quiso castigarlos con ellos en esta vida, y que mueran [hundiéndose] en la incredulidad.\qt@no{85}}
\qt@newcmd\qurantrans@es@mcccxxi{Cuando es revelado un capítulo [del Corán] en el que se les ordena creer en Dios y combatir junto al Mensajero, los que están en condiciones de ir se excusan diciéndote: ``Permítenos quedarnos con los eximidos".\qt@no{86}}
\qt@newcmd\qurantrans@es@mcccxxii{Por haber preferido quedarse con los eximidos, Dios bloqueó sus corazones y no pueden discernir.\qt@no{87}}
\qt@newcmd\qurantrans@es@mcccxxiii{El Mensajero y quienes creen en él luchan con sus bienes materiales y sus personas. Ellos recibirán las bondades [en esta vida y en la otra], y serán quienes [finalmente] triunfen.\qt@no{88}}
\qt@newcmd\qurantrans@es@mcccxxiv{Dios tiene reservado para ellos jardines [en el Paraíso] por donde corren ríos, donde morarán por toda la eternidad. Ese es el triunfo grandioso.\qt@no{89}}
\qt@newcmd\qurantrans@es@mcccxxv{Se presentaron algunos beduinos [ante ti, ¡oh, Mujámmad!] pidiéndote permiso para no ir a luchar sin excusa válida, pero los [hipócritas] que mintieron a Dios y a Su Mensajero se quedaron sin excusarse siquiera. A estos incrédulos Dios les infligirá un castigo doloroso.\qt@no{90}}
\qt@newcmd\qurantrans@es@mcccxxvi{Los débiles, los enfermos y los que carecen de recursos no tienen nada que reprocharse por no poder salir [a combatir], si son sinceros con Dios y Su Mensajero. A los que hacen el bien no hay motivo para censurarlos si en algún momento no pueden hacerlo. Dios es Absolvedor, Misericordioso.\qt@no{91}}
\qt@newcmd\qurantrans@es@mcccxxvii{Tampoco deben ser reprochados aquellos que cuando se presentaron ante ti [¡oh, Mujámmad!] para que les proveyeras de montura [y así poder combatir por la causa de Dios], les informaste que no contabas con ninguna cabalgadura para ellos, y entonces se retiraron con los ojos inundados de lágrimas, tristes por no poder contribuir [a la causa de Dios].\qt@no{92}}
\qt@newcmd\qurantrans@es@mcccxxviii{Los que deben ser censurados son aquellos [hipócritas] que te pidieron permiso para rezagarse [sin excusa válida y no contribuyeron ni siquiera con sus bienes materiales] a pesar de ser ricos. Ellos prefirieron quedarse con los eximidos, y por ello Dios bloqueó sus corazones y no pueden discernir.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcccxxix{Pretendieron excusarse cuando ustedes regresaron a ellos [de la batalla]; ahora diles [¡oh, Mujámmad!]: ``No se excusen, pues no les creeremos, Dios ya nos informó sobre ustedes". Dios y luego Su Mensajero observarán lo que hacen [y ello dejará al descubierto si son sinceros o no], finalmente comparecerán ante el Conocedor de lo oculto y lo manifiesto, que les revelará lo que solían hacer.\qt@no{94}}
\qt@newcmd\qurantrans@es@mcccxxx{Cuando ustedes retornaron [después de la batalla], ellos les juraron por Dios [que no pudieron acompañarlos] para que los excusaran; pero apártense de ellos, pues son gente repugnante. En pago por cuanto cometieron, su morada será el Infierno.\qt@no{95}}
\qt@newcmd\qurantrans@es@mcccxxxi{Les juran por Dios para que se conformen con ellos; pero aunque ustedes se complacieran con ellos, sepan que Dios no Se complace con los corruptos.\qt@no{96}}
\qt@newcmd\qurantrans@es@mcccxxxii{Algunos beduinos son más incrédulos e hipócritas [que los habitantes de las ciudades], y es más probable que no conozcan los preceptos que Dios reveló a Su Mensajero. Dios todo lo sabe, es Sabio.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcccxxxiii{Entre los beduinos hay quienes consideran que toda donación es una pérdida, y esperan que ustedes sean azotados por un infortunio [para librarse de tener que hacer una contribución]. ¡Que los azote a ellos un infortunio! Dios todo lo oye, todo lo sabe.\qt@no{98}}
\qt@newcmd\qurantrans@es@mcccxxxiv{Pero también hay entre los beduinos quienes creen en Dios y en el Día del Juicio, y hacen caridades anhelando acercarse más a Dios y merecer las súplicas del Mensajero. Así es como lograrán estar más próximos a Dios. Él los introducirá en Su misericordia. Dios es Absolvedor, Misericordioso.\qt@no{99}}
\qt@newcmd\qurantrans@es@mcccxxxv{Dios se complace con los primeros que aceptaron el Islam y emigraron [a Medina], se complace con aquellos que los socorrieron, y con todos los que sigan su ejemplo [en la fe y las buenas obras], y todos ellos se complacen con Dios. Él les ha reservado jardines por donde corren ríos, donde morarán por toda la eternidad. Ese es el triunfo grandioso.\qt@no{100}}
\qt@newcmd\qurantrans@es@mcccxxxvi{Entre la gente de Medina y los beduinos que habitan a su alrededor hay hipócritas. Estos persisten en la hipocresía, tú no los conoces [¡oh, Mujámmad!], pero Yo sí los conozco. Los castigaré dos veces [una en esta vida con adversidades y la otra en la tumba], luego [el Día del Juicio] sufrirán un terrible castigo.\qt@no{101}}
\qt@newcmd\qurantrans@es@mcccxxxvii{Otros, en cambio, reconocen sus pecados [y se arrepienten], pues realizaron obras malas que empañaron sus obras buenas. A estos Dios les aceptará su arrepentimiento, porque Dios es Absolvedor, Misericordioso.\qt@no{102}}
\qt@newcmd\qurantrans@es@mcccxxxviii{[¡Oh, Mujámmad!] Toma una parte de sus bienes materiales [como zakat] para expurgarles [con ello sus pecados] y purificarlos [de la avaricia], y ruega por ellos, que tus súplicas les transmiten paz. Dios todo lo oye, todo lo sabe.\qt@no{103}}
\qt@newcmd\qurantrans@es@mcccxxxix{¿Acaso no saben que Dios acepta el arrepentimiento de Sus siervos y sus caridades [y les multiplica su recompensa por ellas]? Dios es el Indulgente, el Misericordioso.\qt@no{104}}
\qt@newcmd\qurantrans@es@mcccxl{Diles [¡oh, Mujámmad!, a los hipócritas]: ``Obren como quieran, pero sepan que Dios, Su Mensajero y los creyentes verán sus obras". Luego comparecerán ante el Conocedor de lo oculto y lo manifiesto, y Él les informará lo que cometieron.\qt@no{105}}
\qt@newcmd\qurantrans@es@mcccxli{Otros esperan el designio de Dios, Quien los castigará [si no se arrepienten] o los perdonará [si lo hacen]. Dios lo sabe todo, es Sabio.\qt@no{106}}
\qt@newcmd\qurantrans@es@mcccxlii{Quienes [de los hipócritas] construyeron una mezquita para hacer daño, difundir la incredulidad, sembrar la discordia entre los creyentes y dar refugio a quienes combaten a Dios y a Su Mensajero, desde hace tiempo juran que la construyeron para hacer un acto de beneficencia, pero Dios atestigua que mienten.\qt@no{107}}
\qt@newcmd\qurantrans@es@mcccxliii{No ores [¡oh, Mujámmad!] en ella nunca, y sabe que una mezquita construida con piedad desde el primer día es más digna de que ores en ella, pues allí hay gente que desea purificarse, y Dios ama a quienes se purifican.\qt@no{108}}
\qt@newcmd\qurantrans@es@mcccxliv{¿Acaso no es mejor quien construye sobre la base de la piedad y la complacencia de Dios que quien construye sobre un acantilado arenoso a punto de desplomarse, que pronto precipitará a sus constructores al Infierno? Dios no guía a los opresores.\qt@no{109}}
\qt@newcmd\qurantrans@es@mcccxlv{La mezquita que construyeron no dejará de sembrar dudas e hipocresía [entre los incrédulos] hasta que sus corazones se detengan. Dios lo sabe todo, es Sabio.\qt@no{110}}
\qt@newcmd\qurantrans@es@mcccxlvi{Dios ha comprado a los creyentes, a cambio del Paraíso, sus vidas y sus bienes materiales que ofrecen por la causa de Dios hasta vencer o morir. Esta es una promesa verdadera que está mencionada en la Tora, el Evangelio y el Corán. ¿Quién es más fiel a su promesa que Dios? Bienaventurados sean por ofrecer [sus placeres mundanos] para comprar [los placeres de la otra vida]. Ese es el triunfo grandioso.\qt@no{111}}
\qt@newcmd\qurantrans@es@mcccxlvii{[El triunfo es de quienes] se arrepienten [ante Dios], Lo adoran, Lo alaban, ayunan, se inclinan y se prosternan [en las oraciones], ordenan el bien y prohíben el mal, y respetan los preceptos [de Dios]. ¡Albricia a los creyentes!\qt@no{112}}
\qt@newcmd\qurantrans@es@mcccxlviii{No corresponde que el Profeta ni los creyentes pidan perdón por los idólatras aunque se trate de sus parientes, una vez que se haga evidente que serán de la gente del Infierno.\qt@no{113}}
\qt@newcmd\qurantrans@es@mcccxlix{Abraham solo pidió perdón por su padre porque se lo había prometido, pero cuando se dio cuenta de que era un enemigo de Dios, se desentendió de él. Abraham era manso de corazón y paciente.\qt@no{114}}
\qt@newcmd\qurantrans@es@mcccl{Dios no desviaría a un pueblo luego de haberlo guiado, sin antes haberles transmitido Sus preceptos. Dios es Conocedor de todas las cosas.\qt@no{115}}
\qt@newcmd\qurantrans@es@mcccli{A Dios pertenece el reino de los cielos y de la Tierra, Él da la vida y la muerte, y no tienen fuera de Dios protector ni defensor alguno.\qt@no{116}}
\qt@newcmd\qurantrans@es@mccclii{Dios perdonó al Profeta, a los creyentes que habían emigrado y a quienes los socorrieron, cuando lo siguieron en los momentos difíciles [de la expedición a Tabuk], y aceptó el arrepentimiento de aquellos cuyos corazones estuvieron a punto de desviarse [al ausentarse de la expedición]. Él es Compasivo y Misericordioso con Sus siervos.\qt@no{117}}
\qt@newcmd\qurantrans@es@mcccliii{También aceptó el arrepentimiento de los tres que se rezagaron [de la expedición]. A estos les resultó estrecha la Tierra a pesar de su vastedad [por la vergüenza que sentían], estaban acongojados y finalmente comprendieron que no tenían más refugio que Dios. Luego [de un tiempo] Él les aceptó su arrepentimiento para que regresaran [a Dios]. Dios es el Indulgente, el Misericordioso.\qt@no{118}}
\qt@newcmd\qurantrans@es@mcccliv{¡Oh, creyentes! Tengan temor de Dios y permanezcan junto a los que dicen siempre la verdad.\qt@no{119}}
\qt@newcmd\qurantrans@es@mccclv{La gente de Medina y los beduinos que habitan a su alrededor no debían negarse a combatir con el Mensajero de Dios [si eran convocados] ni preferir sus propias vidas a la de él, ya que les es registrada una buena obra cada vez que sufren sed, cansancio y hambre mientras luchan por la causa de Dios, y cuando pisan terreno que enfurezca a los incrédulos, cuando los alcanza alguna hostilidad de los enemigos. Dios no deja que se pierda la recompensa de los que hacen el bien.\qt@no{120}}
\qt@newcmd\qurantrans@es@mccclvi{Cuando contribuyen mucho o poco, o atraviesan un valle, les es registrada [una buena obra]. Así Dios los recompensa más de lo que han hecho.\qt@no{121}}
\qt@newcmd\qurantrans@es@mccclvii{No deben salir a combatir todos los creyentes en una expedición. Que de cada región, algunos se queden para estudiar la religión y así puedan exhortar a su gente cuando regresen, para que de este modo se preserve [el conocimiento].\qt@no{122}}
\qt@newcmd\qurantrans@es@mccclviii{¡Oh, creyentes! Combatan a aquellos incrédulos enemigos que habitan a su alrededor [y los combaten], que comprueben su severidad. Dios está con los piadosos.\qt@no{123}}
\qt@newcmd\qurantrans@es@mccclix{Cuando un capítulo [del Corán] es revelado, hay entre ellos quienes dicen: ``¿A quién le aumenta su fe?" Mientras que a los verdaderos creyentes sí les aumenta la fe, y se alegran por eso.\qt@no{124}}
\qt@newcmd\qurantrans@es@mccclx{En cambio, a aquellos cuyos corazones están enfermos [de hipocresía], este [nuevo capítulo] les aumenta maldad a la maldad [espiritual] que ya tienen, y mueren negando la verdad.\qt@no{125}}
\qt@newcmd\qurantrans@es@mccclxi{¿Acaso no ven que son puestos a prueba cada año una o dos veces? Pero aun así no se arrepienten ni reflexionan.\qt@no{126}}
\qt@newcmd\qurantrans@es@mccclxii{Cuando un capítulo [del Corán] es revelado, [los hipócritas] se miran entre sí [y susurran]: ``¿Acaso alguien puede ver [lo que hay en nuestros corazones]?", y se alejan. Pero Dios ha alejado sus corazones [de la verdad] porque son gente que no la comprenden.\qt@no{127}}
\qt@newcmd\qurantrans@es@mccclxiii{Se les ha presentado un Mensajero de entre ustedes mismos que se apena por sus adversidades, se preocupa y desea que alcancen el bien [e ingresen al Paraíso]; es compasivo y misericordioso con los creyentes.\qt@no{128}}
\qt@newcmd\qurantrans@es@mccclxiv{[¡Oh, Mujámmad!] Si rechazan [el Mensaje] diles: ``Me es suficiente con Dios, no hay otra divinidad salvo Él, a Él me encomiendo y Él es el Señor del Trono grandioso".\qt@no{129}}
\qt@newcmd\qurantrans@es@mccclxv{\basmalahes Álif. Lam. Ra’. Éstos son los versículos del Libro sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mccclxvi{¿Acaso se sorprende la gente de que [Dios] le haya concedido la revelación a uno de ellos: ``Advierte a la gente y albricia a los creyentes que por sus buenas obras obtendrán una hermosa recompensa ante su Señor?" Los que se niegan a creer dicen: ``Éste es evidentemente un hechicero".\qt@no{2}}
\qt@newcmd\qurantrans@es@mccclxvii{Su Señor es Dios. Creó los cielos y la Tierra en seis eras y luego se estableció sobre el Trono. Él es Quien decide todos los asuntos, nadie podrá interceder ante Él sin Su permiso. Ese es Dios, su Señor; adórenlo. ¿Es que no reflexionan?\qt@no{3}}
\qt@newcmd\qurantrans@es@mccclxviii{Ante Él deberán comparecer todos, pues la promesa de Dios es verdadera. Él es Quien origina la creación y luego la reproduce para retribuir con equidad a los creyentes que obraron rectamente. En cambio, los que se negaron a creer beberán agua hirviendo y recibirán un castigo doloroso por su incredulidad.\qt@no{4}}
\qt@newcmd\qurantrans@es@mccclxix{Él es Quien hizo que el Sol tuviese luz propia y determinó que la Luna reflejara su luz en distintas fases para que ustedes puedan computar el número de años y los meses. Dios creó esto con la verdad. Él explica los signos para gente de conocimiento.\qt@no{5}}
\qt@newcmd\qurantrans@es@mccclxx{En la sucesión de la noche y el día, y en lo que Dios ha creado en los cielos y en la Tierra, hay signos para la gente piadosa.\qt@no{6}}
\qt@newcmd\qurantrans@es@mccclxxi{Para aquellos que no esperan comparecer ante Mí, se complacen con la vida mundanal, se sienten satisfechos en ella, y son indiferentes con Mis signos,\qt@no{7}}
\qt@newcmd\qurantrans@es@mccclxxii{su morada será el Fuego por cuanto cometieron.\qt@no{8}}
\qt@newcmd\qurantrans@es@mccclxxiii{[Pero] a quienes crean y obren rectamente, su Señor los guiará por medio de la fe hacia los Jardines de las Delicias por donde corren ríos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mccclxxiv{Allí invocarán: ``¡Glorificado seas, oh, Señor!" Y el saludo entre ellos será: ``¡Paz!" Y al finalizar sus súplicas dirán: ``¡Todas las alabanzas pertenecen a Dios, Señor del universo!"\qt@no{10}}
\qt@newcmd\qurantrans@es@mccclxxv{Si Dios precipitara a la gente el castigo de la misma forma en que la gente se precipita a buscar los bienes materiales, ya les habría llegado su hora. Pero abandoné, ciegos en su extravío, a quienes no esperan comparecer ante Mí.\qt@no{11}}
\qt@newcmd\qurantrans@es@mccclxxvi{Cuando a la persona le acontece un mal Me implora recostado, sentado o de pie. Pero en cuanto lo libro del mal, continúa desobediente como si nunca Me hubiera invocado. Así es como los transgresores ven sus obras malas como buenas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mccclxxvii{Destruí a muchas generaciones que los precedieron porque fueron opresores. Sus Mensajeros se presentaron ante ellos con las evidencias, pero no les creyeron. Así castigué al pueblo pecador.\qt@no{13}}
\qt@newcmd\qurantrans@es@mccclxxviii{Luego hice que ustedes se sucedieran en generaciones unos a otros en la Tierra, para observar cómo obraban.\qt@no{14}}
\qt@newcmd\qurantrans@es@mccclxxix{Cuando se les recitan Mis versículos, quienes no esperan comparecer ante Mí dicen: ``Tráenos otro Corán distinto o modifícalo". Respóndeles: ``No me es permitido modificarlo, solo sigo lo que me ha sido revelado. Temo que si desobedezco a mi Señor me azote el castigo de un día terrible".\qt@no{15}}
\qt@newcmd\qurantrans@es@mccclxxx{Di [oh, Mujámmad]: ``Si Dios no hubiera querido, yo no les habría recitado [el Corán] y no lo hubieran conocido jamás. Viví toda mi vida entre ustedes antes de la revelación. ¿Acaso no van a reflexionar?"\qt@no{16}}
\qt@newcmd\qurantrans@es@mccclxxxi{¿Hay alguien más injusto que quien atribuye a Dios sus propias invenciones y desmiente Sus signos? Los que hacen el mal no tendrán éxito.\qt@no{17}}
\qt@newcmd\qurantrans@es@mccclxxxii{Adoran en vez de Dios lo que no puede perjudicarles ni beneficiarles, y dicen: ``Éstos son nuestros intercesores ante Dios". Diles: ``¿Acaso pretenden informarle a Dios algo que suceda en los cielos o en la Tierra que Él no sepa? ¡Glorificado sea! Está por encima de lo que Le asocian".\qt@no{18}}
\qt@newcmd\qurantrans@es@mccclxxxiii{La humanidad conformaba una sola nación, pero luego discreparon y se dividieron. Si no fuera por el designio de tu Señor, ya habrían sido juzgados.\qt@no{19}}
\qt@newcmd\qurantrans@es@mccclxxxiv{Dicen: ``¿Por qué no se le ha concedido [a Mujámmad] un milagro de su Señor?" Respóndeles: ``El conocimiento de lo oculto pertenece solo a Dios. Esperen, que yo también esperaré".\qt@no{20}}
\qt@newcmd\qurantrans@es@mccclxxxv{Cuando agracio a la gente con una misericordia después de haber padecido alguna adversidad, no agradecen Mi favor. Diles: ``Dios les retribuirá por todo lo que hagan". Mis emisarios registran todo cuanto hacen.\qt@no{21}}
\qt@newcmd\qurantrans@es@mccclxxxvi{Él es Quien facilitó que puedan transitar por la tierra y por el mar. Cuando navegan con buenos vientos se complacen, pero si los sacude una fuerte tormenta y las olas los golpean por todos lados y creen que ya no tienen salvación, entonces invocan solamente a Dios con toda sinceridad diciendo: ``Si nos salvas de ésta seremos de los agradecidos".\qt@no{22}}
\qt@newcmd\qurantrans@es@mccclxxxvii{Pero cuando Dios los salva, Lo desobedecen nuevamente sembrando la corrupción en la Tierra con injusticias. ¡Oh, gente! Su corrupción recaerá sobre ustedes mismos. Solo disfrutarán del placer transitorio de esta vida, pero luego comparecerán ante Mí y les comunicaré todo lo que hacían.\qt@no{23}}
\qt@newcmd\qurantrans@es@mccclxxxviii{La vida mundanal es como el agua que hago descender del cielo con la que se riegan los cultivos de la tierra, de los cuales se alimentan los seres humanos y los animales. Cuando los frutos maduran, la tierra se embellece, y piensan las personas que tienen total disposición sobre ella. Entonces arraso los cultivos de noche o de día, devastando la tierra como si no hubiera sido cultivada. Con ejemplos como este explico los signos para gente que reflexiona.\qt@no{24}}
\qt@newcmd\qurantrans@es@mccclxxxix{Dios convoca a la morada de la paz y guía a quien quiere por el sendero recto.\qt@no{25}}
\qt@newcmd\qurantrans@es@mcccxc{Quienes obren el bien obtendrán la mejor recompensa y una gracia aún mayor. Sus rostros no serán ensombrecidos ni sentirán humillación. Ellos serán los moradores del Paraíso en el que vivirán eternamente.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcccxci{Pero quienes hayan obrado el mal recibirán como pago un mal equivalente y una humillación. No encontrarán quién los proteja de Dios. Sus rostros se ennegrecerán como la oscuridad de la noche. Ellos serán los habitantes del Fuego, en el que permanecerán eternamente.\qt@no{27}}
\qt@newcmd\qurantrans@es@mcccxcii{El día que los congregue a todos le diré a los idólatras: ``Permanezcan en sus sitios ustedes y sus ídolos". Luego los separaremos a unos de otros y sus ídolos dirán: ``Nosotros no los obligamos a que nos adoraran.\qt@no{28}}
\qt@newcmd\qurantrans@es@mcccxciii{Dios es suficiente como testigo de que no sabíamos que nos adoraban".\qt@no{29}}
\qt@newcmd\qurantrans@es@mcccxciv{Todos serán retribuidos según sus obras. Comparecerán ante Dios, su verdadero Señor, y sus mentiras se desvanecerán.\qt@no{30}}
\qt@newcmd\qurantrans@es@mcccxcv{Pregúntales: ``¿Quién los sustenta con las gracias del cielo y de la Tierra? ¿Quién los agració con el oído y la vista? ¿Quién hace surgir lo vivo de lo muerto y lo muerto de lo vivo? ¿Quién tiene bajo Su poder todas las cosas?" Responderán: ``¡Dios!" Diles: ``¿Acaso no van a tener temor de Él [y abandonar la idolatría]?"\qt@no{31}}
\qt@newcmd\qurantrans@es@mcccxcvi{Ese es Al-lah, su verdadero Señor. ¿Qué hay más allá de la Verdad sino el extravío? ¿Cómo pueden ser tan desviados?\qt@no{32}}
\qt@newcmd\qurantrans@es@mcccxcvii{Así se cumplió la palabra de tu Señor contra los perversos: no creyeron.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcccxcviii{Di: ``¿Acaso alguno de sus ídolos puede originar una creación y luego reproducirla?" Diles: ``Dios es Quien origina la creación y luego la reproduce. ¿Cómo pueden ser tan desviados [de adorar a otros]?"\qt@no{34}}
\qt@newcmd\qurantrans@es@mcccxcix{Di: ``¿Acaso alguno de sus ídolos puede guiar a alguien a la verdad?" Di: ``Dios es Quien guía hacia la verdad". ¿Acaso no es más sensato seguir a Quien guía hacia la verdad, en vez de seguir a quienes no pueden guiar a nadie y necesitan ellos mismos ser guiados? ¿Cómo pueden actuar de esa forma?\qt@no{35}}
\qt@newcmd\qurantrans@es@mcd{Pero la mayoría de ellos no sigue sino conjeturas. Las conjeturas no son un argumento válido frente a la Verdad. Dios bien sabe lo que hacen.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcdi{El Corán no puede provenir sino de Dios. Confirma las revelaciones anteriores y explica detalladamente Sus preceptos, no hay duda alguna que proviene del Señor del universo.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcdii{Dicen: ``[Mujámmad] lo ha inventado". Diles: ``Entonces produzcan un capítulo similar [a un capítulo del Corán]. Recurran para ello a quienes quieran fuera de Dios, si es que dicen la verdad".\qt@no{38}}
\qt@newcmd\qurantrans@es@mcdiii{Desmienten lo que no conocen y aquello cuya interpretación no han recibido aún. Así también desmintieron sus ancestros. Pero observa cómo fue el final de los opresores.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcdiv{Entre ellos hay quienes creen en él y quienes no. Tu Señor conoce bien a los que siembran la corrupción.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcdv{Pero si te desmienten, diles: ``Yo soy responsable de mis obras y ustedes de las suyas. Ustedes no son responsables de lo que yo haga, como yo tampoco soy responsable de lo que ustedes hagan".\qt@no{41}}
\qt@newcmd\qurantrans@es@mcdvi{Algunos de ellos te escuchan, pero, ¿acaso tú puedes hacer oír a quien Dios le ha impedido oír y razonar?\qt@no{42}}
\qt@newcmd\qurantrans@es@mcdvii{Algunos de ellos te miran, pero, ¿acaso tú puedes hacer ver a quien Dios ha enceguecido?\qt@no{43}}
\qt@newcmd\qurantrans@es@mcdviii{Dios no oprime a las personas en absolutamente nada, sino que son las personas las que se oprimen a sí mismas.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcdix{El día que los congregue, les parecerá no haber permanecido más que una hora. Se reconocerán entre ellos. Quienes desmintieron el encuentro con Dios habrán perdido, porque no seguían la guía.\qt@no{45}}
\qt@newcmd\qurantrans@es@mcdx{Ya sea que te permita presenciar el castigo con el que los amenazo o que te haga morir antes, de igual manera ellos comparecerán ante Mí. Dios es testigo de lo que hacen.\qt@no{46}}
\qt@newcmd\qurantrans@es@mcdxi{A cada comunidad envié un Mensajero. Cada vez que lo desmintieron los destruí, salvando al Mensajero y a los creyentes, pero nadie fue castigado injustamente.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcdxii{Y dijeron: ``¿Cuándo se cumplirá esta amenaza, si es que dices la verdad?"\qt@no{48}}
\qt@newcmd\qurantrans@es@mcdxiii{Diles: ``Yo no puedo perjudicar ni beneficiar, a menos que Dios así lo quiera". Toda comunidad tiene un plazo prefijado; cuando éste llega no pueden retrasarlo ni adelantarlo, ni siquiera una hora.\qt@no{49}}
\qt@newcmd\qurantrans@es@mcdxiv{Di: ``¿Y si el castigo los alcanzara súbitamente de noche o de día? ¿Aun así querrían los pecadores adelantarlo?\qt@no{50}}
\qt@newcmd\qurantrans@es@mcdxv{¿Acaso van a creer cuando ya haya ocurrido? ¿No era eso lo que, despectivamente, querían que fuera adelantado?"\qt@no{51}}
\qt@newcmd\qurantrans@es@mcdxvi{Luego se les dirá a los opresores: ``Sufran el castigo eterno. ¿Acaso no es esta una retribución justa, acorde a lo que solían hacer?"\qt@no{52}}
\qt@newcmd\qurantrans@es@mcdxvii{Te preguntan: ``Es real [el Día del Juicio]?" Di: ``¡Juro por mi Señor que sí! Es la verdad de la que no podrán huir".\qt@no{53}}
\qt@newcmd\qurantrans@es@mcdxviii{Si los opresores tuvieran cuanto hay en la Tierra, querrían darlo como rescate para salvarse. Pero cuando vean el castigo no podrán mostrar su arrepentimiento. Serán juzgados con equidad y no serán tratados injustamente.\qt@no{54}}
\qt@newcmd\qurantrans@es@mcdxix{A Dios pertenece cuanto hay en los cielos y en la Tierra. La promesa de Dios se cumplirá, a pesar de que la mayoría lo ignora.\qt@no{55}}
\qt@newcmd\qurantrans@es@mcdxx{Él da la vida y da la muerte, y ante Él han de comparecer.\qt@no{56}}
\qt@newcmd\qurantrans@es@mcdxxi{¡Oh, gente! Les ha llegado el Mensaje de su Señor, que es un motivo de reflexión, cura para toda incertidumbre que hubiera en sus corazones, guía y misericordia para los creyentes.\qt@no{57}}
\qt@newcmd\qurantrans@es@mcdxxii{Diles: ``Que se alegren por esta gracia y misericordia de Dios. Eso es superior a todas las riquezas que pudieran acumular".\qt@no{58}}
\qt@newcmd\qurantrans@es@mcdxxiii{Diles: ``Dios les ha provisto de sustento, pero consideraron lícita una parte y prohibida otra parte. Díganme: ¿Acaso Dios les dio esa orden, o están atribuyendo a Dios lo que a ustedes les parece?"\qt@no{59}}
\qt@newcmd\qurantrans@es@mcdxxiv{¿Qué creen que se hará con ellos, los que atribuyen a Dios sus propias invenciones, el Día del Juicio? Dios concede grandes favores a la gente, pero la mayoría no Le agradece.\qt@no{60}}
\qt@newcmd\qurantrans@es@mcdxxv{No hay situación en la que se encuentren, no hay pasaje del Corán que reciten ni otra obra que realicen, sin que Yo sea testigo de lo que hacen. A tu Señor no se Le escapa nada en la Tierra ni en el cielo, ni siquiera algo del peso de un átomo. No existe nada menor o mayor a eso que no esté registrado en un Libro claro.\qt@no{61}}
\qt@newcmd\qurantrans@es@mcdxxvi{Los amigos cercanos de Dios no han de temer ni estarán tristes,\qt@no{62}}
\qt@newcmd\qurantrans@es@mcdxxvii{porque creyeron y fueron piadosos.\qt@no{63}}
\qt@newcmd\qurantrans@es@mcdxxviii{Ellos recibirán la albricia en esta vida y en la otra. La promesa de Dios es inalterable. Ese es el éxito grandioso.\qt@no{64}}
\qt@newcmd\qurantrans@es@mcdxxix{No te apenes por lo que dicen. El triunfo será de Dios, Él todo lo oye, todo lo sabe.\qt@no{65}}
\qt@newcmd\qurantrans@es@mcdxxx{A Dios pertenece todo cuanto hay en los cielos y en la Tierra. ¿Y qué siguen, entonces, quienes invocan a ídolos en vez de invocar a Dios? Solo siguen conjeturas y no hacen más que suponer.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcdxxxi{Él es Quien ha hecho la noche para que descansen y el día para que vean. En ello hay signos para quienes reflexionan.\qt@no{67}}
\qt@newcmd\qurantrans@es@mcdxxxii{Dicen: ``Dios ha tenido un hijo". ¡Glorificado sea! Él es el Opulento, Le pertenece cuanto hay en los cielos y en la Tierra. No tienen ninguna prueba de lo que inventan. ¿Acaso van a atribuir a Dios algo que no saben?\qt@no{68}}
\qt@newcmd\qurantrans@es@mcdxxxiii{Di: ``Quienes atribuyen a Dios sus propias invenciones jamás alcanzarán la felicidad".\qt@no{69}}
\qt@newcmd\qurantrans@es@mcdxxxiv{Disfrutarán transitoriamente en la vida mundanal, pero luego comparecerán ante Mí y sufrirán un castigo severo por haberse negado a creer.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcdxxxv{Relátales la historia de Noé, cuando dijo a su gente: ``¡Oh, pueblo mío! Si les molesta que viva con ustedes y que les recuerde el mensaje de Dios, a Él me encomiendo. Decidan lo que van a hacer [conmigo] ustedes y sus ídolos. Tomen una decisión y aplíquenmela, y no me hagan esperar.\qt@no{71}}
\qt@newcmd\qurantrans@es@mcdxxxvi{Pero si lo rechazan sepan que no les pido ningún pago, solo de Dios espero recompensa. Me ha sido ordenado que me cuente entre quienes se entregan a Él.\qt@no{72}}
\qt@newcmd\qurantrans@es@mcdxxxvii{Pero lo desmintieron, entonces lo salvé junto a sus seguidores que abordaron el arca, e hice que fueran los sucesores. Ahogué a quienes desmintieron Mi mensaje. Observa el resultado de quienes fueron advertidos.\qt@no{73}}
\qt@newcmd\qurantrans@es@mcdxxxviii{Luego envié otros Mensajeros, quienes se presentaron ante sus pueblos con las evidencias, pero al igual que sus predecesores no creyeron. Así es como sellamos los corazones de los que transgreden.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcdxxxix{Luego envié a Moisés y a Aarón con Mis signos ante el Faraón y su nobleza. Pero respondieron con soberbia porque eran criminales.\qt@no{75}}
\qt@newcmd\qurantrans@es@mcdxl{Cuando les llegó Mi Mensaje dijeron: ``Esto es claramente hechicería".\qt@no{76}}
\qt@newcmd\qurantrans@es@mcdxli{Moisés dijo: ``¿Esto es lo que dicen cuando les llega la Verdad? ¿Qué es hechicería? Los hechiceros no tendrán éxito".\qt@no{77}}
\qt@newcmd\qurantrans@es@mcdxlii{Dijeron: ``¿Han venido para alejarnos de la religión de nuestros padres, y así ser ustedes dos quienes tengan el dominio en la tierra? Nosotros no les creeremos".\qt@no{78}}
\qt@newcmd\qurantrans@es@mcdxliii{El Faraón dijo: ``Convoquen ante mí a todo hechicero experto".\qt@no{79}}
\qt@newcmd\qurantrans@es@mcdxliv{Cuando se presentaron los magos, Moisés les dijo: ``Arrojen lo que tengan que arrojar".\qt@no{80}}
\qt@newcmd\qurantrans@es@mcdxlv{Y cuando arrojaron [sus bastones, poniendo un hechizo en los ojos de la gente], Moisés dijo: ``Lo que hacen es hechicería y Dios la va a anular. Dios no permite que prosperen las obras de los que siembran la corrupción.\qt@no{81}}
\qt@newcmd\qurantrans@es@mcdxlvi{Dios confirma la verdad con Sus palabras, aunque eso disguste a los pecadores".\qt@no{82}}
\qt@newcmd\qurantrans@es@mcdxlvii{No creyeron en Moisés sino unos pocos de su pueblo que temían que el Faraón y su nobleza los persiguieran. El Faraón era un tirano arrogante y transgresor en su propia tierra.\qt@no{83}}
\qt@newcmd\qurantrans@es@mcdxlviii{Dijo Moisés: ``¡Oh, pueblo mío! Si creen, encomiéndense a Dios, si es que realmente se han entregado a Él".\qt@no{84}}
\qt@newcmd\qurantrans@es@mcdxlix{Dijeron: ``A Ti nos encomendamos, ¡oh, Señor nuestro! No permitas que nos domine este pueblo opresor.\qt@no{85}}
\qt@newcmd\qurantrans@es@mcdl{Y por Tu misericordia, sálvanos de la gente que se niega a creer".\qt@no{86}}
\qt@newcmd\qurantrans@es@mcdli{Le inspiré a Moisés y a su hermano: ``Reserven algunas casas en la ciudad para su pueblo. Conviertan sus casas en lugares de culto, y sean constantes en la oración. [Oh, Moisés]: Albricia [con el auxilio de Dios] a todos los creyentes".\qt@no{87}}
\qt@newcmd\qurantrans@es@mcdlii{Dijo Moisés: ``¡Señor nuestro! Has concedido al Faraón y su nobleza suntuosidad y riqueza en la vida mundanal. ¡Señor nuestro! Eso ha hecho que se extravíen y desvíen a la gente de Tu camino. ¡Señor nuestro! Devasta sus riquezas y endurece sus corazones, porque no creerán hasta que vean el castigo doloroso".\qt@no{88}}
\qt@newcmd\qurantrans@es@mcdliii{Dijo [Dios]: ``El ruego que han hecho fue respondido. Sean rectos y no sigan el camino de los ignorantes".\qt@no{89}}
\qt@newcmd\qurantrans@es@mcdliv{Hice que los Hijos de Israel cruzaran el mar. Pero el Faraón y su ejército los persiguieron injustamente, empujados por el odio. Cuando [el Faraón] sintió que se ahogaba y no tenía salvación, dijo: ``Creo en una única divinidad como lo hace el pueblo de Israel, y a Él me entrego".\qt@no{90}}
\qt@newcmd\qurantrans@es@mcdlv{¿Ahora crees? Mientras que antes eras de los rebeldes [a Dios] y de los que sembraban la corrupción.\qt@no{91}}
\qt@newcmd\qurantrans@es@mcdlvi{Conservaré tu cuerpo [luego de que te ahogues] y te convertirás en un signo para que reflexionen las generaciones que te sucedan. Pero muchas personas son indiferentes a Mis signos.\qt@no{92}}
\qt@newcmd\qurantrans@es@mcdlvii{Establecí al pueblo de Israel en un lugar próspero y lo sustenté con las cosas buenas de la vida. Pero cuando se les presentó la revelación, algunos creyeron y otros no. Tu Señor los juzgará el Día de la Resurrección acerca de lo que discrepaban.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcdlviii{[¡Oh, Mujámmad!] Si tienes alguna duda sobre lo que te ha sido revelado, pregúntales a quienes leían la revelación que te precedió. Te ha llegado la Verdad de tu Señor, no seas de los indecisos.\qt@no{94}}
\qt@newcmd\qurantrans@es@mcdlix{Y no seas como quienes desmintieron las palabras de Dios, porque te contarías entre los perdedores.\qt@no{95}}
\qt@newcmd\qurantrans@es@mcdlx{Aquellos sobre los que se ha confirmado la palabra de tu Señor no creerán,\qt@no{96}}
\qt@newcmd\qurantrans@es@mcdlxi{aunque les llegara todo tipo de evidencia, hasta que finalmente les llegue el castigo doloroso.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcdlxii{No hubo pueblo que al momento de azotarles el castigo, les haya beneficiado creer en ese instante, excepto el pueblo de Jonás. Cuando creyeron los salvé del castigo humillante en esta vida y los dejé disfrutar algún tiempo más.\qt@no{98}}
\qt@newcmd\qurantrans@es@mcdlxiii{Si tu Señor hubiera querido [imponérselos], todos los habitantes de la Tierra habrían creído. ¿Y tú piensas que puedes obligar a la gente a ser creyente?\qt@no{99}}
\qt@newcmd\qurantrans@es@mcdlxiv{Nadie podrá creer a menos que Dios se lo permita, y Él dejará en el extravío a quienes no usen su razonamiento.\qt@no{100}}
\qt@newcmd\qurantrans@es@mcdlxv{Diles: ``Reflexionen en todo cuanto hay en los cielos y en la Tierra", pero no se benefician de los signos ni de las advertencias aquellos que se niegan a creer.\qt@no{101}}
\qt@newcmd\qurantrans@es@mcdlxvi{¿Acaso esperan que lleguen días como los que cayeron sobre los pueblos que les precedieron? Diles: ``Esperen, que yo también estaré con ustedes esperando.\qt@no{102}}
\qt@newcmd\qurantrans@es@mcdlxvii{[Pero cuando llega el castigo a un pueblo] doy socorro a Mis Mensajeros y a los que han creído, porque es Mi compromiso socorrer a los creyentes.\qt@no{103}}
\qt@newcmd\qurantrans@es@mcdlxviii{Di: ``¡Oh, gente! Si dudan de la religión que vivo, sepan que no adoro a los que ustedes adoran fuera de Dios. Yo solo adoro a Dios, que es Quien los hará morir. A mí me ha sido ordenado ser de los creyentes,\qt@no{104}}
\qt@newcmd\qurantrans@es@mcdlxix{consagrarme a la religión monoteísta pura, y no ser de los que asocian divinidades [en la adoración] a Dios,\qt@no{105}}
\qt@newcmd\qurantrans@es@mcdlxx{y jamás invocar en vez de Dios lo que no puede beneficiarme ni perjudicarme, porque si lo hiciera sería de los injustos".\qt@no{106}}
\qt@newcmd\qurantrans@es@mcdlxxi{Si Dios te azota con una desgracia, nadie excepto Él podrá librarte de ella. Y si te concede un bien, nadie podrá impedir que te alcance. Dios concede Su gracia a quien quiere de Sus siervos. Él es el Absolvedor, el Misericordioso.\qt@no{107}}
\qt@newcmd\qurantrans@es@mcdlxxii{Di: ``¡Oh, gente! Les ha llegado la Verdad de su Señor. Quien siga la guía lo hará en beneficio propio; pero quien se descarríe, solo se perjudicará a sí mismo. Yo no soy responsable de lo que ustedes hagan".\qt@no{108}}
\qt@newcmd\qurantrans@es@mcdlxxiii{[¡Oh, Mujámmad!] Aférrate a lo que te ha sido revelado y sé paciente hasta que Dios juzgue. Él es el mejor de los jueces.\qt@no{109}}
\qt@newcmd\qurantrans@es@mcdlxxiv{\basmalahes Álif. Lam. Ra’. [El Corán] es un Libro cuyos versículos han sido perfeccionados y explicados detalladamente por el Sabio, el Conocedor.\qt@no{1}}
\qt@newcmd\qurantrans@es@mcdlxxv{[Diles, ¡oh, Mujámmad!:] ``No adoren sino a Dios, yo he sido enviado a ustedes como amonestador y albriciador.\qt@no{2}}
\qt@newcmd\qurantrans@es@mcdlxxvi{Supliquen perdón a su Señor y arrepiéntanse ante Él, pues así les concederá de Sus gracias hasta un plazo determinado, y recompensará a todo aquel que haga el bien. Temo que si rechazan [el Mensaje] los alcance el castigo de un día terrible.\qt@no{3}}
\qt@newcmd\qurantrans@es@mcdlxxvii{Ante Dios han de comparecer y Él es sobre toda cosa poderoso".\qt@no{4}}
\qt@newcmd\qurantrans@es@mcdlxxviii{Ellos [los hipócritas] pretenden disimular su aversión y creen poder esconderse de Dios. Aunque se cubran con sus ropas, Él sabe bien lo que esconden y lo que manifiestan, pues conoce lo que encierran los pechos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mcdlxxix{No existe criatura en la Tierra sin que sea Dios Quien la sustenta, Él conoce su morada y por donde transita; todo está registrado en un Libro evidente.\qt@no{6}}
\qt@newcmd\qurantrans@es@mcdlxxx{Él es Quien ha creado los cielos y la Tierra en seis eras, y Su Trono se encontraba sobre el agua, para probar quiénes de ustedes obran mejor. Si les dices [¡oh, Mujámmad!]: ``Serán resucitados después de la muerte", dirán los que se niegan a creer: ``Esto no es sino hechicería evidente".\qt@no{7}}
\qt@newcmd\qurantrans@es@mcdlxxxi{Si les retraso su castigo hasta un plazo determinado, dirán [los incrédulos]: ``¿Qué es lo que lo retiene?" ¿Acaso no saben que el día que les alcance el castigo no podrán evitarlo y los rodeará aquello de lo que se burlaban?\qt@no{8}}
\qt@newcmd\qurantrans@es@mcdlxxxii{Si le concedo a la persona algo de Mi gracia y luego se la quito, se desespera y se muestra desagradecida.\qt@no{9}}
\qt@newcmd\qurantrans@es@mcdlxxxiii{Pero cuando le agracio luego de haber padecido una adversidad, dice: ``Se han alejado los males de mí", se regocija con arrogancia.\qt@no{10}}
\qt@newcmd\qurantrans@es@mcdlxxxiv{No se comportan así quienes fueron pacientes [ante las adversidades] y obraron el bien [en los momentos de gracia]; éstos obtendrán el perdón y una gran recompensa.\qt@no{11}}
\qt@newcmd\qurantrans@es@mcdlxxxv{[Por misericordia] tú podrías dejar de transmitirles algo de lo que te fue revelado, porque tu corazón se acongoja cuando dicen: ``¿Por qué no se le ha concedido un tesoro o lo acompaña un ángel [para corroborar que es Profeta]?" Pero a ti solo te corresponde transmitir el Mensaje y amonestarlos; Dios es el protector de todas las cosas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mcdlxxxvi{O cuando dicen: ``Él lo inventó". Diles: ``[Si es verdad que un ser humano puede escribir algo tan maravilloso] escriban ustedes diez suras inventadas como ésta y preséntenlas, y convoquen a quienes puedan [para que los auxilien] en vez de Dios, si es que dicen la verdad".\qt@no{13}}
\qt@newcmd\qurantrans@es@mcdlxxxvii{Pero si no les responden [el desafío], sepan que [el Corán] ha sido revelado con el conocimiento de Dios, porque no hay otra divinidad salvo Él. ¿Acaso no van a someterse a Él [haciéndose musulmanes]?\qt@no{14}}
\qt@newcmd\qurantrans@es@mcdlxxxviii{A quienes prefieran la vida mundanal y sus placeres los recompensaré por sus obras en esta vida, se los concederé y no serán defraudados.\qt@no{15}}
\qt@newcmd\qurantrans@es@mcdlxxxix{Pero no obtendrán en la otra vida sino el castigo del Infierno. Allí, lo que hubieran hecho se desvanecerá, y sus obras habrán sido en vano.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcdxc{¿Acaso quien cree en el Corán y se basa en una prueba que proviene de Su Señor, que es recitada por un testigo de Dios, y que antes se encontraba mencionada en el Libro de Moisés [la Tora] que fue una guía y una misericordia, es comparable con aquellos aliados que no creen en el Corán? Ellos tendrán por morada el Infierno. No tengas dudas [de ello]. [El Corán] es la Verdad que dimana de tu Señor, aunque la mayoría de las personas no crean.\qt@no{17}}
\qt@newcmd\qurantrans@es@mcdxci{¿Hay alguien más injusto que quien inventa mentiras acerca de Dios? Ésos deberán comparecer ante su Señor [para responder por sus mentiras], y entonces todos los testigos dirán: ``Éstos son quienes mintieron acerca de su Señor". ¡Que la maldición de Dios caiga sobre los injustos\qt@no{18}}
\qt@newcmd\qurantrans@es@mcdxcii{que apartan a la gente del sendero de Dios, tratan de modificarlo y no creen en la otra vida!\qt@no{19}}
\qt@newcmd\qurantrans@es@mcdxciii{No podrán escapar de Dios en la Tierra, como tampoco tendrán [el Día del Juicio] quien los pueda proteger de Dios, y les será duplicado el castigo. Ellos no se permitieron oír [el Mensaje] ni querían ver [la verdad].\qt@no{20}}
\qt@newcmd\qurantrans@es@mcdxciv{Ésos son los que se han perdido a sí mismos, porque todo lo que habían inventado [el Día del Juicio] se esfumará.\qt@no{21}}
\qt@newcmd\qurantrans@es@mcdxcv{No hay duda de que en la otra vida serán quienes más pierdan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcdxcvi{En cambio, los que hayan creído y obrado el bien y se sometieron con humildad a su Señor, serán los moradores del Paraíso, donde permanecerán por toda la eternidad.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcdxcvii{El parecido de ambos grupos es como el que tienen uno ciego y sordo con aquel que ve y oye. ¿Pueden compararse? ¿Es que no van a recapacitar?\qt@no{24}}
\qt@newcmd\qurantrans@es@mcdxcviii{[Recuerda] que envié a Noé a su pueblo [y les dijo]: ``He sido enviado para ustedes como un amonestador evidente,\qt@no{25}}
\qt@newcmd\qurantrans@es@mcdxcix{no adoren sino a Dios, pues temo que [si siguen adorando a sus ídolos] los azote el castigo un día doloroso [el Día del Juicio]".\qt@no{26}}
\qt@newcmd\qurantrans@es@md{Los líderes de los que se negaron a creer de su pueblo, dijeron: ``No eres más que un mortal como nosotros, y solo te siguen los pobres y débiles de nuestro pueblo sin ninguna reflexión. No los creemos mejores que nosotros, sino que los consideramos mentirosos".\qt@no{27}}
\qt@newcmd\qurantrans@es@mdi{Dijo [Noé]: ``¡Oh, pueblo mío! Me he presentado ante ustedes con una prueba evidente de mi Señor, Quien me ha agraciado con Su misericordia, a la que ustedes se mantienen ciegos. ¿Acaso creen que vamos a imponerles aceptar [el Mensaje] cuando no están de acuerdo?\qt@no{28}}
\qt@newcmd\qurantrans@es@mdii{¡Oh, pueblo mío! No les pido retribución alguna a cambio [de transmitirles el Mensaje], pues Dios será Quien me recompensará, y no voy a rechazar a los creyentes [pobres como me piden], porque ellos se encontrarán con su Señor [Quien los recompensará por su fe]; y veo que son ustedes un pueblo que se comporta como los ignorantes.\qt@no{29}}
\qt@newcmd\qurantrans@es@mdiii{¡Oh, pueblo mío! ¿Quién me protegerá de Dios si despreciara [a los pobres y débiles]? ¿Es que no recapacitan?\qt@no{30}}
\qt@newcmd\qurantrans@es@mdiv{No les digo que poseo los tesoros de Dios ni que conozco lo oculto, ni les digo que soy un ángel; tampoco digo que Dios no recompensará [en la otra vida] a aquellos que ustedes consideran inferiores [los débiles y los pobres], pues Dios bien sabe lo que hay en sus almas, porque si lo dijera sería de los injustos".\qt@no{31}}
\qt@newcmd\qurantrans@es@mdv{Le dijeron: ``¡Oh, Noé! No has dejado de discutir y objetarnos, haz que se desencadene de una vez sobre nosotros aquello con lo que nos amenazas, si es verdad lo que dices".\qt@no{32}}
\qt@newcmd\qurantrans@es@mdvi{Dijo [Noé]: ``Dios lo desencadenará [al castigo] si Él así lo decreta, y entonces no podrán huir.\qt@no{33}}
\qt@newcmd\qurantrans@es@mdvii{Y aunque los quiera beneficiar con mi exhortación, tampoco les servirá de nada si es voluntad de Dios su desvío. Él es su Señor, y ante Él comparecerán".\qt@no{34}}
\qt@newcmd\qurantrans@es@mdviii{Dicen [los idólatras de La Meca]: ``Él lo inventó". Diles [¡Oh, Mujámmad!]: ``Si yo lo hubiera inventado, sobre mí recaerían las consecuencias de mi delito, y soy inocente del delito [de incredulidad] que ustedes cometen".\qt@no{35}}
\qt@newcmd\qurantrans@es@mdix{[También] le fue revelado a Noé: ``Salvo los que ya han creído, nadie más creerá de tu pueblo; no te aflijas por lo que hacen.\qt@no{36}}
\qt@newcmd\qurantrans@es@mdx{Construye el arca bajo Mi observancia y según Mi inspiración, y no Me hables a favor de quienes obraron injustamente, porque estarán entre los que se ahoguen".\qt@no{37}}
\qt@newcmd\qurantrans@es@mdxi{Mientras construía el arca, cada vez que pasaban ante él los poderosos de su pueblo se burlaban, y él les decía: ``Si se burlan de nosotros, sepan que ya nos burlaremos de ustedes como lo hacen ahora.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdxii{Ya sabrán a quién le alcanzará un castigo humillante [en esta vida], y [en la otra] sufrirá un tormento eterno".\qt@no{39}}
\qt@newcmd\qurantrans@es@mdxiii{Cuando llegó el momento de cumplirse Mi orden [del diluvio], el agua comenzó a fluir y correr impetuosamente por el suelo, [entonces] le dije [a Noé]: ``Embarca una pareja de cada especie [de la fauna doméstica de la zona], así como a tu familia, excepto aquél sobre quien pese la sentencia, y [por supuesto] a los creyentes". No obstante, los que habían creído en él eran muy pocos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdxiv{Dijo [Noé]: ``¡Suban al arca! ¡Que en el nombre de Dios navegue y llegue a buen puerto! Mi Señor es Perdonador, Misericordioso".\qt@no{41}}
\qt@newcmd\qurantrans@es@mdxv{[El arca] navegó con ellos a bordo entre olas altas como montañas. Noé llamó a su hijo que se encontraba en un lugar apartado: ``¡Oh, hijito mío! Sube al arca con nosotros y no te cuentes entre los que se niegan a creer".\qt@no{42}}
\qt@newcmd\qurantrans@es@mdxvi{Dijo [su hijo]: ``Me refugiaré en una montaña que me protegerá de las aguas". Dijo [Noé]: ``Hoy no habrá nada que pueda protegerlos del mandato de Dios, y solo se salvará aquel a quien Dios le tenga misericordia"; entonces las olas se interpusieron entre ambos, y [su hijo] se contó entre los ahogados.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdxvii{Y fue ordenado: ``¡Oh, tierra! Absorbe tu agua. ¡Oh, cielo! Detente". Y entonces el agua fue decreciendo y así se cumplió el mandato, y [el arca] se asentó sobre el monte Yudi, y fue dicho: ``¡La maldición recayó sobre los injustos!"\qt@no{44}}
\qt@newcmd\qurantrans@es@mdxviii{Noé invocó a su Señor diciendo: ``¡Oh, Señor mío! Mi hijo era parte de mi familia [y pensé que no sería destruido]; Tu promesa es verdadera, y Tú eres el más justo de los jueces".\qt@no{45}}
\qt@newcmd\qurantrans@es@mdxix{Dijo [Dios a Noé]: ``¡Oh, Noé! Él no era de [los que se salvarían de] tu familia, pues sus obras no eran rectas; no Me cuestiones respecto aquello sobre lo que no tienes conocimiento. Te advierto para que no te cuentes entre los ignorantes".\qt@no{46}}
\qt@newcmd\qurantrans@es@mdxx{Dijo [Noé]: ``¡Oh, Señor mío! Me refugio en Ti de cuestionarte algo sobre lo que no tengo conocimiento; si no me perdonas y Te apiadas de mí, me contaré entre los perdedores".\qt@no{47}}
\qt@newcmd\qurantrans@es@mdxxi{Entonces, le fue dicho: ``¡Oh, Noé! Desciende del arca con una paz proveniente de Mí. Que las bendiciones sean contigo y con las comunidades que sucederán a quienes están contigo. A algunas de ellas [que no creerán] las dejaré gozar [de esta vida mundanal], pero luego les azotará de Mi parte un castigo doloroso".\qt@no{48}}
\qt@newcmd\qurantrans@es@mdxxii{Estas son historias de lo oculto que te revelo [¡oh, Mujámmad!], ni tú ni tu pueblo las conocían. Ten paciencia, que el éxito final será para los que tienen temor de Dios.\qt@no{49}}
\qt@newcmd\qurantrans@es@mdxxiii{Al pueblo de ‘Ad le envié [como Profeta] a su hermano Hud [quien les dijo]: ``¡Oh, pueblo mío! Adoren solo a Dios, pues no existe otra divinidad salvo Él; ustedes no hacen más que inventar mentiras [acerca de Dios al asociarle divinidades].\qt@no{50}}
\qt@newcmd\qurantrans@es@mdxxiv{¡Oh, pueblo mío! No les pido remuneración alguna a cambio [de trasmitirles el Mensaje], solo anhelo la recompensa de Quien me ha creado. ¿Es que no reflexionan?\qt@no{51}}
\qt@newcmd\qurantrans@es@mdxxv{¡Oh, pueblo mío! Pidan perdón a su Señor y arrepiéntanse, que Él les enviará del cielo lluvias benditas, aumentará su fortaleza y multiplicará su poderío. No den la espalda como los criminales".\qt@no{52}}
\qt@newcmd\qurantrans@es@mdxxvi{Dijeron: ``¡Oh, Hud! No nos has presentado ningún milagro como para que abandonemos nuestros ídolos solo porque tú lo dices. ¡No tenemos fe en ti!\qt@no{53}}
\qt@newcmd\qurantrans@es@mdxxvii{Solo decimos que uno de nuestros ídolos te ha trastornado". Dijo [Hud]: ``Pongo a Dios y a ustedes por testigos de que soy inocente de lo que adoran\qt@no{54}}
\qt@newcmd\qurantrans@es@mdxxviii{en vez de Él. Confabúlense todos contra mí [si quieren] y no me hagan esperar.\qt@no{55}}
\qt@newcmd\qurantrans@es@mdxxix{Yo me encomiendo a Dios, que es mi Señor y el suyo. Sepan que no hay criatura que se escape a Su voluntad. Mi Señor está en el camino recto [y juzga con justicia].\qt@no{56}}
\qt@newcmd\qurantrans@es@mdxxx{Pero si me rechazan, yo habré cumplido con transmitirles aquello con lo que fui enviado, y mi Señor los remplazará por otro pueblo diferente [que será creyente]. Sepan que no Lo perjudican en nada [si no creen en Él]; mi Señor es el Protector de todas las cosas".\qt@no{57}}
\qt@newcmd\qurantrans@es@mdxxxi{Cuando llegó Mi designio [de destruirlos], salvé por misericordia a Hud y a quienes creyeron con él, librándolos de un castigo terrible.\qt@no{58}}
\qt@newcmd\qurantrans@es@mdxxxii{Así fue el pueblo de ‘Ad, negaron los signos de su Señor y desobedecieron a Sus Mensajeros, y siguieron a aquellos que se oponen a la verdad con arrogancia y prepotencia.\qt@no{59}}
\qt@newcmd\qurantrans@es@mdxxxiii{Recibieron la maldición en este mundo y en el Día del Juicio. Los habitantes de ‘Ad negaron a su Señor, y por ello el pueblo de Hud quedó fuera de la misericordia.\qt@no{60}}
\qt@newcmd\qurantrans@es@mdxxxiv{Y al pueblo de Zamud le envié [como Profeta] a su hermano Sálih, quien les dijo: ``¡Oh, pueblo mío! Adoren a Dios, pues no existe otra divinidad salvo Él. Él los creó de la tierra y los hizo vivir en ella. Imploren Su perdón y arrepiéntanse, porque mi Señor está próximo [cuando Lo invocan] y responde sus súplicas".\qt@no{61}}
\qt@newcmd\qurantrans@es@mdxxxv{Dijeron: ``¡Oh, Sálih! Teníamos esperanzas en ti [que fueras nuestro líder] antes de esto. ¿Acaso nos prohíbes que adoremos lo que adoraron nuestros padres? Eso a lo que nos invitas nos resulta muy sospechoso".\qt@no{62}}
\qt@newcmd\qurantrans@es@mdxxxvi{Dijo [Sálih]: ``¡Oh, pueblo mío! ¿Acaso no ven que poseo una prueba evidente de mi Señor y que me ha concedido una misericordia? ¿Quién me protegerá de Dios si Lo desobedezco? Lo que me ofrecen no es más que perdición para mí.\qt@no{63}}
\qt@newcmd\qurantrans@es@mdxxxvii{¡Oh, pueblo mío! Esta es la camella de Dios, y es para ustedes un signo [del poder divino], déjenla que paste en la tierra de Dios y no le hagan ningún daño, pues de lo contrario los azotará un castigo ineludible".\qt@no{64}}
\qt@newcmd\qurantrans@es@mdxxxviii{Pero la mataron con crueldad, y entonces [Sálih] les dijo: ``Disfruten en sus hogares durante tres días [porque luego les llegará el castigo]; esa es una promesa que no dejará de cumplirse".\qt@no{65}}
\qt@newcmd\qurantrans@es@mdxxxix{Pero cuando llegó lo que había decretado para ellos, salvé de la humillación de aquel día a Sálih y a los que habían creído en él, por misericordia. Tu Señor es el Fortísimo, el Poderoso.\qt@no{66}}
\qt@newcmd\qurantrans@es@mdxl{Y el estrépito sorprendió a los injustos, que amanecieron muertos en sus casas\qt@no{67}}
\qt@newcmd\qurantrans@es@mdxli{como si nunca hubieran habitado en ellas. ¿Acaso los habitantes de Zamud no negaron a su Señor? Por ello el pueblo de Zamud quedó fuera de la misericordia.\qt@no{68}}
\qt@newcmd\qurantrans@es@mdxlii{Mis [ángeles] enviados se presentaron ante Abraham para darle una albricia. Dijeron: ``¡La paz sea contigo!" Respondió [Abraham]: ``¡Y con ustedes!" Y no tardó en traerles un ternero asado.\qt@no{69}}
\qt@newcmd\qurantrans@es@mdxliii{Pero cuando observó que sus manos no lo tocaban [al ternero] sospechó de ellos y sintió temor, entonces le dijeron: ``No temas, nosotros fuimos enviados al pueblo de Lot".\qt@no{70}}
\qt@newcmd\qurantrans@es@mdxliv{Su mujer, que estaba de pie, se sonrió [sorprendida por la noticia], y le albricié con Isaac y que Isaac tendría como hijo a Jacob.\qt@no{71}}
\qt@newcmd\qurantrans@es@mdxlv{Ella exclamó: ``¡Cómo es posible! ¿Cómo he de concebir ahora que soy anciana, y mi marido también es un anciano? Esto es algo asombroso".\qt@no{72}}
\qt@newcmd\qurantrans@es@mdxlvi{Le dijeron [los ángeles]: ``¿Acaso te asombras del designio de Dios? ¡Qué la misericordia de Dios y Sus bendiciones sean con ustedes, gente de la casa! Dios es Digno de alabanza, Glorioso".\qt@no{73}}
\qt@newcmd\qurantrans@es@mdxlvii{Pero cuando se disipó el temor de Abraham y le fue dada la albricia, habló en favor del pueblo de Lot.\qt@no{74}}
\qt@newcmd\qurantrans@es@mdxlviii{Abraham era indulgente, lleno de compasión y siempre pedía perdón.\qt@no{75}}
\qt@newcmd\qurantrans@es@mdxlix{[Le fue dicho:] ``¡Oh, Abraham! Desiste de interceder por ellos, pues ha llegado el designio de tu Señor, y los azotará un castigo inapelable".\qt@no{76}}
\qt@newcmd\qurantrans@es@mdl{Y cuando Mis emisarios se presentaron ante Lot, éste [pensando que eran viajeros] se preocupó [por lo que su pueblo pudiere hacerles] y se sintió impotente para protegerlos; exclamó: ``¡Éste es un día terrible!"\qt@no{77}}
\qt@newcmd\qurantrans@es@mdli{La gente de su pueblo, que ya eran conocidos por sus obscenidades, se presentaron presurosamente ante él, y éste les dijo: ``¡Oh, pueblo mío! Aquí están mis hijas [si desean casarse], porque eso es lo lícito y puro para ustedes. Tengan temor de Dios y no me avergüencen ante mis huéspedes. ¿Es que no hay entre ustedes ni un solo hombre recto?"\qt@no{78}}
\qt@newcmd\qurantrans@es@mdlii{Respondieron: ``Tú sabes que no tenemos ningún deseo por tus hijas, y sabes bien lo que realmente queremos".\qt@no{79}}
\qt@newcmd\qurantrans@es@mdliii{[Lot] exclamó: ``¡Ojalá tuviera fuerzas [para enfrentarme] contra ustedes, o un apoyo fuerte al que recurrir!"\qt@no{80}}
\qt@newcmd\qurantrans@es@mdliv{Dijeron [los ángeles]: ``¡Oh, Lot! Somos emisarios de tu Señor, y sabe que no podrán hacerte ningún daño. Márchate con tu familia durante la noche, y que ninguno de ustedes vuelva la mirada atrás, excepto tu esposa que sufrirá el mismo castigo que ellos. Su destrucción será al alba, ¿acaso el alba no está cerca?"\qt@no{81}}
\qt@newcmd\qurantrans@es@mdlv{Cuando llegó Mi designio, volteé [sus hogares] dejando arriba sus cimientos, e hice llover sobre ellos piedras de arcilla a montones,\qt@no{82}}
\qt@newcmd\qurantrans@es@mdlvi{marcadas por tu Señor. Sepan [¡oh, idólatras!] que este castigo no está lejos de los injustos [como ustedes].\qt@no{83}}
\qt@newcmd\qurantrans@es@mdlvii{Al pueblo de Madián le envié [como Profeta] a su hermano Jetró, quien les dijo: ``¡Oh, pueblo mío! Adoren a Dios, pues no existe otra divinidad salvo Él, y no mermen en la medida ni el peso. Los veo hoy en la prosperidad, pero temo que los azote el castigo de un día ineludible.\qt@no{84}}
\qt@newcmd\qurantrans@es@mdlviii{¡Oh, pueblo mío! Cumplan en la medida y el peso con equidad, no se apoderen de los bienes ajenos, y no siembren la corrupción y el mal en la Tierra.\qt@no{85}}
\qt@newcmd\qurantrans@es@mdlix{Confórmense con lo que Dios los sustenta, pues ello es lo mejor para ustedes, si son creyentes. Sepan que yo no he sido enviado para velar por sus obras".\qt@no{86}}
\qt@newcmd\qurantrans@es@mdlx{Le respondieron: ``¡Oh, Jetró! ¿Es tu [forma de] adoración la que te ordena que dejemos aquello que adoraban nuestros padres, y dejemos de hacer con nuestros bienes lo que queramos? ¿En serio te crees afable y honrado?"\qt@no{87}}
\qt@newcmd\qurantrans@es@mdlxi{Dijo: ``¡Oh, pueblo mío! Me baso en una prueba evidente de mi Señor, Él me ha proveído un sustento generoso. No iba a prohibir lo que considero lícito para mí mismo. Solo pretendo su bienestar en la medida que pueda, pero mi éxito depende de Dios; a Él me encomiendo y ante Él me arrepiento.\qt@no{88}}
\qt@newcmd\qurantrans@es@mdlxii{¡Oh, pueblo mío! No permitan que su discrepancia conmigo los conduzca a ser alcanzados por un castigo como les ocurrió a los pueblos de Lot, Hud y Sálih. Y recuerden que [el castigo] del pueblo de Lot no está lejos de ustedes.\qt@no{89}}
\qt@newcmd\qurantrans@es@mdlxiii{Pidan perdón a su Señor y arrepiéntanse, porque mi Señor es Misericordioso, Afectuoso".\qt@no{90}}
\qt@newcmd\qurantrans@es@mdlxiv{Dijeron: ``¡Oh, Jetró! No entendemos mucho de lo que estás diciendo, y te consideramos entre nosotros una persona débil. Si no fuera por el clan al que perteneces te lapidaríamos; tú no tienes poder contra nosotros".\qt@no{91}}
\qt@newcmd\qurantrans@es@mdlxv{Dijo: ``¡Oh, pueblo mío! ¿Acaso mi tribu es más importante para ustedes que Dios, a Quien han dado la espalda? Mi Señor abarca [con Su conocimiento] todo lo que hacen.\qt@no{92}}
\qt@newcmd\qurantrans@es@mdlxvi{¡Oh, pueblo mío! Obren acorde a sus principios, que obraré acorde a los míos. Ya sabrán en el futuro quién recibirá un castigo humillante y quién es el que miente. ¡Estén atentos, que yo también estaré atento junto a ustedes!"\qt@no{93}}
\qt@newcmd\qurantrans@es@mdlxvii{Cuando llegó Mi designio salvé, por Mi misericordia, a Jetró y a quienes con él creían. Pero a los injustos les sorprendió el estrépito, y amanecieron en sus casas muertos,\qt@no{94}}
\qt@newcmd\qurantrans@es@mdlxviii{como si no hubieran habitado en ellas. Los habitantes de Madián fueron execrados como habían sido execrados los de Zamud.\qt@no{95}}
\qt@newcmd\qurantrans@es@mdlxix{Envié a Moisés con Mis signos y pruebas evidentes\qt@no{96}}
\qt@newcmd\qurantrans@es@mdlxx{para que se presentara ante el Faraón y su nobleza, pero ésta siguió la orden del Faraón. El Faraón no se encaminó.\qt@no{97}}
\qt@newcmd\qurantrans@es@mdlxxi{Él irá al frente de su pueblo el Día del Juicio y los conducirá al [castigo del] Infierno. ¡Qué pésimo lugar al que ingresarán!\qt@no{98}}
\qt@newcmd\qurantrans@es@mdlxxii{La maldición los alcanzó en este mundo y perdurará hasta el Día del Juicio. ¡Qué terrible maldición los alcanzó!\qt@no{99}}
\qt@newcmd\qurantrans@es@mdlxxiii{Éstas son historias que te he revelado de los pueblos [sobre los que ha descendido un castigo]. Algunos de ellos todavía siguen en pie, y otros han sido devastados.\qt@no{100}}
\qt@newcmd\qurantrans@es@mdlxxiv{No fui injusto con ellos [al castigarlos], sino que ellos lo fueron consigo mismos [al rechazar a los Profetas]. De nada les sirvieron los ídolos que invocaban en lugar de Dios cuando llegó el designio de tu Señor, no hicieron más que aumentar su ruina.\qt@no{101}}
\qt@newcmd\qurantrans@es@mdlxxv{Así es el castigo de tu Señor, cuando decide azotar a un pueblo opresor los azota con un castigo doloroso y severo;\qt@no{102}}
\qt@newcmd\qurantrans@es@mdlxxvi{en esto hay un motivo de reflexión para quien teme el castigo de la otra vida. El Día del Juicio serán congregadas las personas, ese día será atestiguado por todos.\qt@no{103}}
\qt@newcmd\qurantrans@es@mdlxxvii{No lo retrasaré sino hasta su plazo prefijado,\qt@no{104}}
\qt@newcmd\qurantrans@es@mdlxxviii{pero cuando llegue, nadie podrá hablar, excepto quien tenga el permiso de Dios. Entre los congregados estarán los desdichados y los bienaventurados.\qt@no{105}}
\qt@newcmd\qurantrans@es@mdlxxix{Los desdichados estarán en el Infierno, donde se oirán sus alaridos y sollozos.\qt@no{106}}
\qt@newcmd\qurantrans@es@mdlxxx{Estarán en él por toda la eternidad al igual que los cielos y la tierra [de la otra vida], excepto lo que tu Señor quiera. Tu Señor hace lo que quiere.\qt@no{107}}
\qt@newcmd\qurantrans@es@mdlxxxi{En cambio, los bienaventurados estarán en el Paraíso eternamente al igual que los cielos y la tierra [de la otra vida], excepto lo que tu Señor quiera. [Los bienaventurados] serán recompensados con una gracia sin fin.\qt@no{108}}
\qt@newcmd\qurantrans@es@mdlxxxii{No tengas ninguna duda sobre lo que [los idólatras] adoran, pues lo que adoran [sin reflexionar] no es sino lo mismo que antes adoraban sus padres. Les daré lo que les corresponda, sin merma alguna.\qt@no{109}}
\qt@newcmd\qurantrans@es@mdlxxxiii{Concedí a Moisés el Libro, pero se opusieron a él, y de no ser porque tu Señor había decretado [retrasar el castigo hasta el Día del Juicio] ya los habría aniquilado. Ellos [los judíos] también dudan acerca del Corán.\qt@no{110}}
\qt@newcmd\qurantrans@es@mdlxxxiv{Tu Señor los juzgará a todos por sus obras. Él conoce perfectamente lo que hacen.\qt@no{111}}
\qt@newcmd\qurantrans@es@mdlxxxv{Mantente firme [¡oh, Mujámmad!, en el sendero recto] como se te ha ordenado, y que también lo hagan quienes se arrepientan [de su incredulidad y te sigan], y no trasgredan los límites. Él ve perfectamente todo lo que hacen.\qt@no{112}}
\qt@newcmd\qurantrans@es@mdlxxxvi{No se inclinen hacia los opresores [aceptando su injusticia], porque [si lo hacen] los alcanzará el Fuego, y no tendrán protector fuera de Dios ni serán socorridos.\qt@no{113}}
\qt@newcmd\qurantrans@es@mdlxxxvii{Observa las oraciones prescritas en los dos extremos del día y durante la noche, pues las obras buenas borran las obras malas. Esto es una exhortación para quienes reflexionan.\qt@no{114}}
\qt@newcmd\qurantrans@es@mdlxxxviii{Sé paciente [ante las dificultades], porque Dios no dejará que se pierda la recompensa de los que hacen el bien.\qt@no{115}}
\qt@newcmd\qurantrans@es@mdlxxxix{En las generaciones que los precedieron hubo solo unos pocos piadosos que se opusieron a la corrupción en la Tierra, a quienes salvé [junto a sus Profetas]. En cambio, los injustos [que eran la mayoría] permanecieron cegados por los placeres [de la vida mundanal] y terminaron siendo criminales.\qt@no{116}}
\qt@newcmd\qurantrans@es@mdxc{Tu Señor jamás destruiría un pueblo injustamente, cuando sus habitantes hacen el bien.\qt@no{117}}
\qt@newcmd\qurantrans@es@mdxci{Si tu Señor hubiera querido, habría hecho de todos los seres humanos una sola nación [de creyentes], [pero por Su sabiduría divina concedió al ser humano libre albedrío] y ellos no dejarán de discrepar [unos con otros],\qt@no{118}}
\qt@newcmd\qurantrans@es@mdxcii{excepto aquellos de quienes tu Señor tuvo misericordia [porque siguieron la guía], y con ese objetivo Dios los creó. Pero ha de cumplirse la palabra de tu Señor: ``Llenaré el Infierno de yinnes y de seres humanos [que rechacen a los Profetas]".\qt@no{119}}
\qt@newcmd\qurantrans@es@mdxciii{Todo esto que te he revelado sobre las historias de los Mensajeros es para [consolar y] afianzar tu corazón. Te han sido revelados, en este capítulo [del Corán] signos que evidencian la Verdad, y son una exhortación y un motivo de reflexión para los creyentes.\qt@no{120}}
\qt@newcmd\qurantrans@es@mdxciv{Diles [¡Oh, Mujámmad!] a quienes no creen: ``Obren a su manera, que nosotros lo haremos a la nuestra [según los preceptos del Islam],\qt@no{121}}
\qt@newcmd\qurantrans@es@mdxcv{y esperen, que nosotros también aguardaremos [que Dios decida quién tiene razón]".\qt@no{122}}
\qt@newcmd\qurantrans@es@mdxcvi{Dios conoce lo oculto de los cielos y de la Tierra, y a Él retornan todos los asuntos. Adórenlo, pues, y encomiéndense a Él, y sepan que su Señor está bien atento a lo que hacen.\qt@no{123}}
\qt@newcmd\qurantrans@es@mdxcvii{\basmalahes Álif. Lam. Ra’. Éstos son versículos de un Libro elocuente que muestra la verdad.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdxcviii{He descendido el Corán en idioma árabe para que puedan comprender sus significados en su contexto.\qt@no{2}}
\qt@newcmd\qurantrans@es@mdxcix{Te contaré la historia más hermosa de las que te he revelado en el Corán, de la que antes no tenías conocimiento.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdc{Cuando José dijo a su padre [Jacob]: ``¡Padre mío! He soñado que se prosternaban ante mí once estrellas, el Sol y la Luna".\qt@no{4}}
\qt@newcmd\qurantrans@es@mdci{Dijo [Jacob]: ``¡Hijito mío! No les cuentes el sueño a tus hermanos porque conspirarán contra ti [por envidia]; el demonio es el enemigo declarado de los seres humanos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcii{Tu Señor te elegirá [como Profeta] y te enseñará a interpretar los sueños; y completará Su bendición en ti [con la revelación] y en la descendencia de Jacob, tal como bendijo a tus antepasados, Abraham e Isaac; tu Señor todo lo sabe, es Sabio".\qt@no{6}}
\qt@newcmd\qurantrans@es@mdciii{En la historia de José y sus hermanos hay signos para los que buscan la verdad.\qt@no{7}}
\qt@newcmd\qurantrans@es@mdciv{[Los hermanos de José] dijeron: ``José y su hermano [Benjamín] son los preferidos de nuestro padre, a pesar de que somos muchos sus hijos. Nuestro padre está en un error evidente".\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcv{[Dijo uno de ellos]: ``Maten a José o destiérrenlo para que la atención de nuestro padre sea para nosotros por igual. Luego nos arrepentiremos y podremos ser de los virtuosos nuevamente".\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcvi{Dijo uno de ellos: ``No maten a José. Si ya tienen decidido deshacerse de él, mejor arrójenlo a lo profundo de un pozo seco, alguna caravana lo recogerá".\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcvii{[Entonces se dirigieron a su padre] diciendo: ``¡Padre nuestro! ¿Por qué no nos dejas cuidar de José? Solo tenemos buenas intenciones con él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcviii{Deja que venga con nosotros mañana, se divertirá y jugará. Nosotros lo cuidaremos".\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcix{Dijo [Jacob]: ``Me entristece que lo lleven lejos de mí, y temo que ustedes se descuiden y lo devore un lobo".\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcx{Dijeron: ``Si lo devorara un lobo, siendo nosotros un grupo numeroso, seríamos unos inútiles".\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcxi{Cuando se lo llevaron, acordaron arrojarlo a lo profundo de un pozo seco. Una vez que lo hicieron le inspiré a José: ``Algún día les recordarás lo que están haciendo ahora, sin que ellos te reconozcan".\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcxii{Al anochecer, se presentaron ante su padre llorando.\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcxiii{Dijeron: ``¡Padre! Competíamos corriendo entre nosotros y dejamos a José con nuestras provisiones, y lo devoró un lobo. Te decimos la verdad, aunque no quieras creernos".\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcxiv{Y le mostraron su túnica manchada con sangre falsa. Dijo [Jacob]: ``Lo que ha sucedido no es como me lo cuentan, sino que es una falsedad que inventaron. Me resignaré pacientemente y que Dios me dé consuelo para sobrellevar la desgracia que me acaban de contar".\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcxv{Cuando pasó una caravana [cerca del pozo], enviaron a uno de ellos a buscar agua. Éste echó el cubo y al subirlo [vio a José y] exclamó: ``¡Buenas noticias! Aquí hay un muchacho". Y lo ocultaron para venderlo; pero Dios bien sabía lo que hacían.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcxvi{[Mientras espiaban, sus hermanos vieron lo que ocurría y reclamaron que José era su esclavo.] Lo vendieron [a la caravana] por un precio insignificante, unas pocas monedas, para deshacerse de él.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcxvii{Y luego el egipcio que lo compró le dijo a su mujer: ``Recíbelo honorablemente, podría sernos útil o quizá lo adoptemos como hijo". Así concedí a José una buena posición en esa tierra, y le enseñé la interpretación de los sueños. La voluntad de Dios siempre prevalece, pero la mayoría de la gente no lo sabe.\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcxviii{Y cuando alcanzó la mayoría de edad, le concedí el discernimiento y la sabiduría [a través de la revelación]. Así es como recompenso a los que hacen el bien.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcxix{Pero la señora de la casa en la cual estaba se sintió atraída por él. Lo llamó y, cerrando las puertas, exclamó: ``¡Ven aquí, soy tuya!" Dijo José: ``¡Qué Dios me proteja! Mi amo [tu esposo] me ha colmado de honores. Debes saber que los traidores no acaban bien".\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcxx{Ella lo deseó, y él la hubiera deseado de no ser porque vio una señal de su Señor. Así lo preservé del pecado y la obscenidad, porque era uno de Mis siervos elegidos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcxxi{[José procuró huir y] ambos corrieron hacia la puerta, ella [al intentar detenerlo] rasgó la túnica de él por detrás y fueron sorprendidos por el marido de ella junto a la puerta, por lo que ella se apresuró a decir: ``¿Qué pena merece quien ha pretendido deshonrar a tu mujer, sino que lo encarcelen o reciba un castigo severo?"\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcxxii{Dijo José: ``Fue ella quien intentó seducirme". Entonces un testigo de la familia de ella dijo: ``Si su camisa fue rasgada por delante, ella ha dicho la verdad y él es quien miente.\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcxxiii{Pero si su camisa fue rasgada por detrás, entonces ella miente y él dice la verdad".\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcxxiv{Cuando el esposo vio que la camisa estaba rasgada por detrás, dijo: ``Es una astucia propia de mujeres; sus artimañas son terribles.\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcxxv{¡José! Olvida lo sucedido [y no se lo menciones a nadie]. Y tú, mujer, pide perdón por lo que has hecho; porque has incurrido en una falta grave".\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcxxvi{Pero algunas mujeres de la ciudad comentaron: ``La mujer del gobernador pretende seducir a su joven criado. Su amor por él la ha trastornado. Pensamos que está profundamente equivocada".\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcxxvii{Cuando [la mujer del gobernador] se enteró de sus habladurías las invitó [a su casa], les preparó un banquete y dio a cada una de ellas un cuchillo [para cortar la comida]. Entonces le dijo [a José]: ``Preséntate ante ellas". Cuando lo vieron quedaron tan asombradas [por su belleza] que se cortaron la mano [por la distracción], y dijeron: ``¡Dios Santo! No es un ser humano, es un ángel hermoso".\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcxxviii{[Dijo ella:] ``Éste es por quien me censuraban. Yo quise seducirlo, pero se mantuvo casto. Si no hace lo que le pido, ordenaré que lo encarcelen y terminará siendo humillado".\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcxxix{Dijo [José]: ``¡Señor mío! Prefiero la cárcel a caer en lo que éstas mujeres me proponen; pero si no apartas de mí su acoso, cederé a sus encantos y cometeré una estupidez".\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcxxx{Pero su Señor respondió a su súplica y apartó de él sus artimañas; Él todo lo oye, todo lo sabe.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcxxxi{Luego, a pesar de las pruebas de su inocencia, optaron por encarcelarlo temporalmente [para evitar los rumores].\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcxxxii{Junto con él fueron encarcelados otros dos jóvenes. Dijo uno de ellos: ``Me vi en un sueño prensando vino". Y dijo el otro: ``Yo me vi llevando pan sobre la cabeza, del cual comían los pájaros. Háblanos sobre su interpretación, porque nos pareces un hombre virtuoso".\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcxxxiii{[Dijo José:] ``Antes de que traigan la comida ya les habré dado su interpretación. La interpretación de los sueños es algo que mi Señor me enseñó; sepan primero que rechazo las costumbres de un pueblo que no cree en Dios y niega la existencia de la otra vida.\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcxxxiv{Yo sigo la religión de mis ancestros, Abraham, Isaac y Jacob. Nosotros no asociamos ningún copartícipe a Dios. Esto es una gracia de Dios para nosotros y para todo aquel que siga la guía, pero la mayoría de la gente no lo agradece.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcxxxv{¡Compañeros de cárcel! ¿Qué es más razonable? ¿Creer en muchos ídolos o creer en Dios, el Único, el Victorioso?\qt@no{39}}
\qt@newcmd\qurantrans@es@mdcxxxvi{Los [ídolos] que adoran en lugar de Dios, no son sino nombres que ustedes y sus padres han elegido [para algunas piedras y estatuas], siendo que Dios no les reveló nada al respecto. El juicio solo pertenece a Dios, Quien ordenó que no adoren a nada ni nadie excepto a Él; esa es la religión verdadera, pero la mayoría de la gente lo ignora.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdcxxxvii{¡Compañeros de cárcel! [La interpretación de sus sueños es que] uno servirá vino [de nuevo] al rey; mientras que el otro será crucificado y los pájaros comerán de su cabeza. El asunto sobre el que me han consultado ya ha sido decretado".\qt@no{41}}
\qt@newcmd\qurantrans@es@mdcxxxviii{Le dijo [José] a quien supo que quedaría en libertad: ``Menciona mi caso ante el rey". Pero el demonio le hizo olvidar que lo mencionara ante su amo, por lo que [José] permaneció en la cárcel varios años más.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdcxxxix{[Cierto día] dijo el rey: ``He visto en mis sueños siete vacas gordas devoradas por siete vacas flacas, y siete espigas verdes y otras [siete] secas. ¡Cortesanos! Expliquen mi sueño, si es que saben interpretarlo".\qt@no{43}}
\qt@newcmd\qurantrans@es@mdcxl{Respondieron: ``Son sueños incoherentes, y nosotros no somos expertos en la interpretación de sueños".\qt@no{44}}
\qt@newcmd\qurantrans@es@mdcxli{Entonces dijo aquel de los dos que se había salvado [de la prisión] al recordar [a José] mucho tiempo después: ``Yo les explicaré su significado; envíenme [a la cárcel para preguntar a José]".\qt@no{45}}
\qt@newcmd\qurantrans@es@mdcxlii{``¡José! ¡Tú que dices la verdad! Interpreta qué significa un sueño donde siete vacas gordas son devoradas por siete vacas flacas, y [donde aparecen] siete espigas verdes y otras [siete] secas; para que regrese con su explicación ante la gente y así sepan [sobre tu don]".\qt@no{46}}
\qt@newcmd\qurantrans@es@mdcxliii{Dijo [José]: ``Deben sembrar como de costumbre siete años, pero lo que cosechen déjenlo dentro de la espiga [para conservarlo] excepto una parte, de la que pueden comer.\qt@no{47}}
\qt@newcmd\qurantrans@es@mdcxliv{Luego vendrán siete años de sequía en los que comerán lo que hayan acopiado, salvo la parte [reservada para volver a sembrar].\qt@no{48}}
\qt@newcmd\qurantrans@es@mdcxlv{Luego vendrá un año en que la gente será bendecida con la lluvia, y en él volverán a tener jugo de los frutos".\qt@no{49}}
\qt@newcmd\qurantrans@es@mdcxlvi{[Al escuchar la interpretación,] el rey dijo: ``¡Tráiganlo ante mí!" Pero cuando el enviado se presentó ante José, éste le dijo: ``Regresa ante tu amo y pregúntale qué pasó con aquellas mujeres que se cortaron las manos. Mi Señor está bien enterado de sus conspiraciones".\qt@no{50}}
\qt@newcmd\qurantrans@es@mdcxlvii{[Las mujeres fueron reunidas ante el rey y] les dijo: ``¿Qué sucedió cuando intentaron seducir a José?" Dijeron: ``¡Que Dios nos ampare! No sabemos nada malo de él". Entonces la mujer del gobernador dijo: ``Ahora la verdad ha salido a la luz. Yo soy la que quiso seducirlo, y él decía la verdad.\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcxlviii{Digo esto para que [mi esposo] sepa que no lo traicioné en su ausencia, y sé bien que Dios desbarata las intrigas de los traidores.\qt@no{52}}
\qt@newcmd\qurantrans@es@mdcxlix{No pretendo excusarme, porque el alma suele ordenar el mal, y solo están a salvo de ello aquellos a quienes mi Señor los protege. Mi Señor es Absolvedor, Misericordioso".\qt@no{53}}
\qt@newcmd\qurantrans@es@mdcl{Dijo el rey: ``¡Tráiganlo ante mí! Haré que sea mi hombre de confianza". Cuando hablaron le dijo: ``Desde hoy gozas de autoridad y confianza".\qt@no{54}}
\qt@newcmd\qurantrans@es@mdcli{Dijo [José]: ``Ponme a cargo de los graneros [y las arcas] del país, porque yo sé cómo administrarlas con prudencia".\qt@no{55}}
\qt@newcmd\qurantrans@es@mdclii{Así fue como hice a José gobernar la tierra [de Egipto], donde pudo establecerse a su gusto. Concedo Mi misericordia a quien quiero, y no dejo que se pierda la recompensa de los que hacen el bien [en este mundo].\qt@no{56}}
\qt@newcmd\qurantrans@es@mdcliii{Pero para los creyentes piadosos la recompensa en la otra vida es superior.\qt@no{57}}
\qt@newcmd\qurantrans@es@mdcliv{[Pasados algunos años,] llegaron los hermanos de José [a Egipto en busca de provisiones] y se presentaron ante él, y él los reconoció, mientras que ellos no lo reconocieron.\qt@no{58}}
\qt@newcmd\qurantrans@es@mdclv{Cuando les hubo suministrado sus provisiones, les dijo: ``[La próxima vez que vengan,] traigan a su hermano por parte de padre. ¿No ven que les he dado la medida justa y soy el mejor de los anfitriones?\qt@no{59}}
\qt@newcmd\qurantrans@es@mdclvi{Si no lo traen, no obtendrán más provisiones de mí, ni se les permitirá acercarse a mí".\qt@no{60}}
\qt@newcmd\qurantrans@es@mdclvii{Dijeron: ``Convenceremos a su padre para que se desprenda de él, haremos todo lo posible de nuestra parte".\qt@no{61}}
\qt@newcmd\qurantrans@es@mdclviii{[José] dijo a sus criados: ``Pongan [el valor que pagaron por] su mercancía en su equipaje nuevamente, para que lo encuentren cuando vuelvan a su gente y así ansíen regresar".\qt@no{62}}
\qt@newcmd\qurantrans@es@mdclix{Cuando regresaron ante su padre dijeron: ``¡Padre! Se nos ha negado el grano [en el futuro a menos que llevemos a Benjamín], envía pues a nuestro hermano con nosotros para que podamos aprovisionarnos, y ten certeza de que lo cuidaremos".\qt@no{63}}
\qt@newcmd\qurantrans@es@mdclx{Dijo [Jacob]: ``¿Acaso esperan que se los confíe de la misma manera que antaño les confié a su hermano [José]? Dios es mejor custodio que ustedes, y el más Misericordioso de los misericordiosos.\qt@no{64}}
\qt@newcmd\qurantrans@es@mdclxi{Y cuando abrieron su equipaje encontraron que se les había devuelto [el valor de] su mercancía; dijeron: ``¡Padre! ¿Qué más queremos? ¡Aquí está nuestra mercancía, nos ha sido devuelta! [Si dejas venir a Benjamín con nosotros] podremos traer más provisiones para nuestra gente, cuidaremos de nuestro hermano, y obtendremos otra carga de camello. Lo que hemos traído es una carga escasa".\qt@no{65}}
\qt@newcmd\qurantrans@es@mdclxii{[Dijo Jacob:] ``No lo enviaré hasta que me juren solemnemente por Dios que lo traerán de regreso, a menos que se vean impedidos por fuerza mayor". Cuando hicieron el juramento les dijo: ``Dios es testigo de este compromiso".\qt@no{66}}
\qt@newcmd\qurantrans@es@mdclxiii{Dijo [Jacob]: ``¡Hijos míos! No entren todos [a la ciudad] por la misma puerta, mejor ingresen por puertas diferentes, pero sepan que no puedo hacer nada contra el designio de Dios, pues Él es Quien decreta todos los asuntos. En Él he depositado mi confianza, y a Él deben encomendarse quienes en Él confían".\qt@no{67}}
\qt@newcmd\qurantrans@es@mdclxiv{Pero aunque entraron del modo que les aconsejó su padre, esto de nada les habría servido contra el designio de Dios, pues solo era una prevención que Jacob había tomado [para proteger a sus hijos]. Jacob tenía un conocimiento que le había enseñado [a través de la revelación]. Pero la mayoría de la gente lo ignora.\qt@no{68}}
\qt@newcmd\qurantrans@es@mdclxv{Y cuando [los hijos de Jacob] se presentaron ante José, éste abrazó a su hermano [Benjamín], y le dijo [en secreto]: ``Yo soy tu hermano, ya no sientas pena por lo que ellos hicieron [conmigo]".\qt@no{69}}
\qt@newcmd\qurantrans@es@mdclxvi{Y tras haberles dado sus provisiones, escondió una copa [del rey] en el saco de su hermano [Benjamín]. Y [cuando iban saliendo de la ciudad] un pregonero gritó: ``¡Gente de la caravana, son unos ladrones!"\qt@no{70}}
\qt@newcmd\qurantrans@es@mdclxvii{Dijeron [los hermanos de José] dirigiéndose a los guardias: ``¿Qué es lo que se ha perdido?"\qt@no{71}}
\qt@newcmd\qurantrans@es@mdclxviii{Respondieron: ``Perdimos una copa del rey. A quien la encuentre le daremos la carga de un camello [de recompensa], y [dijo el pregonero:] yo lo garantizo".\qt@no{72}}
\qt@newcmd\qurantrans@es@mdclxix{``¡Por Dios! Bien saben que no hemos venido a corromper en la tierra [de Egipto] ni somos ladrones" [dijeron los hermanos de José].\qt@no{73}}
\qt@newcmd\qurantrans@es@mdclxx{Dijeron [los guardias]: ``¿Cuál debería ser el castigo de quien esté mintiendo?"\qt@no{74}}
\qt@newcmd\qurantrans@es@mdclxxi{[Respondieron:] ``El castigo de aquel a quien se le encontrase [la copa] en su equipaje debería ser que sea aprisionado. Así es como se castiga a los que cometen ese crimen".\qt@no{75}}
\qt@newcmd\qurantrans@es@mdclxxii{Entonces [fueron llevados ante José para ser registrados, y] empezó por el equipaje de ellos antes que el de su hermano [Benjamín], de donde sacó la copa. Así se lo inspiré a José. No habría podido quedarse con su hermano [de otra forma], pues así era la ley del rey, y Dios así lo quiso. Elevo en grados a quien quiero [a través del conocimiento], pero por encima de todo sabio está El que todo lo sabe.\qt@no{76}}
\qt@newcmd\qurantrans@es@mdclxxiii{[Tan pronto como la copa fue descubierta en el equipaje de Benjamín, los hermanos] dijeron: ``Si ha robado, ya antes un hermano suyo había robado", pero José se contuvo y no les respondió, sino que pensó para sus adentros: ``Ustedes son mucho peores, y Dios sabe bien la mentira que están diciendo".\qt@no{77}}
\qt@newcmd\qurantrans@es@mdclxxiv{Dijeron [los hermanos]: ``¡Oh, gobernador! Él tiene un padre muy anciano, quédate con uno de nosotros en su lugar; vemos que eres un hombre de bien".\qt@no{78}}
\qt@newcmd\qurantrans@es@mdclxxv{Dijo [José]: ``¡Dios nos libre de castigar a otro que aquel al que le encontramos la copa en su poder! Porque seríamos injustos".\qt@no{79}}
\qt@newcmd\qurantrans@es@mdclxxvi{Cuando perdieron toda esperanza de persuadirlo, se retiraron a deliberar. Dijo el mayor de ellos: ``¿Recuerdan que nuestro padre nos hizo jurar solemnemente por Dios, pues ya antes habíamos fallado con respecto a José? No me moveré de esta tierra hasta que mi padre lo autorice, o Dios juzgue a mi favor, porque Él es el mejor de los jueces.\qt@no{80}}
\qt@newcmd\qurantrans@es@mdclxxvii{Vuelvan ante nuestro padre y díganle: ¡Padre! Tu hijo ha robado, y solo atestiguamos sobre lo que hemos sabido, y no tenemos acceso a lo oculto [para saber si realmente lo hizo o no].\qt@no{81}}
\qt@newcmd\qurantrans@es@mdclxxviii{Y pregunta en la ciudad donde estuvimos y a la caravana con la que regresamos, pues decimos la verdad".\qt@no{82}}
\qt@newcmd\qurantrans@es@mdclxxix{[Pero Jacob al escucharlos] dijo: ``Lo que ha sucedido no es como me lo cuentan, sino que es una falsedad que inventaron. Me resignaré pacientemente y que Dios me dé consuelo para sobrellevar la desgracia que me acaban de contar. Quiera Dios devolverme a todos [mis hijos]. Él todo lo sabe, es el Sabio".\qt@no{83}}
\qt@newcmd\qurantrans@es@mdclxxx{Y [le recordó el dolor por su hijo perdido y] se apartó de ellos diciendo: ``¡Qué pena siento por la falta de José!" Y perdió la vista por tanta pena, y quedó desconsolado, sufriendo en silencio.\qt@no{84}}
\qt@newcmd\qurantrans@es@mdclxxxi{Dijeron [sus hijos]: ``¡Por Dios! No dejarás de recordar a José hasta enfermar o morir".\qt@no{85}}
\qt@newcmd\qurantrans@es@mdclxxxii{Dijo [Jacob]: ``Solo me quejo a Dios en mi lamento y mi dolor, y sé de Dios lo que ustedes no saben.\qt@no{86}}
\qt@newcmd\qurantrans@es@mdclxxxiii{¡Hijos míos! Vuelvan [a Egipto], averigüen sobre José y su hermano, y no desesperen de la bondad de Dios, pues no desesperan de la bondad de Dios sino los incrédulos".\qt@no{87}}
\qt@newcmd\qurantrans@es@mdclxxxiv{[En Egipto] se presentaron ante José y le dijeron: ``¡Oh, gobernador! Hemos sido alcanzados por la sequía, nosotros y nuestras familias, por eso trajimos mercadería de escaso valor, pero danos una justa medida y sé caritativo con nosotros; Dios recompensa a los generosos".\qt@no{88}}
\qt@newcmd\qurantrans@es@mdclxxxv{Entonces les dijo [José]: ``¿Acaso recuerdan lo que hicieron con José y su hermano, llevados por la ignorancia?"\qt@no{89}}
\qt@newcmd\qurantrans@es@mdclxxxvi{Dijeron [sorprendidos]: ``¿Eres tú José?" Respondió: ``Yo soy José y éste es mi hermano [Benjamín]. Dios nos ha agraciado [con el reencuentro]. Quienes tengan temor de Dios y sean pacientes [ante las adversidades], sepan que Dios no dejará de recompensar a los que hacen el bien".\qt@no{90}}
\qt@newcmd\qurantrans@es@mdclxxxvii{Dijeron: ``¡Por Dios! Te ha enaltecido Dios muy por encima de nosotros. Nosotros estábamos en el error".\qt@no{91}}
\qt@newcmd\qurantrans@es@mdclxxxviii{Dijo [José]: ``Hoy no les reprocharé nada de lo que hayan hecho en el pasado. Que Dios los perdone, Él es el más Misericordioso de los misericordiosos.\qt@no{92}}
\qt@newcmd\qurantrans@es@mdclxxxix{Vayan con mi camisa y pónganla sobre el rostro de mi padre, que así recuperará la vista; y traigan a toda la familia".\qt@no{93}}
\qt@newcmd\qurantrans@es@mdcxc{Cuando la caravana partía, dijo su padre [Jacob a quienes estaban junto a él]: ``Aunque piensen que desvarío, en este momento noto la presencia de José en el aire".\qt@no{94}}
\qt@newcmd\qurantrans@es@mdcxci{Dijeron [los otros hijos]: ``¡Por Dios! Sigues en tu antiguo error".\qt@no{95}}
\qt@newcmd\qurantrans@es@mdcxcii{Cuando llegaron, le colocaron [la camisa] sobre su rostro y recuperó inmediatamente la vista. [Jacob] exclamó: ``¿No les dije que yo sabía de Dios lo que ustedes ignoran?"\qt@no{96}}
\qt@newcmd\qurantrans@es@mdcxciii{Dijeron: ``¡Padre! Pide a Dios que perdone nuestros pecados, nosotros estábamos en el error".\qt@no{97}}
\qt@newcmd\qurantrans@es@mdcxciv{Respondió: ``Pediré a mi Señor que los perdone, Él es el Absolvedor, el Misericordioso".\qt@no{98}}
\qt@newcmd\qurantrans@es@mdcxcv{Luego [cuando llegaron todos a Egipto y] se presentaron ante José, éste abrazó a sus padres y dijo: ``Vivan en Egipto, si Dios quiere estarán seguros aquí".\qt@no{99}}
\qt@newcmd\qurantrans@es@mdcxcvi{Hizo sentar en el trono a sus padres, que junto a todos [los hermanos] cayeron prosternados ante José, quien dijo: ``¡Padre mío! Esta es la interpretación del sueño que tuve [cuando era niño], y mi Señor hizo que se cumpliera. Dios me favoreció sacándome de la cárcel y trayéndolos del desierto ante mí, a pesar de que el demonio había sembrado la discordia entre mis hermanos y yo. Mi Señor es Sutil con quien quiere, y Él todo lo sabe, es Sabio.\qt@no{100}}
\qt@newcmd\qurantrans@es@mdcxcvii{¡Señor mío! Me has concedido autoridad y me has enseñado la interpretación de los sueños. ¡Creador de los cielos y la Tierra! Tú eres mi Protector en esta vida y en la otra, hazme morir sometido a Ti, y reúneme con los virtuosos".\qt@no{101}}
\qt@newcmd\qurantrans@es@mdcxcviii{[¡Oh, Mujámmad!] Esta historia que te he revelado había permanecido oculta hasta ahora. Tú no estabas presente cuando [los hermanos de José] planearon [eliminarlo] y se complotaron.\qt@no{102}}
\qt@newcmd\qurantrans@es@mdcxcix{La mayoría de los seres humanos, aunque te esfuerces [para que crean], no serán creyentes.\qt@no{103}}
\qt@newcmd\qurantrans@es@mdcc{Tú no pides remuneración alguna por transmitir el Mensaje, que está dirigido a toda la humanidad.\qt@no{104}}
\qt@newcmd\qurantrans@es@mdcci{¡Cuántos signos hay en los cielos y en la Tierra que pasan frente a ellos, pero no prestan atención!\qt@no{105}}
\qt@newcmd\qurantrans@es@mdccii{La mayoría de los que creen en Dios caen en dedicarle actos de adoración a otros.\qt@no{106}}
\qt@newcmd\qurantrans@es@mdcciii{¿Acaso [estas personas] se sienten a salvo de ser alcanzados por el castigo de Dios, o a salvo de que les llegue la Hora del Juicio de improviso, cuando menos lo esperan?\qt@no{107}}
\qt@newcmd\qurantrans@es@mdcciv{Di: ``Éste es mi sendero, tanto yo como quienes me siguen invitamos a adorar a Dios con conocimiento. ¡Glorificado sea Dios! No soy de los que idolatran divinidades junto a Dios".\qt@no{108}}
\qt@newcmd\qurantrans@es@mdccv{No he enviado antes de ti sino a hombres que pertenecían a sus propias comunidades para que le transmitieran Mi revelación. ¿Por qué [quienes rechazan este mensaje] no viajan por el mundo y observan cómo fue que acabaron los pueblos de la antigüedad [que desmintieron a los Profetas]? La morada de la otra vida será mejor para quienes tienen temor de Dios. ¿Es que no van a reflexionar?\qt@no{109}}
\qt@newcmd\qurantrans@es@mdccvi{[Todos los Profetas sufrieron persecución y rechazo] al punto que cuando los Mensajeros se resignaron y tuvieron la certeza de que les desmentirían definitivamente, les llegó Mi auxilio: entonces, todos aquellos a quienes quise [salvar] fueron salvados [y los que rechazaron la verdad fueron destruidos]: pues la gente que se hunde en el pecado no puede escapar de Mi ira.\qt@no{110}}
\qt@newcmd\qurantrans@es@mdccvii{En las historias [de los Profetas] hay un motivo de enseñanza para la gente que reflexiona. [El Corán] no es un relato inventado, sino que es una confirmación de lo ya revelado anteriormente, así como una explicación detallada de todas las cosas, una guía y misericordia para los creyentes.\qt@no{111}}
\qt@newcmd\qurantrans@es@mdccviii{\basmalahes Álif. Lam. Ra’. Éstos son los versículos del Libro que te fue revelado [¡oh, Mujámmad!] por tu Señor, aunque la mayoría de la gente no crea.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdccix{Dios es Quien elevó los cielos sin columnas que pudieran ver, luego se estableció sobre el Trono; sometió al Sol y a la Luna haciendo que cada uno recorriera [su órbita] por un plazo prefijado; Él decreta todos los asuntos y explica detalladamente Sus signos para que tengan certeza de que ante Él comparecerán.\qt@no{2}}
\qt@newcmd\qurantrans@es@mdccx{Él fue quien extendió la tierra, dispuso en ella montañas firmes y ríos, a los frutos los creó en pares, [Dios] hace que la noche suceda al día. En esto hay señales para quienes recapacitan.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdccxi{En la tierra hay regiones colindantes cuyos terrenos son variados, en ellos hay huertos de vides, cultivos de cereales, palmeras de un solo tronco o de varios; todo es regado por una misma agua. Algunas dispuso que tuvieran mejor sabor que otras, en esto hay signos [de Dios] para quienes reflexionan.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdccxii{Si te asombras [de estos signos], más asombroso aún es que digan [los incrédulos]: ``¿Acaso cuando seamos reducidos a polvo seremos resucitados?" Ellos no creyeron en su Señor, serán arriados con argollas en sus cuellos [al castigo] y serán los moradores del Infierno, donde sufrirán por toda la eternidad.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdccxiii{Te desafían a que les adelantes el castigo en vez de pedirte ser agraciados por la misericordia divina, siendo que antes de ellos otros pueblos semejantes [en su incredulidad] fueron castigados. Es tu Señor Quien perdona a la gente a pesar de sus injusticias, pero también es severo en el castigo.\qt@no{6}}
\qt@newcmd\qurantrans@es@mdccxiv{Dicen los que se niegan a creer: ``¿Por qué no desciende con él un milagro de su Señor?" [Respóndeles, ¡oh, Mujámmad!,] que tú solo eres un amonestador y que para cada pueblo he enviado un [Profeta como] guía.\qt@no{7}}
\qt@newcmd\qurantrans@es@mdccxv{Dios bien sabe qué se gesta en el vientre de cada hembra, y si completará el ciclo de gestación o no. Él asignó a todas las cosas un tiempo establecido.\qt@no{8}}
\qt@newcmd\qurantrans@es@mdccxvi{Él conoce lo oculto y lo manifiesto, es el Grande, el Sublime.\qt@no{9}}
\qt@newcmd\qurantrans@es@mdccxvii{[Ante Dios] es igual que digan algo en secreto o en público, que se oculten de noche o se muestren de día.\qt@no{10}}
\qt@newcmd\qurantrans@es@mdccxviii{El [ser humano] tiene [ángeles] guardianes por delante y por detrás, que lo protegen por orden de Dios. Sepan que Dios no cambia la condición de un pueblo hasta que ellos no cambien lo que hay en sí mismos. Pero si Dios decreta el castigo para un pueblo, no existe nada que lo pueda impedir, y no encontrarán fuera de Él protector alguno.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdccxix{Él es Quien los hace ver el relámpago con temor [a su peligro] y anhelo [de las lluvias], Él es quien forma las nubes pesadas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mdccxx{El trueno Lo glorifica con su alabanza, así como los ángeles por temor a Él. [Dios] envía los rayos y fulmina con ellos a quien quiere, sin embargo [los que se niegan a creer todavía] discuten acerca de Dios. Él es severo en el castigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mdccxxi{Solo Él tiene el verdadero derecho a ser invocado, y aquellos [ídolos] que invocan en lugar de Dios no podrán responder sus súplicas. [Su ejemplo] es como quien extiende sus manos [frente a un pozo profundo de agua] creyendo que ésta vendrá a su boca, pero esto es imposible. Las súplicas [a los ídolos] de los que se niegan a creer son en vano.\qt@no{14}}
\qt@newcmd\qurantrans@es@mdccxxii{Ante Dios se prosternan quienes están en los cielos y en la Tierra de buen o mal grado, tal como lo hacen sus sombras, por la mañana y por la tarde.\qt@no{15}}
\qt@newcmd\qurantrans@es@mdccxxiii{Pregúntales [¡oh, Mujámmad! a los idólatras]: ``¿Quién es el Señor de los cielos y de la Tierra?" Y diles: ``Él es Dios". Pregúntales: ``¿Es que toman en vez de Él [ídolos como] protectores que no pueden beneficiarse ni perjudicarse ni siquiera a sí mismos?" Y también: ``¿Acaso se pueden equiparar el ciego y el vidente? ¿O las tinieblas y la luz? ¿O es que aquello que Le asocian a Dios ha creado algo como lo hace Dios, por lo que se confundieron y creyeron que debían adorarlo?" Diles: ``Dios es Quien ha creado todas las cosas. Él es el Único, el que tiene dominio absoluto sobre todas las cosas".\qt@no{16}}
\qt@newcmd\qurantrans@es@mdccxxiv{[Dios] envía el agua del cielo, que corre por los valles acorde a la capacidad de los mismos, y en su torrente acarrea espuma en su superficie, igual que la espuma que sale de la fundición para fabricar las alhajas o los utensilios. Con ello Dios les expone un ejemplo para que sepan diferenciar la verdad de lo falso: en cuanto a la espuma, se desvanece rápidamente, y aquello que beneficia a la gente permanece en la tierra [enriqueciéndola]; así es como Dios les expone los ejemplos.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdccxxv{Quienes crean en su Señor obtendrán lo mejor, y quienes se nieguen a creer, sepan que aunque poseyeran todo cuanto existe en la Tierra, o el doble, y lo ofrecieran como rescate [para salvarse del tormento], recibirán un castigo terrible; su morada será el Infierno. ¡Qué pésima morada!\qt@no{18}}
\qt@newcmd\qurantrans@es@mdccxxvi{¿Acaso quien reconoce que lo que te reveló tu Señor es la Verdad es igual al ciego [de corazón que no quiere ver]? Solo recapacitan los dotados de intelecto,\qt@no{19}}
\qt@newcmd\qurantrans@es@mdccxxvii{que cumplen con el compromiso que asumieron y no lo quebrantan,\qt@no{20}}
\qt@newcmd\qurantrans@es@mdccxxviii{que no rompen los lazos familiares que Dios ordenó respetar, que tienen temor de su Señor y Su terrible castigo,\qt@no{21}}
\qt@newcmd\qurantrans@es@mdccxxix{que son perseverantes [en la adoración] anhelando el rostro de su Señor [y Su complacencia], que practican la oración prescrita, que hacen caridades con parte de lo que les he proveído, tanto en privado como en público, y si son maltratados responden con una buena actitud [sabiendo disculpar]; éstos obtendrán como recompensa una morada hermosa\qt@no{22}}
\qt@newcmd\qurantrans@es@mdccxxx{e ingresarán en los Jardines del Edén junto a quienes creyeron entre sus padres, cónyuges y descendientes. Luego, los ángeles ingresarán ante ellos por todas las puertas,\qt@no{23}}
\qt@newcmd\qurantrans@es@mdccxxxi{y les dirán: ``¡La paz sea sobre ustedes! Porque fueron perseverantes [en la adoración]. ¡Qué hermosa es la recompensa de la morada eterna!"\qt@no{24}}
\qt@newcmd\qurantrans@es@mdccxxxii{Pero en cambio, quienes quebrantan el compromiso que asumieron con Dios, rompen los lazos familiares que Dios ordenó respetar y siembran la corrupción en la Tierra, serán maldecidos y merecerán la peor de las moradas.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdccxxxiii{Dios concede sustento abundante a quien quiere y se lo restringe a quien quiere. [Algunos] se regocijan con la vida mundanal, pero ¿qué es la vida mundanal comparada con la otra, sino un goce ilusorio?\qt@no{26}}
\qt@newcmd\qurantrans@es@mdccxxxiv{Dicen los que se niegan a creer: ``¿Por qué no se le concede un milagro de su Señor [que así creeremos]?" Diles [¡oh, Mujámmad!]: ``Dios extravía a quien quiere, y guía hacia Él a quien se arrepiente".\qt@no{27}}
\qt@newcmd\qurantrans@es@mdccxxxv{Los corazones de los creyentes se sosiegan con el recuerdo de Dios. ¿Acaso no es con el recuerdo de Dios que se sosiegan los corazones?\qt@no{28}}
\qt@newcmd\qurantrans@es@mdccxxxvi{Quienes creen y obran rectamente serán los bienaventurados, tendrán un destino hermoso.\qt@no{29}}
\qt@newcmd\qurantrans@es@mdccxxxvii{Te he enviado a una comunidad que fue precedida por otras, para que les recites lo que te he revelado, pero ellos no creyeron en el Compasivo. Diles: ``Él es mi Señor, no hay otra divinidad salvo Dios, a Él me encomiendo y confío, y a Él he de retornar".\qt@no{30}}
\qt@newcmd\qurantrans@es@mdccxxxviii{Si existiera un libro revelado que pudiera mover las montañas, abrir la tierra o hacer hablar a los muertos, ése sería el Corán. Pero todos los asuntos dependen del decreto de Dios. ¿Acaso no saben los creyentes que si Dios quisiera guiaría a todas las personas? Los que se niegan a creer seguirán padeciendo calamidades que azotarán a su territorio y a sus alrededores por su incredulidad, hasta que les llegue el castigo que Dios les ha advertido. Dios no quebranta Sus promesas.\qt@no{31}}
\qt@newcmd\qurantrans@es@mdccxxxix{También se burlaron de los Mensajeros que vinieron antes de ti, pero los toleré por un tiempo [dándoles la oportunidad de enmendarse, y como no lo hicieron], luego los aniquilé. ¡Qué terrible fue Mi castigo!\qt@no{32}}
\qt@newcmd\qurantrans@es@mdccxl{¿Es, acaso, Quien tiene a cada uno de los seres vivos bajo Su tutela suprema, [tratando a cada uno de ellos] según lo que merece, [comparable a cualquier otra cosa existente]? Pero a pesar de eso asocian a Dios [en la adoración]. Diles: ``¡Mencionen [a los socios de Dios] si es que existen! ¿Acaso creen que van a informarle de algo que existe en la Tierra y que Él no sepa, o solo hablan sin sentido?" [El demonio] los hizo ver, a los que se negaron a creer, la idolatría como algo bueno, y [por eso] apartan a la gente del camino recto. Pero aquel a quien Dios extravía, nadie lo podrá guiar.\qt@no{33}}
\qt@newcmd\qurantrans@es@mdccxli{Ellos serán castigados en esta vida, pero el tormento que les aguarda en la otra será aún más severo, y no tendrán quién los proteja de Dios.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdccxlii{La descripción del Paraíso que le fue prometido a los piadosos: En él correrán ríos, sus frutos no se agotarán jamás y su sombra será eterna. Esa será la recompensa de los temerosos de Dios, mientras que el castigo de los incrédulos será el Infierno.\qt@no{35}}
\qt@newcmd\qurantrans@es@mdccxliii{Aquellos a quienes concedí el Libro [el Corán] se regocijan con lo que te fue revelado [¡oh, Mujámmad!], pero entre los aliados hay quienes negaron algunas partes [del Corán]. Diles: ``Me ha sido ordenado adorar a Dios y no asociarle nada [en la adoración]; a Él me encomiendo y ante Él compareceré".\qt@no{36}}
\qt@newcmd\qurantrans@es@mdccxliv{Así te he revelado el Corán en [idioma] árabe. Pero si tú sigues sus pasiones después de haberte llegado el conocimiento, no tendrás, fuera de Dios, defensor ni protector alguno.\qt@no{37}}
\qt@newcmd\qurantrans@es@mdccxlv{He enviado a otros Mensajeros antes de ti, y les concedí esposas e hijos. Ningún Mensajero podría presentar un milagro salvo con el permiso de Dios. Cada asunto está registrado en un Libro.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdccxlvi{Dios anula o confirma [de Su Designio] lo que quiere. Él tiene en Su poder el Libro donde están registradas todas las cosas [la Tabla Protegida].\qt@no{39}}
\qt@newcmd\qurantrans@es@mdccxlvii{[¡Oh, Mujámmad!] Puede que te haga ver parte de lo que les tengo reservado [a los incrédulos como castigo], o que te haga morir antes de ello. Tú solo tienes el deber de transmitir el Mensaje, y ante Mí comparecerán.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdccxlviii{¿Acaso no vieron que Yo decreté que fueran perdiendo territorio a manos de los creyentes? Cuando Dios decide algo nadie lo puede impedir. Él es rápido en ajustar cuentas.\qt@no{41}}
\qt@newcmd\qurantrans@es@mdccxlix{En la antigüedad [los incrédulos] también se confabularon [contra los Mensajeros], pero Dios desbarató los planes de todos ellos. Él bien sabe lo que cada ser se propone realizar. Ya sabrán los que se niegan a creer quiénes merecerán la peor de las moradas.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdccl{Dicen los que se niegan a creer: ``Tú no eres un Mensajero". Diles [¡oh, Mujámmad!]: ``Es suficiente Dios como testigo [de mi veracidad] entre ustedes y yo, y también [son testigos de ello] quienes tienen conocimiento sobre los Libros revelados anteriormente.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdccli{\basmalahes Álif. Lam. Ra’. Éste es el Libro que te he revelado para que saques a la gente de las tinieblas a la luz con el permiso de tu Señor, y los guíes hacia el sendero de Dios, el Poderoso, el Loable.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdcclii{A Dios pertenece cuanto existe en los cielos y en la Tierra. ¡Ya verán los que se niegan a creer, el castigo terrible que les aguarda!\qt@no{2}}
\qt@newcmd\qurantrans@es@mdccliii{Los que prefieren la vida mundanal a la próxima y desvían a la gente del camino de Dios, haciéndolo parecer tortuoso. Ellos son los que están en un extravío profundo.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdccliv{Todos los Mensajeros que envié hablaban el lenguaje de su pueblo para así transmitirles claramente el Mensaje. Pero Dios extravía a quien quiere y guía a quien quiere; Él es el Poderoso, el Sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdcclv{Envié a Moisés con Mis signos [al Faraón y su pueblo, y le dije:] ``Saca a tu pueblo de las tinieblas a la luz, y recuérdales las bendiciones que Dios les concedió". En ello hay signos para quien es perseverante y agradecido.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcclvi{Moisés le dijo a su pueblo: ``Recuerden las bendiciones de Dios para con ustedes cuando los salvó de las huestes del Faraón, quienes los sometían a castigos crueles, degollaban a sus hijos varones y dejaban con vida a sus hijas mujeres. Eso era una dura prueba de su Señor para ustedes".\qt@no{6}}
\qt@newcmd\qurantrans@es@mdcclvii{Y cuando su Señor anunció: ``Si Le agradecen, Él incrementará su sustento; y sepan que si lo rechazan, Su castigo será severo".\qt@no{7}}
\qt@newcmd\qurantrans@es@mdcclviii{Dijo Moisés: ``Si ustedes y todos los que habitan en la Tierra no creen, sepan que Él no necesita de Sus criaturas, y es digno de alabanza".\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcclix{¿Acaso no les fue relatado lo que les aconteció a sus predecesores, al pueblo de Noé, ‘Ad, Zamud, y a todos aquellos que les sucedieron y que solo Dios conoce? Cuando sus Mensajeros se presentaron ante ellos con pruebas claras [de la verdad, los que se negaron a creer] se mordieron los dedos del odio [que sentían por ellos] y les dijeron: ``Nosotros no creemos en el Mensaje que han traído, y tenemos una duda profunda sobre aquello a lo que nos convocan".\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcclx{Sus Mensajeros les respondieron: ``¿Acaso tienen dudas acerca de Dios, Creador de los cielos y de la Tierra? Él los convoca [a que Lo adoren] para que así les sean perdonados sus pecados y se les permita vivir hasta el plazo que se les ha prefijado". Dijeron: ``Son seres humanos igual que nosotros y solo quieren apartarnos de lo que adoraron nuestros padres; presenten una evidencia clara [de que son Mensajeros de Dios]".\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcclxi{Sus Mensajeros les dijeron: ``Solo somos seres humanos como ustedes, pero Dios agracia [con la profecía] a quien quiere de Sus siervos. No nos es posible presentar un milagro excepto con el permiso de Dios. ¡Los creyentes deben encomendarse a Dios!\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcclxii{Nosotros nos encomendamos a Dios, pues Él nos ha guiado por Su camino, y seremos pacientes ante sus hostilidades. A Dios se encomiendan quienes en Él confían".\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcclxiii{Los que se negaron a creer dijeron a sus Mensajeros: ``Si no vuelven a nuestra religión los expulsaremos de nuestra tierra", pero Su Señor les reveló: ``Exterminaré a los opresores,\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcclxiv{los haré habitar la tierra después de ellos. Eso será para quienes teman [el día de] la comparecencia ante Mí y teman Mi advertencia".\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcclxv{Entonces [los Mensajeros] pidieron el socorro de Dios, y todo prepotente y obstinado fue destruido,\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcclxvi{[tras el Día del Juicio] será castigado en el Infierno, donde se le dará de beber un agua de pus\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcclxvii{que beberá a sorbos, y apenas podrá tragarla. La muerte lo acechará por todos lados pero no morirá; recibirá un castigo terrible.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcclxviii{El ejemplo de las obras de quienes no creyeron en su Señor será como el de las cenizas expuestas al viento en un día tempestuoso: [El Día del Juicio] no encontrarán recompensa alguna por sus actos. Ésa será la ruina total.\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcclxix{¿Acaso no ves [¡oh, Mujámmad!] que Dios creó los cielos y la Tierra con un fin justo y verdadero? Si quisiera los haría desaparecer y los reemplazaría por otros.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcclxx{Eso no es difícil para Dios.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcclxxi{[El Día de la Resurrección] saldrán de sus tumbas para comparecer ante Dios, y los más débiles dirán a los soberbios [líderes de la incredulidad]: ``Nosotros fuimos sus seguidores [en la vida mundanal]. ¿Nos librarán ahora del castigo de Dios?" Dirán: ``Si Dios nos hubiera guiado los habríamos conducido por el camino recto. Lo mismo da que nos desesperemos o que tengamos paciencia; hoy no podremos escapar del castigo".\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcclxxii{Cuando todos hayan sido sentenciados, el demonio dirá: ``La promesa que Dios les hizo era verdadera, en cambio yo les hice promesas que no cumplí. Yo solo tenía poder para seducirlos mediante susurros, pero fueron ustedes quienes me siguieron. No me culpen ahora, sino que repróchense a ustedes mismos. Yo no puedo socorrerlos en nada ni tampoco ustedes a mí, y hoy me desentiendo de que me hayan asociado [a Dios]". Los opresores recibirán un castigo doloroso.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcclxxiii{En cambio, quienes hayan creído y obrado correctamente serán introducidos en jardines por donde corren ríos y donde morarán por toda la eternidad, con el permiso de Dios. El saludo allí será: ¡Salam [paz]!\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcclxxiv{¿Por qué no observas el siguiente ejemplo que te propone Dios?: Una palabra buena es como un árbol bondadoso cuya raíz está firme y sus ramas se extienden hacia el cielo,\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcclxxv{y da frutos en toda época [del año] con el permiso de su Señor. Así es como Dios expone ejemplos para que la gente reflexione.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcclxxvi{En cambio, una palabra maligna es como un árbol dañino que ha sido arrancado de la tierra y no tiene dónde afirmarse.\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcclxxvii{Dios afianza a los creyentes con la palabra firme en esta vida y en la otra, y extravía a los que cometen injusticias. Dios hace lo que quiere.\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcclxxviii{¿Acaso no reparas en aquellos que en vez de agradecer a Dios por Sus bendiciones son ingratos y conducen a su pueblo a la perdición?\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcclxxix{Serán ingresados al Infierno. ¡Qué pésima morada!\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcclxxx{Porque Le atribuyeron a Dios iguales para desviar [a la gente] de Su camino. Diles [a ellos]: ``Disfruten [en esta vida lo que puedan], porque su destino será el Infierno".\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcclxxxi{Diles a Mis siervos creyentes que cumplan con las oraciones prescritas y den en caridad parte de lo que les he proveído, tanto en privado como en público, antes de que llegue el día en el cual no habrá comercio ni amistad [que pueda alterar el juicio].\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcclxxxii{Dios es Quien creó los cielos y la Tierra e hizo descender la lluvia del cielo con la que hace brotar los frutos para sustento de ustedes. Él es Quien puso a su servicio los barcos para que, con Su permiso, surquen el mar, y también puso a su servicio los ríos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcclxxxiii{[También] puso al servicio de ustedes el Sol y la Luna, que siguen su curso incesantemente, y también puso a su servicio la noche y el día.\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcclxxxiv{Él les ha dado todo cuanto Le han pedido. Si intentaran contar las bendiciones de Dios no podrían enumerarlas. El ser humano es injusto y desagradecido.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcclxxxv{Y [recuerda, ¡oh, Mujámmad!] cuando Abraham dijo: ``¡Oh, Señor mío! Haz que esta ciudad sea un lugar seguro, y protégeme junto a mi descendencia de caer en la adoración de ídolos.\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcclxxxvi{¡Oh, Señor mío! La adoración a los ídolos ha extraviado a muchas personas. Todo aquel que me siga [en la fe monoteísta] será de los míos, pero quien me desobedezca [rechazando el Mensaje]… Tú eres Absolvedor, Misericordioso.\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcclxxxvii{¡Oh, Señor nuestro! He establecido parte de mi descendencia en un valle árido de poca vegetación junto a Tu Casa Sagrada, para que, ¡oh, Señor nuestro!, cumplan con la oración. Infunde en los corazones de la gente amor por mi descendencia, y provéelos de todo alimento para que sean agradecidos.\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcclxxxviii{¡Oh, Señor nuestro! Tú bien sabes lo que ocultamos y lo que manifestamos, y no hay nada en la Tierra ni en el cielo que pueda esconderse de Dios.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcclxxxix{¡Alabado sea Dios!, Quien me agració en la vejez con [mis hijos] Ismael e Isaac. Mi Señor escucha bien las súplicas de quienes Lo invocan.\qt@no{39}}
\qt@newcmd\qurantrans@es@mdccxc{¡Oh, Señor mío! Haz que tanto mis descendientes como yo seamos fervientes practicantes de la oración. ¡Oh, Señor nuestro! Concédeme esta súplica.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdccxci{¡Oh, Señor nuestro! Perdóname, así como a mis padres y a todos los creyentes el Día que se celebre el Juicio [Final]".\qt@no{41}}
\qt@newcmd\qurantrans@es@mdccxcii{No pienses [¡oh, Mujámmad!] que Dios está distraído de lo que hacen los opresores. Él solo está tolerándolos hasta que llegue el día en el que sus miradas quedarán paralizadas.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdccxciii{Ese día saldrán apresurados de sus tumbas con las cabezas erguidas, no podrán parpadear ni tampoco pensar [presas del terror].\qt@no{43}}
\qt@newcmd\qurantrans@es@mdccxciv{Advierte a la gente [¡oh, Mujámmad!] sobre el día en que los azote el castigo, y los que cometían injusticias digan: ``¡Oh, Señor nuestro! Toléranos un tiempo más [y retórnanos a la vida mundanal] para que respondamos a Tu llamado y sigamos a los Mensajeros". [Pero se les responderá:] ``¿Acaso no habían jurado antes que no serían resucitados?"\qt@no{44}}
\qt@newcmd\qurantrans@es@mdccxcv{Habitaron en los mismos territorios en que vivieron quienes [no creyeron y] fueron injustos consigo mismos [rechazando el Mensaje], y no creyeron a pesar de que se enteraron de cómo los aniquilé y de que les expuse muchos ejemplos para que reflexionaran.\qt@no{45}}
\qt@newcmd\qurantrans@es@mdccxcvi{Se confabularon [contra ti], pero Dios desbarató sus planes, a pesar de que sus confabulaciones podrían haber derrumbado montañas.\qt@no{46}}
\qt@newcmd\qurantrans@es@mdccxcvii{No pienses [¡oh, Mujámmad!] que Dios no cumplirá con la promesa que les hizo a Sus Mensajeros; Dios es Poderoso, Dueño de la retribución.\qt@no{47}}
\qt@newcmd\qurantrans@es@mdccxcviii{El día en que la Tierra sea cambiada por otra y los cielos [por otros cielos], todos se presentarán ante Dios, el Único, el Victorioso.\qt@no{48}}
\qt@newcmd\qurantrans@es@mdccxcix{Verás a los criminales encadenados.\qt@no{49}}
\qt@newcmd\qurantrans@es@mdccc{Sus vestimentas serán de alquitrán y sus rostros serán abrasados por el fuego.\qt@no{50}}
\qt@newcmd\qurantrans@es@mdccci{Dios retribuirá a cada ser según sus obras; Dios es rápido en ajustar cuentas.\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcccii{Éste [Corán] es un Mensaje para toda la humanidad, para advertirles [sobre el castigo] y para que sepan que Dios es uno. Que los dotados de intelecto reflexionen [en su contenido].\qt@no{52}}
\qt@newcmd\qurantrans@es@mdccciii{\basmalahes Álif. Lam. Ra’. Éstos son los versículos del Libro, una recitación clara.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdccciv{Llegará el momento en que quienes se negaron a creer desearán haber sido musulmanes entregados a la voluntad de Dios.\qt@no{2}}
\qt@newcmd\qurantrans@es@mdcccv{Déjalos que coman, que disfruten y sean seducidos por el apego a esta vida mundanal, que ya sabrán.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdcccvi{No he destruido una ciudad [que estuviera condenada] hasta que le llegara su término prefijado.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdcccvii{Ninguna nación puede adelantar ni retrasar su final.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcccviii{Y dicen: ``¡Oh, tú [Mujámmad]! A quien se le ha descendido la revelación, eres un demente.\qt@no{6}}
\qt@newcmd\qurantrans@es@mdcccix{¿Por qué no te presentas acompañado por los ángeles, si es verdad lo que dices?"\qt@no{7}}
\qt@newcmd\qurantrans@es@mdcccx{Pero cuando envío a los ángeles es con el castigo, y si los hubiera enviado [en respuesta a sus desafíos] ya no les quedaría tiempo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcccxi{Yo he revelado el Corán y Yo soy su custodio.\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcccxii{Envié antes de ti [otros Mensajeros] a los pueblos antiguos,\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcccxiii{pero cada vez que se les presentaba un Mensajero se burlaban de él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcccxiv{Así es como [la burla] se adueña del corazón de los pecadores.\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcccxv{No creerán en él a pesar del ejemplo de lo que les aconteció a los pueblos anteriores.\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcccxvi{Y aunque les abriera una puerta en el cielo por la que pudieran ascender [y contemplar a los ángeles] no creerían.\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcccxvii{Dirían: ``Nuestros ojos ven visiones, nos han hechizado".\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcccxviii{He dispuesto constelaciones en el cielo, y las he embellecido para quienes las contemplan.\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcccxix{He protegido al cielo de todo demonio maldito.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcccxx{Si intenta escuchar, le arrojaré una bola de fuego visible.\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcccxxi{He extendido la Tierra, he dispuesto en ella montañas firmes y he hecho crecer en ella de todo en forma equilibrada.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcccxxii{Facilité los medios para que puedan vivir en ella ustedes y el resto de las criaturas.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcccxxiii{En Mi poder están las reservas de su sustento y les proveo de él en la medida que he determinado.\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcccxxiv{Envié los vientos fecundadores y hago descender del cielo agua con la que les doy de beber, y no son ustedes los dueños de sus reservas.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcccxxv{Yo doy la vida y doy la muerte, y Yo soy el heredero [a quien todo lo creado ha de retornar].\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcccxxvi{Conozco a quienes los precedieron y también a quienes los sucederán.\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcccxxvii{Tu Señor los congregará. Él es Sabio, lo sabe todo.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcccxxviii{He creado al ser humano de arcilla, un barro maleable.\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcccxxix{Y al yinn lo había creado ya antes de fuego.\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcccxxx{[Recuerda] cuando tu Señor dijo a los ángeles: ``Voy a crear un ser humano de arcilla, de barro maleable.\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcccxxxi{Cuando lo haya completado e insuflado en él el espíritu que he creado para él, hagan una reverencia [en honor a Mí] ante él".\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcccxxxii{Todos los ángeles hicieron la reverencia,\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcccxxxiii{excepto Iblís, que se negó a ser de quienes hicieron la reverencia.\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcccxxxiv{Dijo [Dios]: ``¡Oh, Iblís! ¿Por qué no te cuentas entre quienes hicieron la reverencia?"\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcccxxxv{Dijo: ``No he de hacerla ante un ser humano [que es inferior a mí], al que has creado de arcilla, de barro maleable".\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcccxxxvi{Dijo [Dios]: ``Sal de aquí, pues te maldigo.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcccxxxvii{Serás maldito hasta el Día del Juicio".\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcccxxxviii{Dijo: ``¡Oh, Señor mío! Tolérame hasta el Día de la Resurrección".\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcccxxxix{Dijo: ``Te concedo la prórroga que me pides,\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcccxl{hasta el día cuyo término está definido".\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcccxli{Dijo: ``¡Oh, Señor mío! Por haber dejado que me extravíe, los seduciré y descarriaré a todos,\qt@no{39}}
\qt@newcmd\qurantrans@es@mdcccxlii{excepto a quienes de Tus siervos hayas protegido".\qt@no{40}}
\qt@newcmd\qurantrans@es@mdcccxliii{Dijo [Dios]: ``A quien siga Mi camino recto lo protegeré.\qt@no{41}}
\qt@newcmd\qurantrans@es@mdcccxliv{No tendrás poder alguno sobre Mis siervos, salvo los que se extravíen siguiéndote".\qt@no{42}}
\qt@newcmd\qurantrans@es@mdcccxlv{El Infierno es el lugar donde se reunirán todos ellos.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdcccxlvi{El Infierno posee siete puertas y cada una está destinada para un grupo determinado [de pecadores].\qt@no{44}}
\qt@newcmd\qurantrans@es@mdcccxlvii{Mientras que los piadosos serán retribuidos con jardines y manantiales.\qt@no{45}}
\qt@newcmd\qurantrans@es@mdcccxlviii{[Se les dirá:] Ingresen a ellos en paz, y estén seguros de que no se les privará de nada.\qt@no{46}}
\qt@newcmd\qurantrans@es@mdcccxlix{Purificaremos sus corazones de todo rencor. Serán todos como hermanos y se sentarán unos enfrente de otros.\qt@no{47}}
\qt@newcmd\qurantrans@es@mdcccl{Allí no volverán a sufrir, y vivirán por toda la eternidad.\qt@no{48}}
\qt@newcmd\qurantrans@es@mdcccli{Anúnciales a Mis siervos [oh, Mujámmad] que soy el Absolvedor, el Misericordioso,\qt@no{49}}
\qt@newcmd\qurantrans@es@mdccclii{y que Mi castigo es el verdadero castigo doloroso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mdcccliii{Relátales sobre los huéspedes de Abraham.\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcccliv{Cuando se presentaron ante él, dijeron: ``¡La paz sea contigo!" [Abraham y su esposa, luego de haberles ofrecido comida y observar que no comían, dijeron]: ``Ustedes nos infunden temor".\qt@no{52}}
\qt@newcmd\qurantrans@es@mdccclv{Le dijeron: ``No temas, te anunciamos el nacimiento de un hijo sabio".\qt@no{53}}
\qt@newcmd\qurantrans@es@mdccclvi{Dijo: ``¿Me dan ahora la albricia [de un hijo] siendo que me ha alcanzado la vejez?"\qt@no{54}}
\qt@newcmd\qurantrans@es@mdccclvii{Dijeron: ``Te albriciamos con la verdad. No seas de quienes han perdido la esperanza".\qt@no{55}}
\qt@newcmd\qurantrans@es@mdccclviii{Dijo: ``Solo desesperan de la misericordia de su Señor los extraviados".\qt@no{56}}
\qt@newcmd\qurantrans@es@mdccclix{Preguntó: ``¿Cuál es su misión? ¡Oh, emisarios [de Dios]!"\qt@no{57}}
\qt@newcmd\qurantrans@es@mdccclx{Dijeron: ``Hemos sido enviados [para castigar] a un pueblo de pecadores,\qt@no{58}}
\qt@newcmd\qurantrans@es@mdccclxi{salvo a la familia de Lot, a quienes salvaremos,\qt@no{59}}
\qt@newcmd\qurantrans@es@mdccclxii{pero no a su mujer, a quien Dios decretó que fuese de los condenados".\qt@no{60}}
\qt@newcmd\qurantrans@es@mdccclxiii{Los emisarios se presentaron ante la casa de Lot.\qt@no{61}}
\qt@newcmd\qurantrans@es@mdccclxiv{Dijo [Lot]: ``Me son desconocidos".\qt@no{62}}
\qt@newcmd\qurantrans@es@mdccclxv{Dijeron: ``Hemos sido enviados para ejecutar el castigo del cual tu pueblo dudaba.\qt@no{63}}
\qt@newcmd\qurantrans@es@mdccclxvi{Venimos a ti con la Verdad. Siempre decimos la verdad.\qt@no{64}}
\qt@newcmd\qurantrans@es@mdccclxvii{Sal por la noche con tu familia [y tus seguidores]. Marcha detrás de ellos [para protegerlos] y que ninguno de ustedes mire hacia atrás. Diríjanse hacia donde se les ha ordenado".\qt@no{65}}
\qt@newcmd\qurantrans@es@mdccclxviii{Entonces le revelé [a Lot Mi decreto]: ``Todos ellos [los pecadores] serán destruidos al amanecer".\qt@no{66}}
\qt@newcmd\qurantrans@es@mdccclxix{Pero se presentaron los habitantes de la ciudad contentos.\qt@no{67}}
\qt@newcmd\qurantrans@es@mdccclxx{Les dijo [Lot]: ``Ellos son mis huéspedes. No me avergüencen.\qt@no{68}}
\qt@newcmd\qurantrans@es@mdccclxxi{Tengan temor de Dios y no me humillen".\qt@no{69}}
\qt@newcmd\qurantrans@es@mdccclxxii{Dijeron: ``¿No te habíamos prohibido que protegieras gente [en tu casa de nuestras perversiones]?"\qt@no{70}}
\qt@newcmd\qurantrans@es@mdccclxxiii{Les respondió: ``Cásense con las mujeres del pueblo si quieren".\qt@no{71}}
\qt@newcmd\qurantrans@es@mdccclxxiv{[Dice Dios:] ¡Juro por tu vida! [¡oh, Mujámmad!], que la aberración embriagaba sus mentes.\qt@no{72}}
\qt@newcmd\qurantrans@es@mdccclxxv{Les sorprendió el castigo al amanecer.\qt@no{73}}
\qt@newcmd\qurantrans@es@mdccclxxvi{Puse al pueblo de cabeza y les envié una lluvia de piedras de arcilla.\qt@no{74}}
\qt@newcmd\qurantrans@es@mdccclxxvii{En eso hay signos para quienes reflexionan.\qt@no{75}}
\qt@newcmd\qurantrans@es@mdccclxxviii{[Esta ciudad arrasada] está aún en una ruta [a la vista de los viajeros].\qt@no{76}}
\qt@newcmd\qurantrans@es@mdccclxxix{En eso hay un signo para los creyentes.\qt@no{77}}
\qt@newcmd\qurantrans@es@mdccclxxx{Los habitantes del pueblo de Jetró cometían injusticias,\qt@no{78}}
\qt@newcmd\qurantrans@es@mdccclxxxi{por lo que los castigué. Ambas [ciudades, la de Lot y la de Jetró] son visibles desde una ruta.\qt@no{79}}
\qt@newcmd\qurantrans@es@mdccclxxxii{Los habitantes de Al Hiyr desmintieron a los Mensajeros.\qt@no{80}}
\qt@newcmd\qurantrans@es@mdccclxxxiii{Les presenté Mis signos, pero los rechazaron.\qt@no{81}}
\qt@newcmd\qurantrans@es@mdccclxxxiv{Construían sus casas esculpiendo las montañas y allí se sentían seguros.\qt@no{82}}
\qt@newcmd\qurantrans@es@mdccclxxxv{Pero los sorprendió el castigo al amanecer,\qt@no{83}}
\qt@newcmd\qurantrans@es@mdccclxxxvi{y no los benefició en nada la riqueza que poseían.\qt@no{84}}
\qt@newcmd\qurantrans@es@mdccclxxxvii{No he creado los cielos, la Tierra y cuanto hay entre ambos sino con un fin justo y verdadero. La Hora se aproxima, así que tú disculpa [a los que niegan el Mensaje] y trátalos de buena manera.\qt@no{85}}
\qt@newcmd\qurantrans@es@mdccclxxxviii{Tu Señor es el Creador, el que todo lo sabe.\qt@no{86}}
\qt@newcmd\qurantrans@es@mdccclxxxix{Te he distinguido con la revelación de los siete versículos que se reiteran como parte del grandioso Corán.\qt@no{87}}
\qt@newcmd\qurantrans@es@mdcccxc{No codicies aquello conque he agraciado a algunos de los ricos [de los que desmienten el Mensaje] y no sientas pena por ellos [a causa de su incredulidad]. Y baja tu ala protegiendo a los creyentes.\qt@no{88}}
\qt@newcmd\qurantrans@es@mdcccxci{Di: ``He sido enviado para advertirles claramente [sobre un castigo]",\qt@no{89}}
\qt@newcmd\qurantrans@es@mdcccxcii{como el que le envié a los que rechazaron [el Mensaje de Dios].\qt@no{90}}
\qt@newcmd\qurantrans@es@mdcccxciii{Como los que creen en una parte del Corán y en otra no.\qt@no{91}}
\qt@newcmd\qurantrans@es@mdcccxciv{¡Por tu Señor! Que haré rendir cuentas a todos ellos\qt@no{92}}
\qt@newcmd\qurantrans@es@mdcccxcv{por todo lo que hicieron.\qt@no{93}}
\qt@newcmd\qurantrans@es@mdcccxcvi{Divulga lo que se te ordena [públicamente] y no te preocupes por los idólatras.\qt@no{94}}
\qt@newcmd\qurantrans@es@mdcccxcvii{Yo te protegeré de quienes se burlen,\qt@no{95}}
\qt@newcmd\qurantrans@es@mdcccxcviii{de quienes ponen junto a Dios otras deidades, ellos ya pronto sabrán [el castigo que les espera].\qt@no{96}}
\qt@newcmd\qurantrans@es@mdcccxcix{Sé que te apenas por cuanto dicen,\qt@no{97}}
\qt@newcmd\qurantrans@es@mcm{pero glorifica con alabanzas a tu Señor y cuéntate entre quienes se prosternan [en oración para aliviar su angustia],\qt@no{98}}
\qt@newcmd\qurantrans@es@mcmi{y adora a tu Señor hasta que te llegue la certeza.\qt@no{99}}
\qt@newcmd\qurantrans@es@mcmii{\basmalahes La orden de Dios [para que comience el Día del Juicio] llegará pronto, no pretendan adelantarla. ¡Glorificado sea! Él está por encima de cuanto Le asocian.\qt@no{1}}
\qt@newcmd\qurantrans@es@mcmiii{Él envía a los ángeles con la revelación de Sus órdenes a quien Le place de Sus siervos para que advierta: ``No hay otra divinidad más que Yo, tengan temor de Mí".\qt@no{2}}
\qt@newcmd\qurantrans@es@mcmiv{Dios creó los cielos y la Tierra con un fin justo y verdadero. Él está por encima de cuanto Le asocian.\qt@no{3}}
\qt@newcmd\qurantrans@es@mcmv{Creó al ser humano de [algo tan ínfimo como] un óvulo fecundado, y sin embargo este discute constantemente [la existencia y el poder de su Señor].\qt@no{4}}
\qt@newcmd\qurantrans@es@mcmvi{Dios creó a los ganados, de los cuales ustedes obtienen sus abrigos y otros beneficios, y también de ellos se alimentan.\qt@no{5}}
\qt@newcmd\qurantrans@es@mcmvii{Ustedes se regocijan cuando los arrean por la tarde y cuando los llevan a pastar por la mañana.\qt@no{6}}
\qt@newcmd\qurantrans@es@mcmviii{Llevan sus cargas a lugares que ustedes no podrían alcanzar sino con mucha dificultad. Su Señor es Compasivo, Misericordioso.\qt@no{7}}
\qt@newcmd\qurantrans@es@mcmix{[Dios creó] los caballos, las mulas y los asnos como montura y para que se luzcan con ellos. Y creó muchas otras cosas que no conocen.\qt@no{8}}
\qt@newcmd\qurantrans@es@mcmx{Dios es Quien enseña cuál es el sendero recto, del que muchos se desvían. Si hubiera querido los habría guiado a todos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mcmxi{Él es Quien hace descender agua del cielo para que beban de ella y brote la vegetación de la que pastorean sus rebaños.\qt@no{10}}
\qt@newcmd\qurantrans@es@mcmxii{Con ella hace crecer los cereales, los olivos, las palmeras, las vides y toda variedad de frutos. En ello hay signos para quienes reflexionan.\qt@no{11}}
\qt@newcmd\qurantrans@es@mcmxiii{Dios ha creado para beneficio de ustedes la noche, el día, el Sol, la Luna y las estrellas; todos están sometidos a Su voluntad. En esto hay signos para quienes razonan.\qt@no{12}}
\qt@newcmd\qurantrans@es@mcmxiv{Él creó para ustedes una gran diversidad en la Tierra. En ello hay signos para quienes recapacitan.\qt@no{13}}
\qt@newcmd\qurantrans@es@mcmxv{Él es Quien ha puesto al mar a servicio de ustedes para que puedan comer de él carne fresca y extraer adornos para engalanarse. Pueden ver los barcos surcarlo y usarlos para buscar la gracia de Dios [su sustento]. ¿Por qué no son agradecidos?\qt@no{14}}
\qt@newcmd\qurantrans@es@mcmxvi{Dios afirmó la tierra con montañas para que se estabilizara, dispuso ríos y caminos para que puedan guiarse,\qt@no{15}}
\qt@newcmd\qurantrans@es@mcmxvii{y también señales, y para que se orienten en sus viajes, [creó] las estrellas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcmxviii{¿Es procedente comparar a Quien es capaz de crear con quien no puede crear nada? ¿Acaso no recapacitan?\qt@no{17}}
\qt@newcmd\qurantrans@es@mcmxix{Si intentaran contar las gracias de Dios no podrían enumerarlas. Dios es Absolvedor, Misericordioso.\qt@no{18}}
\qt@newcmd\qurantrans@es@mcmxx{Dios sabe lo que ocultan y lo que manifiestan.\qt@no{19}}
\qt@newcmd\qurantrans@es@mcmxxi{[Los ídolos] a quienes ustedes invocan en lugar de Dios, no solo no pueden crear absolutamente nada, sino que ellos mismos son creados.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcmxxii{Son [objetos] inertes, sin vida. ¿Cómo van a saber ellos cuándo serán resucitados?\qt@no{21}}
\qt@newcmd\qurantrans@es@mcmxxiii{Su divinidad es una sola, pero los corazones de quienes no creen en la otra vida no admiten [la fe] porque son soberbios.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcmxxiv{No hay duda de que Dios sabe lo que ocultan y lo que manifiestan. Él no ama a los soberbios.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcmxxv{Cuando se les pregunta [a los idólatras]: ``¿Qué opinan sobre lo que ha revelado su Señor?" Responden: ``Son leyendas de los antiguos".\qt@no{24}}
\qt@newcmd\qurantrans@es@mcmxxvi{Éstos cargarán con sus propios pecados el Día de la Resurrección, y con parte de los pecados de aquellos a quienes extraviaron y que los siguieron por ignorancia. ¡Qué pésima es la carga que llevarán!\qt@no{25}}
\qt@newcmd\qurantrans@es@mcmxxvii{También se complotaron [los incrédulos] anteriormente [en Babel], pero Dios destruyó sus [altas] edificaciones desde los cimientos y los techos se derrumbaron sobre ellos. El castigo les llegó de donde menos lo esperaban.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcmxxviii{Luego, el Día de la Resurrección, Dios los humillará y les preguntará: ``¿Dónde están aquellos que ustedes Me asociaban y a los que defendían?" [Ese día] quienes recibieron el conocimiento [de cada nación] dirán [a sus pueblos]: ``Hoy, la humillación y el castigo pesarán sobre los incrédulos".\qt@no{27}}
\qt@newcmd\qurantrans@es@mcmxxix{Cuando los ángeles tomen las almas de quienes hayan sido incrédulos, éstos se entregarán [diciendo]: ``No cometimos ningún mal". [Pero los ángeles responderán:] ``¡Sí lo cometieron! Dios sabe bien lo que hacían.\qt@no{28}}
\qt@newcmd\qurantrans@es@mcmxxx{Ingresen por las puertas del Infierno, allí permanecerán eternamente. ¡Qué pésima morada la que tendrán los soberbios!"\qt@no{29}}
\qt@newcmd\qurantrans@es@mcmxxxi{[Y ese día] se les preguntará a los piadosos: ``¿Qué ha revelado su Señor?" Responderán: ``Lo mejor". Quienes hayan obrado rectamente obtendrán en este mundo una bella recompensa, pero la morada de la otra vida será aún mejor. ¡Qué placentera será la morada de los piadosos!\qt@no{30}}
\qt@newcmd\qurantrans@es@mcmxxxii{Ingresarán a los Jardines del Edén por donde corren ríos, y allí tendrán todo lo que deseen. Así retribuye Dios a los piadosos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mcmxxxiii{Cuando los ángeles tomen las almas de los piadosos, les dirán: ``¡Que la paz sea sobre ustedes! Ingresen al Paraíso como recompensa por sus obras".\qt@no{32}}
\qt@newcmd\qurantrans@es@mcmxxxiv{¿Acaso esperan [los incrédulos] que se presenten ante ellos los ángeles [para tomar sus almas] o que los azote el castigo [para recién entonces creer]? Eso hicieron quienes los precedieron. Dios no fue injusto con ellos [al enviarles el castigo], sino que ellos fueron injustos consigo mismos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcmxxxv{Sufrirán las consecuencias de las malas acciones que cometieron y los azotará el castigo del cual se burlaban.\qt@no{34}}
\qt@newcmd\qurantrans@es@mcmxxxvi{Los idólatras argumentarán: ``Si Dios hubiera querido, ni nosotros ni nuestros antepasados habríamos adorado a otro fuera de Él, ni habríamos declarado ilícitas las cosas sin Su permiso". Lo mismo dijeron quienes los precedieron. Pero los Mensajeros solo tienen la obligación de transmitir el Mensaje con claridad [y Dios será Quien los juzgará].\qt@no{35}}
\qt@newcmd\qurantrans@es@mcmxxxvii{Envié a cada nación un Mensajero [para que los exhortara a] adorar a Dios y a rechazar la idolatría. Algunos de los pueblos fueron guiados por Dios, y a otros se les decretó el extravío. ¡Viajen por el mundo y observen cual fue el destino de quienes desmintieron [Mis signos]!\qt@no{36}}
\qt@newcmd\qurantrans@es@mcmxxxviii{Debes saber [¡oh, Mujámmad!] que por más que te empeñes en guiarlos, Dios no guiará [por la fuerza] a quienes hayan elegido el extravío. Éstos no tendrán quién los auxilie.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcmxxxix{Juran solemnemente por Dios que Él no resucitará a los muertos. ¡Sí! [Los resucitará,] pues es una promesa inalterable [de Dios] y Él no falta a Su promesa. Aunque la mayoría de la gente lo ignore.\qt@no{38}}
\qt@newcmd\qurantrans@es@mcmxl{[Dios los resucitará] para demostrarles cuál era la Verdad sobre la que discrepaban y para que los incrédulos comprendan que estaban equivocados.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcmxli{Cuando decreto algo, digo: ``¡Sé!" Y es.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcmxlii{A quienes emigraron por la causa de Dios después de haber sido perseguidos, les concederé una hermosa recompensa en esta vida, aunque la recompensa en la otra vida será aún mayor, si lo supieran.\qt@no{41}}
\qt@newcmd\qurantrans@es@mcmxliii{Ellos fueron pacientes y se encomendaron plenamente a su Señor.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcmxliv{No envié antes de ti sino hombres a quienes les transmitía Mi revelación. ¡Consulten a la gente de conocimiento lo que no sepan!\qt@no{43}}
\qt@newcmd\qurantrans@es@mcmxlv{Los envié con evidencias claras y con Libros revelados. Y a ti [¡oh, Mujámmad!] te he revelado el conocimiento [de la Sunnah] para que expliques a la gente la revelación [el Corán] que habían recibido, para que así reflexionen.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcmxlvi{¿Acaso quienes se confabularon [contra el Profeta] se sienten a salvo de que Dios los haga tragar por la tierra, o de que les llegue el castigo por donde menos lo esperan?\qt@no{45}}
\qt@newcmd\qurantrans@es@mcmxlvii{¿O de que los sorprenda ocupados en sus quehaceres sin que puedan evitarlo?\qt@no{46}}
\qt@newcmd\qurantrans@es@mcmxlviii{¿O de que los alcance una lenta decadencia? Su Señor es Compasivo, Misericordioso [y no les adelantará el castigo].\qt@no{47}}
\qt@newcmd\qurantrans@es@mcmxlix{¿Acaso no observan que todo cuanto Dios ha creado proyecta su sombra a su derecha y a su izquierda prosternándose ante Dios, mostrando su humildad?\qt@no{48}}
\qt@newcmd\qurantrans@es@mcml{Ante Dios se prosternan los ángeles y toda criatura existente en los cielos y en la Tierra, y no se comportan con soberbia.\qt@no{49}}
\qt@newcmd\qurantrans@es@mcmli{[Los ángeles] temen a su Señor que está por encima de ellos, y ejecutan todo cuanto se les ordena.\qt@no{50}}
\qt@newcmd\qurantrans@es@mcmlii{Dios dice: ``No adoren falsas divinidades. Yo soy la única divinidad, tengan temor devocional solo de Mí".\qt@no{51}}
\qt@newcmd\qurantrans@es@mcmliii{A Él pertenece cuanto hay en los cielos y en la Tierra. Solamente a Él se debe adorar. ¿Acaso van a temer a otro que no sea Dios?\qt@no{52}}
\qt@newcmd\qurantrans@es@mcmliv{Todas las gracias que tienen provienen de Dios. Pero ustedes solo recurren a Él cuando padecen una desgracia.\qt@no{53}}
\qt@newcmd\qurantrans@es@mcmlv{Luego, cuando los libra de la desgracia, algunos de ustedes vuelven a dedicar actos de adoración a otros que a su Señor,\qt@no{54}}
\qt@newcmd\qurantrans@es@mcmlvi{y no agradecen cuanto les ha concedido. Disfruten [transitoriamente, que] pronto sabrán.\qt@no{55}}
\qt@newcmd\qurantrans@es@mcmlvii{Ofrecen una parte de cuanto Dios les concede a sus ídolos, y no saben que ellos no pueden perjudicarlos ni beneficiarlos. ¡Por Dios! Serán interrogados sobre lo que inventan.\qt@no{56}}
\qt@newcmd\qurantrans@es@mcmlviii{¡Glorificado sea Dios! Le atribuyen hijas, pero solo desean para sí mismos los hijos varones.\qt@no{57}}
\qt@newcmd\qurantrans@es@mcmlix{Cuando se le anuncia a uno de ellos [el nacimiento de] una niña, se refleja en su rostro la aflicción y la angustia\qt@no{58}}
\qt@newcmd\qurantrans@es@mcmlx{por lo que se le ha anunciado, se esconde de la gente avergonzado y duda si la dejará vivir a pesar de su deshonra o la enterrará viva. ¡Qué pésimo es lo que hacen!\qt@no{59}}
\qt@newcmd\qurantrans@es@mcmlxi{Quienes no creen en la otra vida son el peor ejemplo [de ignorancia e incredulidad], y Dios es el más sublime ejemplo [de perfección absoluta]. Él es el Poderoso, el Sabio.\qt@no{60}}
\qt@newcmd\qurantrans@es@mcmlxii{Si Dios castigara inmediatamente a la gente por sus injusticias, no dejaría ningún ser vivo sobre la faz de la Tierra. Pero les da una prórroga por un plazo determinado, y cuando venza su plazo no podrán retrasarlo ni adelantarlo ni siquiera un instante.\qt@no{61}}
\qt@newcmd\qurantrans@es@mcmlxiii{Le atribuyen a Dios lo que detestan para sí mismos e inventan mentiras diciendo que alcanzarán el bienestar [en esta vida y en la otra]. Ellos serán los primeros en ser arrojados al Fuego.\qt@no{62}}
\qt@newcmd\qurantrans@es@mcmlxiv{Yo, Dios, juro por Mí mismo que envié Mensajeros a las naciones que te precedieron [¡oh, Mujámmad!], pero el demonio les hizo ver sus malas acciones como buenas. Él es su aliado en esta vida, pero en la otra recibirán un castigo doloroso.\qt@no{63}}
\qt@newcmd\qurantrans@es@mcmlxv{No te he revelado el Libro [¡oh, Mujámmad!] sino para que les aclares aquello sobre lo que discrepaban, como guía y misericordia para los creyentes.\qt@no{64}}
\qt@newcmd\qurantrans@es@mcmlxvi{Dios hace descender agua del cielo dando vida con ella a la tierra azotada por la sequía. En esto hay un signo para quienes recapacitan.\qt@no{65}}
\qt@newcmd\qurantrans@es@mcmlxvii{En los ganados tienen ustedes un ejemplo [del poder divino]. Les doy a beber de lo que se produce en sus vientres, entre quimo y sangre: leche pura, gustosa para quienes la beben.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcmlxviii{De los frutos de las palmeras y de las vides se obtiene un embriagante y también un sustento puro. En esto hay un signo para quienes razonan.\qt@no{67}}
\qt@newcmd\qurantrans@es@mcmlxix{Tu Señor les inspiró a las abejas: ``Habiten en las moradas que hayan construido en las montañas, en los árboles y en las que la gente les construya.\qt@no{68}}
\qt@newcmd\qurantrans@es@mcmlxx{Aliméntense de los frutos y transiten por donde les ha facilitado su Señor". De su abdomen sale un jarabe de diferentes colores que es medicina para la gente. En esto hay un signo para quienes reflexionan.\qt@no{69}}
\qt@newcmd\qurantrans@es@mcmlxxi{Dios los crea a todos y luego los hace morir. A algunos de ustedes los hace llegar a la vejez en la que olvidan todo cuanto sabían. Dios lo sabe todo, es Poderoso.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcmlxxii{Dios facilita los recursos a unos más que a otros. Los que han sido favorecidos con más recursos se niegan a compartirlos con aquellos que posee su diestra para no equipararse con ellos. ¿Acaso se niegan a reconocer [y compartir] las gracias de Dios?\qt@no{71}}
\qt@newcmd\qurantrans@es@mcmlxxiii{Dios les ha creado cónyuges de su misma naturaleza, y luego les concede hijos y luego nietos. Dios les ha proveído todo lo bueno y beneficioso. ¿Acaso creen en las falsedades y reniegan de la gracia de Dios?\qt@no{72}}
\qt@newcmd\qurantrans@es@mcmlxxiv{En lugar de adorar a Dios, adoran lo que no tiene ni tendrá dominio alguno sobre las provisiones del cielo y de la Tierra.\qt@no{73}}
\qt@newcmd\qurantrans@es@mcmlxxv{No comparen a Dios. Dios sabe y ustedes no saben.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcmlxxvi{Dios les expone un ejemplo [para que reflexionen]: ¿Puede equipararse un [incrédulo] esclavo [de sus pasiones] que carece de todo poder, con [un creyente] a quien le he concedido un sustento generoso y hace caridades en privado y en público? [¿Cómo pueden entonces comparar al Creador con los seres creados?] ¡Alabado sea Dios! La mayoría de la gente no reflexiona.\qt@no{75}}
\qt@newcmd\qurantrans@es@mcmlxxvii{Dios les expone otro ejemplo [para que reflexionen acerca de Su unicidad]: ¿Acaso pueden equipararse dos personas: un incapaz y mudo que no hace nada bien y representa una carga para su tutor, y una persona que alza su voz para defender la justicia y está en el sendero recto?\qt@no{76}}
\qt@newcmd\qurantrans@es@mcmlxxviii{Dios conoce los secretos de los cielos y de la Tierra. La Hora [del Día del Juicio] llegará tan rápido como un abrir y cerrar de ojos, o más rápido aún. Dios tiene poder sobre todas las cosas.\qt@no{77}}
\qt@newcmd\qurantrans@es@mcmlxxix{Dios los hizo nacer del vientre de sus madres sin conocimiento [del mundo que los rodea]. Él los dotó de oído, vista e intelecto, para que sean agradecidos.\qt@no{78}}
\qt@newcmd\qurantrans@es@mcmlxxx{¿No han observado las aves suspendidas en el cielo? Es Dios quien las sustenta. En esto hay signos para los creyentes.\qt@no{79}}
\qt@newcmd\qurantrans@es@mcmlxxxi{Dios hizo que sus viviendas sean para ustedes un lugar de sosiego. Puso a su disposición el cuero de los rebaños para que hagan con él sus tiendas, las cuales son fáciles de transportar los días que viajan o acampan. También de su lana, pelo y crin hacen utensilios y alfombras con las que hacen confortable esta vida.\qt@no{80}}
\qt@newcmd\qurantrans@es@mcmlxxxii{Dios les proporcionó sombra de cuanto creó, refugios en las montañas, vestimentas que los resguardan del calor [y el frío] y armaduras que los protegen en los combates. Así es como Dios les provee de Sus gracias para que se sometan a Él.\qt@no{81}}
\qt@newcmd\qurantrans@es@mcmlxxxiii{Pero si se niegan a creer, sabe que a ti solo te incumbe transmitir [el Mensaje] con claridad.\qt@no{82}}
\qt@newcmd\qurantrans@es@mcmlxxxiv{Ellos saben que las gracias provienen de Dios pero lo niegan; la mayoría de ellos son ingratos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mcmlxxxv{El día que haga surgir de cada nación [a su Profeta] como testigo, no se les permitirá a los incrédulos excusarse ni que se arrepientan.\qt@no{84}}
\qt@newcmd\qurantrans@es@mcmlxxxvi{Cuando los injustos vean el castigo, no habrá atenuantes ni prórrogas.\qt@no{85}}
\qt@newcmd\qurantrans@es@mcmlxxxvii{Cuando los idólatras vean a sus ídolos dirán: ``¡Señor nuestro! Éstos son los ídolos a quienes invocábamos en lugar de Ti", pero ellos [los ídolos] los contradecirán: ``Son unos mentirosos".\qt@no{86}}
\qt@newcmd\qurantrans@es@mcmlxxxviii{Ese día serán entregados a Dios [para que los castigue], y sus mentiras se desvanecerán.\qt@no{87}}
\qt@newcmd\qurantrans@es@mcmlxxxix{A los incrédulos que desviaron a la gente del camino de Dios, les duplicaré el castigo por haber sembrado la corrupción.\qt@no{88}}
\qt@newcmd\qurantrans@es@mcmxc{[El Día del Juicio] haré surgir de cada nación [a su Profeta] para que atestigüe en contra de ellos, y a ti [¡oh, Mujámmad!] como testigo de tu nación. Te he revelado el Libro que contiene todas las explicaciones, el cual es guía, misericordia y albricias para los musulmanes que se someten a Dios.\qt@no{89}}
\qt@newcmd\qurantrans@es@mcmxci{Dios ordena la justicia, hacer el bien y ayudar a la familia; pero prohíbe la obscenidad, la mala conducta y la opresión. Así los exhorta para que reflexionen.\qt@no{90}}
\qt@newcmd\qurantrans@es@mcmxcii{Cumplan su compromiso con Dios. No quebranten los juramentos después de haberlos realizado, habiendo puesto a Dios como testigo. Dios sabe bien cuanto hacen.\qt@no{91}}
\qt@newcmd\qurantrans@es@mcmxciii{No sean como quien deshace el hilado que había realizado cuidadosamente. No hagan del juramento un medio de engaño. No rompan un pacto hecho con una nación por beneficiarse de un pacto con otra nación más poderosa. Dios los pone a prueba para que se les evidencie quienes Lo obedecen de quienes no. El Día del Juicio juzgará entre ustedes sobre lo que discrepaban.\qt@no{92}}
\qt@newcmd\qurantrans@es@mcmxciv{Si Dios hubiera querido habría hecho de ustedes una sola nación [de creyentes]. Pero se descarría quien quiere y se guía quien quiere. Todos serán interrogados por cuanto hicieron.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcmxcv{No hagan de sus juramentos una herramienta de engaño. Si lo hacen se los castigará por haberse extraviado y desviado a otros del sendero de Dios, y el castigo que sufrirán será terrible.\qt@no{94}}
\qt@newcmd\qurantrans@es@mcmxcvi{No vendan su compromiso con Dios a vil precio. Lo que Dios les tiene reservado en esta vida y en la otra es mejor para ustedes, si lo supieran.\qt@no{95}}
\qt@newcmd\qurantrans@es@mcmxcvii{[Sepan que] lo que ustedes tienen es temporal y lo que Dios tiene es eterno. A quienes hayan sido pacientes les multiplicaré la recompensa de sus obras.\qt@no{96}}
\qt@newcmd\qurantrans@es@mcmxcviii{Al creyente que obre rectamente, sea varón o mujer, le concederé una vida buena y le multiplicaré la recompensa de sus buenas obras.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcmxcix{Cuando recites el Corán refúgiate en Dios del demonio maldito.\qt@no{98}}
\qt@newcmd\qurantrans@es@mm{El demonio no tiene poder sobre los creyentes que se encomiendan a su Señor.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmi{Solamente tiene poder sobre quienes lo toman como aliado protector y aquellos que lo adoran asociándolo [en el poder y la adoración] a Dios.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmii{Cuando revelo un precepto para abrogar otro, y Dios bien sabe lo que hace, dicen [tus detractores]: ``Eres tú quien lo ha inventado". Pero la mayoría de ellos son ignorantes.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmiii{Diles: ``Es el Espíritu Santo [el ángel Gabriel] quien lo ha revelado [por orden] de tu Señor con la Verdad para afirmar a los creyentes, y como guía y albricias para los musulmanes que se someten a Dios".\qt@no{102}}
\qt@newcmd\qurantrans@es@mmiv{Sé muy bien que dicen: ``Es un hombre quien se lo transmite [el Corán]". Pero bien saben que el idioma de quien ellos aluden no es el árabe, mientras que éste [Corán] es en árabe puro.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmv{A quienes no crean en los signos de Dios, Dios no los guiará y recibirán un castigo doloroso.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmvi{Solamente inventan mentiras quienes no creen en los signos de Dios. Ellos son los mentirosos [y no el Profeta].\qt@no{105}}
\qt@newcmd\qurantrans@es@mmvii{Quienes renieguen de la fe en Dios por haber sido forzados a ello, permaneciendo sus corazones tranquilos [y firmes] en la fe [no serán reprochados]; pero quienes lo hagan y se complazcan con la incredulidad, incurrirán en la ira de Dios y tendrán un castigo terrible,\qt@no{106}}
\qt@newcmd\qurantrans@es@mmviii{porque prefirieron la vida mundanal a la otra. Dios no guía al pueblo incrédulo.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmix{A ellos Dios les ha sellado sus corazones, sus oídos y sus ojos [con la incredulidad], y son indiferentes [ante los signos].\qt@no{108}}
\qt@newcmd\qurantrans@es@mmx{No hay duda de que en la otra vida ellos serán los perdedores.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmxi{Quienes emigraron luego de haber sido perseguidos, combatieron y fueron pacientes, tu Señor será Absolvedor y Misericordioso con ellos.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmxii{Ese día toda alma argumentará para alcanzar la salvación y será juzgada acorde a sus obras; nadie será tratado injustamente.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmxiii{Dios les expone el ejemplo de una ciudad [La Meca], cuyos habitantes se sentían seguros y tranquilos, les llegaba abundante sustento proveniente de todas las regiones. Pero no agradecieron los favores de Dios, entonces Él los hizo padecer hambre y temor por cuanto habían cometido.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmxiv{El Mensajero que se les presentó era uno de ellos, pero lo desmintieron y el castigo los sorprendió por las injusticias que cometían.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmxv{Coman de lo lícito y bueno que Dios les ha sustentado. Agradezcan las bendiciones de Dios, si es que solo a Él adoran.\qt@no{114}}
\qt@newcmd\qurantrans@es@mmxvi{Se les ha prohibido [alimentarse de] la carne del animal muerto por causa natural, la sangre, la carne de cerdo, la del animal que haya sido sacrificado invocando otro nombre que no sea el de Dios. Pero si alguien se ve forzado [a ingerirlos por hambre extrema], sin intención de pecar ni excederse, no cometerá pecado. Dios es Absolvedor, Indulgente.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmxvii{No profieran mentiras dejando que sus lenguas determinen [a su antojo] diciendo: ``Esto es lícito y aquello es ilícito", inventando mentiras acerca de Dios. Quienes inventen mentiras acerca de Dios no prosperarán jamás.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmxviii{Ellos tendrán un goce transitorio, pero luego [el Día del Juicio] recibirán un castigo doloroso.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmxix{A los judíos les prohibí lo que te he narrado anteriormente. No fui injusto con ellos sino que ellos lo fueron consigo mismos.\qt@no{118}}
\qt@newcmd\qurantrans@es@mmxx{Con quienes hayan cometido un mal por ignorancia y luego se arrepientan y enmienden, tu Señor será Absolvedor, Misericordioso.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmxxi{Abraham fue un guía ejemplar, era obediente a Dios, monoteísta, y jamás fue idólatra.\qt@no{120}}
\qt@newcmd\qurantrans@es@mmxxii{Era agradecido por los favores de Dios. Él lo eligió y lo guió por el sendero recto.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmxxiii{Le concedí en la vida mundanal todo lo bueno, y en la otra vida estará con los justos.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmxxiv{A ti [¡oh, Mujámmad!] te he inspirado: ``Sigue la religión pura monoteísta de Abraham, que jamás fue de los idólatras".\qt@no{123}}
\qt@newcmd\qurantrans@es@mmxxv{Les fue ordenado [a los judíos] dedicar el día sábado a la adoración cuando discreparon [y no aceptaron que este día fuera el viernes]. Tu Señor juzgará entre ellos el Día de la Resurrección sobre lo que discrepaban.\qt@no{124}}
\qt@newcmd\qurantrans@es@mmxxvi{Convoca al sendero de tu Señor con sabiduría y bellas palabras. Argumenta de la mejor manera. Tu Señor sabe bien quién se extravía de Su camino y quién sigue la guía.\qt@no{125}}
\qt@newcmd\qurantrans@es@mmxxvii{Si los agreden, respondan del mismo modo que se los ha agredido [y no se excedan]. Pero si son pacientes [y perdonan] será lo mejor para ustedes.\qt@no{126}}
\qt@newcmd\qurantrans@es@mmxxviii{Sé paciente y sabe que la paciencia es una virtud que Dios concede a quien quiere. No sientas pena [por la incredulidad de tu pueblo] ni te angusties por lo que traman.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmxxix{Dios está con los piadosos y con los que hacen el bien.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmxxx{\basmalahes Glorificado sea Quien transportó a Su Siervo durante la noche, desde la mezquita sagrada a la mezquita lejana cuyos alrededores bendije, para mostrarle algunos de Mis signos. Él todo lo oye, todo lo ve.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmxxxi{He revelado a Moisés el Libro como guía para el pueblo de Israel, y les ordené: ``No tomen protector fuera de Mí".\qt@no{2}}
\qt@newcmd\qurantrans@es@mmxxxii{¡Él era un descendiente de quienes salvé junto a Noé [en el arca]! Fue un siervo agradecido.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmxxxiii{He revelado en el Libro lo que decreté para el pueblo de Israel: ``Corromperán la Tierra dos veces y se convertirán en tiranos soberbios.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmxxxiv{Cuando corrompan por primera vez, enviaré contra ustedes siervos Míos en huestes de gran fortaleza y rudeza, que atacarán sus hogares. Esta promesa será cumplida.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmxxxv{Luego les permitiré que retornen a sus hogares [victoriosos] expulsándolos. Los agraciaré con bienes materiales e hijos y los convertiré en un pueblo numeroso.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmxxxvi{Si obran bien será en beneficio propio, pero si obran mal será en contra suya. Cuando corrompan por segunda vez, los vencerán [sus enemigos] e ingresarán al Templo como lo hicieron la primera vez y devastarán todo lo que encuentren.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmxxxvii{Luego su Señor se apiadará de ustedes, pero si reinciden [en la corrupción] los volveré a castigar. El Infierno será prisión para los que se nieguen a creer.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmxxxviii{El Corán guía por el sendero más justo y firme, y di a los creyentes que obran rectamente que recibirán una gran recompensa.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmxxxix{Pero a quienes no crean en la otra vida les he preparado un castigo doloroso.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmxl{El ser humano ruega a Dios el mal con la misma facilidad con que ruega pidiendo el bien: el ser humano es muy precipitado.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmxli{He hecho del día y de la noche dos signos: el signo de la noche es la oscuridad, y el signo del día es la luminosidad para que busquen el favor de su Señor, e hice que con estos dos signos pudieran saber el número de los años y el cómputo de los meses. Todas las cosas las he explicado detalladamente.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmxlii{Todo ser humano será responsable por sus actos, y el Día de la Resurrección le entregaré un libro abierto.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmxliii{[Se le dirá:] ``Lee tu libro, pues hoy será suficiente con que tú mismo leas el registro de tus obras [para saber cuál será tu destino]".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmxliv{Quien siga la guía será en beneficio propio, pero quien se desvíe solo se perjudicará a sí mismo. Nadie cargará con pecados ajenos. No he castigado a ningún pueblo sin antes haberle enviado un Mensajero.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmxlv{Cuando quiero destruir una ciudad permito que sus dirigentes siembren la corrupción, entonces la sentencia contra ella se cumple y la destruyo totalmente.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmxlvi{Así es como he destruido a muchas generaciones luego de Noé. ¡Es suficiente con que Dios vea y sepa de los pecados que cometen Sus siervos!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmxlvii{Quienes prefieran los placeres transitorios de la vida mundanal sepan que se los concederé a quien Yo quiera, pero les destinaré el Infierno, donde ingresarán humillados y condenados [por haberse olvidado de obrar para la otra vida].\qt@no{18}}
\qt@newcmd\qurantrans@es@mmxlviii{Mientras que a quienes anhelen la vida del más allá, sean creyentes y se esfuercen por alcanzarla, se les retribuirá por su esfuerzo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmxlix{A todos [en esta vida] se les concederá de los favores de tu Señor, a los unos y a los otros. Sus favores no le son vedados a nadie.\qt@no{20}}
\qt@newcmd\qurantrans@es@mml{Observa cómo he agraciado a unos sobre otros [con bienes materiales en este mundo], pero en la otra vida la distinción será mayor [entre los que creen y los que no creen].\qt@no{21}}
\qt@newcmd\qurantrans@es@mmli{No adoren a otros junto a Dios, porque serán condenados y humillados.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmlii{Tu Señor ha ordenado que no adoren sino a Él y que honren a sus padres. Si uno de ellos o ambos llegan a la vejez, no sean insolentes con ellos, ni siquiera les digan: ``¡Uf!" Háblenles siempre con bondad.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmliii{Trátenlos con humildad y compasión, y rueguen [por ellos diciendo]: ``¡Oh, Señor mío! Ten misericordia de ellos como ellos la tuvieron conmigo cuando me criaron siendo niño".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmliv{Su Señor es Quien mejor conoce lo que hay en sus corazones. Si son piadosos, sepan que Él perdona a los que se arrepienten.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmlv{Da a los parientes lo que es su derecho, también al pobre y al viajero insolvente, pero no derroches,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmlvi{porque los que derrochan son hermanos de los demonios, y el demonio fue ingrato con su Señor.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmlvii{Pero si no puedes darles una ayuda, y esperas una misericordia de tu Señor, excúsate con amabilidad.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmlviii{No seas avaro ni tampoco derrochador, porque te verás censurado [en el primer caso] y arruinado [en el segundo].\qt@no{29}}
\qt@newcmd\qurantrans@es@mmlix{Tu Señor concede un sustento abundante a quien quiere, y se lo restringe a quien quiere. Él a Sus siervos los conoce bien, y los ve siempre.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmlx{No maten a sus hijos por temor a la pobreza. Yo los sustento a ellos y a ustedes. Matarlos es un pecado gravísimo.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmlxi{No se acerquen a lo que lleve a la fornicación, pues es una inmoralidad y un mal camino.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmlxii{No maten, pues Dios lo ha prohibido, salvo con motivo justo. A quien se le dé muerte injustamente le concedo a su familiar directo o apoderado el derecho, pero que éste no mate buscando venganza. Su derecho [a exigir justicia] está legalmente garantizado.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmlxiii{No utilicen los bienes del huérfano a menos que sea para beneficiarlo, y entréguenselos cuando alcance la madurez. Cumplan con sus compromisos, porque se los interrogará por ellos.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmlxiv{Midan y pesen con equidad. Esto es lo más conveniente y mejor para ustedes.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmlxv{No hagan ni digan nada si no tienen conocimiento. Serán interrogados acerca de [lo que hayan hecho con] su oído, vista y corazón.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmlxvi{No caminen por la Tierra con arrogancia, pues ella no se abrirá por su andar, ni tampoco podrán igualar a las montañas en altura [para ser tan imponentes como ellas].\qt@no{37}}
\qt@newcmd\qurantrans@es@mmlxvii{Todos estos comportamientos son perjudiciales para ustedes y detestables ante su Señor.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmlxviii{Esto es parte de la sabiduría que tu Señor te ha revelado. No adoren a nadie junto a Dios porque serán arrojados en el Infierno, condenados y humillados.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmlxix{¿Acaso creen que su Señor prefirió para ustedes los hijos varones y para Sí hijas que son los ángeles? Lo que dicen es muy grave.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmlxx{En este Corán he expuesto todo tipo de argumentos para que reflexionen, pero [a algunos] esto los hace extraviarse aún más.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmlxxi{Diles: ``Si junto a Dios hubiera otros dioses, como dicen [los idólatras], ellos buscarían acercarse al Señor del Trono [para complacerlo]".\qt@no{42}}
\qt@newcmd\qurantrans@es@mmlxxii{¡Glorificado sea! Él está por encima de lo que dicen.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmlxxiii{Lo glorifican los siete cielos, la Tierra y todo cuanto hay en ellos. No existe nada que no Lo glorifique con alabanzas, aunque ustedes no puedan percibir sus glorificaciones. Él es Magnánimo, Perdonador.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmlxxiv{Cuando recitas el Corán ponemos un velo imperceptible entre tú y quienes no creen en la otra vida.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmlxxv{[Como respuesta a su rechazo] hice sus corazones duros y sus oídos sordos para que no pudieran comprender [el Mensaje]. Cuando mencionas en el Corán que tu Señor es la única divinidad [con derecho a ser adorada], te dan la espalda disgustados.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmlxxvi{Yo bien sé cómo se burlan cuando te escuchan [recitar el Corán] o cuando hablan en secreto; y dicen los idólatras: ``Están siguiendo a un hombre hechizado".\qt@no{47}}
\qt@newcmd\qurantrans@es@mmlxxvii{Observa cómo te comparan y por ello se extravían. No pueden encontrar el camino.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmlxxviii{Dicen: ``¿Acaso cuando seamos huesos y polvo seremos resucitados y creados nuevamente?"\qt@no{49}}
\qt@newcmd\qurantrans@es@mmlxxix{Respóndeles: ``¡Sí! Aunque se conviertan en piedra, hierro\qt@no{50}}
\qt@newcmd\qurantrans@es@mmlxxx{o cualquier otra materia que veneren en su pensamiento". Dirán: ``¿Quién nos resucitará?" Respóndeles: ``Quien los creó por primera vez". Pero negando con su cabeza te dirán: ``¿Cuándo?" Diles: ``Es posible que sea pronto".\qt@no{51}}
\qt@newcmd\qurantrans@es@mmlxxxi{El día que los convoque responderán alabándolo, y les parecerá que no han permanecido [en las tumbas] sino poco tiempo.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmlxxxii{Exhorta a Mis siervos a hablar con respeto, porque el demonio quiere sembrar la discordia entre ellos. El demonio es el enemigo declarado del ser humano.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmlxxxiii{Su Señor conoce lo que hay en sus corazones. Si quiere tendrá misericordia con ustedes, o si quiere los castigará [con justicia]. Pero tú [¡oh, Mujámmad!] no eres responsable de lo que ellos hagan.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmlxxxiv{Tu Señor conoce bien a quienes están en los cielos y en la Tierra. He favorecido a los Profetas unos sobre otros: a David le revelé los Salmos.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmlxxxv{Diles: ``Aquellos que invocan en lugar de Dios no pueden salvarlos de ningún mal, ni siquiera evitarlo".\qt@no{56}}
\qt@newcmd\qurantrans@es@mmlxxxvi{[Aquellos] a los que ustedes invocan buscan el medio de acercarse más a su Señor, anhelan Su misericordia y temen Su castigo. ¡Porque el castigo de tu Señor es temible!\qt@no{57}}
\qt@newcmd\qurantrans@es@mmlxxxvii{No hay ninguna ciudad [de incrédulos] que no vaya a destruir o castigar antes del Día de la Resurrección. Esto es lo que ha sido decretado y registrado en el Libro [preservado].\qt@no{58}}
\qt@newcmd\qurantrans@es@mmlxxxviii{No les envié los milagros que pedían porque los desmentirían como lo hicieron los pueblos del pasado. Al pueblo de Zamud le envié la camella como un milagro evidente, pero cometieron la injusticia [de matarla]. Entonces les envié signos para atemorizarlos.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmlxxxix{Cuando te dije [¡oh, Mujámmad!]: ``Tu Señor tiene poder total sobre las personas [y Él te protegerá]". Lo que te mostré y el árbol maldito mencionado en el Corán, no es sino para probar la fe de las personas. Los atemorizo [con Mis signos], pero esto les incrementó aún más su desobediencia.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmxc{[Recuerda] cuando dije a los ángeles: ``Hagan una reverencia ante Adán". Todos hicieron la reverencia excepto Iblís, quien dijo: ``¿Acaso voy a hacer una reverencia ante quien has creado de barro?"\qt@no{61}}
\qt@newcmd\qurantrans@es@mmxci{Dijo también: ``¿Por qué lo has honrado más que a mí?" Si me das tiempo hasta el Día de la Resurrección desviaré a la mayoría de sus descendientes.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmxcii{Dijo [Dios]: ``¡Vete! Y quienes de ellos te sigan merecerán el Infierno, pues es el castigo que les tengo reservado.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmxciii{Seduce con tus palabras a quien puedas de ellos, arremete con tu caballería y con tu infantería. Hazte su socio inseparable en sus bienes e hijos y hazles las promesas que quieras. Pero sepan que el demonio solo hace promesas falsas".\qt@no{64}}
\qt@newcmd\qurantrans@es@mmxciv{[Dijo Dios:] ``Pero no tienes poder alguno sobre Mis siervos creyentes". Es suficiente con tu Señor como protector [para quienes se encomiendan a Él].\qt@no{65}}
\qt@newcmd\qurantrans@es@mmxcv{Su Señor es Quien impulsa los barcos en el mar para que con ellos puedan procurar Su favor. Él es Misericordioso con ustedes.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmxcvi{Cuando los alcanza una desgracia en el mar se dan cuenta que cuanto invocaban fuera de Dios no puede salvarlos, y que solo Dios es Quien puede hacerlo. Pero cuando los salva llevándolos a tierra firme, Lo niegan nuevamente. ¡El ser humano es ingrato!\qt@no{67}}
\qt@newcmd\qurantrans@es@mmxcvii{¿Acaso se sienten a salvo de que Dios los haga tragar por la tierra o que les envíe un huracán? Si así lo hiciera, no encontrarían quién los pudiera proteger.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmxcviii{¿O se sienten seguros de que cuando se encuentren en el mar otra vez, Él no les envíe una tormenta y los ahogue como castigo a su ingratitud? Si así lo hiciera, no tendrían quién Le reclamara por ustedes.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmxcix{He honrado a los hijos de Adán y les he facilitado los medios para viajar por la tierra y por el mar, les he proveído de todo lo bueno y los he favorecido sobre muchas otras criaturas.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmc{El día que convoque a todos los seres humanos junto a sus guías y les entregue sus registros, a quien le sea entregado el libro de sus obras en la derecha, [se alegrará] leyendo su libro porque verá que no ha sido defraudado en lo más mínimo.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmci{Pero quien haya estado en esta vida ciego [en la incredulidad], en la otra también lo estará y más perdido aún.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcii{Los idólatras [¡oh, Mujámmad!] querían persuadirte que cedieras a favor de sus peticiones, contrariando las instrucciones que te había revelado. Si lo hubieras hecho, te habrían convertido en su aliado.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmciii{Si no te hubiera fortalecido, te habrías inclinado a aceptar parte de sus peticiones.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmciv{Y si hubieras cedido en algo, te habría hecho sufrir un castigo doble en esta vida y en la otra. No hubieras encontrado quién te protegiera de Mí.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcv{Casi logran intimidarte para que abandones tu tierra [La Meca], pero si lo hubiesen logrado no habrían permanecido en ella sino poco tiempo [porque habría enviado sobre ellos el castigo].\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcvi{Lo mismo sucedió con los Mensajeros que envié antes de ti. No encontrarás cambio alguno en Mi proceder.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcvii{Observa las oraciones prescritas desde pasado el mediodía hasta la oscuridad de la noche, y también la oración del alba, y prolonga la recitación en ella, pues ésta es atestiguada [por los ángeles de la noche y el día].\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcviii{También levántate parte de la noche a realizar oraciones voluntarias, para que tu Señor te conceda un rango digno de alabanza.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcix{Di: ``¡Señor mío! Concédeme una entrada y una salida dignas [en todos los asuntos de mi vida], y concédeme los medios para lograr el triunfo".\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcx{Y di: ``Ha triunfado la Verdad y se ha disipado la falsedad; la falsedad siempre se desvanece".\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcxi{Revelé el Corán, que es cura para los corazones y misericordia para los creyentes, pero al mismo tiempo no hace sino aumentar la perdición de los idólatras.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcxii{El incrédulo, cuando lo agracio, no Me agradece por arrogancia; pero cuando lo aflige un mal se desespera.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcxiii{Diles: ``Que cada uno obre como le plazca, pero sepan que su Señor conoce a quien está mejor encaminado".\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcxiv{Te preguntan acerca del espíritu. Diles: ``El espíritu es una de las creaciones de Dios, de las que solo Él tiene conocimiento. No se les ha permitido acceder sino a una pequeña parte del inmenso conocimiento de Dios".\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcxv{Si quisiera, borraría todo lo que te he revelado, y entonces no encontrarías quién abogara por ti ante Mí [para que lo pudieras recordar].\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcxvi{Pero no lo haré por misericordia. El favor con el que tu Señor te ha agraciado es inmenso.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcxvii{Diles: ``Si los seres humanos y los yinnes se unieran para redactar un texto similar al Corán, no podrían lograrlo, aunque se ayudaran mutuamente".\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcxviii{He expuesto a los seres humanos en este Corán toda clase de ejemplos. Pero la mayoría de las personas no creen y rechazan la Verdad.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcxix{Dicen [los que se niegan a creer]: ``No creeremos en ti hasta que no hagas fluir para nosotros vertientes de la tierra\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcxx{o poseas un huerto con palmeras y vides, y hagas brotar en él ríos,\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcxxi{o hagas descender sobre nosotros un castigo del cielo como advertiste, o nos traigas a Dios y a los ángeles para que los podamos ver,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcxxii{o poseas una casa de oro o asciendas al cielo, y aun así no creeremos en ti a menos que nos traigas del cielo un libro que podamos leer". Diles: ``¡Glorificado sea mi Señor! Pero, ¿no soy acaso solo un ser humano enviado como Mensajero?"\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcxxiii{Lo que impidió que creyera la gente cuando se les presentaron los Mensajeros con la guía fue la misma retórica: [Decían] ``¿No encontró Dios nada mejor que enviar a un ser humano como Mensajero?"\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcxxiv{Diles: ``Si los ángeles habitaran la Tierra, entonces les habría enviado del cielo un ángel como Mensajero".\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcxxv{Diles: ``Dios es suficiente testigo de mi veracidad entre ustedes y yo. Él está bien informado sobre Sus siervos y los observa".\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcxxvi{A quien Dios guíe estará bien encaminado, pero a quienes permita que se extravíen nadie los podrá socorrer salvo Él. Los congregaré de cabeza el Día de la Resurrección, ciegos, mudos y sordos. El Infierno será su morada; siempre que el fuego se atenúe avivaré su llama.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcxxvii{Ese será su castigo por no haber creído en Mis milagros y haber dicho: ``¿Acaso cuando seamos huesos y polvo seremos resucitados y creados nuevamente?"\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcxxviii{¿Acaso no ven que Dios, Quien ha creado los cielos y la Tierra, tiene el poder de crearlos nuevamente? Les ha establecido un plazo determinado para su resurrección, pero los idólatras lo niegan con incredulidad.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmcxxix{Diles: ``Si tuvieran en sus manos las arcas de mi Señor, no las compartirían por temor a empobrecer. ¡Qué avaro es el ser humano!"\qt@no{100}}
\qt@newcmd\qurantrans@es@mmcxxx{Concedí a Moisés nueve milagros evidentes. Pregunta [¡oh, Mujámmad!] al pueblo de Israel si no es verdad que cuando [Moisés] se presentó ante el Faraón, éste le dijo: ``¡Oh, Moisés! Creo que estás afectado por un hechizo".\qt@no{101}}
\qt@newcmd\qurantrans@es@mmcxxxi{Dijo [Moisés]: ``Tú sabes bien que solo el Señor de los cielos y de la Tierra ha enviado estos milagros claros. ¡Oh, Faraón! Creo que estás perdido".\qt@no{102}}
\qt@newcmd\qurantrans@es@mmcxxxii{[El Faraón] quiso expulsarlos de la tierra, pero lo ahogué junto a su ejército.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmcxxxiii{Luego dije al pueblo de Israel: ``Habiten la tierra y sepan que cuando llegue el Día del Juicio del que Dios les advirtió, los haré comparecer a todos".\qt@no{104}}
\qt@newcmd\qurantrans@es@mmcxxxiv{Lo he revelado [al Corán] con la verdad y lo he protegido para que así les llegue. No te he enviado [¡oh, Mujámmad!] sino como albriciador y amonestador.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmcxxxv{Te he revelado el Corán en partes para que se lo recites gradualmente a la gente. Te lo he ido revelando poco a poco.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmcxxxvi{Diles: ``Crean o no crean en él [es su responsabilidad]". Quienes fueron agraciados con el conocimiento de las revelaciones anteriores, cuando escuchan la recitación del Corán se prosternan ante Dios.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmcxxxvii{Y dicen: ``¡Glorificado sea nuestro Señor! La promesa de nuestro Señor se ha cumplido".\qt@no{108}}
\qt@newcmd\qurantrans@es@mmcxxxviii{Se prosternan ante Dios con los ojos llenos de lágrimas, y [el Corán] les acrecienta su humildad y sumisión.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmcxxxix{Diles: ``Ya sea que Lo invoquen diciendo: ¡Oh, Dios!, ¡Oh, Compasivo!, O cualquier otro nombre con el que Le invoquen, Él los oirá. Sepan que Él posee los nombres [y atributos] más sublimes. Cuando realicen una oración moderen su voz en la recitación, no la hagan con voz muy alta ni tampoco en silencio".\qt@no{110}}
\qt@newcmd\qurantrans@es@mmcxl{Di: ``¡Alabado sea Dios! Él no tiene ningún hijo ni tiene asociado alguno en Su soberanía ni necesita de ningún socorredor". ¡Glorifica a Dios proclamando Su grandeza!\qt@no{111}}
\qt@newcmd\qurantrans@es@mmcxli{\basmalahes ¡Alabado sea Dios! Quien ha revelado a Su siervo el Libro en el que no hay contradicciones ni defectos,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcxlii{un Libro justo para advertir [a los que rechazan el Mensaje] de Su castigo severo, y para albriciar a los creyentes que obran rectamente que recibirán una hermosa recompensa\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcxliii{en la que permanecerán por toda la eternidad.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcxliv{También para advertir a quienes dicen que Dios ha engendrado un hijo:\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcxlv{No tienen conocimiento sobre eso ni lo tenían sus antepasados. ¡Qué graves palabras salen de sus bocas! No dicen sino mentiras.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcxlvi{¿Acaso vas a dejar que te consuma la pena si ellos se niegan a creer en estas palabras?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcxlvii{He hecho de cuanto hay en la Tierra un adorno para probar quién obra mejor,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcxlviii{pero luego la convertiré en un terreno árido.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcxlix{¿Acaso consideras [¡oh, Mujámmad!] que la historia de los jóvenes de la caverna y [su devoción por] la escritura fue uno de Mis milagros más sorprendentes?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcl{Recuerda cuando los jóvenes se refugiaron en la caverna y dijeron: ``¡Señor nuestro! Acógenos en Tu misericordia y concédenos que nuestra situación se solucione correctamente".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcli{Entonces hice que durmieran en la caverna por muchos años.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmclii{Luego hice que despertaran para distinguir cuál de los dos grupos [creyentes e incrédulos] calculaba mejor el tiempo que habían permanecido allí.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcliii{Te relato su verdadera historia: Eran jóvenes que creían en su Señor y les aumenté su guía,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcliv{fortalecí sus corazones cuando se reunieron [antes de dejar sus hogares y su gente] y dijeron: ``Nuestro Señor es el Señor de los cielos y de la Tierra. No invocaremos nada fuera de Él, si lo hiciéramos estaríamos cometiendo una desviación.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmclv{Nuestro pueblo adora fuera de Él falsas deidades. ¿Por qué no presentan un fundamento válido para hacerlo? ¿Acaso hay alguien más injusto que quien inventa una mentira y la atribuye a Dios?"\qt@no{15}}
\qt@newcmd\qurantrans@es@mmclvi{[Dijo uno de ellos:] ``Si se apartan de ellos y reniegan de cuanto adoran en vez de Dios, refúgiense en la caverna, que su Señor los cubrirá con Su misericordia y les facilitará una salida a su situación".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmclvii{Se podía observar cómo el Sol naciente se alejaba de la caverna por la derecha dejándolos al ocultarse por la izquierda, mientras ellos permanecían en un espacio de la misma. Este es uno de los milagros de Dios. Aquel a quien Dios guíe estará bien encaminado, pero a quien deja en el extravío no podrá encontrar protector que lo guíe.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmclviii{Habrías creído que estaban despiertos, pero estaban dormidos. Los volteaba hacia la derecha y hacia la izquierda, y su perro estaba con las patas delanteras extendidas en la entrada. Si los hubieras visto, habrías huido aterrorizado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmclix{Entonces los desperté para que se preguntaran unos a otros. Uno de ellos dijo: ``¿Cuánto tiempo piensan que hemos permanecido aquí?" Respondieron: ``Permanecimos un día o parte de un día". Dijeron: ``Nuestro Señor sabe mejor cuánto tiempo hemos permanecido. Enviemos a uno de nosotros con nuestro dinero a la ciudad para que busque la mejor comida y nos aprovisione, que se conduzca con sutileza y que no llame la atención de nadie,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmclx{porque si se enteran de nuestra presencia nos apedrearán o nos obligarán a regresar a su religión, y si eso sucede jamás estaremos entre los que alcancen el triunfo [en el más allá]".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmclxi{Pero hice que los descubrieran para que supieran que la promesa de Dios es verdadera, y que la Hora del Juicio es indubitable [y luego los hice morir]. Fue entonces cuando los habitantes del pueblo discutieron acerca de ellos. Algunos dijeron: ``Construyan una pared que bloquee la entrada de la cueva, pues solo Dios sabe la verdad sobre ellos". Pero aquellos cuya opinión prevaleció dijeron: ``Construyamos sobre ellos un oratorio".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmclxii{Algunos dirán que eran tres y cuatro con su perro. Otros que eran cinco y seis con su perro, conjeturando sobre lo que no tienen conocimiento. Y otros dirán que eran siete y ocho con su perro. Diles: ``Mi Señor es Quien sabe exactamente cuántos eran, y solo pocos lo saben. No profundicen sobre ellos más de lo que les ha sido revelado. No consulten [a quien no tenga conocimiento] sobre ellos".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmclxiii{No digas acerca de algo: ``¡Haré tal cosa!"\qt@no{23}}
\qt@newcmd\qurantrans@es@mmclxiv{Salvo que agregues: ``¡Si Dios quiere!" Pero si te olvidas de mencionar a tu Señor, invoca su nombre y reza diciendo: ``Ruego a mi Señor que me guíe a la vía más recta".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmclxv{Permanecieron en su caverna trescientos años y nueve más.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmclxvi{Diles: ``Dios es Quien realmente sabe cuánto permanecieron. Él conoce los secretos de los cielos y de la Tierra; Él todo lo ve, todo lo oye. No tienen protector fuera de Él, y Él no asocia a nadie en Sus decisiones".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmclxvii{Recita lo que se te ha revelado del Libro de tu Señor. No hay quien pueda tergiversar Sus palabras, y no encontrarás protector fuera de Él.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmclxviii{Reúnete con quienes invocan a su Señor por la mañana y por la tarde anhelando Su rostro. No te apartes de ellos buscando el encanto de la vida mundanal. No obedezcas a aquel cuyo corazón se ha olvidado de recordarme, sigue sus pasiones y actúa con negligencia.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmclxix{Diles: ``La Verdad proviene de su Señor. Quien quiera que crea, y quien no quiera que no lo haga". Pero sepan que tengo preparado para los que cometen injusticias un fuego que los rodeará. Cuando sofocados pidan de beber, se les verterá un líquido como el metal fundido que les quemará el rostro. ¡Qué pésima bebida y qué horrible morada!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmclxx{En cambio, quienes crean y obren rectamente, sepan que recompensaré todas sus obras.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmclxxi{Ellos alcanzarán los Jardines del Edén por donde corren ríos. Serán engalanados con brazaletes de oro, vestidos con prendas verdes de seda y brocado. Estarán recostados sobre sofás. ¡Qué placentera recompensa y qué hermoso lugar de descanso!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmclxxii{Exponles el ejemplo de dos hombres. Al incrédulo le concedí dos viñedos cercados con palmeras y en medio de ambos un sembrado.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmclxxiii{Ambos viñedos dieron sus frutos sin ninguna pérdida, e hice brotar en medio de ellos un río.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmclxxiv{Su dueño, que poseía abundantes riquezas, hablando [arrogantemente] con el creyente le dijo: ``Tengo más riqueza que tú y mi gente es más fuerte".\qt@no{34}}
\qt@newcmd\qurantrans@es@mmclxxv{Luego ingresó en su viñedo lleno de soberbia e incredulidad y exclamó: ``No creo que este viñedo perezca jamás,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmclxxvi{tampoco creo que jamás llegue la Hora [del Día del Juicio]. Pero si llego a ser resucitado estoy seguro de que tendré un viñedo mejor que éste".\qt@no{36}}
\qt@newcmd\qurantrans@es@mmclxxvii{El creyente con quien hablaba le preguntó [haciéndolo reflexionar]: ``¿No crees en Quien ha creado a tu padre de polvo, luego a toda su descendencia de un óvulo fecundado, y te ha dado la forma de un ser humano con todas sus facultades?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmclxxviii{En cuanto a mí, creo que Dios es mi Señor y no Le asocio copartícipe alguno [en la adoración].\qt@no{38}}
\qt@newcmd\qurantrans@es@mmclxxix{Deberías haber dicho cuando ingresaste a tus viñedos: ‘Esto es lo que Dios ha querido, todo el poder proviene de Dios’. Ya ves que poseo menos riqueza e hijos que tú.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmclxxx{Pero sabe que mi Señor me concederá algo mejor que tus viñedos [en la otra vida], y es posible que envíe del cielo una tempestad que los aniquile,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmclxxxi{o que el agua del río que hay entre ellos sea absorbida por la tierra y no puedas alcanzarla".\qt@no{41}}
\qt@newcmd\qurantrans@es@mmclxxxii{Y en efecto, sus frutos fueron destruidos. [Él] se golpeaba las manos lamentándose por lo que había invertido en ellos, y ahora estaban allí devastados. Entonces dijo: ``No debería haber igualado a otros junto a mi Señor".\qt@no{42}}
\qt@newcmd\qurantrans@es@mmclxxxiii{No tuvo quien pudiera salvarlo del designio de Dios, ni siquiera pudo defenderse a sí mismo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmclxxxiv{Eso evidenció que el verdadero triunfo proviene de Dios, la verdadera divinidad. Él es Quien mejor recompensa, y las obras que se realicen para buscar Su complacencia serán las que tengan mejor final.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmclxxxv{Exponles el ejemplo de la vida mundanal, y diles que es como el agua que envío del cielo, que riega la vegetación, pero luego ésta se seca y los vientos la dispersan. Dios tiene poder sobre todas las cosas.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmclxxxvi{Los bienes materiales y los hijos son parte de los encantos de la vida mundanal, [que éstos no los hagan olvidar de lo que Dios ha ordenado. Utilicen bien sus riquezas y eduquen correctamente a sus hijos,] pues las obras que a Dios Le complacen son las que perduran y tienen gran recompensa.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmclxxxvii{[Recuerden] el día que pulverice las montañas y la tierra quede allanada, los congregaré y nadie podrá ausentarse.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmclxxxviii{Cuando comparezcan ante tu Señor en fila, se les dirá: ``Se presentan ante Mí como los creé al nacer. ¿Acaso pensaban que no los iba a juzgar?"\qt@no{48}}
\qt@newcmd\qurantrans@es@mmclxxxix{A cada uno se le expondrá el registro de sus obras, y verás a los pecadores que por temor a su contenido dirán: ``¡Ay de nosotros! ¿Qué clase de registro es éste, que no deja de mencionar nada, ni grande ni pequeño?" Encontrarán mencionado todo cuanto hayan cometido, pero tu Señor no oprimirá a nadie.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcxc{[Recuerda] cuando dije a los ángeles: ``Hagan una reverencia ante Adán". La hicieron, excepto Iblís, que era un yinn, y desobedeció la orden de su Señor. ¿Acaso lo toman a él y a sus descendientes como protectores en vez de tomarme a Mí, a pesar de que son sus enemigos? ¡Qué pésimo sustituto eligen los que cometen la injusticia [de la incredulidad en Dios]!\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcxci{No los hice [a los ídolos ni al demonio] testigos de la creación de los cielos y de la Tierra, ni siquiera de su propia creación, puesto que no habría de tomar como auxiliadores a quienes desvían.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcxcii{El día que se les diga [a los idólatras]: ``Invoquen a aquellos que pretendían que eran Mis socios". Los invocarán, pero no obtendrán respuesta. Pondremos entre ellos un abismo que los separe.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcxciii{Los pecadores verán el Fuego y sabrán que caerán en él, pero no encontrarán escapatoria.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcxciv{Expuse en el Corán todo tipo de ejemplo, pero el ser humano es un gran discutidor.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcxcv{¿Qué impide a la gente llegar a creer ahora que les ha llegado la guía, o pedir a su Señor que perdone sus pecados, excepto [su deseo de] que la suerte de los pueblos [perversos] de la antigüedad les sobrevenga [también] a ellos, o que les sobrevenga el castigo [final] en el más allá?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcxcvi{Envié a los Mensajeros como albriciadores y advertidores. Los que se niegan a creer discuten con argumentos falsos para refutar la Verdad y se burlan de Mis versículos y advertencias.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcxcvii{¿Acaso hay alguien más injusto que quien habiéndosele expuesto los signos de su Señor, los niega y se olvida de lo que han hecho sus manos? He cubierto sus corazones y ensordecido sus oídos para que no lo entiendan [al Corán]. Aunque los invites a seguir la guía, si siguen así, no se encaminarán jamás.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcxcviii{Tu Señor es el Perdonador, Misericordioso. Si les quisiera dar su merecido por lo que cometieron les adelantaría el castigo. Pero he prefijado para ellos un día del que no podrán escapar.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcxcix{A otras ciudades de la antigüedad las destruí cuando comenzaron a cometer injusticias. Decreté una fecha para su destrucción.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcc{[Recuerda] cuando Moisés dijo a su fiel servidor: ``No desistiré hasta que llegue a la confluencia de los dos mares, aunque esto me lleve muchos años".\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcci{Pero cuando alcanzaron la confluencia se olvidaron del pescado, al que Dios resucitó y emprendió milagrosamente el camino hacia el mar.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmccii{Y cuando cruzaron más allá [de la confluencia] dijo [Moisés] a su servidor: ``Trae nuestra comida, que nos hemos agotado con este viaje".\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcciii{Dijo: ``Cuando nos refugiamos junto a la roca, allí me olvidé del pescado. Solo el demonio pudo hacer que me olvidara de contarte que milagrosamente saltó y emprendió el regreso hacia el mar".\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcciv{Dijo [Moisés]: ``Esa es la señal que buscábamos", y regresaron sobre sus huellas.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmccv{Encontraron a uno de Mis siervos [Al Jidr] a quien había agraciado con Mi misericordia y enseñado ciertos conocimientos [que Moisés no poseía].\qt@no{65}}
\qt@newcmd\qurantrans@es@mmccvi{Moisés le dijo: ``¿Puedo seguirte para que me enseñes la guía que se te ha enseñado?"\qt@no{66}}
\qt@newcmd\qurantrans@es@mmccvii{Respondió: ``No tendrás paciencia conmigo.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmccviii{¿Cómo podrías tener paciencia con algo que desconoces?"\qt@no{68}}
\qt@newcmd\qurantrans@es@mmccix{Dijo: ``Si Dios quiere, verás que seré paciente y no te desobedeceré".\qt@no{69}}
\qt@newcmd\qurantrans@es@mmccx{Dijo: ``Si me sigues, no me preguntes sobre lo que hago hasta que te haga mención de ello".\qt@no{70}}
\qt@newcmd\qurantrans@es@mmccxi{Entonces partieron hasta que abordaron un pequeño barco [y cuando llegaron a la costa] le hizo un boquete. Dijo [Moisés]: ``¿Has hecho un boquete para que se ahoguen quienes [estén viajando] a abordo? Has cometido algo grave".\qt@no{71}}
\qt@newcmd\qurantrans@es@mmccxii{Dijo: ``¿No te había dicho que no tendrías paciencia conmigo?"\qt@no{72}}
\qt@newcmd\qurantrans@es@mmccxiii{[Pero le respondió Moisés:] ``Disculpa mi olvido, y no me sometas a una prueba difícil".\qt@no{73}}
\qt@newcmd\qurantrans@es@mmccxiv{Entonces partieron hasta que se encontraron con un joven al que mató. Dijo [Moisés]: ``¿Has matado a una persona inocente sin que él haya matado a nadie? Has hecho algo terrible".\qt@no{74}}
\qt@newcmd\qurantrans@es@mmccxv{Dijo: ``¿No te había dicho que no tendrías paciencia conmigo?"\qt@no{75}}
\qt@newcmd\qurantrans@es@mmccxvi{Dijo [Moisés]: ``Si volviera a preguntarte acerca de algo después de esto, ya no me admitas como compañero [de viaje], te habría dado excusa suficiente".\qt@no{76}}
\qt@newcmd\qurantrans@es@mmccxvii{Partieron hasta que llegaron a un pueblo y pidieron a sus habitantes que los alimentaran, pero se negaron a darles hospitalidad. Luego encontraron en el pueblo un muro que estaba a punto de derrumbarse, y [Al Jidr] lo reconstruyó. Le dijo [Moisés]: ``Si hubieras querido, podrías haber pedido una paga por ello".\qt@no{77}}
\qt@newcmd\qurantrans@es@mmccxviii{Dijo: ``Aquí nos separamos. Pero te informaré sobre la interpretación de aquello con lo que no tuviste paciencia.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmccxix{En cuanto al barco, pertenecía a unos pobres que trabajaban en el mar, y quise averiarlo porque detrás de ellos venía un rey que se apoderaba por la fuerza de todos los barcos [que estuvieran en perfectas condiciones].\qt@no{79}}
\qt@newcmd\qurantrans@es@mmccxx{En cuanto al joven, sus padres eran creyentes y supe [por inspiración divina] que él les induciría al desvío y la incredulidad.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmccxxi{Quiso su Señor concederles en su lugar otro hijo más puro y bondadoso.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmccxxii{En cuanto al muro, pertenecía a dos jóvenes huérfanos del pueblo. Debajo de él había un tesoro que les pertenecía. Su padre había sido un hombre piadoso y tu Señor quiso que cuando alcanzaran la madurez encontraran el tesoro, como una misericordia de tu Señor. Yo no lo hice por iniciativa propia. Ésta es la interpretación de aquello sobre lo que no tuviste paciencia".\qt@no{82}}
\qt@newcmd\qurantrans@es@mmccxxiii{Te preguntan [¡oh, Mujámmad!] acerca de Dhul Qarnain. Diles: ``Voy a relatarles una parte de su historia".\qt@no{83}}
\qt@newcmd\qurantrans@es@mmccxxiv{Le concedí poder en la Tierra y le facilité los medios [para que siguiera el camino del bien].\qt@no{84}}
\qt@newcmd\qurantrans@es@mmccxxv{Él emprendió un camino\qt@no{85}}
\qt@newcmd\qurantrans@es@mmccxxvi{hasta alcanzar la parte más occidental, donde vio que el Sol se ocultaba en un manantial cálido, y encontró allí un pueblo [que cometía toda clase de injusticias]. Le inspiré: ``¡Oh, Dhul Qarnain! Puedes castigarlos o tratarlos con benevolencia".\qt@no{86}}
\qt@newcmd\qurantrans@es@mmccxxvii{Dijo: ``A quien persista en la opresión lo castigaré y luego deberá comparecer ante su Señor, Quien le infligirá un castigo severo.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmccxxviii{Pero en cambio, a quien crea y obre correctamente se le concederá una bella recompensa, y le corresponderé con un trato amable".\qt@no{88}}
\qt@newcmd\qurantrans@es@mmccxxix{Luego siguió otro camino\qt@no{89}}
\qt@newcmd\qurantrans@es@mmccxxx{hasta alcanzar el lugar más oriental, donde vio que el Sol salía sobre un pueblo que no tenía resguardo para protegerse de él.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmccxxxi{Tengo conocimiento que trató a estos como lo había hecho [con el pueblo anterior].\qt@no{91}}
\qt@newcmd\qurantrans@es@mmccxxxii{Luego siguió otro camino\qt@no{92}}
\qt@newcmd\qurantrans@es@mmccxxxiii{hasta llegar a un valle entre dos montañas, donde encontró un pueblo que apenas comprendía las palabras [de su idioma].\qt@no{93}}
\qt@newcmd\qurantrans@es@mmccxxxiv{Dijeron: ``¡Oh, Dhul Qarnain! Gog y Magog siembran la corrupción en la Tierra. ¿Podríamos pedirte que, a cambio de una retribución, levantes una muralla entre ellos y nosotros?"\qt@no{94}}
\qt@newcmd\qurantrans@es@mmccxxxv{Les dijo: ``Lo que mi Señor me ha concedido es superior [a lo que puedan ofrecerme]. Ayúdenme y erigiré una muralla entre ustedes y ellos.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmccxxxvi{Tráiganme piezas de hierro hasta cubrir el espacio de las dos montañas". Les dijo: ``Enciendan un fuego y soplen [con fuelles] hasta que esté incandescente"; y agregó: ``Luego tráiganme cobre fundido para derramarlo encima".\qt@no{96}}
\qt@newcmd\qurantrans@es@mmccxxxvii{[Gog y Magog] no pudieron escalarla ni tampoco perforarla.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmccxxxviii{Dijo [Dhul Qarnain]: ``Ésta es una misericordia de mi Señor, pero cuando llegue la promesa de mi Señor [el Día del Juicio] la reducirá a polvo. La promesa de mi Señor es verdadera".\qt@no{98}}
\qt@newcmd\qurantrans@es@mmccxxxix{Ese día dejaré que surjan [Gog y Magog] como oleadas chocando unas con otras [sembrando la corrupción y el exterminio], pero luego será tocada la trompeta y los congregaré a todos.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmccxl{Ese día expondré el Infierno a los que se negaron a creer.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmccxli{Aquellos que tenían sus ojos velados a Mi recuerdo [el Corán] y no soportaban oír [la verdad].\qt@no{101}}
\qt@newcmd\qurantrans@es@mmccxlii{¿Acaso piensan los que se niegan a creer que si toman algunos de Mis siervos como protectores en Mi lugar [eso podrá protegerlos del castigo]? Tengo preparado el Infierno como castigo para los que se negaron a creer [en las enseñanzas de los Profetas].\qt@no{102}}
\qt@newcmd\qurantrans@es@mmccxliii{Diles: ``¿Quieren que les haga saber quiénes son los que no obtendrán beneficio alguno por sus obras?"\qt@no{103}}
\qt@newcmd\qurantrans@es@mmccxliv{[Son] aquellos que desperdiciaron los esfuerzos que realizaron en este mundo mientras creían obrar el bien.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmccxlv{Son quienes no creen en los signos de su Señor ni que comparecerán ante Él. Sus obras habrán sido en vano y en el Día de la Resurrección no tendrán nada que pese en la balanza.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmccxlvi{Recibirán el Infierno como castigo por no haber creído y por haberse burlado de Mis signos y de Mis Mensajeros.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmccxlvii{Pero quienes hayan creído y obrado rectamente tendrán como morada los jardines del Paraíso,\qt@no{107}}
\qt@newcmd\qurantrans@es@mmccxlviii{donde vivirán por toda la eternidad y no desearán mudarse jamás.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmccxlix{Diles: ``Si los mares fueran tinta para escribir las Palabras de mi Señor, se agotaría el agua de los mares antes de que se agotaran las Palabras de mi Señor, aunque se trajeran otros mares de tinta [equivalentes a los que existen]".\qt@no{109}}
\qt@newcmd\qurantrans@es@mmccl{Diles: ``Yo no soy más que un hombre a quien se le ha revelado que solo deben adorar a Dios, su única divinidad. Quien anhele encontrarse con su Señor [y que Él esté complacido], que realice obras piadosas y que no adore a nadie más que a Él".\qt@no{110}}
\qt@newcmd\qurantrans@es@mmccli{\basmalahes Kaf. Ha’. Ia’. ‘Ain. Sad.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcclii{Esto es un relato de la misericordia que tuvo tu Señor con Su siervo Zacarías,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmccliii{cuando invocó a su Señor en secreto.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmccliv{Dijo: ``¡Señor mío! Mis huesos se han debilitado y mi cabeza se ha llenado de canas. Mis ruegos nunca fueron rechazados.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcclv{Temo por [la fe de] mi familia tras mi muerte, pues mi mujer siempre ha sido estéril. Concédeme un hijo\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcclvi{que me suceda y herede [la profecía] de la familia de Jacob. ¡Oh, Señor mío! Hazlo uno de aquellos con los que Tú estás complacido".\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcclvii{[Le dijo un ángel:] ``¡Oh, Zacarías! Te albricio con un hijo al que pondrás por nombre Juan. Nadie ha sido llamado así antes que él".\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcclviii{Dijo: ``¡Señor mío! ¿Cómo he de tener un hijo si mi mujer es estéril y yo he llegado ya a la vejez extrema?"\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcclix{Dijo [el ángel]: ``Así será, pues tu Señor dice: ‘Eso es fácil para Mí, te he creado antes, cuando no existías’".\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcclx{Dijo [Zacarías]: ``¡Señor mío! Concédeme una señal [de que mi esposa quedará embarazada]". Dijo: ``Tu señal será que no podrás hablar a la gente durante tres noches seguidas, a pesar de no tener impedimento".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcclxi{[Cumplida la señal, Zacarías] salió del oratorio hacia su gente [cuando su mujer quedó embarazada] y les indicó por señas que debían glorificar a Dios por la mañana y por la tarde.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcclxii{[Cuando su hijo alcanzó la pubertad, le dije:] ``¡Oh, Juan! Aférrate al Libro con firmeza". Le concedí sabiduría desde su infancia,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcclxiii{que fuera compasivo, puro y piadoso,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcclxiv{honraba a sus padres, no era soberbio ni desobediente.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcclxv{La paz fue con él el día que nació, el día que falleció y será con él el día que sea resucitado.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcclxvi{Recuerda [¡oh, Mujámmad!] la historia de María que se menciona en el libro, cuando se apartó de su familia para retirarse a un lugar al este\qt@no{16}}
\qt@newcmd\qurantrans@es@mmcclxvii{y puso un velo para apartarse de la vista de los hombres de su pueblo. Entonces le envié a Mi ángel, quien se le presentó con forma humana.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmcclxviii{Ella dijo: ``Me refugio en el Compasivo de ti, [apártate de aquí] si es que tienes temor de Dios".\qt@no{18}}
\qt@newcmd\qurantrans@es@mmcclxix{Le dijo: ``Soy un enviado de tu Señor para agraciarte con un hijo puro".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmcclxx{Ella dijo: ``¿Cómo voy a tener un hijo si no me ha tocado ningún hombre ni he fornicado?"\qt@no{20}}
\qt@newcmd\qurantrans@es@mmcclxxi{Le dijo [el ángel]: ``Así será, pues tu Señor dice: ‘Eso es fácil para Mí. Lo convertiré [a tu hijo] en un milagro y una misericordia para la humanidad. Es un asunto decidido’".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmcclxxii{Cuando se sintió embarazada, decidió retirarse a un lugar apartado.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmcclxxiii{Los dolores de parto la llevaron junto al tronco de una palmera. Exclamó: ``Preferiría haber muerto antes que esto, y así hubiera sido olvidada completamente".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmcclxxiv{Entonces [el ángel] la llamó desde abajo [del valle]: ``No estés triste, tu Señor ha hecho fluir debajo de ti un arroyo.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmcclxxv{Sacude el tronco de la palmera y caerán sobre ti dátiles frescos.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmcclxxvi{Come, bebe y anímate. Pero cuando veas a alguien dile: ‘He realizado un voto de silencio al Compasivo, y no hablaré hoy con ninguna persona’".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmcclxxvii{Se presentó ante su pueblo llevándolo en brazos [a Jesús]. Le dijeron: ``¡Oh, María! Has hecho algo abominable.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmcclxxviii{¡Tú desciendes de Aarón! Tu padre no era un hombre deshonesto ni tu madre una fornicadora".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmcclxxix{Ella lo señaló [al niño], y entonces le dijeron: ``¿Cómo vamos a hablar con un niño que aún está en la cuna?"\qt@no{29}}
\qt@newcmd\qurantrans@es@mmcclxxx{Entonces [Jesús] habló: ``Soy un siervo de Dios, Él me revelará el Libro y hará de mí un Profeta.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmcclxxxi{Seré bendecido dondequiera que me encuentre, y me ha encomendado hacer la oración, dar caridad mientras viva,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmcclxxxii{honrar a mi madre, y no ser arrogante ni insolente.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmcclxxxiii{La paz fue conmigo el día que nací, el día que muera y el día que sea resucitado".\qt@no{33}}
\qt@newcmd\qurantrans@es@mmcclxxxiv{Ese es Jesús, hijo de María, la verdad sobre la que ellos discuten.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmcclxxxv{No es propio de Dios tener un hijo. ¡Glorificado sea! Cuando decide algo dice: ``¡Sé!", y es.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmcclxxxvi{[Dijo Jesús:] ``Dios es mi Señor y el de ustedes, ¡adórenlo! Ese es el sendero recto".\qt@no{36}}
\qt@newcmd\qurantrans@es@mmcclxxxvii{Pero discreparon las sectas sobre él. ¡Cuán desdichados serán ese día los que negaron la verdad cuando comparezcan [ante Dios] en un día terrible!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmcclxxxviii{Oirán y verán muy bien [su error] el día que comparezcan ante Mí. Pero los que cometen injusticias [atribuyendo un hijo a Dios] en esta vida están evidentemente extraviados.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmcclxxxix{Adviérteles acerca del día que se lamenten, cuando la sentencia sea cumplida. Pero ellos, a pesar de esto, siguen indiferentes y no creen.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmccxc{Yo heredaré la Tierra y a quienes están sobre ella. Ante mí regresarán.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmccxci{Nárrales [¡oh, Mujámmad!] la historia de Abraham que se menciona en el Libro. Era un hombre veraz, un Profeta.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmccxcii{Cuando [Abraham] dijo a su padre: ``¡Oh, padre mío! ¿Por qué adoras a lo que no oye ni ve ni puede beneficiarte en absoluto?\qt@no{42}}
\qt@newcmd\qurantrans@es@mmccxciii{¡Oh, padre mío! Se me ha revelado un conocimiento que tú no tienes. Sígueme, y te guiaré por el sendero recto.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmccxciv{¡Oh, padre mío! No adores al demonio, porque el demonio fue desobediente con el Compasivo.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmccxcv{¡Oh, padre mío! Temo que te alcance un castigo del Compasivo y seas de los que acompañen al demonio [al Infierno]".\qt@no{45}}
\qt@newcmd\qurantrans@es@mmccxcvi{Dijo [su padre]: ``¡Oh, Abraham! ¿Acaso rechazas a mis ídolos? Si no dejas de hacerlo te lapidaré. Aléjate de mí por buen tiempo".\qt@no{46}}
\qt@newcmd\qurantrans@es@mmccxcvii{Dijo [Abraham]: ``¡Que la paz sea sobre ti! Pediré perdón por ti a mi Señor. Él ha sido generoso conmigo.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmccxcviii{Me alejaré de ustedes y de cuanto invocan en vez de Dios, e imploraré a mi Señor, y espero que mis ruegos a mi Señor no sean rechazados".\qt@no{48}}
\qt@newcmd\qurantrans@es@mmccxcix{Cuando se apartó de ellos y de cuanto adoraban en vez de Dios, lo agracié con [sus hijos] Isaac y Jacob, y a ambos los designé Profetas.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmccc{Los agracié con Mi misericordia y que fueran recordados siempre con gran respeto.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmccci{Nárrales [oh, Mujámmad] la historia de Moisés mencionada en el Libro. Él fue elegido para ser Profeta y Mensajero.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcccii{Lo llamé desde la ladera derecha del monte e hice que se aproximara para hablarle en forma confidencial.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmccciii{Hice que, por Mi misericordia, su hermano Aarón fuera también un Profeta.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmccciv{Nárrales [oh, Mujámmad] la historia de Ismael mencionada en el Libro. Siempre cumplió su palabra, fue Profeta y Mensajero.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcccv{Invitaba a su gente a realizar la oración y dar caridad, y alcanzó la complacencia de Dios.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcccvi{Nárrales la historia de Enoc que se menciona en el Libro. Fue un hombre veraz, y Profeta.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcccvii{Lo elevé a un lugar sublime.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcccviii{Ellos son a quienes Dios ha agraciado: Profetas descendientes de Adán, descendientes de los que transportamos [en el arca] con Noé, de los descendientes de Abraham y de Israel [Jacob], entre los que guie y elegí. Cuando se les recitaban los versículos del Compasivo, se prosternaban llorando conmovidos.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcccix{Pero vinieron después de ellos generaciones que descuidaron la oración y siguieron sus pasiones, por lo que tendrán una merecida condena.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcccx{Salvo quienes se arrepintieron, creyeron y obraron rectamente. Éstos ingresarán al Paraíso y no serán oprimidos en absoluto.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcccxi{[Entrarán] a los Jardines del Edén, prometidos por el Compasivo a Sus siervos [en las revelaciones] de lo oculto. Su promesa será cumplida.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcccxii{No oirán frivolidades allí, sino saludos de paz, y recibirán su sustento por la mañana y por la tarde.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcccxiii{Ése es el Paraíso que haremos heredar a quienes de Mis siervos hayan sido piadosos.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcccxiv{[Dice el ángel Gabriel:] ``Los ángeles no descienden sino por orden de tu señor. Él conoce nuestro presente, pasado y futuro. Tu Señor nunca olvida.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcccxv{Es el Señor de los cielos, de la Tierra y de cuanto hay entre ambos. Adóralo y persevera en Su adoración. ¿Conoces a alguien similar a Él?"\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcccxvi{El ser humano dice: ``¿Acaso luego de morir seré resucitado?"\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcccxvii{¿Acaso no recuerda el ser humano que lo creé por primera vez cuando no era nada?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcccxviii{¡Por tu Señor! Los congregaré junto con los demonios [que adoraban], y he de hacerlos comparecer de rodillas alrededor del Infierno [para ser juzgados].\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcccxix{Luego sacaré de cada comunidad a aquellos que hayan sido más insolentes con el Compasivo.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcccxx{Yo sé mejor que nadie quiénes son los que más merecen ser arrojados al Infierno.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcccxxi{Todos ustedes lo contemplarán [al Infierno], y esa es una determinación irrevocable de tu Señor.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcccxxii{Luego, salvaré a los piadosos y dejaré en él a los que cometieron la injusticia [de la idolatría] de rodillas.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcccxxiii{Cuando se les recitan Mis claros versículos, los que se niegan a creer dicen con arrogancia a los creyentes: ``¿Quién posee de nosotros moradas más placenteras y mejores lugares de encuentro?"\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcccxxiv{Pero, ¿a cuántas generaciones que les precedieron, de mayor riqueza y mejor aspecto, he destruido?\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcccxxv{Diles: ``A quienes se encuentren desviados, el Compasivo los dejará continuar en el desvío hasta que les acontezca lo que Dios ha deparado para ellos: su destrucción en esta vida o luego de comparecer en el Día del Juicio. Entonces sabrán quiénes se encuentran en peor situación y quién tiene el ejército más débil".\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcccxxvi{Dios encaminará a quienes siguieron la guía. Las obras que a Dios Le complacen son las que realmente perduran y las que tienen una gran recompensa.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcccxxvii{¿Acaso observas a quien no cree en Mis signos y dice: ``Me serán concedidos bienes materiales e hijos [cuando sea resucitado]"?\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcccxxviii{¿Acaso tiene conocimiento de lo oculto o tiene un pacto con el Compasivo?\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcccxxix{¡Claro que no! Registraré lo que dice y le prolongaré [por ello] el castigo.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcccxxx{Yo seré Quien herede sus bienes materiales e hijos y [el Día del Juicio] comparecerá completamente solo.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcccxxxi{[Los idólatras] tomaron a los ídolos como divinidades en lugar de Dios para que les dieran protección.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcccxxxii{¡Pero no! [Estos ídolos] negarán que hayan sido objeto de culto y se convertirán en sus adversarios.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcccxxxiii{¿Acaso no ves que he enviado demonios sobre los incrédulos para que les induzcan a cometer el mal?\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcccxxxiv{No esperes que el castigo los azote antes de tiempo; que ya tienen sus días contados.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcccxxxv{El día que congregue a las delegaciones de piadosos ante el Compasivo,\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcccxxxvi{y conduzca a los pecadores hacia el Infierno sedientos.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcccxxxvii{No tendrán quién interceda por ellos, salvo quienes hayan asumido el compromiso con el Compasivo [de creer que Él es la única divinidad con derecho a ser adorada].\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcccxxxviii{Dicen: ``El Compasivo tuvo un hijo".\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcccxxxix{Han proferido algo terrible;\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcccxl{los cielos estuvieron a punto de hendirse, la Tierra de abrirse y las montañas de caer derrumbadas,\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcccxli{porque Le atribuyeron un hijo al Compasivo.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcccxlii{No es propio [de la grandiosidad] del Compasivo tener un hijo.\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcccxliii{Todos los que habitan en los cielos y en la Tierra se presentarán sumisos ante el Compasivo.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcccxliv{Los ha enumerado y contado perfectamente.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcccxlv{Todos se presentarán solos ante Él el Día del Juicio.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcccxlvi{El Compasivo hará que quienes hayan creído y obrado rectamente sean amados [por la gente].\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcccxlvii{Te he facilitado [el Corán] revelándotelo [oh, Mujámmad] en tu idioma para que albricies con él a los piadosos y adviertas a tus enemigos.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcccxlviii{A muchas generaciones que los precedieron las he destruido. ¿Acaso puedes ver a alguno de ellos u oír sus murmullos?\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcccxlix{\basmalahes Ta’. Ha’.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcccl{No te he revelado el Corán para que te agobie,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcccli{sino que es una exhortación para quienes tienen temor [de Dios].\qt@no{3}}
\qt@newcmd\qurantrans@es@mmccclii{[El Corán] fue revelado por Quien creó la Tierra y los altos cielos;\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcccliii{el Compasivo, que se estableció sobre el Trono.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcccliv{A Él pertenece cuanto hay en los cielos y en la Tierra, lo que existe entre ellos y lo que hay bajo la tierra.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmccclv{Dios conoce lo que pronuncias en voz alta, las confidencias que dices en voz baja y lo que está aún más oculto [los pensamientos].\qt@no{7}}
\qt@newcmd\qurantrans@es@mmccclvi{¡Dios! No hay más divinidad que Él. A Él pertenecen los nombres [y los atributos] más sublimes.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmccclvii{¿Conoces la historia de Moisés?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmccclviii{Cuando vio un fuego y dijo a su familia: ``Permanezcan aquí, pues he visto un fuego y tal vez pueda traerles una brasa encendida o encuentre junto al fuego quién pueda indicarnos [el camino]".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmccclix{Cuando llegó a él, una voz lo llamó: ``¡Oh, Moisés!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmccclx{Yo soy tu Señor; quítate las sandalias, pues estás en el valle sagrado de Tuwa,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmccclxi{Y Yo te he elegido; escucha lo que voy a revelarte.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmccclxii{Yo soy Al-lah, y no hay más divinidad que Yo. Adórame solo a Mí y haz la oración para recordarme.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmccclxiii{El Día de la Resurrección es indubitable, y nadie salvo Dios sabe cuándo llegará. Ese día cada alma recibirá la recompensa o el castigo que se merezca por sus obras.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmccclxiv{No te dejes seducir por quienes no creen en la resurrección y siguen sus pasiones, porque serás de los que pierdan.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmccclxv{¿Qué es lo que tienes en tu diestra? ¡Oh, Moisés!"\qt@no{17}}
\qt@newcmd\qurantrans@es@mmccclxvi{Respondió: ``Es mi bastón. Me sirve de apoyo, y con él vareo los árboles para que mi ganado coma [de su follaje]; además de otros usos".\qt@no{18}}
\qt@newcmd\qurantrans@es@mmccclxvii{Dijo [Dios]: ``Arrójalo, ¡oh, Moisés!"\qt@no{19}}
\qt@newcmd\qurantrans@es@mmccclxviii{Lo arrojó, y este se convirtió en una serpiente que reptaba.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmccclxix{Dijo [Dios]: ``Recógela y no temas, pues la volveré a su forma original.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmccclxx{Introduce tu mano en tu costado y saldrá blanca, resplandeciente, sin defecto alguno. Ese será otro milagro.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmccclxxi{Te he mostrado algunos de Mis mayores milagros.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmccclxxii{Ve ante el Faraón, pues se ha extralimitado".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmccclxxiii{Dijo [Moisés]: ``¡Oh, Señor mío! Abre mi corazón [y dame valor],\qt@no{25}}
\qt@newcmd\qurantrans@es@mmccclxxiv{facilita mi misión,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmccclxxv{suelta el nudo que hay en mi lengua\qt@no{27}}
\qt@newcmd\qurantrans@es@mmccclxxvi{para que comprendan mis palabras,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmccclxxvii{[¡Señor!] Designa a alguien de mi familia para que me ayude\qt@no{29}}
\qt@newcmd\qurantrans@es@mmccclxxviii{¡Que sea mi hermano Aarón!,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmccclxxix{para que con él me sienta fortalecido,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmccclxxx{y asócialo en mi misión\qt@no{32}}
\qt@newcmd\qurantrans@es@mmccclxxxi{para que Te glorifiquemos\qt@no{33}}
\qt@newcmd\qurantrans@es@mmccclxxxii{y Te recordemos mucho.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmccclxxxiii{Tú bien ves que necesitamos de Ti".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmccclxxxiv{Dijo [Dios]: ``Te ha sido concedido lo que pides, ¡oh, Moisés!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmccclxxxv{Ya te había agraciado anteriormente,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmccclxxxvi{cuando le inspiré a tu madre:\qt@no{38}}
\qt@newcmd\qurantrans@es@mmccclxxxvii{‘Deposítalo en un cesto y déjalo en el río, que la corriente lo llevará hasta una orilla donde será recogido por un enemigo Mío y suyo [el Faraón]’. Desperté cariño hacia ti [entre los que te encontraron], para que crecieras educado bajo Mi observancia.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmccclxxxviii{Cuando tu hermana, que seguía tus rastros, le dijo [al Faraón]: ‘¿Acaso quieres que te indique a alguien que puede encargarse de cuidarlo?’ Y así te devolví a tu madre para que se tranquilizara y no estuviera triste. [También te concedí una gracia] cuando [involuntariamente] mataste a un hombre [del pueblo del Faraón] y te salvé de que tomaran represalias contra ti. Te he probado con pruebas difíciles. Luego permaneciste unos años en Madián y ahora has regresado aquí, tal como estaba decretado, ¡oh, Moisés!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmccclxxxix{Te he elegido [para que seas Mi Mensajero].\qt@no{41}}
\qt@newcmd\qurantrans@es@mmcccxc{Vayan tú y tu hermano acompañados de Mis milagros, y no descuiden Mi recuerdo.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmcccxci{Preséntense ante el Faraón, pues se ha extralimitado,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmcccxcii{pero háblenle cortésmente, para hacerlo entrar en razón o sienta temor de Dios".\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcccxciii{Dijeron: ``¡Oh, Señor nuestro! Tememos que se violente y abuse de nosotros".\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcccxciv{Dijo [Dios]: ``No tengan miedo, pues Yo estoy con ustedes escuchando y observando todo.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcccxcv{Vayan ante él y díganle: ‘Somos Mensajeros enviados por tu Señor, para que dejes ir con nosotros a los Hijos de Israel y no los tortures más. Hemos venido con un milagro de tu Señor. Quien sigua la guía estará a salvo.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcccxcvi{Nos ha sido revelado que quien desmienta y rechace [el Mensaje] será castigado’".\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcccxcvii{Dijo [el Faraón]: ``Respóndeme, ¡oh, Moisés! ¿Y quién es su Señor?"\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcccxcviii{Dijo [Moisés]: ``Nuestro Señor es Quien creó todo con una naturaleza particular, y luego lo encamina [para que cumpla su destino]".\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcccxcix{Entonces, preguntó [el Faraón]: ``¿Cuál fue el destino de las generaciones anteriores?"\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcd{Dijo [Moisés]: ``Solo mi Señor lo sabe, y Él lo tiene registrado todo en un Libro. Mi Señor no se equivoca nunca ni se olvida de nada.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcdi{Él nos dispuso la Tierra como un lecho [propicio para habitarlo] y nos trazó en ella caminos, e hizo descender agua del cielo para que con ella broten diferentes plantas.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcdii{Coman de ellas y apacienten sus ganados. En esto hay signos para los dotados de entendimiento.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcdiii{De ella [la tierra] los he creado, a ella los haré retornar [cuando mueran], y de ella los haré surgir nuevamente [el Día de la Resurrección]".\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcdiv{Le mostré [al Faraón] todos Mis milagros, pero los desmintió y se rehusó a creer.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcdv{Dijo [el Faraón]: ``¡Oh, Moisés! ¿Acaso viniste a expulsarnos de nuestra tierra con tu hechicería?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcdvi{Nosotros te traeremos una hechicería igual que la tuya, solo fija un día para que tú y nosotros nos encontremos en un lugar y que nadie falte".\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcdvii{Dijo [Moisés]: ``Nuestra cita será el día de la fiesta, cuando la gente se congregue a la media mañana".\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcdviii{Entonces el Faraón se retiró y se dedicó a reclutar hechiceros. Luego, el día de la cita, concurrió.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcdix{Moisés les dijo [a los hechiceros]: ``¡Ay de ustedes! No inventen mentiras contra Dios, pues los aniquilará con Su castigo: Los que inventan mentiras acerca de Dios serán los perdedores".\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcdx{Entonces, [los hechiceros] debatieron entre ellos acerca de Moisés, y deliberaron secretamente.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcdxi{Dijeron: ``Estos son solo dos hechiceros que con su magia quieren expulsarlos de su tierra y acabar con sus nobles costumbres.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcdxii{[Oh, hechiceros de Egipto,] Decidan su plan a seguir, y luego acudan como un solo cuerpo: pues, ¡quien sea superior hoy, ha de conseguir prosperidad!"\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcdxiii{Dijeron: ``¡Oh, Moisés! ¿Arrojas tú o lo hacemos nosotros primero?"\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcdxiv{Dijo [Moisés]: ``Arrojen ustedes primero". Entonces arrojaron sus cuerdas y varas, y por el hechizo que habían empleado, estas parecían moverse [como si fueran verdaderas serpientes].\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcdxv{[Al ver esto,] Moisés sintió temor en su interior,\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcdxvi{pero le dije: ``No tengas temor, porque tú serás el vencedor.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcdxvii{Arroja lo que tienes en tu diestra, que anulará lo que ellos hicieron, pues solo se trata de una hechicería, y los hechiceros jamás han de triunfar".\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcdxviii{Los hechiceros [al percibir que el milagro que acompañaba a Moisés no era magia] se postraron y exclamaron: ``Creemos en el Señor de Aarón y Moisés".\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcdxix{Dijo [el Faraón enfurecido]: ``¿Acaso van a creer en él sin que yo se los haya autorizado? Seguramente él es su maestro que les ha enseñado la magia. Ordenaré que se les ampute la mano y el pie opuestos, y luego los haré clavar sobre troncos de palmera. Así sabrán quién es el que puede infligir el castigo más severo y duradero".\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcdxx{Dijeron: ``No antepondremos nuestra lealtad a ti a los milagros evidentes que hemos presenciado, y [menos aún] a Quien nos creó. Haz pues con nosotros lo que has decidido; tú solo puedes condenarnos en esta vida.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcdxxi{Creemos en nuestro Señor, para que nos perdone nuestros pecados y los hechizos que nos obligaste a hacer. La recompensa de Dios es mejor y más duradera".\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcdxxii{Quien se presente ante su Señor siendo culpable tendrá el Infierno como castigo, en el que no podrá morir [para librarse del tormento] ni vivir [sin padecerlo].\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcdxxiii{En cambio, quien se presente ante su Señor creyendo en Él y habiendo obrado rectamente, obtendrá los más altos grados [en el Paraíso].\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcdxxiv{Morarán eternamente en los Jardines del Edén, bajo los cuales corren ríos. Esa será la recompensa de quienes se purifiquen.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcdxxv{Le ordené a Moisés: ``Sal por la noche con Mis siervos, y abre [por Mi voluntad] el mar dejándoles un camino de tierra firme [por donde puedan huir], y no tengan temor de que los alcancen ni tampoco de morir ahogados".\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcdxxvi{Cuando el Faraón y su ejército siguieron [a los creyentes], el mar se los tragó.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcdxxvii{El Faraón, en lugar de guiar a su pueblo, lo llevó al extravío.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcdxxviii{¡Oh, Hijos de Israel! [Recuerden cuando] los salvé de sus enemigos, los cité en la ladera derecha del monte [para que pudieran presenciar Mis milagros], y les envié el maná y las codornices.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcdxxix{Coman de las cosas buenas que les he proveído, pero no se extralimiten, pues Mi ira recaería sobre ustedes. Aquel sobre quien caiga Mi ira será un desdichado.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcdxxx{Yo soy Perdonador con quienes se arrepienten, creen, obran rectamente y se encaminan [por el sendero recto].\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcdxxxi{[Cuando Moisés se presentó a la cita, Dios le dijo:] ``¡Oh, Moisés! ¿Qué te ha urgido a presentarte dejando atrás a tu pueblo?"\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcdxxxii{Dijo: ``Ellos vienen detrás mío; solo me adelanté para complacerte, ¡oh, Señor mío!"\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcdxxxiii{Dijo [Dios]: ``He puesto a prueba a tu pueblo después que los dejaste, y el samaritano los extravió".\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcdxxxiv{Cuando Moisés regresó ante su pueblo enojado y avergonzado, les dijo: ``¡Oh, pueblo mío! ¿Acaso su Señor no les ha hecho una promesa hermosa? ¿Acaso les parece que me ausenté por mucho tiempo? ¿Acaso quieren que la ira de su Señor se desate sobre ustedes, y por ello quebrantaron la promesa que me hicieron?"\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcdxxxv{Dijeron: ``No quebrantamos la promesa que te hicimos intencionalmente, sino que cuando arrojamos al fuego las joyas del pueblo [del Faraón] que teníamos en nuestro poder, el samaritano también las arrojó,\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcdxxxvi{y fundió las joyas dándoles la forma de un becerro que emitía un sonido como un mugido, y entonces exclamaron [el samaritano y sus seguidores]: ‘Esta es nuestra divinidad y la de Moisés, pero Moisés la ha olvidado’".\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcdxxxvii{¿Acaso no vieron que no podía hablarles, y no podía dañarlos ni beneficiarlos?\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcdxxxviii{Pero antes [que regresara Moisés] Aarón les había advertido: ``¡Oh, pueblo mío! Se los está poniendo a prueba con eso. Su verdadero Señor es el Compasivo, síganme y obedezcan mis órdenes".\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcdxxxix{Respondieron: ``No dejaremos de postrarnos ante él hasta que vuelva Moisés".\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcdxl{Dijo [Moisés]: ``¡Oh, Aarón! ¿Qué te impidió, cuando viste que se desviaban,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcdxli{buscarme [para informarme lo sucedido]? ¿Es que desobedeciste mi orden [de velar por ellos]?"\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcdxlii{Dijo [Aarón]: ``¡Oh, hermano mío! No me recrimines agarrándome por la barba y la cabeza. Tuve miedo de que [si los dejaba para salir a buscarte] me dijeras: ‘Lo que has hecho es causar la discordia y la división entre los Hijos de Israel [al haberte ausentado], y no has cumplido con lo que te ordené’".\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcdxliii{Dijo [Moisés]: ``Y tú Samaritano, ¿qué has hecho?"\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcdxliv{Dijo: ``Vi algo que ellos no pudieron ver. Entonces tomé un puñado de tierra de las huellas que dejó el mensajero y lo arrojé [sobre las joyas cuando se fundían]. Así me lo sugirió mi alma".\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcdxlv{Dijo [Moisés]: ``Aléjate de nosotros; tu castigo en esta vida será que digas: ‘No se me acerquen’ [y vivirás solo], pero te aguarda una cita ineludible [el Día del Juicio]. Observa [lo que haremos con] lo que consideraste tu divinidad, y a lo cual has adorado: Lo quemaremos y esparciremos sus restos en el mar.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcdxlvi{Tu única divinidad es Dios. No existe nada ni nadie con derecho a ser adorado salvo Él, y todo lo abarca con Su conocimiento".\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcdxlvii{Así es como te he revelado [¡oh, Mujámmad!] las historias de quienes te precedieron, porque te he concedido el Mensaje.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmcdxlviii{Quien se aparte de él, llevará una pesada carga el Día del Juicio,\qt@no{100}}
\qt@newcmd\qurantrans@es@mmcdxlix{que cargará por toda la eternidad. ¡Qué pésima carga tendrán que soportar el Día de la Resurrección!\qt@no{101}}
\qt@newcmd\qurantrans@es@mmcdl{Ese día, cuando la trompeta sea soplada, reuniré a los culpables, y sus miradas estarán ensombrecidas.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmcdli{Se susurrarán unos a otros, y algunos dirán: ``Solo permanecimos [en la vida mundanal] diez días".\qt@no{103}}
\qt@newcmd\qurantrans@es@mmcdlii{Y otros, los más sensatos, dirán: ``Solo permanecimos un día." Bien sé lo que dicen.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmcdliii{Te preguntan [¡oh, Mujámmad!] qué ocurrirá con las montañas [el Día del Juicio]. Diles: ``Mi Señor las reducirá a polvo,\qt@no{105}}
\qt@newcmd\qurantrans@es@mmcdliv{y las convertirá en inmensas llanuras.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmcdlv{No habrá valles ni colinas".\qt@no{107}}
\qt@newcmd\qurantrans@es@mmcdlvi{Ese día todos acudirán al llamado del [ángel] pregonero, y nadie errará el camino; las voces callarán ante el Misericordioso, y solo se oirá el sonido de sus pasos.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmcdlvii{Entonces, ninguna intercesión será aceptada, salvo la de quien el Misericordioso quiera y sus palabras le sean aceptadas.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmcdlviii{Dios bien conoce el pasado y el futuro, mientras que ellos nunca podrán alcanzar este conocimiento.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmcdlix{[El Día del Juicio] todos los rostros se humillarán ante Dios, el Viviente, Quien se basta a Sí mismo y se ocupa de toda la creación. Estarán condenados al castigo quienes sean culpables de injustica [idolatría].\qt@no{111}}
\qt@newcmd\qurantrans@es@mmcdlx{En cambio, el creyente que haya obrado rectamente no ha de temer que lo traten injustamente ni lo priven de la recompensa [de sus buenas obras].\qt@no{112}}
\qt@newcmd\qurantrans@es@mmcdlxi{He revelado el Corán en idioma árabe, y expuse en él toda clase de advertencias para que tengan temor de Dios o los haga reflexionar.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmcdlxii{¡Exaltado sea Dios! El único Soberano real. No te adelantes [¡oh, Mujámmad!] a repetir lo que te es revelado del Corán hasta que [el ángel Gabriel] concluya [de recitarlo], y di: ``¡Oh, Señor mío! Acrecienta mi conocimiento".\qt@no{114}}
\qt@newcmd\qurantrans@es@mmcdlxiii{Ya antes había tomado un compromiso de Adán [de no prestarse a los susurros del demonio], pero lo olvidó [y comió del árbol prohibido], no tuvo una resolución firme.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmcdlxiv{[Recuerda] cuando dije a los ángeles: ``¡Hagan una reverencia ante Adán!" Todos la hicieron excepto Iblís.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmcdlxv{Dije: ``¡Oh, Adán! Este [el demonio] es un enemigo para ti y para tu esposa; que no los haga expulsar del Paraíso pues serás un desdichado.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmcdlxvi{En el Paraíso no padecerás hambre ni te faltará con qué cubrir tu desnudez,\qt@no{118}}
\qt@newcmd\qurantrans@es@mmcdlxvii{ni tampoco sufrirás sed ni calor".\qt@no{119}}
\qt@newcmd\qurantrans@es@mmcdlxviii{Pero el demonio lo sedujo diciéndole: ``¡Oh, Adán! ¿Quieres que te indique el árbol de la inmortalidad y el poder eterno?"\qt@no{120}}
\qt@newcmd\qurantrans@es@mmcdlxix{Cuando ambos comieron del árbol, advirtieron su desnudez y comenzaron a cubrirse con hojas del Paraíso. Adán desobedeció a su Señor y cometió un pecado.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmcdlxx{Más tarde, su Señor lo eligió [como Profeta], lo perdonó y lo guió.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmcdlxxi{Dijo [Dios]: ``¡Desciendan del Paraíso [y habiten la Tierra]! Serán enemigos unos de otros. Cuando les llegue de Mí una guía, quienes sigan Mi guía no se extraviarán [en esta vida] ni serán desdichados [en el más allá].\qt@no{123}}
\qt@newcmd\qurantrans@es@mmcdlxxii{Pero quien se aleje de Mi recuerdo [Mi religión] llevará una vida de tribulación, y el Día del Juicio lo resucitaré ciego.\qt@no{124}}
\qt@newcmd\qurantrans@es@mmcdlxxiii{Y entonces dirá: ‘¡Oh, Señor mío! ¿Por qué me has resucitado ciego, si antes veía?’"\qt@no{125}}
\qt@newcmd\qurantrans@es@mmcdlxxiv{Dirá [Dios]: ``Así como cuando te llegaron Mis signos los ignoraste, hoy tú serás ignorado".\qt@no{126}}
\qt@newcmd\qurantrans@es@mmcdlxxv{Así voy a retribuir a quienes se extralimitaron y no creyeron en los signos de su Señor. Pero el castigo de la otra vida será aún más severo y duradero.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmcdlxxvi{¿Acaso no se les ha evidenciado [a quienes rechazan este Mensaje] cuántas civilizaciones destruí, siendo que ellos pueden observar sus ruinas? En ello hay signos para los dotados de entendimiento.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmcdlxxvii{De no ser porque tu Señor ha decretado [retrasarles el castigo hasta el Día del Juicio a quienes te desmientan] y ha prefijado para cada ser su plazo [de vida durante la cual puede arrepentirse], ya los habría aniquilado.\qt@no{129}}
\qt@newcmd\qurantrans@es@mmcdlxxviii{Ten paciencia ante sus injurias, y glorifica con alabanzas a tu Señor antes de la salida del Sol y antes del ocaso, durante la noche y durante los extremos del día, para que así [Dios te retribuya con una gran recompensa y] quedes complacido.\qt@no{130}}
\qt@newcmd\qurantrans@es@mmcdlxxix{No codicies [¡oh, Mujámmad!] aquello conque he agraciado a algunos de los ricos [de los incrédulos], pues son solo placeres de esta vida mundanal con los que los ponemos a prueba. La recompensa que tu Señor tiene reservada es mejor y más duradera.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmcdlxxx{Ordena a tu familia practicar la oración prescrita y sé constante en su cumplimiento. Que el trabajo en búsqueda del sustento no te haga descuidar el cumplimiento de lo que Dios ha prescrito, porque soy Yo quien los sustento. La bienaventuranza es para los piadosos.\qt@no{132}}
\qt@newcmd\qurantrans@es@mmcdlxxxi{[Los que rechazan el Mensaje] dicen: ``¿Por qué no nos muestra un milagro de su Señor [que compruebe su profecía]?" Pero si ya les han llegado pruebas evidentes en los primeros Libros revelados.\qt@no{133}}
\qt@newcmd\qurantrans@es@mmcdlxxxii{Y si hubiera decretado destruirlos con un castigo antes de la llegada de Mi Mensajero, habrían dicho: ``¡Oh, Señor nuestro! Si nos hubieras enviado un Mensajero habríamos seguido Tu Mensaje antes de ser humillados [con el castigo] y desdichados para siempre".\qt@no{134}}
\qt@newcmd\qurantrans@es@mmcdlxxxiii{Diles [¡oh, Mujámmad!]: ``Todos esperan [saber qué ocurrirá]; sigan esperando, que ya sabrán quiénes están en el camino recto y siguen la guía".\qt@no{135}}
\qt@newcmd\qurantrans@es@mmcdlxxxiv{\basmalahes Se aproxima la hora en que la gente deberá comparecer [ante Dios para ser juzgada], sin embargo se muestran indiferentes, lejanos.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcdlxxxv{Siempre que les llega de su Señor una nueva revelación, la escuchan y la toman a broma,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcdlxxxvi{con sus corazones distraídos. Los injustos dicen entre sí en secreto: ``[Mujámmad] no es más que un mortal al igual que nosotros. [Y recriminando a los que lo escuchaban dicen:] ¿Cómo aceptan ser cautivados por la magia de sus palabras si saben [que es un farsante]?"\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcdlxxxvii{Diles [¡oh, Mujámmad!]: ``Mi Señor bien sabe todo lo que se dice en el cielo y en la Tierra. Él todo lo oye, todo lo sabe".\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcdlxxxviii{Y dicen [otros idólatras]: ``[El Corán] no es más que sueños incoherentes, o [palabras que] él mismo ha inventado, o es un poeta. Que nos muestre un milagro como lo hicieron los primeros [Mensajeros, si es verdad lo que dice]".\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcdlxxxix{Ninguno de los pueblos a los que exterminé creyeron [al ver los milagros], ¿acaso éstos van a creer? [No lo harán].\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcdxc{No envié antes de ti sino hombres a quienes transmití Mi revelación. Pregunten a la gente de conocimiento si es que no saben.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcdxci{No les di [a los Mensajeros] cuerpos que no necesitaran comer, tampoco eran inmortales.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcdxcii{Luego cumplí con la promesa que les había hecho. Los salvé a ellos y a otros que quise, pero hice perecer a los transgresores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcdxciii{Les he revelado un Libro en el que hay una amonestación para ustedes. ¿Cómo es que no reflexionan?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcdxciv{¡Cuántos pueblos opresores destruí, e hice surgir después de ellos nuevas generaciones!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcdxcv{Cuando sintieron que Mi tormento se desencadenaba sobre ellos, trataron de escapar.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcdxcvi{[Entonces se les dijo irónicamente:] ``No intenten escapar, regresen a la vida placentera que llevaban y esperen en sus hogares, quizás tengan que dar explicaciones".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcdxcvii{Respondieron: ``¡Ay de nosotros! En verdad hemos sido injustos".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcdxcviii{Y no cesaron de lamentarse hasta que los aniquilé, dejándolos inertes como paja segada.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcdxcix{No creé el cielo y la Tierra y todo cuanto existe entre ellos solo como un juego.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmd{Si hubiera buscado divertirme, lo habría hecho por Mi cuenta [sin crear nada para ello].\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdi{Por el contrario, refuto lo falso con la Verdad, y lo falso se desvanece. Les aguarda la perdición por como han descrito [a Dios].\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdii{A Él pertenece cuanto existe en los cielos y en la Tierra, y quienes están junto a Él [los ángeles] no dejan, por soberbia, de adorarlo ni se cansan de hacerlo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdiii{Lo glorifican noche y día, sin cesar.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdiv{¿Acaso las divinidades que adoran en la Tierra tienen poder para resucitar a los muertos?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdv{Si hubiese habido en los cielos y en la Tierra otras divinidades además de Dios, éstos se habrían destruido. ¡Glorificado sea Dios, Señor del Trono! Él está por encima de lo que Le atribuyen.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdvi{Él no es interrogado por lo que hace, a diferencia de Sus siervos que sí serán interrogados.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdvii{A aquellos que adoran a otras divinidades en lugar de Dios, diles: ``Presenten pruebas válidas. Éste es mi Mensaje y el de quienes me siguen, y el Mensaje de quienes nos precedieron. Pero la mayoría no reconoce la Verdad y la rechazan".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdviii{No envié en el pasado a ningún Mensajero, excepto que recibiera la misma revelación que tú: ``Nada ni nadie merece ser adorado excepto Yo, ¡Adórenme solo a Mí!"\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdix{[Algunos] dicen: ``El Misericordioso ha tenido un hijo". ¡Glorificado sea! Por el contrario, [los ángeles y los Profetas] son solo siervos distinguidos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdx{No dan prioridad a sus palabras sobre la Palabra de Dios, y cumplen con lo que Él manda.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdxi{[Dios] Conoce tanto lo que hicieron como lo que harán, y solo podrán interceder por quienes Dios se complazca. Por temor a Él están sobrecogidos.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdxii{Si uno de ellos dijera: ``Yo soy un dios junto a Él", lo condenaría al Infierno, porque así castigo a los injustos.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdxiii{¿Acaso los que se niegan a creer no reparan en que los cielos y la Tierra formaban una masa homogénea y la disgregué, y que creé del agua a todo ser vivo? ¿Es que aún después de esto no van a creer?\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdxiv{Afirmé la Tierra con montañas para que no tiemble, y dispuse caminos para que encuentren guía.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdxv{Hice del cielo un techo protector, pero aun así los que se niegan a creer rechazan reflexionar en Mis signos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdxvi{Él es Quien creó la noche y el día, el Sol y la Luna. Cada uno recorre su órbita.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdxvii{No he concedido la inmortalidad a ningún ser humano. Si tú [¡oh, Mujámmad!] has de morir, ¿por qué razón iban ellos a ser inmortales?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdxviii{Toda alma probará la muerte. Los pondré a prueba con cosas malas y cosas buenas, pero finalmente volverán a Mí para ser juzgados.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdxix{Cuando los que se niegan a creer te ven, se burlan de ti, y dicen: ``Éste es quien desdeña a nuestros ídolos"; sin embargo, son ellos los que, cuando es mencionado el Misericordioso, rechazan la verdad.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdxx{El ser humano es impaciente por naturaleza. Ya les mostraré Mi castigo, así que no pidan que se adelante.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdxxi{Dicen: ``¿Cuándo se cumplirá tu advertencia? Si es verdad lo que dices".\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdxxii{Si supieran los que se niegan a creer, que llegará un momento en que no podrán impedir que el fuego queme sus rostros y sus espaldas, y no serán socorridos.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdxxiii{Por el contrario, [el fuego] les llegará por sorpresa dejándolos desconcertados sin que puedan evitarlo, y no serán indultados.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdxxiv{También se burlaron de otros Mensajeros anteriores a ti [¡oh, Mujámmad!], y el castigo azotó a los que se burlaban por haberlos ridiculizado.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdxxv{Diles [¡oh, Mujámmad!]: ``¿Quién sino el Misericordioso los protege durante la noche y el día?" Pero ellos, a pesar de esto, se niegan a recordar a su Señor.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdxxvi{¿Acaso creen que existen otras divinidades que los puedan socorrer en vez de Mí? [Lo que consideran divinidades] no pueden defenderse ni protegerse a sí mismos de Mí.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdxxvii{A ellos y a sus padres los dejé disfrutar muchas bondades y les otorgué una larga vida. ¿Acaso no ven que van perdiendo el control del territorio? ¿Pensaron que iban a ser los vencedores?\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdxxviii{Diles [¡oh, Mujámmad!]: ``Solo los exhorto con la revelación". Pero los sordos [de corazón] no oyen cuando se los exhorta.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdxxix{Mas cuando los alcance un soplo del castigo de tu Señor, dirán: ``¡Ay de nosotros! Fuimos injustos".\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdxxx{Y dispondré la balanza de la justicia el Día de la Resurrección, y nadie será oprimido en lo más mínimo. Todas las obras, aunque sean tan ínfimas como un grano de mostaza, serán tenidas en cuenta. Nadie lleva las cuentas mejor que Yo.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdxxxi{Concedí a Moisés y a Aarón el Criterio [la Tora], para iluminar y exhortar a los piadosos,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdxxxii{a los que tienen temor a su Señor en privado, y sienten temor de la Hora [del Juicio].\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdxxxiii{Este [Corán] es un Mensaje bendito que he revelado. ¿Acaso van a rechazarlo?\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdxxxiv{Antes [de Moisés] le concedí la guía a Abraham, a quien bien conocía.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdxxxv{Cuando dijo a su padre y a su pueblo: ``¿Qué son estas estatuas a las que dedican su adoración?"\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdxxxvi{Respondieron: ``Vimos que nuestros padres las adoraban".\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdxxxvii{Dijo: ``Ustedes y sus padres están en un error evidente".\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdxxxviii{Dijeron: ``¿Nos hablas en serio o estás bromeando?"\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdxxxix{Dijo: ``Su Señor es el Señor de los cielos y de la Tierra, el Creador de ambos, y yo doy testimonio de ello.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdxl{Juro por Dios que voy a tramar algo contra sus ídolos cuando se hayan retirado".\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdxli{Y los hizo pedazos excepto al más grande, para que su atención se volviera sobre él.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdxlii{Exclamaron: ``¿Quién fue capaz de hacer esto con nuestros dioses? Sin duda se trata de un malhechor".\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdxliii{Alguien dijo: ``Oímos a un joven, llamado Abraham, hablar [mal] de ellos".\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdxliv{Dijeron: ``Tráiganlo a la vista de la gente, para que puedan atestiguar [contra él]".\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdxlv{Le dijeron: ``¡Oh, Abraham! ¿Fuiste tú quien destruyó nuestros dioses?"\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdxlvi{Respondió: ``¡Fue ese, el mayor de todos! Pregúntenle [a sus dioses], si es que ellos son capaces [al menos] de hablar".\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdxlvii{Comenzaron a criticarse unos a otros diciendo: ``Ustedes son los malhechores".\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdxlviii{Pero luego volvieron a su estado anterior [y le dijeron]: ``Tú bien sabes que no pueden hablar".\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdxlix{Dijo [Abraham]: ``¿Acaso adoran en vez de Dios lo que no puede beneficiarlos ni perjudicarlos [en lo más mínimo]?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdl{¡Uf, qué perdidos están ustedes y lo que adoran en vez de Dios! ¿Es que no van a reflexionar?"\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdli{Exclamaron: ``¡Quémenlo [en la hoguera] para vengar a sus ídolos! Si es que van a hacer algo".\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdlii{Pero dijo [Dios]: ``¡Oh, fuego! Sé fresco y no dañes a Abraham".\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdliii{Pretendieron deshacerse de él, pero hice que fueran ellos los perdedores.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdliv{Lo salvé a él y también a Lot, para que fueran a la tierra que bendije para toda la humanidad.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdlv{Y le concedí [dos hijos, Ismael e] Isaac, y luego [al hijo de Isaac,] Jacob, y a ambos los hice hombres rectos,\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdlvi{y líderes ejemplares para que guiasen [a la gente] siguiendo Mi voluntad. Y les inspiré realizar buenas obras, practicar la oración prescrita y pagar el zakat. Fueron devotos en la adoración.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdlvii{A Lot le concedí conocimiento y sabiduría, y lo salvé de la ciudad donde se cometían obscenidades. Era un pueblo malvado lleno de corruptos.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdlviii{Lo ingresé en Mi misericordia, porque era uno de los justos.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdlix{Cuando antes [de Lot] Noé Me invocó, le respondí [su súplica], salvándolo junto a su familia de la gran calamidad.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdlx{Lo protegí del pueblo que rechazó Mis signos, era un pueblo perverso, y por eso hice que todos se ahogaran.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdlxi{[Recuerda] cuando [los Profetas] David y Salomón emitieron su fallo sobre un campo sembrado en el que las ovejas de su vecino [habían ingresado por la noche arruinándolo], y fui testigo de su sentencia,\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdlxii{Le hice comprender a Salomón [el veredicto más justo], y a ambos les concedí conocimiento y sabiduría. A David le sometí las montañas y los pájaros para que cantaran junto a él alabanzas a Dios. Así lo hice.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmdlxiii{Le enseñé cómo fabricar cotas de malla, para que se protegieran en la batalla. ¿Acaso son agradecidos?\qt@no{80}}
\qt@newcmd\qurantrans@es@mmdlxiv{A Salomón le sometí los vientos fuertes, que soplaban por orden suya hacia la tierra que bendije. Tengo conocimiento de todas las cosas.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmdlxv{También le sometí a los demonios, algunos buceaban para él [en busca de perlas y gemas] y también realizaban otras tareas. Yo era su Protector.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmdlxvi{[El Profeta] Job invocó a su Señor: ``[¡Oh, Dios! Tú bien sabes que] he sido probado con enfermedades, pero Tú eres el más Misericordioso".\qt@no{83}}
\qt@newcmd\qurantrans@es@mmdlxvii{Respondí su invocación y lo curé de sus enfermedades, y le di nueva descendencia, multiplicándola como misericordia de Mi parte y como recuerdo para los adoradores devotos.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmdlxviii{[Los Profetas] Ismael, Enoc, Dhul-Kifl y Elías, todos ellos fueron muy pacientes.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmdlxix{Los introduje en Mi misericordia porque obraban con justicia.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmdlxx{[El Profeta] Jonás, cuando se marchó enojado [con la gente de su pueblo que se negaron a creer en él], pensó que no lo iba a castigar [por no haber tenido paciencia, pero lo hice tragar por la ballena], e invocó desde la oscuridad [de su estómago]: ``No hay otra divinidad más que Tú. ¡Glorificado seas! En verdad he sido de los injustos".\qt@no{87}}
\qt@newcmd\qurantrans@es@mmdlxxi{Respondí su súplica y lo libré de su angustia. Así salvo a los creyentes.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmdlxxii{Cuando [el Profeta] Zacarías rogó a su Señor: ``¡Oh, Señor mío! No me dejes solo [sin hijos]. Tú eres Quien concede descendencia".\qt@no{89}}
\qt@newcmd\qurantrans@es@mmdlxxiii{Respondí su súplica y le agracié con [su hijo] Juan, haciendo que su mujer fuera otra vez fértil. Los agracié porque siempre se apresuraban a realizar obras buenas, Me invocaban con temor y esperanza, y eran humildes ante Mí.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmdlxxiv{[Recuerda] a aquella que conservó su virginidad, cuando infundí Mi espíritu en ella. Así hice de ella y su hijo un signo [de Mi poder divino] para toda la humanidad.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmdlxxv{La religión de todos los Profetas es una religión única. Yo soy su Señor, ¡adórenme solo a Mí!\qt@no{92}}
\qt@newcmd\qurantrans@es@mmdlxxvi{Pero luego [las generaciones que vinieron después] se dividieron, aunque todos regresarán ante Mí.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmdlxxvii{Quien sea creyente y realice obras buenas sepa que no habrá ingratitud para su esfuerzo. Todo lo tengo registrado.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmdlxxviii{Es imposible que [los habitantes de] una ciudad que haya destruido fueran a arrepentirse [ni podrán volver a este mundo].\qt@no{95}}
\qt@newcmd\qurantrans@es@mmdlxxix{[Cuando se aproxime el Último Día] serán liberados Gog y Magog, y se precipitarán desde todas las laderas [devastando cuanto encuentren a su paso].\qt@no{96}}
\qt@newcmd\qurantrans@es@mmdlxxx{La promesa de la verdad se acerca. Cuando llegue, la mirada de los que se negaron a creer quedará fija [y exclamarán:] ``¡Ay de nosotros! Fuimos indiferentes a esta realidad y fuimos de los malhechores".\qt@no{97}}
\qt@newcmd\qurantrans@es@mmdlxxxi{Ustedes y cuanto adoran en vez de Dios serán combustible para el fuego del Infierno al que ingresarán.\qt@no{98}}
\qt@newcmd\qurantrans@es@mmdlxxxii{Si estos [ídolos] fueran divinidades como ustedes pretenden, no ingresarían en él. Pero todos ustedes junto a lo que adoraban estarán allí por toda la eternidad.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmdlxxxiii{Allí emitirán alaridos [por el tormento], y por eso no podrán oír nada más.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmdlxxxiv{Pero aquellos para quienes estaba decretado que recibirían ``lo más hermoso", estarán alejados del Infierno,\qt@no{101}}
\qt@newcmd\qurantrans@es@mmdlxxxv{No oirán su crepitar y estarán disfrutando lo que deseen por toda la eternidad.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmdlxxxvi{No los afligirá el gran espanto [del castigo], y los ángeles acudirán a su encuentro [cuando salgan de las tumbas y les dirán]: ``Éste es el día que se les había prometido".\qt@no{103}}
\qt@newcmd\qurantrans@es@mmdlxxxvii{El cielo ese día será enrollado como un pergamino. Así como inicié la primera creación, la repetiré. Ésta es una promesa que he de cumplir.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmdlxxxviii{Ya mencioné anteriormente en las Escrituras Reveladas como lo había hecho en la Tabla Protegida, que la Tierra será heredada por Mis siervos justos.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmdlxxxix{En esto hay mensaje suficiente para un pueblo que realmente adora a Dios.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmdxc{No te he enviado [¡oh, Mujámmad!] sino como misericordia para todos los seres.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmdxci{Diles: ``Me ha sido revelado que Dios es un Dios único. ¿Acaso no van a ser musulmanes?\qt@no{108}}
\qt@newcmd\qurantrans@es@mmdxcii{Pero si rechazan [el Mensaje] diles: ``Les advierto sobre un castigo que caerá sobre todos por igual, aunque no tengo conocimiento si lo que les advierto está cerca o lejos.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmdxciii{Él bien sabe tanto lo que dicen abiertamente como lo que dicen en secreto.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmdxciv{Pero ignoro si Él los está poniendo a prueba al tolerarlos y dejarlos disfrutar de la vida [mundanal] por un tiempo".\qt@no{111}}
\qt@newcmd\qurantrans@es@mmdxcv{Di: ``¡Oh, Señor nuestro! Juzga con la verdad. Tú eres el Misericordioso, Aquel a quien recurrir contra lo que atribuyen [falsamente a Dios]".\qt@no{112}}
\qt@newcmd\qurantrans@es@mmdxcvi{\basmalahes ¡Oh, gente! Tengan temor de su Señor. El terremoto que ocurrirá cuando llegue la Hora [del Juicio] será algo terrible.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdxcvii{El día que llegue, las mujeres que estén amamantando a sus hijos se desentenderán de ellos, las embarazadas abortarán [por el terror], y verás a las personas caminar como ebrios, pero no estarán ebrios sino que el castigo de Dios será intenso.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdxcviii{Hay gente que discute acerca de Dios sin conocimiento, y siguen a todo demonio rebelde.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdxcix{Fue decretado que a quien lo siguiese, él lo extraviará y lo conducirá al castigo del Infierno.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdc{¡Oh, gente! Si tienen dudas de que tengo el poder para resucitarlos, sepan que he creado [a Adán] de barro, luego [a toda su descendencia] de un óvulo fecundado que luego se transforma en un embrión, luego en una masa de tejidos, algunos ya formados y otros por formarse; ello es una evidencia [de Mi poder y sabiduría]. Preservo en el útero materno a aquellos que decreté que completen su gestación. Los hago nacer, y luego de la infancia alcanzan la madurez; algunos mueren [antes de esta etapa] y otros alcanzan la vejez, y ya no recuerdan nada del conocimiento que habían adquirido. También pueden observar a la tierra árida, y cómo cuando hago que llueva sobre ella, se remueve, se hincha, y brota toda clase de plantas bellas.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdci{Porque Dios es la Verdad. Él resucitará a los muertos, y es sobre toda cosa Poderoso.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdcii{La Hora [del Día del Juicio] se aproxima, no hay duda acerca de ello, y [ese día] Dios resucitará a quienes están en las tumbas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdciii{Hay gente que discute acerca de Dios sin conocimiento, sin guía ni Libro que los ilumine.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdciv{Con arrogancia pretenden apartar a la gente del camino de Dios. Serán humillados en esta vida, y el Día de la Resurrección los haré sufrir el castigo de quemarse.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdcv{[Se les dirá] ``Esto es lo que merecen por lo que hicieron con sus propias manos". Pero sepan que Dios no es injusto con Sus siervos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdcvi{Hay gente cuya fe está siempre al borde [de la incredulidad]. Si les ocurre un bien se sienten tranquilos; pero si les ocurre una desgracia reniegan de la fe, perdiéndose la recompensa de este mundo y el otro. Esa es la auténtica perdición.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdcvii{Ellos invocan en lugar de Dios aquello que no puede perjudicarlos ni beneficiarlos. Están en un error profundo.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdcviii{Adoran aquello cuyo perjuicio es más patente que su supuesto beneficio. ¡Qué pésimo protector y compañero!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdcix{Dios introducirá a los que crean y obren rectamente en jardines por donde corren ríos. Dios hace lo que quiere.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdcx{Aquel que pensaba que Dios no lo auxiliaría [al Profeta] en este mundo y en el otro [y se ve ahora decepcionado], que intente llegar al cielo por algún medio y la corte [la ayuda de Dios al Profeta], y vea si ese ardid puede acabar con lo que lo enfurece.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdcxi{Así [como en las revelaciones anteriores] he revelado versículos claros, porque Dios guía a quien quiere.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcxii{El Día de la Resurrección Dios juzgará sobre las diferencias entre los seguidores de la fe [del Islam], del judaísmo, del sabeísmo, del cristianismo, los adoradores del fuego y los idólatras. Dios es testigo de todas las cosas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcxiii{¿Acaso no ves que se prosternan ante Dios quienes están en los cielos y en la Tierra, y el Sol, la Luna, las estrellas, las montañas, los árboles, los animales, y muchos de los seres humanos? Pero muchos otros [seres humanos] merecen el castigo. A quien Dios humille no habrá quien pueda dignificarlo; Dios hace lo que quiere.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcxiv{Éstos [los creyentes y los incrédulos] son dos grupos que disputan acerca de su Señor, pero sepan que quienes se niegan a creer serán cubiertos con ropas de fuego, y se verterá sobre sus cabezas agua hirviente\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcxv{que les abrasará el vientre y la piel,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcxvi{y serán atormentados allí con mazas de hierro.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcxvii{Cada vez que, angustiados, quieran salir de allí, [los ángeles] los harán regresar y les dirán: ``¡Sufran el tormento del Infierno!"\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcxviii{Dios hará entrar en jardines por donde corren ríos a los creyentes que hayan obrado rectamente. Serán engalanados con pulseras de oro y perlas, y serán vestidos con seda.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcxix{[En la vida mundanal] habían sido guiados hacia la bella palabra y al camino de la alabanza.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcxx{A los que se nieguen a creer y aparten a la gente del sendero de Dios, e impidan acudir a la Mezquita Sagrada [de La Meca] que establecí para todas las gentes por igual, tanto para el residente como para el viajero, y a quienes quieran profanarla con injusticias, los haré sufrir un castigo doloroso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcxxi{[Recuerda] cuando establecí a Abraham junto a la Casa Sagrada para que solo Me adorara a Mí y no dedicara actos de adoración a otros, y purificara Mi Casa [de la idolatría] para quienes realicen el rito de circunvalarla, y para quienes oren de pie, inclinados y prosternados,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcxxii{[le dije:] ``Convoca a la gente a realizar la peregrinación; vendrán a ti a pie o montados, desde todo lugar apartado".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcxxiii{Para que sean testigos de todas las gracias [de la peregrinación y la casa de Dios], y recuerden el nombre de Dios en los días consabidos al sacrificar las reses del ganado que Él les ha proveído. Coman de ellas y den de comer al desvalido y al pobre.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdcxxiv{Luego de cumplir los ritos, que cumplan sus votos y que circunvalen la Antigua Casa [de La Meca].\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcxxv{Así deben hacer. Quien respete los preceptos sagrados de Dios, será mejor para él ante su Señor [porque lo recompensará en esta vida y en la otra]. Sepan que les son lícitas las reses, excepto lo que se les ha mencionado [como prohibido]. Manténganse alejados de la impureza de los ídolos y apartados de las afirmaciones falsas.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcxxvi{Sean monoteístas puros creyentes en Dios, y no sean [jamás] idólatras. Quien asocia divinidades a Dios [en la adoración] es como quien cae del cielo y [luego de estrellarse contra la tierra] las aves de rapiña lo devoran o un viento lo arrastra a un lugar lejano.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdcxxvii{Sepan que respetar los ritos de Dios dimana de la piedad que hay en los corazones.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdcxxviii{Pueden beneficiarse de los animales hasta un plazo determinado; pero luego, su lugar [de sacrificio] es junto a la Antigua Casa.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdcxxix{He prescrito para cada comunidad sus propios ritos, para que recuerden el nombre de Dios al sacrificar las reses que les proveí. Su Dios es uno solo. Entréguenle a Él su voluntad. Albricia a los humildes sumisos [que obtendrán la bienaventuranza],\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcxxx{aquellos cuyos corazones se emocionan cuando se menciona a Dios, son pacientes ante las desgracias, cumplen con la oración y hacen caridades con lo que les he agraciado.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcxxxi{Establecí que [el sacrificio] de los ganados sea parte de los ritos de Dios, en ello hay un bien para ustedes. Mencionen el nombre de Dios sobre ellos cuando estén dispuestos en fila [para ser sacrificados]. Luego, cuando se desplomen sobre sus costados [sin vida], coman de ellos y den de comer al mendigo y al necesitado. Así los puse a su servicio para que sean agradecidos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcxxxii{Dios no necesita de la carne ni de la sangre [de sus ofrendas], Él desea que ustedes alcancen la piedad [mediante la práctica de este rito]. Con este fin se los facilitó. Alaben a Dios por haberlos guiado. Y albricia a los que hacen el bien [que alcanzarán el Paraíso].\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcxxxiii{Dios defiende a los que han creído. Sepan que Dios no ama al traidor ni al desagradecido.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcxxxiv{Se les ha permitido [combatir a los creyentes] que son atacados porque son víctimas de una injusticia. Dios tiene el poder para socorrerlos.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcxxxv{Ellos fueron expulsados injustamente de sus hogares solo por haber dicho: ``Nuestro Señor es Dios". Si Dios no se hubiera servido de algunas personas [creyentes] para combatir a otros [incrédulos], se habrían destruido monasterios, iglesias, sinagogas y mezquitas, en donde se recuerda frecuentemente el nombre de Dios. Dios socorre a quien se esfuerza denodadamente por Su religión. Dios es Fuerte, Poderoso.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcxxxvi{Aquellos que, si les doy autoridad en la Tierra, cumplen con la oración, pagan el zakat, ordenan el bien y prohíben el mal. A Dios pertenece el resultado de todas las cosas.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcxxxvii{Si te desmienten [¡oh, Mujámmad!], sabe que ya antes habían desmentido los pueblos de Noé, ‘Ad, Zamud,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcxxxviii{de Abraham, Lot,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcxxxix{los habitantes de Madián, y también fue desmentido Moisés. Les concedí un plazo a los que se negaban a creer, pero luego los sorprendí. ¡Qué terrible fue Mi castigo!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdcxl{¡Cuántas ciudades aniquilé porque eran injustas y opresoras! Quedaron reducidas a ruinas, sus pozos secos y sus castillos derrumbados.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdcxli{¿Acaso [los que se niegan a creer] no viajan por el mundo, y no tienen intelecto para reflexionar, ni oídos? No son sus ojos los que están ciegos, sino los corazones que están dentro de sus pechos [los que están ciegos].\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdcxlii{Te desafían a que adelantes el castigo, pero sabe que Dios no faltará a Su promesa. Un día para tu Señor es como mil años de los que ustedes computan.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdcxliii{A cuántas ciudades que eran injustas les aplacé [su tiempo], pero finalmente las sorprendí con el castigo. Ante Mí comparecerán.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdcxliv{Di: ``¡Oh, gente!, yo soy un claro amonestador enviado a ustedes".\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdcxlv{Los que creyeron y obraron rectamente obtendrán el perdón y un sustento generoso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdcxlvi{Pero aquellos que se esforzaron por desmentir Mis signos, serán los moradores del Infierno.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdcxlvii{No envié antes de ti [¡oh, Mujámmad!], Mensajero ni Profeta alguno al que no le ocurriera que al recitar [lo que le había sido inspirado] el demonio intentara confundir algo en su recitación. Pero Dios anula lo que el demonio inspira. Dios aclara Su revelación, porque Dios es Conocedor, Sabio.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdcxlviii{Los susurros del demonio seducen a aquellos cuyos corazones están enfermos [de dudas] y a los duros de corazón. Los injustos están en un error profundo.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdcxlix{Aquellos que fueron agraciados con el conocimiento y la sabiduría, saben que el Corán es la Verdad que proviene de su Señor; creen en él y así se sosiegan sus corazones. Dios guía por el camino recto a los que creen.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdcl{Los que se niegan a creer no cesarán de dudar sobre él hasta que los sorprenda la Hora [del Juicio], o les llegue el castigo de un día nefasto.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdcli{Ese día la soberanía solo Le pertenecerá a Dios, que juzgará entre ellos. Sepan que los que hayan creído y hecho obras de bien estarán en los Jardines de las Delicias,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdclii{mientras que los que se negaron a creer y desmintieron Mis preceptos tendrán un castigo humillante.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdcliii{Aquellos que emigraron por la causa de Dios y fueron asesinados o murieron en el camino, Dios los proveerá con un bello sustento. Dios es el mejor de los sustentadores.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdcliv{Los introducirá en un Paraíso en el que estarán complacidos. Dios es Conocedor, Tolerante.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdclv{Aquel que se defienda de forma proporcional a la injusticia de que es víctima, y se le siga agraviando, Dios lo socorrerá. Dios es Remisorio, Absolvedor.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdclvi{Dios hace que la noche suceda al día y el día a la noche. Dios todo lo oye, todo lo ve.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdclvii{Dios es la Verdad, y aquello que [los idólatras] invocan en vez de Él es falso. Dios es el Sublime, el Grande.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdclviii{¿Acaso no ves que Dios envía agua del cielo y con ella la tierra se reverdece? Dios es Sutil, Conocedor.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdclix{A Él pertenece cuanto hay en los cielos y en la Tierra. Dios es el Opulento, el Loable.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdclx{¿Acaso no ves que Dios ha puesto al servicio de ustedes cuanto hay en la Tierra, que los barcos surcan el mar por Su designio, y que Él contiene al cielo para que no caiga sobre la Tierra a menos que sea por Su Voluntad? Dios es Compasivo y Misericordioso con la gente.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdclxi{Él es Quien les dio la vida, luego les da la muerte y luego los resucitará [para juzgarlos]. Pero el ser humano es desagradecido.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdclxii{A cada comunidad le he revelado sus propios ritos para que los observen. [¡Oh, Mujámmad!] No dejes que [te discutan] sobre los preceptos. Exhorta a creer en tu Señor, porque tú estás en la guía del camino recto.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdclxiii{Pero si te desmienten, diles: ``Dios bien sabe lo que hacen".\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdclxiv{Dios juzgará entre ustedes el Día del Juicio sobre lo que solían discrepar.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdclxv{¿Acaso no sabes que Dios conoce cuanto hay en el cielo y en la Tierra? Todo está registrado en un libro, eso es fácil para Dios.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdclxvi{[Los idólatras] adoran en lugart de Dios lo que no les fue revelado y carecen de conocimiento. Los injustos no tendrán quién los auxilie.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdclxvii{Cuando se les recitan Mis claros versículos, ves el disgusto en los rostros de los que se niegan a creer; poco les falta para lanzarse [con la intención de matarlos] sobre quienes los recitan. Diles [¡oh, Mujámmad!]: ``¿Quieren saber de algo peor [que su repudio por el Corán]? Es el castigo del Infierno con el que Dios ha advertido a los que se niegan a creer. ¡Qué pésimo destino!"\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdclxviii{¡Oh, gente! Se les expone un ejemplo, presten atención: Aquellos [ídolos] que invocan en vez de Dios no podrían crear ni una mosca, aunque todos se reunieran para ello. Y si una mosca les quitara algo [a los ídolos], ellos no podrían impedirlo. ¡Qué débil es el que invoca y qué débil es el invocado!\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdclxix{No valoran ni enaltecen a Dios como Se merece. Dios es Fuerte, Poderoso.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdclxx{Dios selecciona a algunos ángeles como Mensajeros y selecciona algunas personas como Mensajeros. Dios todo lo oye, todo lo ve,\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdclxxi{conoce el pasado y el futuro, y ante Dios regresan todos los asuntos.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdclxxii{¡Oh, creyentes! Inclínense y prostérnense [durante la oración], adoren a su Señor y hagan el bien, que así alcanzarán el triunfo.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdclxxiii{Esfuércense por la causa de Dios como es debido. Él los eligió [para que sigan Su religión] y no les prescribió nada que no puedan cumplir. Ésta es la religión monoteísta de su padre Abraham, él los llamó musulmanes anteriormente y también fueron llamados así en esta revelación, para que el Mensajero fuera testigo [de sus obras] y ustedes sean testigos ante la humanidad [de la llegada de los Profetas anteriores]. Cumplan con la oración, paguen el zakat y aférrense a Dios, pues Él es su Protector. ¡Qué excelente Protector, y qué excelente Defensor!\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdclxxiv{\basmalahes Bienaventurados los creyentes\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdclxxv{que en sus oraciones son humildes [ante Dios],\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdclxxvi{se apartan de las frivolidades,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdclxxvii{pagan el zakat,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdclxxviii{preservan sus genitales [del adulterio y la fornicación],\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdclxxix{y solo cohabitan con sus esposas o con lo que posee su diestra, porque eso no es censurable.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdclxxx{Pero quien busque algo más allá de eso, está transgrediendo [la ley].\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdclxxxi{[Son de los bienaventurados quienes] sean fieles a la confianza depositada en ellos, cumplen con sus compromisos y acuerdos,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdclxxxii{y cumplen con sus oraciones.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdclxxxiii{[Quienes tengan estas virtudes] serán los herederos\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdclxxxiv{que heredarán el Firdaus, en el que morarán por toda la eternidad.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdclxxxv{Creé al [primer] ser humano de barro.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdclxxxvi{Luego [hice que se reprodujera por medio de la fecundación, y] preservé el óvulo fecundado dentro de una cavidad segura.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdclxxxvii{Transformé el óvulo fecundado en un embrión, luego en una masa de tejidos, luego de esa masa de tejidos creé sus huesos a los que vestí de carne, finalmente soplé en el feto su espíritu. ¡Bendito sea Dios, el mejor de los creadores!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdclxxxviii{[Sepan que] después de haber sido creados, han de morir,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdclxxxix{pero el Día de la Resurrección serán devueltos a la vida.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcxc{Creé siete cielos por encima de ustedes, y no he descuidado la creación.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcxci{Hice descender del cielo el agua en una medida limitada para que permanezca en la tierra, pero si quisiera la podría hacer desaparecer.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcxcii{Con ella hago brotar jardines de palmeras y viñedos de los que obtienen abundantes frutos con los que se alimentan.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcxciii{Y [también] un árbol que crece en el monte Sinaí, que produce aceite y aderezo, una delicia para los comensales.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcxciv{En los ganados hay una lección: Doy a ustedes de beber de lo que hay en sus ubres, obtienen de ellos muchos beneficios y también se alimentan;\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcxcv{usan a los animales y a los barcos como transporte.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcxcvi{Envié a Noé a su pueblo y les dijo: ``¡Oh, pueblo mío! Adoren solamente a Dios, pues no existe otra divinidad salvo Él. ¿Acaso no van a tener temor de Él?"\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcxcvii{Pero los magnates de su pueblo que no creyeron, dijeron [a los más débiles]: ``Éste es un mortal como ustedes, que solo pretende poder. Si Dios hubiera querido [que siguiéramos Su Mensaje] habría enviado ángeles [en lugar de seres humanos]. Nunca oímos algo similar de nuestros antepasados.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcxcviii{[Noé] no es más que un demente, sopórtenlo por un tiempo [hasta que muera]".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcxcix{Dijo Noé: ``¡Oh, Señor mío! Socórreme, porque ellos me desmienten".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcc{Entonces le dije: ``Construye el arca bajo Mi observancia, acorde a lo que te inspire. Cuando llegue Mi designio y el agua comience a brotar de la tierra [y se inicie la inundación], haz subir una pareja de cada especie y embarca a tu familia, salvo a quienes el decreto [de la inundación] los haya condenado. No Me pidas por los injustos, pues ellos perecerán ahogados.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcci{Cuando tú y quienes estén contigo se encuentren en el arca, di: ¡Alabado sea Dios, Quien nos salvó de un pueblo de injustos!"\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdccii{Y di: ``¡Señor mío! Hazme llegar a un destino bendito, pues Tú eres Quien mejor hace llegar a destino".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcciii{En ello hay signos [de Dios], pero [sepan que] siempre pondré a prueba [a los seres humanos].\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcciv{Luego [de la destrucción del pueblo de Noé], hice surgir nuevas generaciones,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdccv{y les envié un Mensajero de entre ellos [que les dijo]: ``Adoren solamente a Dios, ya que no existe otra divinidad salvo Él. ¿Es que no van a tener temor [de Dios]?"\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdccvi{Pero [nuevamente] los magnates de su pueblo que no creyeron y desmintieron el Día del Juicio, a pesar de que les había concedido una vida llena de riquezas, dijeron [a los más débiles]: ``Éste es un mortal igual que ustedes, come lo que comen y bebe lo que beben.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdccvii{Si obedecen a un ser humano como ustedes, serán unos perdedores.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdccviii{¿Acaso les promete que luego de que mueran y sean polvo y huesos, van a ser resucitados?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdccix{¡Qué lejos está de la realidad lo que él les promete!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdccx{No hay otra vida más que la mundanal; vivimos, morimos y jamás seremos resucitados.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdccxi{Él es solo un ser humano que ha inventado una gran mentira acerca de Dios, y no le vamos a creer".\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdccxii{Dijo [el Profeta]: ``¡Señor mío! Socórreme, pues me han desmentido".\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdccxiii{Dijo [Dios]: ``Dentro de poco se arrepentirán".\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdccxiv{El estruendo los sorprendió con la verdad [que negaban], y los convertí en despojos. ¡Que el pueblo injusto sea destruido!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdccxv{Luego hice surgir nuevas generaciones.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdccxvi{Ninguna comunidad puede adelantar ni retrasar su plazo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdccxvii{Envié a Mis Mensajeros unos tras otros. Cada comunidad a la que le llegaba su Mensajero, lo desmentía. Así que las destruí una tras otra e hice que se convirtieran en ejemplos. ¡Que sean destruidos los pueblos que se niegan a creer!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdccxviii{Luego envié a Moisés y a su hermano Aarón, con Mis signos y un poder visible,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdccxix{al Faraón y su nobleza. Pero estos fueron soberbios y se comportaron con arrogancia.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdccxx{Y dijeron: ``¿Acaso vamos a creer en dos mortales iguales a nosotros, mientras su pueblo nos sirve como esclavos?"\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdccxxi{Los desmintieron, y como consecuencia fueron destruidos.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdccxxii{Le entregué a Moisés el Libro para que fueran de los bien guiados.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdccxxiii{Hice de Jesús y su madre María, un signo [de Mi poder]. A ambos les di refugio en una colina, un lugar de descanso seguro con aguas cristalinas.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdccxxiv{¡Oh, Mensajeros! Coman de las cosas buenas y hagan buenas obras, que Yo bien sé lo que hacen.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdccxxv{Esta es la comunidad a la que pertenecen [la de los Profetas], que es una única comunidad, y Yo soy su Señor; tengan temor de Mí.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdccxxvi{Pero [algunas personas] fragmentaron la comunidad creando sectas, y cada facción se complace con lo que tiene [como creencia].\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdccxxvii{Déjalos [¡oh, Mujámmad!, a los que se niegan a creer,] en su confusión por un tiempo [hasta que les llegue su hora].\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdccxxviii{¿Acaso piensan que los bienes materiales y los hijos que les concedí\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdccxxix{son un indicio de que recibirán Mis gracias [en esta vida y la futura]? Todo lo contrario, pero no se dan cuenta.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdccxxx{No cabe duda de que aquellos que tienen temor de su Señor,\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdccxxxi{aquellos que creen en los signos de su Señor,\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdccxxxii{aquellos que no dedican actos de adoración excepto a su Señor,\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdccxxxiii{aquellos que dan en caridad parte de lo que se les ha concedido, y aun así sienten temor en sus corazones porque saben que comparecerán ante su Señor,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdccxxxiv{ellos se apresuran a realizar obras de bien, y son los primeros en hacerlas.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdccxxxv{No exijo a nadie por encima de sus posibilidades. [Sepan que] tengo un Libro que dice la verdad, y nadie será tratado injustamente.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdccxxxvi{En cambio, los corazones [de los incrédulos] están cegados al Mensaje y cometen malas obras.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdccxxxvii{Cuando castigue a los que tuvieron una vida llena de lujos, pedirán auxilio a gritos.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdccxxxviii{[Y se les dirá entonces:] De nada sirve que pidan auxilio hoy, pues nadie podrá salvarlos de Mi castigo.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdccxxxix{Mis versículos les eran recitados, pero los rechazaban.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdccxl{Por soberbia, pasaban la noche desprestigiando [el Corán].\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdccxli{¿Por qué no reflexionan sobre el Corán, o es que les llegó algo diferente que a sus antepasados?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdccxlii{Conocían a su Mensajero [Mujámmad], pero igualmente lo rechazaron.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdccxliii{Afirmaron que era un demente, pero él se presentó con la Verdad, aunque a la mayoría de ellos les disguste la verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdccxliv{Si la verdad siguiera a las pasiones [de los que se negaron a creer], los cielos, la Tierra y todo lo que hay en ellos se habría corrompido. Pero los ennoblecí con el Corán, y a pesar de eso lo rechazaron.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdccxlv{[¡Oh, Mujámmad] ¿Acaso les pides alguna remuneración a cambio [de transmitirles el Mensaje]? La recompensa de tu Señor es superior, y Él es Quien mejor agracia.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdccxlvi{Tú los invitas al camino recto.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdccxlvii{Pero quienes no creen en la vida del más allá, se desvían de ese camino.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdccxlviii{Aunque les tuviera misericordia y los librara de los males que sufren, persistirían desorientados en su extravío.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdccxlix{Los afligí con un castigo, pero aun así no se sometieron a su Señor ni imploraron auxilio.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdccl{Hasta que abra sobre ellos una de las puertas del castigo infernal, entonces perderán toda esperanza.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdccli{Él es Quien los agració con el oído, la vista y el intelecto, pero poco se lo agradecen.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdcclii{Él es Quien los diseminó por la Tierra, y ante Él serán reunidos.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmdccliii{Él es Quien da la vida y da la muerte, y Él decretó la alternancia de la noche y el día. ¿Es que no razonan?\qt@no{80}}
\qt@newcmd\qurantrans@es@mmdccliv{Sin embargo, [los que se niegan a creer] dicen lo mismo que sus antecesores:\qt@no{81}}
\qt@newcmd\qurantrans@es@mmdcclv{``Cuando muramos y nos convirtamos en polvo y huesos, ¿seremos resucitados?\qt@no{82}}
\qt@newcmd\qurantrans@es@mmdcclvi{Eso ya se nos había prometido a nosotros y a nuestros antepasados con anterioridad. Pero no es más que una fábula de los antiguos".\qt@no{83}}
\qt@newcmd\qurantrans@es@mmdcclvii{Pregúntales [¡oh, Mujámmad!]: ``Si saben, ¿a quién pertenece la Tierra y todo lo que existe sobre ella?"\qt@no{84}}
\qt@newcmd\qurantrans@es@mmdcclviii{Sin duda responderán: ``A Dios". Diles: ``¿Acaso no van a recapacitar [en que deberían adorarlo solo a Él]?"\qt@no{85}}
\qt@newcmd\qurantrans@es@mmdcclix{Pregúntales: ``¿Quién es el creador de los siete cielos, y el Señor del Trono grandioso?"\qt@no{86}}
\qt@newcmd\qurantrans@es@mmdcclx{Sin duda responderán: ``Dios". Diles: ``¿Acaso no van a temer?"\qt@no{87}}
\qt@newcmd\qurantrans@es@mmdcclxi{Pregúntales: ``Si lo saben, ¿Quién tiene en Sus manos el dominio de todas las cosas, y puede amparar a quien Él quiere y nadie puede protegerse de Él [y Su castigo]?"\qt@no{88}}
\qt@newcmd\qurantrans@es@mmdcclxii{Sin duda que responderán: ``Dios". Diles: ``¿Acaso están hechizados [y no pueden ver la verdad]?"\qt@no{89}}
\qt@newcmd\qurantrans@es@mmdcclxiii{Aunque les envié la verdad, ellos la desmienten.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmdcclxiv{Dios no ha tenido un hijo, ni existe otra divinidad salvo Él. Si así fuera, cada divinidad acapararía su propia creación, y entonces pretenderían dominarse unas a otras. ¡Glorificado sea Dios! Dios está por encima de lo que Le atribuyen.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmdcclxv{Él es el Conocedor de lo oculto y lo manifiesto, Él está por encima de cuanto Le asocian.\qt@no{92}}
\qt@newcmd\qurantrans@es@mmdcclxvi{Di [¡oh, Mujámmad! esta súplica]: ``¡Oh, Señor mío! Si me haces presenciar el castigo que les espera [a los que se niegan a creer],\qt@no{93}}
\qt@newcmd\qurantrans@es@mmdcclxvii{Señor, no me pongas entre los injustos".\qt@no{94}}
\qt@newcmd\qurantrans@es@mmdcclxviii{[¡Oh, Mujámmad!] Tengo poder para hacerte ver el castigo que les he destinado.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmdcclxix{Si eres maltratado, responde con una buena actitud [sabiendo disculpar]. Yo bien sé lo que [Me] atribuyen.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmdcclxx{Di: ``¡Oh, Señor mío! Me refugio en Ti de los susurros de los demonios,\qt@no{97}}
\qt@newcmd\qurantrans@es@mmdcclxxi{y me refugio en Ti, oh, Señor, de su presencia maligna".\qt@no{98}}
\qt@newcmd\qurantrans@es@mmdcclxxii{Cuando la muerte los sorprenda [a los que se negaron a creer y vivieron en el pecado], dirán: ``¡Oh, Señor mío! Hazme regresar a la vida otra vez,\qt@no{99}}
\qt@newcmd\qurantrans@es@mmdcclxxiii{para [creer en Ti y] realizar las obras buenas que no hice". Pero no se les dará otra oportunidad, pues son solo palabras [que no cumplirán]. Detrás de ellos habrá una barrera hasta que sean resucitados.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmdcclxxiv{Cuando se sople la trompeta [por segunda vez para dar comienzo al Día del Juicio, y todos sean resucitados], de nada les servirá el linaje, ni los parientes se preguntarán unos por otros.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmdcclxxv{[Ese día] aquellos cuyas buenas obras pesen más en la balanza serán los bienaventurados.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmdcclxxvi{En cambio, aquellos cuyas malas obras sean las que más pesen, estarán perdidos y morarán en el Infierno por toda la eternidad.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmdcclxxvii{El fuego abrasará sus rostros y quedarán desfigurados.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmdcclxxviii{[Se les dirá:] ``¿Acaso no se les recitaron Mis versículos y los desmentían?"\qt@no{105}}
\qt@newcmd\qurantrans@es@mmdcclxxix{Dirán: ``¡Oh, Señor nuestro! Estábamos dominados por nuestras pasiones, éramos gente extraviada.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmdcclxxx{¡Oh, Señor nuestro! Sácanos de él [y retórnanos a la vida], y si reincidimos [en la incredulidad] entonces sí seremos injustos".\qt@no{107}}
\qt@newcmd\qurantrans@es@mmdcclxxxi{Dios les dirá: ``Permanezcan en él [humillados], y no vuelvan a hablarme".\qt@no{108}}
\qt@newcmd\qurantrans@es@mmdcclxxxii{Algunos de Mis siervos decían: ``¡Oh, Señor nuestro! Somos creyentes, perdónanos y ten misericordia de nosotros. Tú eres el mejor de los misericordiosos".\qt@no{109}}
\qt@newcmd\qurantrans@es@mmdcclxxxiii{Pero ustedes [oh, incrédulos y pecadores] los tomaron a burla hasta olvidarse de Mi Mensaje, y se reían de ellos.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmdcclxxxiv{Hoy los recompensaré [a los creyentes] por su paciencia [a la hostilidad de ustedes], y ellos serán los bienaventurados.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmdcclxxxv{Dios les preguntará: ``¿Cuántos años han permanecido en la Tierra?"\qt@no{112}}
\qt@newcmd\qurantrans@es@mmdcclxxxvi{Responderán: ``Permanecimos un día o menos aún. Mejor pregúntale a los [los ángeles] encargados de llevar la cuenta [pues no estamos seguros]".\qt@no{113}}
\qt@newcmd\qurantrans@es@mmdcclxxxvii{Dios les dirá: ``No permanecieron sino poco tiempo. ¡Si tan solo hubieran sabido!\qt@no{114}}
\qt@newcmd\qurantrans@es@mmdcclxxxviii{¿Acaso creían que los creé sin ningún sentido? ¿Creían que no iban a comparecer ante Mí?\qt@no{115}}
\qt@newcmd\qurantrans@es@mmdcclxxxix{¡Exaltado sea Dios! El único Soberano real, no hay otra divinidad salvo Él, Señor del noble Trono.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmdccxc{[Sepan que] quien invoque a otros [dioses] junto a Dios carece de fundamentos válidos, y tendrá que rendir cuenta de ello ante su Señor. Los que se negaron a creer no triunfarán [el Día del Juicio].\qt@no{117}}
\qt@newcmd\qurantrans@es@mmdccxci{Di [¡oh, Mujámmad!, enseñando a los creyentes]: ``¡Oh, Señor mío! Perdona y ten misericordia. Tú eres el mejor de los misericordiosos".\qt@no{118}}
\qt@newcmd\qurantrans@es@mmdccxcii{\basmalahes Este es un capítulo [del Corán] que revelé y prescribí [sus preceptos]. En él he revelado versículos de clara evidencia para que reflexionen.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdccxciii{A la fornicadora y al fornicador aplíquenles, a cada uno de ellos, cien azotes. Si verdaderamente creen en Dios y en el Día del Juicio, no permitan que la compasión que puedan sentir por ellos les impida aplicar la pena establecida por Dios. Que un grupo de creyentes sea testigo cuando se les aplique la pena.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdccxciv{El hombre que haya fornicado solo habrá podido hacerlo con una fornicadora igual que él o con una idólatra [cuya ley no le prohíbe ese delito]. Y la mujer que haya fornicado solo habrá podido hacerlo con un fornicador igual que ella o con un idólatra [cuya ley no le prohíbe ese delito]. [Sepan que] la fornicación está prohibida para los creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdccxcv{A quienes difamen a mujeres decentes [acusándolas de fornicadoras o adúlteras] y no presenten cuatro testigos, aplíquenles ochenta azotes y no acepten nunca más su testimonio. Ellos son los perversos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdccxcvi{Pero a aquellos que [después de haberlas difamado] se arrepientan y enmienden [les será aceptado su testimonio]. Dios es Absolvedor, Misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdccxcvii{Quienes acusen a sus cónyuges [de haber cometido adulterio] sin tener testigos más que ellos mismos, deberán jurar cuatro veces por Dios [ante un juez] que dicen la verdad.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdccxcviii{Y por último pedir que la maldición de Dios caiga sobre sí mismos si mienten.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdccxcix{Ella quedará libre de castigo si jura cuatro veces por Dios [ante un juez] que él miente.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdccc{Por último, deberá pedir que la maldición de Dios caiga sobre ella misma si él dice la verdad.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdccci{Si no fuese por la gracia de Dios y Su misericordia con ustedes, y porque Dios acepta el arrepentimiento y es Sabio [les hubiera hecho descender el castigo que imprecaban].\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdcccii{Los que vinieron con la calumnia son un grupo de ustedes. No piensen [¡oh, creyentes!] que esto acarreará un mal para ustedes; por el contrario, es un bien. Cada uno de los que cometieron este pecado recibirá su merecido, y el mayor responsable entre ellos tendrá un castigo severo.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdccciii{Cuando los creyentes y las creyentes oyeron la calumnia, deberían haberla considerado como en contra de ellos mismos, y haber dicho: ``Esto es una mentira evidente".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdccciv{¿Por qué no presentaron cuatro testigos del hecho? [Sepan que] para Dios quienes no presentan testigos [cuando acusan a alguien] son los mentirosos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdcccv{Si no fuese por la gracia y la misericordia de Dios sobre ustedes en esta vida y en la otra, habrían sufrido un terrible castigo por lo que dijeron.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdcccvi{Propagaron la calumnia con su lengua, repitiendo con la boca aquello sobre lo cual no tenían conocimiento [que fuera verdad], y creyeron que lo que hacían era leve, pero ante Dios era gravísimo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdcccvii{Cuando oyeron la acusación tenían que haber dicho: ``No debemos hablar de ello. ¡Glorificado seas Señor! Esto es una calumnia grandísima".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcccviii{Dios les prohíbe que vuelvan a cometer falta semejante, si es que realmente son creyentes.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcccix{Dios les hace claros sus Signos. Dios lo sabe todo, es Sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcccx{Aquellos que desean que se propague la obscenidad entre los creyentes tendrán un castigo doloroso en esta vida y en la otra. Dios sabe y ustedes no saben.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcccxi{Si no fuera por la gracia y la misericordia de Dios sobre ustedes, y porque Él es Compasivo y Misericordioso [rápido descendería el castigo por sus pecados].\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcccxii{¡Oh, creyentes! No sigan los pasos del demonio, porque quien siga los pasos del demonio debe saber que él induce a cometer obscenidades y actos reprobables. Si no fuera por la gracia y la misericordia de Dios, ninguno de ustedes podría purificarse jamás de sus pecados, pero Dios purifica a quien quiere [perdonándole sus pecados]. Dios todo lo oye, todo lo sabe.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcccxiii{Que los que hacen obras de bien y los que tienen riqueza no juren dejar de ayudar [a los pobres debido a su participación en la calumnia a Aishah] a sus parientes, a los pobres y a quienes dejaron sus hogares por la causa de Dios, y [es mejor] que los perdonen y los disculpen. ¿Acaso no aman ser perdonados por Dios? Dios es Indulgente, Misericordioso.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcccxiv{Quienes difamen a las mujeres honestas, inocentes y creyentes, serán maldecidos en esta vida y en la otra, y sufrirán un castigo enorme.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcccxv{El día que sus propias lenguas, manos y pies atestigüen contra ellos por lo que cometieron.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcccxvi{Ese día, Dios les pagará lo que merecen por lo que hicieron, y finalmente sabrán que Dios es la Verdad evidente.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcccxvii{Las palabras perversas son para los perversos. Los perversos son objeto de palabras perversas. En cambio, las palabras buenas son para los buenos. Estas buenas personas son inocentes de cuanto los acusan, sus faltas les serán perdonadas y tendrán una recompensa generosa.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcccxviii{¡Oh, creyentes! No entren en ninguna casa que no sea la suya sin antes pedir permiso y saludar a su gente. Esto es lo mejor para ustedes, para que así recapaciten.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcccxix{Si no encuentran a nadie en ella, no ingresen hasta que se les dé permiso. Si se les dice: ``¡No entren!", entonces vuelvan [sobre sus pasos], eso es lo más puro. Dios conoce bien lo que hacen.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdcccxx{Pero sepan que no es un deber pedir permiso para ingresar a lugares públicos en el que tienen tareas que realizar. Dios conoce bien lo que manifiestan y lo que ocultan.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcccxxi{Dile a los creyentes [¡oh, Mujámmad!] que recaten sus miradas y se abstengan de cometer obscenidades, porque eso es más puro para ellos. Dios está bien informado de lo que hacen.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcccxxii{Dile a las creyentes que recaten sus miradas, se abstengan de cometer obscenidades, no muestren de sus atractivos [en público] más de lo que es obvio, y que dejen caer el velo sobre su escote, solo muestren sus encantos a sus maridos, sus padres, sus suegros, sus hijos, los hijos de sus maridos, sus hermanos, sus sobrinos por parte de su hermano y de su hermana, las mujeres, las esclavas, sus sirvientes hombres que ya no tengan deseo sexual y los niños que todavía no sienten atracción por el sexo. [Diles también] que no hagan oscilar sus piernas [al caminar] a fin de atraer la atención sobre sus atractivos ocultos. Pidan perdón a Dios por sus pecados, ¡oh, creyentes!, que así alcanzarán el éxito.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdcccxxiii{Ayuden a que los solteros y los esclavos piadosos se casen. [No teman] si son pobres, porque Dios los sustentará con Su gracia. Él es Vasto, lo sabe todo.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdcccxxiv{Quienes no cuenten con los medios para casarse, que tengan paciencia y se abstengan [de mantener relaciones prematrimoniales] hasta que Dios les provea los medios con Su gracia. Si alguno de los esclavos les pide la manumisión, y saben de su honestidad, otórguensela y ayúdenle [a pagar la manumisión] dándole parte de las riquezas con las que Dios los ha agraciado. No fuercen a sus esclavas a prostituirse con el fin de obtener ganancias, siendo que ellas quieren casarse. Y si [a pesar de esta prohibición] fueran forzadas a hacerlo, [que sepan ellas que] Dios es Absolvedor, Misericordioso.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdcccxxv{Les he revelado [en el Sagrado Corán] signos evidentes y relatos de quienes los precedieron, y exhortación para los piadosos.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcccxxvi{Dios es la luz de los cielos y de la Tierra. Su luz es como [la que surge de] una hornacina en la cual hay una lámpara dentro de un recipiente de vidrio, tan brillante como un astro resplandeciente. La lámpara se enciende con el aceite de un árbol bendito de olivo, procedente de una zona central entre oriente y occidente, cuyo aceite por poco alumbra sin haber sido tocado por el fuego: Es luz sobre luz. Dios guía hacia Su luz a quien Él quiere, y expone ejemplos para que la gente recapacite. Él lo sabe todo.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcccxxvii{[Esas hornacinas están] en las casas [de oración] que Dios permitió que fueran erigidas y honradas para que se invoque Su nombre. En ellas Lo glorifican por la mañana y por la tarde.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcccxxviii{[En las mezquitas hay] hombres a los que ni los negocios ni las ventas los distraen del recuerdo de Dios, la práctica de la oración prescrita y el pago del zakat, porque temen el día en que los corazones y las miradas se estremezcan.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcccxxix{Dios los recompensará de la mejor forma por sus buenas obras, y por Su gracia les multiplicará su recompensa. Dios agracia sin medida a quien Él quiere.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcccxxx{Las obras de los que se negaron a creer son como un espejismo en el desierto: el sediento cree que es agua, pero cuando llega a él no encuentra nada. Pero sí se encontrarán con Dios, que les dará el castigo que merezcan. Dios es rápido en ajustar cuentas.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcccxxxi{[El estado de los que se negaron a creer es] como tinieblas en un mar profundo cubierto de olas, unas sobre otras, que a su vez están cubiertas por nubes. Son tinieblas que se superponen unas sobre otras. Si alguien mirase su mano, apenas podría distinguirla. De este modo, a quien Dios no ilumine jamás encontrará la luz.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcccxxxii{¿Acaso no ves que todo cuanto existe en los cielos y la Tierra glorifica a Dios? Hasta las aves con sus alas desplegadas lo hacen. Cada ser tiene su oración y forma de glorificar. Dios bien sabe lo que hacen.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcccxxxiii{A Dios pertenece el reino de los cielos y de la Tierra, y ante Él compareceréis.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcccxxxiv{¿Acaso no reparas que Dios impulsa las nubes lentamente, luego las agrupa, y después ves caer la lluvia? Dios hace descender nubes como montañas, cargadas de granizo con el que azota a quien quiere, pero protege de él a quien quiere. El solo resplandor del relámpago podría enceguecer.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcccxxxv{Dios hace que la noche y el día se sucedan. En esto hay un motivo de reflexión para los que tienen ojos [y quieren ver].\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdcccxxxvi{Dios creó a todo ser vivo del agua. Algunos de ellos se arrastran sobre sus vientres, otros caminan sobre dos patas, y otros sobre cuatro. Dios crea lo que quiere. Dios es sobre toda cosa Poderoso.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdcccxxxvii{He revelado [en este Corán] signos evidentes. Dios guía a quien Él quiere hacia el camino recto.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdcccxxxviii{Dicen [los hipócritas]: ``Creemos en Dios y en el Mensajero, y los obedecemos". Pero luego, a pesar de haberlo dicho, un grupo de ellos te dan la espalda. Esos no son los creyentes.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdcccxxxix{Cuando se los llama para que acepten el juicio de Dios y Su Mensajero, hay un grupo de ellos que se rehúsan,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdcccxl{salvo cuando el fallo les es favorable, entonces lo acatan con sumisión.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdcccxli{¿Es que sus corazones están enfermos [de tanta hipocresía], o dudan [acerca de Mujámmad], o acaso temen que Dios y Su Mensajero los opriman? Ellos son los injustos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdcccxlii{En cambio, los creyentes, cuando se los llama a aceptar el juicio de Dios y Su Mensajero en sus asuntos, dicen: ``¡Escuchamos y obedecemos!" Ellos son los bienaventurados.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdcccxliii{Quienes obedezcan a Dios y a Su Mensajero, tengan temor a Dios y sean piadosos, ellos serán los bienaventurados.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdcccxliv{[Los hipócritas] juran por Dios que si los convocas [¡oh, Mujámmad!] para luchar por la causa de Dios, dejarán sus hogares y saldrán a combatir. Pero diles: ``No juren en falso, su obediencia es solo de palabra". Dios está bien informado de lo que hacen.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdcccxlv{Diles: ``Obedezcan a Dios y obedezcan a Su Mensajero". Pero si se rehúsan, el Mensajero solo rendirá cuentas por lo que se le ha encomendado, y ellos deberán rendir cuentas por lo que se les ha ordenado. Pero si le obedecen [al Mensajero] se encaminarán. Mi Mensajero solo tiene la obligación de transmitir [el Mensaje] con claridad.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdcccxlvi{Dios prometió hacer prevalecer en la Tierra a quienes crean y obren correctamente, como lo hizo con quienes los precedieron. [Dios] les concederá el poder necesario para que puedan practicar la religión que Dios ha dispuesto [el Islam], y transformará su temor en seguridad. Me adorarán sin atribuirme copartícipe alguno. Pero luego de todo esto, quienes se nieguen a creer [y no agradezcan Mis gracias], esos son los perversos.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdcccxlvii{Cumplan con la oración prescrita, paguen el zakat, y obedezcan al Mensajero, que así obtendrán la misericordia.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdcccxlviii{No creas que los que se negaron a creer podrán escapar [de Mi castigo] en la Tierra. Su morada será el Infierno. ¡Qué mal destino!\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdcccxlix{¡Oh, creyentes! Que sus sirvientes y sus hijos que todavía no han alcanzado la pubertad, les pidan permiso [para ingresar a sus alcobas] antes de la oración del alba, a la siesta cuando se quitan la ropa [para descansar], y después de la oración de la noche, pues éstos son tres momentos en los que su desnudez podría quedar al descubierto. Fuera de ello, pueden entrar sin pedir permiso, porque se frecuentan unos a otros con asiduidad. Así es como Dios les aclara Sus Signos. Dios es Conocedor, Sabio.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdcccl{Cuando sus hijos alcancen la pubertad deberán pedir permiso en todo momento, como lo hacen los adultos. Así es como Dios les aclara Sus signos. Dios es Conocedor, Sabio.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdcccli{Las mujeres que hayan llegado a la menopausia y ya no tengan deseo sexual, pueden aligerar sus vestimentas, siempre que no sea para exhibirse y provocar. Pero si se abstienen por recato es mejor para ellas. Dios todo lo oye, todo lo sabe.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdccclii{No es motivo de reproche que el ciego, el cojo, el enfermo ni ustedes mismos coman [de lo que les ofrezcan, ya sea comida procedente] de su propia casa, o de la casa de sus padres o de sus madres o de sus hermanos o de sus hermanas, o de sus tíos o tías paternos, o de sus tíos o tías maternos, o de aquellas [casas] que están a su cargo o [de la casa] de algún amigo; ni incurren en falta si comen juntos o por separado. Pero siempre que entren a [cualquiera de estas] casas, salúdense unos a otros con el saludo de la paz, un saludo bendecido y excelente, como Dios manda. Así es como Dios les aclara Sus Signos para que puedan comprender.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdcccliii{Los verdaderos creyentes son aquellos que creen en Dios y Su Mensajero, y que cuando están reunidos con él [el Mensajero de Dios] por un motivo importante, no se retiran sin antes pedirle permiso. Los que te piden permiso son los que realmente creen en Dios y Su Mensajero. Cuando te pidan permiso [¡oh, Mujámmad!, para retirarse] por algún motivo que les concierna, dáselo a quienes quieras, y pide perdón a Dios por ellos. Dios es Absolvedor, Misericordioso.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdcccliv{No llamen al Mensajero de la misma manera que se llaman unos a otros. Dios conoce bien a quienes se retiran con disimulo [sin pedir permiso]. Que estén precavidos aquellos que desobedezcan las órdenes del Mensajero de Dios, no sea que les sobrevenga una desgracia o los azote un castigo severo.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdccclv{¿Acaso no es de Dios cuanto hay en los cielos y en la Tierra? Él sabe bien lo que hacen. El día que comparezcan ante Él, les informará todas sus obras, pues Dios es conocedor de todas las cosas.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdccclvi{\basmalahes Bendito sea Quien reveló la fuente de todo criterio a Su siervo [el Profeta Mujámmad], para que con él advierta a todos los mundos.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdccclvii{A Él pertenece la soberanía de los cielos y de la Tierra. Él no ha tenido ningún hijo, y no comparte Su soberanía con nadie, creó todos los elementos de la creación y facultó plenamente a cada uno de ellos para cumplir su función.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdccclviii{Pero [los que se niegan a creer] adoran en vez de Dios a ídolos que no pueden crear nada, pues ellos mismos han sido creados, ni siquiera tienen el poder de apartar de sí mismos un perjuicio ni de atraer hacia sí mismos un beneficio. Tampoco tienen poder sobre la muerte, la vida ni la resurrección.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdccclix{Los que se niegan a creer dicen [acerca del Corán]: ``Esto no es más que una mentira que [Mujámmad] ha inventado con la ayuda de otros". Pero son ellos los que han cometido una injusticia y una mentira.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdccclx{Dicen: ``Son las fábulas de nuestros ancestros que ha copiado, las cuales le son dictadas por la mañana y por la tarde".\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdccclxi{Diles [¡oh, Mujámmad!]: ``Lo ha revelado Quien conoce lo oculto en los cielos y en la Tierra; Él es Absolvedor, Misericordioso".\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdccclxii{Y dicen: ``¿Qué clase de Mensajero es éste? Se alimenta y anda por el mercado [ganándose la vida] igual que nosotros. [Si de verdad es un Mensajero,] ¿Por qué no desciende un ángel y lo secunda en su misión de advertir?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdccclxiii{¿Por qué no le es enviado un tesoro o le es concedido un huerto del que pueda comer?" Los opresores dicen: ``Solo siguen a un hombre hechizado".\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdccclxiv{Mira [¡oh, Mujámmad!] cómo te comparan y se extravían sin poder encontrar el camino.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdccclxv{Bendito sea Quien, si quisiera, te concedería [en este mundo] algo mejor que lo que ellos pretenden: jardines por donde corren ríos y grandes palacios.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdccclxvi{[Dicen esto porque] no creen en la Hora [del Día del Juicio], pero he preparado un fuego para quienes desmienten la Hora.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdccclxvii{Cuando [el Infierno] los vea de lejos, oirán cómo brama [de furia] y crepita.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdccclxviii{Y cuando, encadenados, sean arrojados en un lugar estrecho del Infierno, pedirán sollozando ser destruidos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdccclxix{[Pero se les dirá:] ``Hoy no pedirán una sola vez ser destruidos, sino que lo han de pedir muchas veces".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdccclxx{Diles [¡oh, Mujámmad!]: ``¿Acaso [ese tormento] es mejor que el Paraíso eterno que se les ha prometido a los piadosos? Para ellos [los piadosos] el Paraíso será su recompensa y destino final,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdccclxxi{allí tendrán cuanto deseen por toda la eternidad. Esa es la promesa [de Dios], con la que tu Señor se ha comprometido.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdccclxxii{El día que Él los congregue junto a lo que adoraban en lugar de Dios, y [Dios] les pregunte [a los ídolos]: ‘¿Fueron ustedes los que desviaron a Mis siervos, o fueron ellos mismos los que se desviaron del camino?’\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdccclxxiii{Ellos responderán: ‘¡Glorificado seas! No nos correspondía tomar algún otro protector fuera de Ti. Tú [¡oh, Señor nuestro!] los agraciaste, a ellos y a sus padres, y los dejaste disfrutar por largo tiempo, hasta que olvidaron el Mensaje y fueron gente perdida’.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdccclxxiv{[Entonces, Dios dirá a los idólatras:] ``Sus ídolos los han desmentido, y ahora no podrán escapar de Mi castigo ni encontrar quién los socorra. [Sepan que] a quien cometa la injusticia [de dedicar actos de adoración a otro que Dios], lo haré sufrir un gran castigo".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdccclxxv{Todos los Mensajeros que envié antes de ti [¡oh, Mujámmad!] se alimentaban y caminaban por el mercado [procurando su sustento]. Los ponemos a prueba unos con otros, para que se evidencie quién es paciente. Tu Señor lo ve todo.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdccclxxvi{Dicen quienes no creen que comparecerán ante Mí: ``¿Por qué no descienden sobre nosotros los ángeles [con el Mensaje]; por qué no vemos directamente a nuestro Señor?" Se han considerado demasiado importantes a sí mismos y su insolencia es enorme.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdccclxxvii{El día que vean a los ángeles, no habrá buenas noticias para los criminales. Los ángeles les dirán: ``[El Paraíso] les queda vedado para siempre".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdccclxxviii{[Ese día] reduciré todas sus obras a polvo disperso en el aire.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdccclxxix{En cambio, los moradores del Paraíso tendrán la mejor morada y el mejor lugar de descanso.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdccclxxx{El día que el cielo se abra con las nubes y los ángeles desciendan del cielo, uno tras otro.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdccclxxxi{Ese día, la verdadera soberanía será del Misericordioso, y para los que se negaron a creer será un día difícil.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdccclxxxii{El injusto morderá sus propias manos [lamentándose] y dirá: ``¡Ojalá hubiera seguido el camino del Mensajero!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdccclxxxiii{¡Ay de mí! ¡Ojalá no hubiera tomado a aquel por amigo!,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdccclxxxiv{pues me alejó del Mensaje, a pesar de que me había llegado". El demonio lleva al ser humano a la decepción.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdccclxxxv{Dijo el Mensajero: ``¡Oh, Señor mío! Mi pueblo ha abandonado el Corán".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdccclxxxvi{[Sabe, ¡oh, Mujámmad!, que] dispuse que todos los Profetas tuvieran enemigos de entre los pecadores. Pero tu Señor es suficiente como guía y protector.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdccclxxxvii{Los que se negaron a creer dicen: ``¿Por qué no le ha sido revelado el Corán de una sola vez?" Sabe que te lo he revelado gradualmente para dar firmeza a tu corazón.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdccclxxxviii{Siempre que ellos presenten un argumento [en contra del Mensaje] te revelaré la Verdad, para que los refutes con un fundamento más claro y una explicación mejor.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdccclxxxix{Los que sean arrastrados sobre sus caras al Infierno serán quienes tengan el peor destino, los más extraviados del camino.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcccxc{Le revelé a Moisés el Libro [la Tora], y le asigné a su hermano Aarón para que lo ayudara [en la transmisión del Mensaje].\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcccxci{Y les dije: ``Vayan ambos al pueblo que desmintió Mis signos". Pero finalmente lo destruí por completo.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcccxcii{Al pueblo de Noé, cuando desmintieron a los Profetas, los ahogué e hice de ellos un Signo para la gente. Tengo reservado para los injustos un castigo doloroso.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcccxciii{A los pueblos de ‘Ad, Zamud y Rass, y a muchas otras generaciones entre ellos [también los castigué].\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcccxciv{A todos les advertí de lo que sucedía [a los que se negaban a creer], pero aun así terminaron siendo destruidos por completo.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcccxcv{Todos han visto las ruinas de la ciudad sobre la cual hice caer una lluvia de piedras, pero no recapacitan, pues no creen en la resurrección.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcccxcvi{Y cuando te ven se burlan de ti diciendo: ``¿Éste es al que Dios envió como Mensajero?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcccxcvii{De no haber sido porque nos mantuvimos firmes en la adoración de nuestros ídolos, nos hubiera desviado". Pero ya sabrán, cuando vean el castigo, quiénes eran los desviados.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcccxcviii{¿Has visto a esos que toman su propio ego como su dios? Tú no eres responsable por sus acciones.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcccxcix{¿Acaso crees que la mayoría de ellos escuchan tus palabras y reflexionan? Ellos son como los ganados que no razonan, o aún más extraviados del camino.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcm{¿No ves cómo tu Señor extiende la sombra? Si Él quisiera podría dejarla fija, pero ha hecho que se deslice siguiendo el curso del sol.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcmi{Luego hace que desaparezca gradualmente.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcmii{Él es Quien dispuso que la noche los cubra [con su oscuridad], que el sueño les sirva para descansar, y que el día sea una resurrección [para buscar el sustento].\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcmiii{Él es Quien envía los vientos como anuncios de Su misericordia, y hace descender del cielo agua pura,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcmiv{para revivir con ella la tierra árida, y dar de beber a la gran cantidad de animales y seres humanos que ha creado.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcmv{Y distribuye el agua [entre los seres creados] para que recapaciten, pero la mayoría de la gente es ingrata.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcmvi{Si hubiera querido, habría enviado a cada ciudad un Profeta.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcmvii{No obedezcas a los que se niegan a creer, y lucha contra ellos esforzadamente, exhortándolos con el Corán.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcmviii{Él es Quien ha hecho confluir las dos masas de agua, una dulce y la otra salada. Entre ambas puso un espacio intermedio y una barrera infranqueable.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcmix{Él es Quien creó al ser humano del agua, y dispuso para él un parentesco de sangre y otro por matrimonio. Tu Señor tiene poder sobre todas las cosas.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcmx{Sin embargo [los idólatras] adoran, en lugar de Dios, lo que no tiene poder para causarles beneficio ni perjuicio alguno. El que se niega a creer, da la espalda a su Señor.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcmxi{Te he enviado [¡oh, Mujámmad!] para que albricies [a los piadosos con el Paraíso] y adviertas [del Infierno a los que se niegan a creer].\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcmxii{Diles: ``No les pido ninguna remuneración a cambio [de enseñarles el Mensaje]. Quien quiera, que tome un camino hacia su Señor".\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcmxiii{Encomiéndate al Viviente Inmortal, y glorifícalo con Sus alabanzas. Él basta como conocedor de los pecados de Sus siervos.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcmxiv{Él es Quien creó los cielos, la Tierra y todo lo que hay entre ambos en seis eras, luego se estableció sobre el Trono. Él es Misericordioso. Pregunta sobre Él [su Ser, nombres y atributos] a quien tenga conocimiento.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcmxv{Cuando se les dice [a los idólatras]: ``Prostérnense ante el Compasivo", exclaman: ``¿Quién es el Compasivo? No nos vamos a prosternar ante quien nos ordenas". Y eso los aleja aún más.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcmxvi{Bendito sea Quien creó en el cielo constelaciones, y puso en él [al Sol como] una fuente irradiante de luz, y una Luna luminosa.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcmxvii{Él es Quien dispuso la sucesión de la noche y el día para que reflexionen y Le agradezcan.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcmxviii{Los siervos del Misericordioso son aquellos que caminan sobre la faz de Tierra con humildad, y cuando son increpados por los ignorantes les responden [con palabras de] paz.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcmxix{Los que pasan la noche prosternados y de pie adorando a su Señor,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcmxx{e imploran: ``¡Oh, Señor nuestro! Sálvanos del castigo del Infierno, porque su castigo será permanente,\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcmxxi{será una morada terrible y un mal destino".\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcmxxii{[Los siervos del Misericordioso son] aquellos que cuando hacen una caridad no dan todo lo que tienen ni tampoco escatiman, sino que dan con equilibrio.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcmxxiii{Los que no invocan a nada ni a nadie junto con Dios, no matan a quien Dios ha prohibido matar salvo con justo derecho, y no cometen fornicación ni adulterio. [Sepan que] quienes cometan algo de esto merecerán recibir una pena,\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcmxxiv{el Día de la Resurrección se les multiplicará el tormento, en el que permanecerán humillados,\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcmxxv{salvo quienes se arrepientan, crean y hagan obras de bien. A estos Dios les perdonará sus pecados, y en su lugar les registrará buenas obras. Dios es Absolvedor, Misericordioso.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcmxxvi{A quien se arrepienta y haga obras de bien, Dios le aceptará su arrepentimiento.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcmxxvii{Aquellos que no dan falso testimonio, y cuando pasan junto a la frivolidad lo hacen con dignidad.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcmxxviii{Aquellos que cuando se los exhorta a reflexionar sobre los versículos de su Señor no se hacen los sordos ni los ciegos.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcmxxix{Aquellos que piden: ``¡Oh, Señor nuestro! Agrácianos con cónyuges y descendientes que sean un motivo de alegría y tranquilidad para nosotros, y haz que seamos un ejemplo para los que tienen temor [de Dios]".\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcmxxx{Ellos serán recompensados con el Paraíso por su perseverancia, y serán recibidos [por los ángeles] con un saludo de paz.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcmxxxi{Allí vivirán por toda la eternidad. ¡Qué hermosa morada y lugar de permanencia!\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcmxxxii{Diles [¡oh, Mujámmad!]: ``¿Por qué iba a prestarles atención mi Señor si no Le ruegan? Pero ustedes [que se han negado a creer] han desmentido Su Mensaje, y por eso merecen que los azote el castigo".\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcmxxxiii{\basmalahes Ta’. Sin. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcmxxxiv{Estos son los signos de un Libro claro.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcmxxxv{¿Es que vas a consumirte [de tanto pesar] porque [tu gente] se niegan a creer?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcmxxxvi{Si quisiera les enviaría un signo del cielo, ante el cual sus cuellos se inclinarían con sumisión.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcmxxxvii{Siempre que se les presentó una revelación del Misericordioso se apartaron de ella.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcmxxxviii{Negaron la Verdad [una y otra vez]; ya se les informará acerca de lo que se burlaban.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcmxxxix{¿Acaso no observan la Tierra y reparan sobre cuántas especies nobles he creado en ella?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcmxl{En eso hay un signo, pero la mayoría no cree.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcmxli{Tu Señor es Poderoso, Misericordioso.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcmxlii{[Recuerda] cuando tu Señor llamó a Moisés y le dijo: ``Dirígete al pueblo injusto:\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcmxliii{El pueblo del Faraón, y exhórtalos a comportarse con temor de Dios".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcmxliv{Dijo [Moisés]: ``¡Oh, Señor mío! Temo que me desmientan,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcmxlv{y entonces mi pecho se oprima y mi lengua no pueda expresarse con fluidez. Envía, a [mi hermano] Aarón conmigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcmxlvi{Ellos me acusan de un crimen y temo que me maten".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcmxlvii{Dijo [Dios]: ``No temas. Vayan ambos con Mis signos, que estaré junto a ustedes escuchando.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcmxlviii{Preséntense ante el Faraón y díganle: ‘Somos Mensajeros enviados por el Señor del Universo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmcmxlix{Deja marchar con nosotros a los Hijos de Israel’".\qt@no{17}}
\qt@newcmd\qurantrans@es@mmcml{Dijo [el Faraón]: ``¿Acaso no te criamos [¡oh, Moisés!] desde niño, y permaneciste con nosotros muchos años de tu vida,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmcmli{e hiciste lo que hiciste, convirtiéndote en un renegado [desagradecido con nosotros de todo lo que te dimos]?"\qt@no{19}}
\qt@newcmd\qurantrans@es@mmcmlii{Dijo [Moisés]: ``Cuando lo hice estaba aún en la perdición.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmcmliii{Luego hui de ustedes por temor [a que me mataran]. Pero mi Señor me agració con la sabiduría y me hizo uno de Sus Mensajeros.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmcmliv{En cuanto al favor que me recuerdas, ¿acaso no se debió a que habías esclavizado a los Hijos de Israel?"\qt@no{22}}
\qt@newcmd\qurantrans@es@mmcmlv{Preguntó el Faraón: ``¿Quién es el Señor del Universo?"\qt@no{23}}
\qt@newcmd\qurantrans@es@mmcmlvi{Dijo [Moisés]: ``Es el Señor de los cielos, la Tierra y todo lo que hay entre ambos. Deberían tener certeza de eso".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmcmlvii{Dijo [el Faraón] a quienes estaban en torno a él: ``¿Han oído?"\qt@no{25}}
\qt@newcmd\qurantrans@es@mmcmlviii{Agregó [Moisés]: ``Es su Señor y el Señor de sus ancestros".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmcmlix{Dijo [el Faraón a su pueblo]: ``El Mensajero que les ha sido enviado es un demente".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmcmlx{[Moisés] prosiguió: ``Él es el Señor del oriente y del occidente, y de lo que hay entre ambos. Deberían razonar sobre eso".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmcmlxi{Dijo [el Faraón]: ``Si tienes otro dios que no sea yo, haré que te encarcelen".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmcmlxii{Dijo [Moisés]: ``¿Incluso si te presentara una prueba evidente [de que soy Profeta]?"\qt@no{30}}
\qt@newcmd\qurantrans@es@mmcmlxiii{Dijo [el Faraón]: ``Preséntala, si es que dices la verdad".\qt@no{31}}
\qt@newcmd\qurantrans@es@mmcmlxiv{Entonces [Moisés] arrojó su vara, y ésta se convirtió en una serpiente auténtica.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmcmlxv{[Luego introdujo su mano por el cuello de su túnica y] al retirarla, ante todos los presentes, estaba blanca y resplandeciente.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmcmlxvi{Dijo [el Faraón] a la nobleza que estaba a su alrededor: ``Es un hechicero experto,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmcmlxvii{que pretende expulsarlos de su tierra [de Egipto] con su magia. ¿Qué me aconsejan hacer?"\qt@no{35}}
\qt@newcmd\qurantrans@es@mmcmlxviii{Dijeron: ``Demóralos a él y a su hermano, y envía emisarios por las ciudades\qt@no{36}}
\qt@newcmd\qurantrans@es@mmcmlxix{para que te traigan a todo hechicero experto".\qt@no{37}}
\qt@newcmd\qurantrans@es@mmcmlxx{Entonces, todos los hechiceros se reunieron el día fijado.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmcmlxxi{Se le dijo a la gente: ``¿Acaso no van a reunirse [para presenciar el duelo]?\qt@no{39}}
\qt@newcmd\qurantrans@es@mmcmlxxii{Seguiremos a los hechiceros, si son ellos los que vencen".\qt@no{40}}
\qt@newcmd\qurantrans@es@mmcmlxxiii{Cuando los hechiceros se presentaron ante el Faraón, consultaron: ``¿Tendremos una recompensa si somos los vencedores?"\qt@no{41}}
\qt@newcmd\qurantrans@es@mmcmlxxiv{Respondió [el Faraón]: ``¡Sí!, [se los recompensará debidamente] y estarán entre mis allegados".\qt@no{42}}
\qt@newcmd\qurantrans@es@mmcmlxxv{Les dijo Moisés [a los hechiceros]: ``Arrojen lo que vayan a arrojar".\qt@no{43}}
\qt@newcmd\qurantrans@es@mmcmlxxvi{Entonces, arrojaron sus cuerdas y varas, y dijeron: ``¡Por el poder del Faraón! Seremos los vencedores".\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcmlxxvii{[Moisés] arrojó su vara, y ésta se tragó sus ilusiones.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcmlxxviii{Los hechiceros [al percibir que eso no era hechicería] se prosternaron [ante Dios],\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcmlxxix{y dijeron: ``Creemos en el Señor del Universo,\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcmlxxx{el Señor de Moisés y de Aarón".\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcmlxxxi{Dijo [el Faraón sorprendido]: ``¿Acaso van a creer en él sin que yo se los permita? Creo que él es su maestro, el que les ha enseñado la magia. ¡Ya verán [mi venganza]! Haré que les amputen una mano y un pie opuestos, y luego los haré crucificar a todos".\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcmlxxxii{Dijeron: ``¡No nos importa! Nos volvemos al Señor.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcmlxxxiii{Anhelamos que Nuestro Señor perdone nuestros pecados por haber sido los primeros creyentes [en el Mensaje de Moisés]".\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcmlxxxiv{[Luego] Le inspiré a Moisés: ``Sal durante la noche con Mis siervos; y serán perseguidos".\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcmlxxxv{El Faraón envió emisarios a las ciudades para reclutar [hombres].\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcmlxxxvi{[Diciendo:] ``Ellos son solo unos pocos,\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcmlxxxvii{pero están llenos de odio hacia nosotros.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcmlxxxviii{Mientras que nosotros somos numerosos y estamos alerta".\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcmlxxxix{Así fue como los saqué [al Faraón y a su ejército de Egipto, un país repleto] de jardines, manantiales,\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcmxc{tesoros y residencias suntuosas.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcmxci{Hice que los Hijos de Israel lo heredaran.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcmxcii{[El Faraón y su ejército] iniciaron la persecución [de los Hijos de Israel] a la salida del sol.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcmxciii{Cuando los dos grupos se divisaron, los seguidores de Moisés exclamaron: ``¡[Pronto] seremos alcanzados!"\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcmxciv{Dijo [Moisés]: ``¡No, [no nos alcanzarán]! Pues mi Señor está conmigo, y Él me guiará [para saber cómo salvarnos]".\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcmxcv{Le inspiré a Moisés: ``Golpea el mar con tu vara", y el mar se dividió en dos. Cada lado [del mar] se asemejaba a una enorme montaña.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcmxcvi{Luego hice que los perseguidores [el Faraón y su ejército] los siguieran,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcmxcvii{y fue entonces cuando salvé a Moisés y a todos los que estaban con él,\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcmxcviii{ahogando a los perseguidores.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcmxcix{En esto hay un signo, aunque la mayoría de ellos no eran creyentes.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmm{Tu Señor es el Poderoso, el Misericordioso.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmi{[Y] relátales [también, ¡oh, Mujámmad!] la historia de Abraham,\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmii{cuando dijo a su padre y a su pueblo: ``¿Qué adoran?"\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmiii{Respondieron: ``Adoramos ídolos, a los que estamos consagrados".\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmiv{Dijo [Abraham]: ``¿Acaso pueden ellos oír sus súplicas?\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmv{¿Pueden concederles a ustedes algún beneficio o pueden causarles algún daño?"\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmvi{Respondieron: ``No, pero es lo que adoraban nuestros padres [y nosotros simplemente los imitamos]".\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmvii{Dijo [Abraham]: ``¿Acaso no han reflexionado en lo que adoran,\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmviii{tanto ustedes como sus ancestros?\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmix{Ellos [los que adoran] son mis enemigos, excepto el Señor del Universo,\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmx{pues él es Quien me ha creado y me guía,\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmxi{Él me da de comer y de beber.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmxii{Cuando enfermo, Él es Quien me cura.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmxiii{Él es Quien me hará morir y luego me dará vida [resucitándome],\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmxiv{de Él anhelo que perdone mis pecados el Día del Juicio.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmxv{¡Oh, Señor mío! Concédeme sabiduría y estar entre los justos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmxvi{Concédeme tener una buena reputación entre las generaciones futuras.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmxvii{Hazme estar entre los que heredarán el Jardín de las Delicias.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmxviii{Perdona a mi padre, pues está extraviado\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmxix{y no me humilles el Día de la Resurrección,\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmxx{el día en que de nada servirán las riquezas ni los hijos,\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmxxi{y solo estará a salvo quien tenga el corazón puro".\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmxxii{[Ese día] el Paraíso estará cerca de los piadosos.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmxxiii{El Infierno será expuesto ante los extraviados.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmxxiv{Se les preguntará [a los idólatras]: ``¿Dónde está lo que adoraban\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmxxv{en lugar de Dios? ¿Acaso pueden ellos socorrerlos o siquiera defenderse a sí mismos?"\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmxxvi{Serán arrojados [en el Infierno] tanto los ídolos como aquellos descarriados que los adoraron,\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmxxvii{y también los secuaces del demonio, todos juntos.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmxxviii{Dirán, mientras disputan:\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmxxix{``[Juramos] por Dios que estábamos en un error evidente,\qt@no{97}}
\qt@newcmd\qurantrans@es@mmmxxx{pues equiparábamos a los ídolos con el Señor del Universo [al adorarlos].\qt@no{98}}
\qt@newcmd\qurantrans@es@mmmxxxi{Pero fueron los pecadores los que nos desviaron.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmmxxxii{No tenemos a nadie que pueda interceder por nosotros,\qt@no{100}}
\qt@newcmd\qurantrans@es@mmmxxxiii{ni siquiera tenemos un amigo íntimo [que nos ayude].\qt@no{101}}
\qt@newcmd\qurantrans@es@mmmxxxiv{¡Ojalá se nos diera otra oportunidad [de retornar a la vida mundanal] para poder ser de los creyentes!"\qt@no{102}}
\qt@newcmd\qurantrans@es@mmmxxxv{En esto hay un signo, pero la mayoría de ellos no eran creyentes.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmmxxxvi{Tu Señor es el Poderoso, el Misericordioso.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmmxxxvii{El pueblo de Noé desmintió a los Mensajeros.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmmxxxviii{Su hermano Noé les dijo: ``Tengan temor de Dios,\qt@no{106}}
\qt@newcmd\qurantrans@es@mmmxxxix{soy para ustedes un Mensajero leal,\qt@no{107}}
\qt@newcmd\qurantrans@es@mmmxl{tengan temor de Dios y síganme.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmmxli{No les pido remuneración a cambio [de transmitirles el Mensaje]. Mi recompensa me la dará el Señor del Universo.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmmxlii{Tengan temor de Dios, y síganme".\qt@no{110}}
\qt@newcmd\qurantrans@es@mmmxliii{Dijeron: ``¿Acaso vamos a creerte, siendo que solo te siguen los más miserables?"\qt@no{111}}
\qt@newcmd\qurantrans@es@mmmxliv{Dijo [Noé]: ``¿Y qué conocimiento puedo tener yo de lo que hacían [antes de venir a mí]?\qt@no{112}}
\qt@newcmd\qurantrans@es@mmmxlv{Solo a mi Señor le compete juzgar sus obras. ¡Si tan solo lo entendieran!\qt@no{113}}
\qt@newcmd\qurantrans@es@mmmxlvi{Yo no rechazaré a ningún creyente.\qt@no{114}}
\qt@newcmd\qurantrans@es@mmmxlvii{Yo solo he sido enviado para amonestarlos claramente".\qt@no{115}}
\qt@newcmd\qurantrans@es@mmmxlviii{Dijeron: ``¡Oh, Noé! Si no dejas de insultar a nuestros ídolos te lapidaremos [hasta la muerte]".\qt@no{116}}
\qt@newcmd\qurantrans@es@mmmxlix{Dijo [Noé]: ``¡Oh, Señor mío! Mi pueblo me ha desmentido.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmml{Juzga definitivamente entre ellos y yo. Salva a los creyentes que están conmigo, y a mí con ellos".\qt@no{118}}
\qt@newcmd\qurantrans@es@mmmli{Los salvé a él y a los que creyeron en él en el arca abarrotada.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmmlii{Y ahogué a los que quedaron [sin subir al arca].\qt@no{120}}
\qt@newcmd\qurantrans@es@mmmliii{En esto hay un signo, pero la mayoría de ellos no eran creyentes.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmmliv{Tu Señor es el Poderoso, el Misericordioso.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmmlv{El pueblo de ‘Ad desmintió a los Mensajeros.\qt@no{123}}
\qt@newcmd\qurantrans@es@mmmlvi{Su hermano Hud les dijo: ``Tengan temor de Dios,\qt@no{124}}
\qt@newcmd\qurantrans@es@mmmlvii{yo soy para ustedes un Mensajero leal,\qt@no{125}}
\qt@newcmd\qurantrans@es@mmmlviii{tengan temor de Dios y síganme.\qt@no{126}}
\qt@newcmd\qurantrans@es@mmmlix{No les pido remuneración a cambio [de transmitirles el Mensaje]. Mi recompensa me la dará el Señor del Universo.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmmlx{Edifican enormes construcciones en todas las colinas solo por ostentación.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmmlxi{Habitan en palacios majestuosos como si fueran a vivir por toda la eternidad.\qt@no{129}}
\qt@newcmd\qurantrans@es@mmmlxii{Cuando atacan lo hacen sin piedad.\qt@no{130}}
\qt@newcmd\qurantrans@es@mmmlxiii{Tengan temor de Dios y síganme.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmmlxiv{Tengan temor de Quien los agració con todo lo que saben,\qt@no{132}}
\qt@newcmd\qurantrans@es@mmmlxv{les concedió hijos, rebaños,\qt@no{133}}
\qt@newcmd\qurantrans@es@mmmlxvi{jardines y manantiales.\qt@no{134}}
\qt@newcmd\qurantrans@es@mmmlxvii{Yo, en realidad, temo que los alcance el castigo de un día gravísimo".\qt@no{135}}
\qt@newcmd\qurantrans@es@mmmlxviii{Dijeron: ``No nos importa, nos da igual si nos exhortas o no,\qt@no{136}}
\qt@newcmd\qurantrans@es@mmmlxix{esto que hacemos es lo que acostumbraban hacer nuestros ancestros,\qt@no{137}}
\qt@newcmd\qurantrans@es@mmmlxx{y seguramente no seremos castigados".\qt@no{138}}
\qt@newcmd\qurantrans@es@mmmlxxi{Lo desmintieron [al Profeta Hud] y por eso los aniquilé. En eso hay un signo, aunque la mayoría de ellos no eran creyentes.\qt@no{139}}
\qt@newcmd\qurantrans@es@mmmlxxii{Tu Señor es el Poderoso, el Misericordioso.\qt@no{140}}
\qt@newcmd\qurantrans@es@mmmlxxiii{El pueblo de Zamud desmintió a los Mensajeros.\qt@no{141}}
\qt@newcmd\qurantrans@es@mmmlxxiv{Su hermano Sálih les dijo: ``Tengan temor de Dios,\qt@no{142}}
\qt@newcmd\qurantrans@es@mmmlxxv{yo soy para ustedes un Mensajero leal,\qt@no{143}}
\qt@newcmd\qurantrans@es@mmmlxxvi{tengan temor de Dios y síganme.\qt@no{144}}
\qt@newcmd\qurantrans@es@mmmlxxvii{No les pido remuneración a cambio [de transmitirles el Mensaje]. Mi recompensa me la dará el Señor del Universo.\qt@no{145}}
\qt@newcmd\qurantrans@es@mmmlxxviii{¿Acaso piensan que se los dejará vivir seguros [para siempre] en medio de lo que ahora los rodea,\qt@no{146}}
\qt@newcmd\qurantrans@es@mmmlxxix{entre jardines y manantiales,\qt@no{147}}
\qt@newcmd\qurantrans@es@mmmlxxx{entre campos cultivados y palmeras esbeltas con frutos tiernos?\qt@no{148}}
\qt@newcmd\qurantrans@es@mmmlxxxi{[Por ostentación] esculpen sus viviendas en las montañas.\qt@no{149}}
\qt@newcmd\qurantrans@es@mmmlxxxii{Tengan temor de Dios y síganme.\qt@no{150}}
\qt@newcmd\qurantrans@es@mmmlxxxiii{Y no obedezcan las órdenes de los que se extralimitan,\qt@no{151}}
\qt@newcmd\qurantrans@es@mmmlxxxiv{que corrompen la Tierra y no contribuyen al establecimiento del bienestar".\qt@no{152}}
\qt@newcmd\qurantrans@es@mmmlxxxv{Dijeron: ``Tú estás hechizado,\qt@no{153}}
\qt@newcmd\qurantrans@es@mmmlxxxvi{y eres un ser humano igual que nosotros. Tráenos una prueba [milagrosa de tu profecía], si es que dices la verdad".\qt@no{154}}
\qt@newcmd\qurantrans@es@mmmlxxxvii{Dijo [Sálih: ``Aquí tienen la prueba que piden,] a esta camella le corresponde beber un día y a ustedes otro.\qt@no{155}}
\qt@newcmd\qurantrans@es@mmmlxxxviii{No le hagan daño, de lo contrario los azotará el castigo de un día horrendo".\qt@no{156}}
\qt@newcmd\qurantrans@es@mmmlxxxix{Pero la mataron, y por la mañana amanecieron arrepentidos.\qt@no{157}}
\qt@newcmd\qurantrans@es@mmmxc{El castigo los azotó. En ello hay un signo, aunque la mayoría de ellos no eran creyentes.\qt@no{158}}
\qt@newcmd\qurantrans@es@mmmxci{Tu Señor es el Poderoso, el Misericordioso.\qt@no{159}}
\qt@newcmd\qurantrans@es@mmmxcii{El pueblo de Lot desmintió a los Mensajeros.\qt@no{160}}
\qt@newcmd\qurantrans@es@mmmxciii{Su hermano Lot les dijo: ``Tengan temor de Dios,\qt@no{161}}
\qt@newcmd\qurantrans@es@mmmxciv{yo soy para ustedes un Mensajero leal.\qt@no{162}}
\qt@newcmd\qurantrans@es@mmmxcv{Tengan temor de Dios y síganme.\qt@no{163}}
\qt@newcmd\qurantrans@es@mmmxcvi{No les pido remuneración a cambio [de transmitirles el Mensaje]. Mi recompensa me la dará el Señor del Universo.\qt@no{164}}
\qt@newcmd\qurantrans@es@mmmxcvii{Se orientan [por elección] a los hombres [para satisfacer sus deseos sexuales] entre toda la gente del mundo,\qt@no{165}}
\qt@newcmd\qurantrans@es@mmmxcviii{a la vez que se apartan de lo que su Señor creó para ustedes, su esposa [una pareja mujer]. Ustedes son un pueblo trasgresor".\qt@no{166}}
\qt@newcmd\qurantrans@es@mmmxcix{Dijeron: ``¡Oh, Lot! Si no dejas de recriminarnos te expulsaremos".\qt@no{167}}
\qt@newcmd\qurantrans@es@mmmc{Dijo [Lot]: ``Yo, soy claramente de los que repudian lo que ustedes hacen.\qt@no{168}}
\qt@newcmd\qurantrans@es@mmmci{¡Oh, Señor mío! Protégenos, a mi familia y a mí, de lo que ellos hacen".\qt@no{169}}
\qt@newcmd\qurantrans@es@mmmcii{Los salvé a él y a toda su familia,\qt@no{170}}
\qt@newcmd\qurantrans@es@mmmciii{excepto a la anciana [esposa de Lot] que estaba entre los que se quedaron.\qt@no{171}}
\qt@newcmd\qurantrans@es@mmmciv{Luego destruí a los demás.\qt@no{172}}
\qt@newcmd\qurantrans@es@mmmcv{Hice caer sobre ellos una lluvia [de piedras]. ¡Qué lluvia aterradora para los que habían sido advertidos!\qt@no{173}}
\qt@newcmd\qurantrans@es@mmmcvi{En ello hay un signo, aunque la mayoría de ellos no eran creyentes.\qt@no{174}}
\qt@newcmd\qurantrans@es@mmmcvii{Tu Señor es el Poderoso, el Misericordioso.\qt@no{175}}
\qt@newcmd\qurantrans@es@mmmcviii{El pueblo de Jetró desmintió a los Mensajeros.\qt@no{176}}
\qt@newcmd\qurantrans@es@mmmcix{Jetró les dijo: ``Tengan temor de Dios,\qt@no{177}}
\qt@newcmd\qurantrans@es@mmmcx{yo soy para ustedes un Mensajero leal.\qt@no{178}}
\qt@newcmd\qurantrans@es@mmmcxi{Tengan temor de Dios y síganme.\qt@no{179}}
\qt@newcmd\qurantrans@es@mmmcxii{No les pido remuneración a cambio [de transmitirles el Mensaje]. Mi recompensa me la dará el Señor del Universo.\qt@no{180}}
\qt@newcmd\qurantrans@es@mmmcxiii{Sean justos al medir y no mermen,\qt@no{181}}
\qt@newcmd\qurantrans@es@mmmcxiv{pesen con equidad,\qt@no{182}}
\qt@newcmd\qurantrans@es@mmmcxv{no estafen a la gente, no obren mal en la Tierra corrompiéndola,\qt@no{183}}
\qt@newcmd\qurantrans@es@mmmcxvi{y tengan temor de Quien los creó, a ustedes y a las primeras generaciones".\qt@no{184}}
\qt@newcmd\qurantrans@es@mmmcxvii{Le respondieron: ``Tú estás hechizado,\qt@no{185}}
\qt@newcmd\qurantrans@es@mmmcxviii{y eres un ser humano igual que nosotros, al que consideramos un mentiroso.\qt@no{186}}
\qt@newcmd\qurantrans@es@mmmcxix{Te desafiamos a que hagas caer sobre nosotros un pedazo de cielo, si es que dices la verdad".\qt@no{187}}
\qt@newcmd\qurantrans@es@mmmcxx{Dijo [Jetró]: ``Mi Señor conoce mejor que nadie lo que hacen".\qt@no{188}}
\qt@newcmd\qurantrans@es@mmmcxxi{Pero lo desmintieron, y por ello los azotó el castigo el día de la sombra. Fue el castigo de un día terrible.\qt@no{189}}
\qt@newcmd\qurantrans@es@mmmcxxii{En ello hay un signo, pero la mayoría de ellos no eran creyentes.\qt@no{190}}
\qt@newcmd\qurantrans@es@mmmcxxiii{Tu Señor es el Poderoso, el Misericordioso.\qt@no{191}}
\qt@newcmd\qurantrans@es@mmmcxxiv{Este [Corán] es una revelación del Señor del Universo.\qt@no{192}}
\qt@newcmd\qurantrans@es@mmmcxxv{Descendió con él el Espíritu Leal [el ángel Gabriel],\qt@no{193}}
\qt@newcmd\qurantrans@es@mmmcxxvi{y lo grabó en tu corazón [¡oh, Mujámmad!] para que seas uno de los que advierten [a su pueblo].\qt@no{194}}
\qt@newcmd\qurantrans@es@mmmcxxvii{Es una revelación en lengua árabe pura,\qt@no{195}}
\qt@newcmd\qurantrans@es@mmmcxxviii{que ya estaba mencionada en las primeras Escrituras.\qt@no{196}}
\qt@newcmd\qurantrans@es@mmmcxxix{¿Acaso no es prueba suficiente que lo reconozcan los sabios de los Hijos de Israel?\qt@no{197}}
\qt@newcmd\qurantrans@es@mmmcxxx{Si se lo hubiera revelado a alguien que no hubiera sido árabe\qt@no{198}}
\qt@newcmd\qurantrans@es@mmmcxxxi{para que se los recitara, no habrían creído.\qt@no{199}}
\qt@newcmd\qurantrans@es@mmmcxxxii{Así he impregnado los corazones de los que hacen el mal,\qt@no{200}}
\qt@newcmd\qurantrans@es@mmmcxxxiii{porque no creerán hasta que vean el castigo doloroso.\qt@no{201}}
\qt@newcmd\qurantrans@es@mmmcxxxiv{Pero éste les llegará sorpresivamente, sin que se den cuenta.\qt@no{202}}
\qt@newcmd\qurantrans@es@mmmcxxxv{Entonces dirán: ``¿No es posible que nos den una prórroga?"\qt@no{203}}
\qt@newcmd\qurantrans@es@mmmcxxxvi{¿Acaso no te desafiaban pidiéndote que les apresurara Mi castigo?\qt@no{204}}
\qt@newcmd\qurantrans@es@mmmcxxxvii{¿Qué te parece si los dejáramos disfrutar unos años más [de la vida mundanal]?\qt@no{205}}
\qt@newcmd\qurantrans@es@mmmcxxxviii{Cuando les llegue el castigo sobre el que fueron advertidos,\qt@no{206}}
\qt@newcmd\qurantrans@es@mmmcxxxix{de nada les servirá que se les haya dado una prórroga para seguir disfrutando [de la vida mundanal].\qt@no{207}}
\qt@newcmd\qurantrans@es@mmmcxl{No he destruido ninguna ciudad sin antes haberle enviado a quien les advirtiera\qt@no{208}}
\qt@newcmd\qurantrans@es@mmmcxli{con el Mensaje, porque no Soy injusto.\qt@no{209}}
\qt@newcmd\qurantrans@es@mmmcxlii{[Este Mensaje] no lo han hecho descender los demonios,\qt@no{210}}
\qt@newcmd\qurantrans@es@mmmcxliii{no les corresponde ni tienen poder para hacerlo.\qt@no{211}}
\qt@newcmd\qurantrans@es@mmmcxliv{A ellos no les permito oír [lo que ordeno a Mis ángeles].\qt@no{212}}
\qt@newcmd\qurantrans@es@mmmcxlv{Así que no invoquen a nada ni nadie junto a Dios, porque se autocondenarían al castigo.\qt@no{213}}
\qt@newcmd\qurantrans@es@mmmcxlvi{Advierte a tus familiares cercanos.\qt@no{214}}
\qt@newcmd\qurantrans@es@mmmcxlvii{Baja tus alas para proteger a los creyentes que te sigan.\qt@no{215}}
\qt@newcmd\qurantrans@es@mmmcxlviii{Pero si te desobedecen, diles: ``Yo no soy responsable de cómo obran".\qt@no{216}}
\qt@newcmd\qurantrans@es@mmmcxlix{Encomiéndate al Poderoso, el Misericordioso.\qt@no{217}}
\qt@newcmd\qurantrans@es@mmmcl{El que te ve cuando te pones de pie [para orar en soledad],\qt@no{218}}
\qt@newcmd\qurantrans@es@mmmcli{y cuando realizas tus movimientos entre los que se prosternan [durante la oración comunitaria].\qt@no{219}}
\qt@newcmd\qurantrans@es@mmmclii{Él todo lo oye, todo lo sabe.\qt@no{220}}
\qt@newcmd\qurantrans@es@mmmcliii{¿Quieren que les informe sobre quién descienden los demonios?\qt@no{221}}
\qt@newcmd\qurantrans@es@mmmcliv{Descienden sobre todo mentiroso perverso [que dice ser adivino].\qt@no{222}}
\qt@newcmd\qurantrans@es@mmmclv{Que prestan oídos [a los comentarios de la gente y los susurros de los demonios], pero la mayoría de lo que dicen son mentiras.\qt@no{223}}
\qt@newcmd\qurantrans@es@mmmclvi{Solo los descarriados siguen a los poetas [dándoles prioridad sobre la revelación].\qt@no{224}}
\qt@newcmd\qurantrans@es@mmmclvii{¿Acaso no ves cómo ellos [los poetas] en sus lugares de reunión divagan [porque no siguen la revelación],\qt@no{225}}
\qt@newcmd\qurantrans@es@mmmclviii{y dicen lo que no hacen?\qt@no{226}}
\qt@newcmd\qurantrans@es@mmmclix{Excepto los creyentes de entre ellos que obran correctamente, mencionan mucho a Dios [en sus poesías], y responden con ellas a los agravios [de los poetas que se negaron a creer y ofendían en sus poesías a Mujámmad y al Islam]. Ya verán quienes hayan sido injustos, cuál será su destino.\qt@no{227}}
\qt@newcmd\qurantrans@es@mmmclx{\basmalahes Ta’. Sin. Estos son los versículos del Corán, el Libro evidente,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmclxi{que es guía y albricia para los creyentes,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmclxii{que cumplen con la oración prescrita, pagan el zakat y están convencidos de la existencia de la otra vida.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmclxiii{En cambio, a quienes no crean en la otra vida les haré ver como buenas sus malas acciones, y así vagarán ciegos de un lado a otro.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmclxiv{Esos sufrirán el peor castigo, y en la otra vida serán los perdedores.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmclxv{Tú [¡oh, Mujámmad!] recibes el Corán que proviene del Sabio, el Conocedor.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmclxvi{[Recuerda] cuando Moisés dijo a su familia: ``He divisado un fuego. Les traeré noticias de él [para orientarnos], o bien una brasa encendida para que podamos calentarnos".\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmclxvii{Cuando llegó a él, una voz lo llamó: ``¡Bendito sea quien está donde el fuego y quienes están a su alrededor. Glorificado sea Dios, Señor del universo!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmclxviii{¡Oh, Moisés! Yo soy Dios, el Poderoso, el Sabio.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmclxix{Arroja tu vara". Cuando la vio moverse como si fuera una serpiente, atemorizado se dio vuelta buscando alejarse sin mirar atrás. [Pero Dios le dijo:] ``¡Oh, Moisés! No tengas temor; los Mensajeros no deben temer cuando están ante Mí.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmclxx{Sí, en cambio, quien haya obrado injustamente. Pero si enmienda, sepan que Yo soy Absolvedor, Misericordioso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmclxxi{Introduce tu mano por el cuello de tu túnica y saldrá blanca, resplandeciente, sin tener ningún mal. Esto es parte de los nueve signos destinados al Faraón y a su pueblo. Ellos son un pueblo perverso".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmclxxii{Pero cuando Mis Signos fueron visibles ante ellos, exclamaron: ``Esto es un hechizo evidente".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmclxxiii{Rechazaron los Signos, a pesar de estar convencidos [de que provenían de Dios], por perversidad y arrogancia. ¡Observa cuál fue el destino de los corruptores!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmclxxiv{Concedí a David y a Salomón el conocimiento. Ambos dijeron: ``¡Alabado sea Dios! Quien nos ha favorecido sobre muchos de Sus siervos creyentes".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmclxxv{Salomón sucedió a David [en la profecía]. Dijo: ``¡Oh, gente! Se me ha enseñado el lenguaje de los pájaros y se nos han concedido numerosos favores. Esto es una gracia evidente".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmclxxvi{Fueron concentradas ante Salomón sus tropas de yinnes, seres humanos y pájaros, y formadas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmclxxvii{Al pasar por un valle donde había hormigas, una de ellas dijo: ``¡Oh, hormigas! Entren en sus hormigueros, no sea que Salomón y sus tropas las pisen sin darse cuenta".\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmclxxviii{[Salomón] al oír lo que ella decía, sonrió y exclamó: ``¡Señor mío! Haz que te agradezca los favores que nos has concedido, tanto a mí como a mis padres, que haga obras de bien que Te complazcan, y cuéntame, por Tu misericordia, entre Tus siervos justos".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmclxxix{[Luego] pasó revista a los pájaros y dijo: ``¿Por qué no veo a la abubilla? ¿Acaso está ausente?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmclxxx{La castigaré severamente o la degollaré, a menos que me presente una excusa convincente".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmclxxxi{No tardó mucho en regresar, y [al volver] dijo: ``Tengo conocimiento de algo que tú ignoras. Te traigo desde Saba información fidedigna.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmclxxxii{He descubierto que allí reina una mujer, a la que se le ha concedido mucha riqueza y poder, y posee un Trono majestuoso.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmclxxxiii{Encontré que ella y su pueblo se prosternan ante el Sol, en vez de hacerlo ante Dios. El demonio les ha hecho ver sus malas obras como buenas, apartándolos del sendero recto y por eso no pueden ver la verdad.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmclxxxiv{No se prosternan ante Dios, Quien hace surgir lo que se encuentra escondido en los cielos y en la Tierra, y sabe lo que ocultan y lo que manifiestan.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmclxxxv{Dios, no hay divinidad salvo Él, el Señor del Trono majestuoso".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmclxxxvi{Dijo [Salomón a la abubilla]: ``Veremos si has dicho la verdad o eres de los que mienten.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmclxxxvii{Ve con esta carta mía y entrégasela, luego mantente apartado y observa cómo reaccionan [ella y su pueblo]".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmclxxxviii{Ella [la reina de Saba] dijo: ``¡Oh, nobles! Me han entregado una carta noble.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmclxxxix{Es de Salomón, y dice: ‘En el nombre de Dios, el Compasivo con toda la creación, el Misericordioso con los creyentes.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcxc{No se muestren altivos conmigo [y mi mensaje] y vengan a mí sumisos [monoteístas]’".\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcxci{Dijo ella: ``¡Oh, nobles! Aconséjenme sobre este asunto. No tomaré ninguna decisión sin que antes se pronuncien".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcxcii{Dijeron: ``Contamos con un gran poderío y una ofensiva poderosa, pero la decisión final te pertenece. Considera cuál será tu orden".\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcxciii{Dijo ella: ``Los reyes, cuando invaden una ciudad, la devastan y humillan a los nobles. Así suelen hacer.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcxciv{Voy a enviarles un regalo y a esperar con qué noticias vuelven los emisarios".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcxcv{Cuando [los emisarios] se presentaron ante Salomón, [este] dijo: ``¿Acaso me ofrecen riquezas [para tentarme], cuando lo que Dios me ha concedido es mejor que las riquezas con las que Él los ha proveído? Son ustedes quienes se complacen con sus regalos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcxcvi{Regresen a su pueblo [con los regalos, y adviertan] que los combatiremos con huestes a las que no podrán vencer, y los expulsaremos de su tierra, sometidos y humillados".\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmcxcvii{Dijo [Salomón a su corte]: ``¡Oh, nobles! ¿Quién de ustedes me traerá su trono antes de que vengan a mí, sumisos?"\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmcxcviii{Uno de los yinnes poderosos dijo: ``Yo te lo traeré antes de que te levantes de tu trono. Yo puedo hacerlo y soy digno de tu confianza".\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmcxcix{Dijo [un creyente piadoso] que tenía conocimiento del Libro: ``Yo te lo traeré antes de que parpadees". Y cuando [Salomón] lo vio delante suyo dijo: ``Esta es una de las gracias de mi Señor para probarme si soy agradecido o ingrato. Quien agradezca [las gracias de su Señor] se beneficiará a sí mismo, pero quien sea ingrato sepa que mi Señor es Opulento, Generoso".\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmcc{Dijo [Salomón]: ``Alteren la apariencia de su trono, para que cuando lo vea sepamos si se deja guiar [a la verdad] o es de aquellos que rehúsan la guía".\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmcci{Cuando ella llegó, se le preguntó: ``¿Así es tu trono?" Respondió: ``Pareciera que fuera él". [Dijo Salomón:] ``Recibimos el conocimiento antes que ella y nos sometimos a Dios".\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccii{Lo que ella adoraba en lugar de Dios le impedía ver la Verdad. Pertenecía a un pueblo de incrédulos.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmcciii{Se le dijo: ``Entra en el palacio [que los yinnes habían construido para Salomón]". Cuando ella lo vio, pensó que ingresaría a un estanque de agua y se recogió el vestido. Dijo [Salomón]: ``Todo este palacio es de cristal pulido". Dijo ella: ``¡Señor mío! He sido injusta conmigo misma [al adorar a otros junto a Dios], me someto junto con Salomón al [único] Dios, el Señor del universo".\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmcciv{Al pueblo llamado Zamud le envié a su hermano Sálih [como Profeta, quien les dijo]: ``Adoren solo a Dios". Pero ellos se dividieron en dos grupos que disputaban entre sí.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccv{Les dijo: ``¡Oh, pueblo mío! ¿Por qué prefieren obrar mal en vez de obrar bien? ¿Por qué no piden perdón a Dios para alcanzar la misericordia?"\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccvi{Dijeron: ``Creemos que tú y quienes te siguen nos traen mala suerte". Respondió: ``Sus adversidades se las envía Dios [por sus pecados]. Ustedes son un pueblo que ha sido seducido [por la superstición]".\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccvii{Había en la ciudad nueve personas que sembraban la corrupción y no contribuían al bienestar.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccviii{Se dijeron: ``Juremos por Dios que los sorprenderemos por la noche [y los mataremos] a él y a su familia, luego diremos a quienes exijan justicia: ‘Nosotros no presenciamos los crímenes de su familia, y decimos la verdad’".\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmccix{Ellos urdieron un plan, pero sin que se dieran cuenta, Yo tenía otro plan.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmccx{Observa cómo desbarato su plan: los destruí a ellos y a todo su pueblo [que fue cómplice].\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmccxi{Sus casas yacen vacías, porque cometieron injusticias. En ello hay un signo para quienes reflexionan.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmccxii{Salvé a quienes creían y tenían temor [de Dios].\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmccxiii{[Recuerda al Profeta] Lot, cuando le dijo a su pueblo: ``¿Cometen esa inmoralidad en público?"\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmccxiv{¿Buscan hombres para satisfacer su deseo en lugar de satisfacerlo con una mujer? Son un pueblo ignorante.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmccxv{Pero la única respuesta de su pueblo fue: ``Expulsen a la familia de Lot de la ciudad; son gente que se hacen los puros".\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmccxvi{Salvé a Lot y a su familia, excepto a su mujer, pues en el decreto era de las condenadas.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmccxvii{Hice que cayera sobre ellos una lluvia [de piedras]. ¡Qué lluvia más aterradora fue la que les envié!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmccxviii{Di: ``¡Alabado sea Dios! Que la paz sea sobre Sus siervos elegidos. ¿Quién es mejor: Dios o lo que Le asocian?"\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmccxix{¿Acaso Quien creó los cielos y la Tierra e hizo descender para ustedes agua del cielo, con la que hace surgir jardines espléndidos allí donde ustedes no podrían haber hecho crecer ni un árbol [puede equipararse a quien no es capaz de crear nada de eso]? ¿Acaso puede haber otra divinidad junto con Dios? Realmente son desviados.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmccxx{¿Acaso Quien hizo de la Tierra un lugar firme, dispuso en ella ríos, fijó montañas y puso entre los dos mares una barrera [puede equipararse a quien no es capaz de crear nada de eso]? ¿Acaso puede haber otra divinidad junto con Dios? La mayoría lo ignora.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmccxxi{¿Acaso Quien responde al afligido cuando Lo invoca, alivia los pesares y los ha hecho a ustedes los responsables de la Tierra [puede equipararse a quien no es capaz de hacer nada de eso]? ¿Acaso puede haber otra divinidad junto con Dios? Pocos son los que reflexionan.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmccxxii{¿Acaso Quien los guía en la oscuridad [de la noche] por la tierra y el mar, y envía los vientos que traen las lluvias como una misericordia [puede compararse a quien no es capaz de hacer nada de eso]? ¿Acaso puede haber otra divinidad junto con Dios? Dios está por encima de [los ídolos] que Le asocian.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmccxxiii{¿Acaso Quien origina la creación y luego la reproduce, y Quien los sustenta [con las gracias] del cielo y de la Tierra [puede equipararse a quien no es capaz de hacer nada de eso]? ¿Acaso puede haber otra divinidad junto con Dios? Di: ``Presenten sus pruebas, si es verdad lo que dicen".\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmccxxiv{Di: ``Nadie en los cielos ni en la Tierra conoce lo oculto salvo Dios. No saben siquiera cuándo serán resucitados.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmccxxv{Su conocimiento no alcanza a comprender la realidad de la otra vida, algunos incluso dudan de su existencia y son ciegos sobre ella.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmccxxvi{Los que se niegan a creer dicen: ``¿Acaso cuando seamos polvo, nosotros y nuestros padres, seremos resucitados?".\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmccxxvii{Eso ya se nos había prometido anteriormente, a nosotros y a nuestros padres. No es más que una fábula de los ancestros".\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmccxxviii{Di: ``Viajen por el mundo y observen cuál fue el final de los que han hecho el mal".\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmccxxix{No te entristezcas por ellos ni te angusties por lo que traman contra ti.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmccxxx{Ellos dicen: ``¿Cuándo se cumplirá tu advertencia? [Te desafiamos] Si es que dices la verdad".\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmccxxxi{Diles: ``Puede ser que sea muy pronto, que esté detrás de ustedes algo de lo que piden que suceda pronto".\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmccxxxii{Tu Señor concede Sus gracias a la gente, pero la mayoría no agradece.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmccxxxiii{Tu Señor conoce lo que esconden sus corazones y lo que manifiestan.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmccxxxiv{Todo lo que está oculto [al conocimiento de las personas] en el cielo y en la Tierra se encuentra registrado en un libro claro.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmccxxxv{El Corán les relata a los Hijos de Israel [la respuesta] a gran parte de los asuntos sobre los que discrepaban.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmccxxxvi{[El Corán] es guía y misericordia para los creyentes.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmccxxxvii{Tu Señor juzgará entre ellos con justicia. Él es el Poderoso, el que todo lo sabe.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmccxxxviii{Encomiéndate a Dios, que tú estás en la verdad evidente.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmccxxxix{Tú no puedes hacer que los muertos [de corazón] oigan ni que los sordos [que no quieren oír] escuchen la prédica cuando rechazan la Verdad.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmccxl{Ni puedes guiar a los ciegos [que no quieren ver] y sacarlos de su extravío. Tú solo puedes hacer que escuchen quienes creen en Mis signos y se someten a Dios [siendo musulmanes].\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmccxli{Cuando ocurra lo que ha sido decretado para ellos, haré salir de la Tierra una bestia que les hablará [milagrosamente diciéndoles] que la gente no estaba convencida de Mis signos.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmccxlii{El día que reúna, de cada nación, a quienes desmentían Mis signos, marcharán uno detrás del otro.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmccxliii{Al llegar [al lugar del juicio, Dios] les dirá: ``Desmintieron Mis signos sin siquiera conocerlos", [y se les preguntará:] ``¿Cuáles fueron sus obras?"\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmccxliv{Luego los azotará el castigo que había sido prometido por haber cometido injusticias, y no podrán decir una sola palabra [para excusarse].\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmccxlv{¿Acaso no ven que he creado la noche para que descansen y el día para que procuren el sustento? En eso hay signos para quienes creen.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmccxlvi{El día que se sople la trompeta se aterrorizarán todos aquellos que estén en los cielos y en la Tierra, salvo quienes Dios proteja. Todos se presentarán sumisos ante Él.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmccxlvii{Verán las montañas, las cuales creían firmes, pasar como lo hacen las nubes. Esto es obra de Dios, Quien ha hecho todo a la perfección. Él conoce lo que hacen.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmccxlviii{Quien se presente con buenas obras será recompensado con algo mejor [que lo que merezca], y estará a salvo del terror de ese día.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmccxlix{Pero quien se presente con obras malas será arrojado de cara al Fuego. [Se le dirá:] ``¿Acaso se les retribuye por algo distinto de lo que habían cometido?"\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmccl{[Diles, oh, Mujámmad:] ``Me ha sido ordenado adorar al Señor de esta ciudad [La Meca], a la que ha declarado sagrada; el Señor de todas las cosas. Me ha sido ordenado ser de los musulmanes [que someten a Dios su voluntad].\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmccli{[Se me ha ordenado] recitar el Corán. Quien siga la guía lo hará en beneficio propio, y a quien se extravíe dile: ``Yo solo he venido a advertirles…".\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmcclii{Di: ``¡Alabado sea Dios! Él les mostrará Sus signos y los reconocerán. [Sepan que] Su Señor no está desatento de lo que hacen".\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmccliii{\basmalahes Ta’. Sin. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmccliv{Éstos son los preceptos del Libro claro.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcclv{Te narro parte de la verdadera historia de Moisés y del Faraón, para la gente que cree.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcclvi{El Faraón fue un tirano en la Tierra. Dividió a sus habitantes en clases y esclavizó a un grupo de ellos, a cuyos hijos varones degolló, dejando con vida a las mujeres [para la servidumbre]. Sembró la corrupción.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcclvii{Quise agraciar a quienes habían sido esclavizados en la Tierra, y convertirlos en líderes ejemplares y en herederos,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcclviii{dándoles poder sobre la tierra, y hacer que el Faraón, Hamán y sus huestes vieran [hecho realidad] lo que temían.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcclix{Inspiré a la madre de Moisés: ``Amamántalo, y cuando temas por él déjalo [en un cesto de mimbre] en el río. No temas ni te entristezcas, porque te lo devolveré y lo haré un Mensajero".\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcclx{Lo recogió la gente del Faraón para que [sin saberlo] se convirtiera en su enemigo y la causa de su pesar. El Faraón, Hamán y sus huestes eran pecadores.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcclxi{Dijo la mujer del Faraón: ``[Este niño] será una alegría para mis ojos y los tuyos. No lo mates. Puede que nos beneficie. ¡Adoptémoslo!" Ellos no presentían [en qué se convertiría].\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcclxii{La madre de Moisés sintió un vacío en su corazón y estuvo a punto de revelar la verdad, de no haber sido porque afiancé su corazón para que fuera una verdadera creyente.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcclxiii{Le dijo [la madre] a la hermana [de Moisés]: ``Sigue sus rastros"; ella lo veía de lejos sin que se dieran cuenta.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcclxiv{No permití que ninguna nodriza pudiera amamantarlo. Dijo [la hermana de Moisés]: ``¿Acaso quieren que les indique una familia que puede cuidarlo y criarlo bien?"\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcclxv{Así se lo devolví a su madre [como nodriza] para consuelo de sus ojos, para que no se entristeciera y supiera que la promesa de Dios siempre se cumple, aunque la mayoría [de la gente] lo ignore.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcclxvi{Cuando se convirtió en adulto y tuvo madurez, le concedí conocimiento y sabiduría. Así es como retribuyo a quienes hacen el bien.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcclxvii{[Moisés] ingresó cierta vez a la ciudad sin que sus habitantes se percataran y encontró a dos hombres que peleaban, uno era de los suyos y el otro era de sus enemigos. El que era de los suyos le pidió ayuda contra el que era de sus enemigos. Entonces Moisés lo golpeó con su puño y [sin intención de hacerlo] le causó la muerte. Exclamó [Moisés]: ``Esto es obra del demonio, que es un enemigo evidente que pretende desviar a la gente".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcclxviii{Dijo: ``¡Señor mío! He sido injusto conmigo mismo; perdóname". Y [Dios] lo perdonó, porque Él es Absolvedor, Misericordioso.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcclxix{Dijo: ``¡Señor mío! Por la gracia que me has concedido, que no sea yo auxiliador de un malhechor criminal".\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcclxx{A la mañana siguiente amaneció temeroso y cauteloso, y quien le había pedido ayuda el día anterior nuevamente le pedía auxilio a gritos. Entonces Moisés le dijo: ``No cabe duda que eres un perdido [busca pleitos]".\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcclxxi{Cuando [Moisés] quiso agredir al enemigo de ambos, éste le dijo: ``¡Oh, Moisés! ¿Acaso pretendes matarme como lo hiciste con otro ayer? Solo quieres imponer tu tiranía en la tierra, en lugar de ser de aquellos que establecen el orden".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcclxxii{Entonces, un hombre que vivía en las afueras de la ciudad se dirigió presuroso [hacia donde Moisés] y le dijo: ``¡Oh, Moisés! La nobleza se confabuló para matarte. ¡Huye! Yo solo te aconsejo".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcclxxiii{Presuroso, Moisés se alejó de la ciudad con temor y cautela, diciendo: ``¡Señor mío! Protégeme de los opresores".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcclxxiv{Y cuando se encontraba camino a Madián dijo: ``¡Pueda que mi Señor me guie por el camino correcto!"\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcclxxv{Cuando llegó a la aguada de Madián, encontró pastores dando de beber a sus rebaños, y vio que apartadas de ellos había dos mujeres que sujetaban a sus rebaños, entonces les preguntó: ``¿Qué les sucede?" Respondieron [ellas]: ``No podemos abrevar a nuestro rebaño hasta que los pastores se hayan ido, y nuestro padre es ya un anciano [para hacerlo él]".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcclxxvi{Entonces [Moisés] abrevó al rebaño por ellas, y al terminar se retiró a la sombra y exclamó: ``¡Señor mío! Realmente necesito cualquier gracia que me concedas".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcclxxvii{[Más tarde,] una de ellas regresó y acercándose a él con recato le dijo: ``Mi padre te envía una invitación para retribuirte por haber abrevado nuestro rebaño". Y cuando se presentó ante él, le relató su historia, y [el padre de las dos mujeres] le dijo: ``No temas, [aquí] estás a salvo de los opresores".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcclxxviii{Una de ellas dijo: ``¡Oh, padre! Contrátalo, pues qué mejor que contratar a un hombre fuerte y honesto".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcclxxix{Dijo [el padre de las dos mujeres a Moisés]: ``Quisiera ofrecerte en matrimonio a una de mis dos hijas a condición de que trabajes con nosotros durante ocho años, pero si deseas quedarte diez será algo que tú hagas voluntariamente. No pretendo dificultarte las cosas, y me encontrarás, si Dios quiere, entre los que tratan con justicia [a sus empleados]".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcclxxx{Dijo [Moisés]: ``Eso es [un acuerdo] entre tú y yo. Cualquiera que sea el plazo que cumpla no será injusto conmigo, y Dios es testigo de lo que decimos".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcclxxxi{Cuando Moisés hubo cumplido el plazo, partió con su familia por la noche [rumbo a Egipto] y [en el camino] divisó un fuego en la ladera de un monte y le dijo a su familia: ``Permanezcan aquí, pues he divisado un fuego y quizás pueda traerles alguna noticia [del camino que debemos seguir], o bien una brasa encendida para que podamos calentarnos".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcclxxxii{Cuando llegó hasta el fuego escuchó un llamado que provenía desde un árbol que se encontraba en la ladera derecha del valle, en el lugar bendecido: ``¡Oh, Moisés! Yo soy Dios, el Señor del Universo.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcclxxxiii{Arroja tu vara". Y cuando la vio moverse como si fuera una serpiente, se dio vuelta para huir sin mirar atrás. [Le dijo Dios:] ``¡Oh, Moisés! Acércate y no temas. Tú eres de los que están a salvo.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcclxxxiv{Introduce tu mano por el cuello de tu túnica, y saldrá blanca y resplandeciente, sin ningún mal; y aprieta tu brazo junto al pecho para vencer el temor. Éstos son dos milagros de tu Señor para [que vean y crean] el Faraón y su nobleza. Ellos son un pueblo corrupto".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcclxxxv{Dijo [Moisés]: ``¡Señor mío! He matado a un hombre de los suyos y temo que me ejecuten.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcclxxxvi{Mi hermano Aarón es más elocuente que yo, envíalo conmigo para que me ayude y confirme lo que yo diga, pues temo que me desmientan".\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcclxxxvii{Dijo [Dios]: ``Te reforzaré con tu hermano y les daré autoridad. No podrán hacerles daño. Gracias a Mis milagros, ustedes dos y quienes los sigan serán los triunfadores".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcclxxxviii{Pero cuando Moisés se presentó con Mis signos evidentes, dijeron: ``Esto no es sino una ilusión creada por hechicería. No hemos oído hablar de esto a nuestros ancestros".\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcclxxxix{Dijo Moisés: ``Mi Señor sabe mejor que nadie quién ha venido con la guía que proviene de Él y quién triunfará en la otra vida. Los que cometen injusticias no prosperarán".\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmccxc{Dijo el Faraón: ``¡Oh, corte! No conozco otra divinidad que no sea yo mismo. ¡Oh, Hamán! Enciende el horno para cocer ladrillos de barro, y construyan para mí una torre para que quizás así pueda ver al dios de Moisés, aunque creo que es un mentiroso".\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmccxci{El Faraón y sus huestes tiranizaron el país violando todos los derechos, pensando que no iban a tener que comparecer ante Mí.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmccxcii{Pero los sorprendí, al Faraón y a sus huestes, y los ahogué en el mar. Observa cuál fue el final de los que cometían injusticias.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmccxciii{Hice que ellos [en esta vida] fueran líderes, pero conducían [a la gente al] Infierno. El Día de la Resurrección no serán socorridos.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmccxciv{Por eso decreté que en esta vida fueran maldecidos, y que en el Día de la Resurrección sean de los apartados de todo bien.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccxcv{Le he revelado a Moisés el Libro [la Tora] después de haber destruido a las anteriores generaciones [de opresores]. En él hay luz, guía y misericordia para que reflexionen.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmccxcvi{Y tú [¡oh, Mujámmad!] no estabas en la ladera occidental [del monte Sinaí] cuando ordené la misión de Moisés, ni fuiste testigo de ello.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmccxcvii{Pero hice surgir otras generaciones que tuvieron larga vida. Tú no viviste [¡oh, Mujámmad!] entre la gente de Madián para transmitirles Mi Mensaje, sino que te he designado Mensajero [para toda la humanidad].\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccxcviii{No estabas en la ladera del monte cuando llamé [a Moisés, y te lo revelo] como una misericordia para que adviertas a tu pueblo, al que no se le había presentado ningún Profeta para advertirles antes de ti. Quizás así reflexionen.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccxcix{Para que no digan cuando les acontezca una desgracia, a causa de las acciones malas que hicieron con sus propias manos: ``¡Señor nuestro! Si nos hubieras mandado un Mensajero, habríamos acatado Tus órdenes y nos hubiéramos contado entre los creyentes".\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccc{Sin embargo, cuando les llegó la Verdad proveniente de Mí dijeron: ``¿Por qué no se le han dado [a Mujámmad] las mismas evidencias que a Moisés?" Pero, ¿acaso no habían rechazado ya lo que anteriormente se le había concedido a Moisés? Dijeron: ``Son dos clases de hechiceros confabulados y no les creemos a ninguno de los dos".\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccci{Diles [¡oh, Mujámmad!]: ``Traigan un libro proveniente de Dios que sea una guía mejor que estos dos y yo lo seguiré, si es que dicen la verdad.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcccii{Pero si aun así no responden [a tu llamado], sabe que no hacen más que seguir sus propias pasiones. ¿Acaso existe alguien más extraviado que quien sigue sus pasiones sin ninguna guía de Dios? Dios no guía a la gente que comete injusticias.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmccciii{Les he revelado la palabra para que reflexionen.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmccciv{Quienes recibieron Mi revelación antes de él, creyeron en él.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcccv{Cuando se les recita [el Corán] dicen: ``Creemos en él; es la Verdad que proviene de nuestro Señor. Antes de escucharlo ya éramos musulmanes [sometidos a Dios]".\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcccvi{Ellos recibirán su recompensa dos veces por haber sido perseverantes, haber respondido el mal con bien, y haber dado en caridad parte de lo que les había proveído,\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcccvii{y cuando oían conversaciones frívolas se apartaban de ellas y exclamaban: ``Nosotros responderemos por nuestras acciones y ustedes por las suyas. ¡Que la paz sea con ustedes! No deseamos tratar con los ignorantes [de corazón]".\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcccviii{Tú no puedes guiar a quien amas, sino que Dios guía a quien Él quiere. Él sabe quiénes seguirán la guía.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcccix{Dicen: ``Si seguimos la guía que has traído, seremos expulsados de nuestra tierra". ¿Acaso no les he preparado un lugar sagrado y seguro, al cual llegan frutos de todas clases como sustento Mío? Pero la mayoría no sabe.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcccx{¡Cuántos pueblos destruí porque no agradecían el favor en que vivían! Observen sus viviendas: no volvieron a ser habitadas después de ellos, salvo brevemente. Yo fui Quien las heredó.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcccxi{Tu Señor no destruiría un pueblo sin antes enviar un Mensajero a su ciudad principal para que les trasmita Su Mensaje. Solo haría sucumbir un pueblo si ellos cometen injusticias.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcccxii{Todo aquello que se les ha concedido no es más que el simple goce de la vida mundanal y sus encantos. Pero la gracia que Dios tiene [reservada para los piadosos] es mejor y más duradera. ¿Acaso no razonan?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcccxiii{¿Acaso aquel a quien le he prometido una bella promesa [el Paraíso] que verá realizada, puede compararse a quien solo le he concedido el goce de la vida mundanal y el Día de la Resurrección será de los condenados [al tormento del Infierno]?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmcccxiv{El día que [Dios] los convoque y les pregunte: ``¿Dónde están los ‘socios’ que Me atribuían?"\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmcccxv{Dirán los [‘socios’] sentenciados [al Infierno]: ``¡Señor nuestro! Éstos son los que desviamos. Los desviamos porque nosotros estábamos desviados. No somos responsables por sus actos, no era a nosotros a quienes adoraban".\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmcccxvi{Se les dirá [a los idólatras]: ``Invoquen a quienes Me asociaban [para que los auxilien]". Los invocarán, pero no habrá respuesta, y verán acercarse el castigo. ¡Si tan solo hubieran seguido la guía!\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmcccxvii{El día que [Dios] los convoque y les pregunte: ``¿Cuál fue su respuesta al llamado de los Mensajeros?"\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmcccxviii{Ese día no sabrán qué argumentar ni podrán preguntarse unos a otros [qué responder].\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmcccxix{Pero quien se haya arrepentido, haya creído y hecho obras de bien, se contará entre quienes tendrán éxito.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmcccxx{Tu Señor es Quien crea y elige hacer lo que quiere, y la elección que Él hace no se somete a la opinión de nadie. ¡Glorificado sea Dios! Está por encima de lo que Le asocian.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmcccxxi{Tu Señor conoce lo que ocultan y lo que manifiestan sus corazones.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmcccxxii{Él es Al-lah, no hay más divinidad que Él. A Dios pertenecen las alabanzas en esta vida y en la otra. Suyo es el juicio, y ante Él comparecerán [el Día del Juicio].\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmcccxxiii{Di [a los que niegan el monoteísmo]: ``¿Si Dios hiciera que la noche durara hasta el Día de la Resurrección, quién sino Dios podría traerles la luz del día? ¿Acaso no van a escuchar [este argumento]?"\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmcccxxiv{Di: ``¿Si Dios hiciera que el día durara hasta el Día de la Resurrección, quién sino Dios podría traerles la oscuridad de la noche para que pudieran descansar? ¿Acaso no van a observar [este argumento]?"\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmcccxxv{Por misericordia fue Dios que creó la noche y el día para que ustedes pudieran descansar [durante la noche] y procurar [durante el día] Su favor. Deberían ser agradecidos.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmcccxxvi{El día que [Dios] los convoque y les pregunte: ``¿Dónde están los ‘socios’ que Me atribuían?"\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmcccxxvii{Cuando extraiga de cada pueblo un testigo y les diga: ``Presenten los fundamentos [de su idolatría]". Entonces, sabrán que la Verdad solo pertenece a Dios, y todo aquello que inventaron desaparecerá.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmcccxxviii{Qarún pertenecía al pueblo de Moisés, pero abusó de ellos. Le había concedido tantos tesoros, que hasta las llaves [de los cofres donde se guardaban] resultaban pesadas para un grupo de hombres fuertes. Pero su pueblo le dijo: ``No te jactes [de lo que tienes] porque Dios no ama a los arrogantes.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmcccxxix{Gánate el Paraíso con lo que Dios te ha concedido, y no te olvides que también puedes disfrutar de lo que Dios ha hecho lícito en esta vida. Sé generoso [con tu prójimo] como Dios lo es contigo, y no contamines la tierra; Dios no ama a los que contaminan [a sabiendas]".\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmcccxxx{Dijo [Qarún con soberbia]: ``Lo que se me ha concedido es gracias a mi conocimiento". ¿Acaso no sabía que Dios ya había destruido naciones más poderosas y con más riquezas que él? [Debido a lo terrible de sus faltas,] a los perversos no se les preguntará por sus pecados.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmcccxxxi{[Cierto día, Qarún] se presentó ante su pueblo con todo su lujo, y quienes amaban la vida mundanal exclamaron: ``¡Ojalá tuviéramos lo mismo que Qarún! Él tuvo mucha suerte".\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmcccxxxii{Pero quienes fueron agraciados con el conocimiento dijeron: ``¡Ay de ustedes! La recompensa de Dios para quien crea y haga obras de bien es superior, pero no la consiguen sino los que son pacientes".\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmcccxxxiii{Hice que la tierra se tragara a Qarún y a su palacio, y no hubo nadie que pudiera socorrerlo, ni siquiera pudo salvarse a sí mismo.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmcccxxxiv{Quienes antes habían deseado estar en su lugar comenzaron a decir: ``Dios le concede un sustento abundante a quien quiere y se lo restringe [a quien Él quiere] de Sus siervos. De no haber sido porque Dios nos agració con Su misericordia, nos hubiera tragado la tierra también a nosotros. Es muy cierto que quienes niegan la verdad nunca prosperan".\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmcccxxxv{La morada de la otra vida [en el Paraíso] es para quienes no son soberbios ni siembran la corrupción en la Tierra. ¡Bienaventurados sean los piadosos!\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmcccxxxvi{[El Día del Juicio Final,] quien se presente habiendo realizado obras buenas será recompensado más de lo merecido por ellas, pero quien se presente habiendo realizado obras malas solo será retribuido por lo que hizo.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmcccxxxvii{[Oh, Mujámmad,] Quien te ha ordenado el Corán, te hará regresar de la muerte a un lugar establecido [el Día del Juicio]. Diles: ``Mi Señor sabe mejor que nadie quién sigue la guía y quién está en un claro desvío".\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmcccxxxviii{Tú no esperabas que fuera a serte revelado un Libro, pero por misericordia de tu Señor [te reveló el Corán]. No apoyes [contra los creyentes] a aquellos que se niegan a creer.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmcccxxxix{No dejes que te aparten de los preceptos de Dios después de haberte sido revelados. Exhorta [a la gente] a adorar a tu Señor y no seas de los que Le asocian [divinidades en la adoración].\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmcccxl{No invoques a nada ni nadie junto con Dios. Nadie tiene derecho a ser adorado salvo Él. Todo ha de perecer excepto Su rostro. Suyo es el juicio y ante Él comparecerán.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmcccxli{\basmalahes Álif. Lam. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcccxlii{¿Acaso piensa la gente que se los dejará decir: ``¡Creemos!", y no van a ser puestos a prueba?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcccxliii{Puse a prueba a quienes los precedieron, para que Dios hiciera evidente quiénes son los sinceros y quiénes los mentirosos.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcccxliv{¿Acaso piensan quienes obran mal que podrán escapar de Mí? ¡Qué mal juzgan!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcccxlv{Quien anhele el encuentro con Dios sepa que el día que Dios fijó ha de llegar. Él todo lo oye, todo lo sabe.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcccxlvi{Quien luche [contra sus pasiones] será en beneficio propio. Dios no tiene necesidad de las cosas creadas.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcccxlvii{A quienes crean y hagan buenas obras les perdonaré sus faltas y los recompensaré por lo mejor de sus actos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcccxlviii{Le he ordenado al ser humano hacer el bien a sus padres. Pero si se esfuerzan por hacer que caigas en la idolatría de dedicar actos de adoración a otro que a Mí, lo cual es algo que no te he enseñado, no les debes obediencia. Ante Mí has de comparecer y te informaré lo que hacías.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcccxlix{A quienes hayan creído y hecho obras de bien los introduciré [al Paraíso] junto a los que obran con justicia.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcccl{Entre la gente hay quienes dicen: ``¡Creemos en Dios!"; pero cuando sufren algún perjuicio por la causa de Dios, consideran que la opresión de los hombres es un castigo de Dios [y reniegan de su fe]. En cambio, cuando tu Señor les concede un triunfo, dicen: ``¡Siempre hemos estado con ustedes!" ¿Acaso no es Dios Quien mejor sabe lo que hay en los corazones de la gente?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcccli{Dios hará evidente quiénes son los que creen y quiénes son los hipócritas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmccclii{Los que se niegan a creer dicen a los creyentes: ``Sigan nuestra fe y nosotros cargaremos con sus pecados". Pero ellos no pueden aligerar la carga de los pecados ajenos, son solo mentirosos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcccliii{Ellos no solo cargarán con sus propios pecados, sino también con los pecados que comentan aquellos que ellos extraviaron. El Día de la Resurrección se les preguntará acerca de las mentiras que inventaban.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcccliv{Envié a Noé a su pueblo y permaneció entre ellos mil años menos cincuenta. Los sorprendió el diluvio mientras cometían injusticias.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmccclv{Salvé [a Noé] y a quienes estaban en el arca. Hice de ella un signo para los universos.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmccclvi{[Recuerda] a Abraham cuando le dijo a su pueblo: ``Adoren [solo] a Dios y tengan temor de Él, eso es lo mejor para ustedes, si supieran.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmccclvii{Lo que adoran en lugar de Dios son solo ídolos que ustedes mismos crean falsamente. Lo que adoran en lugar de Dios no puede proveerles ningún sustento. Así que supliquen a Dios el sustento, adórenle solo a Él y agradézcanle. Porque es ante Él que comparecerán.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmccclviii{Pero si [me] desmienten, ya lo hicieron otras naciones antes que ustedes. El Mensajero solo tiene la obligación de transmitir [el Mensaje] con claridad.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmccclix{¿Acaso no ven cómo Dios origina la creación y luego la reproduce? Eso es fácil para Dios."\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmccclx{Diles [a quienes niegan la Resurrección]: ``Viajen por el mundo y observen cómo [Dios] originó la creación. Luego, Dios la hará surgir nuevamente [el Día de la Resurrección]. Dios es sobre toda cosa Poderoso.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmccclxi{Castiga a quien Él quiere y se apiada de quien Él quiere. Ante Él serán retornados.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmccclxii{No podrán escapar de Dios ni en la Tierra ni en el cielo. No encontrarán fuera de Él quién los proteja ni los auxilie.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmccclxiii{Quienes no crean en los signos de Dios y en el encuentro con Él, esos son los que no tienen esperanza en Mi misericordia, tendrán un castigo doloroso.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmccclxiv{[Recuerda que] la respuesta del pueblo de Abraham fue decir: ``Mátenlo o quémenlo", pero Dios lo salvó de la hoguera [en la que quisieron quemarlo]. En eso hay signos para gente que cree.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmccclxv{Les dijo [Abraham]: ``Adoran ídolos en vez de adorar a Dios por mantener el lazo de afecto entre ustedes y sus antepasados en esta vida. Pero el Día de la Resurrección renegarán unos de otros y se maldecirán mutuamente. Su morada será el Fuego y no tendrán quién los auxilie".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmccclxvi{Lot creyó en Abraham, quien [al ver que su pueblo no creía en él] dijo: ``Emigraré a donde [me ordene] mi Señor, porque Él es el Poderoso, el Sabio".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmccclxvii{Lo agracié con Isaac y Jacob, e hice surgir Profetas de su descendencia, a los cuales revelé Mis Libros. Le di [a Abraham] su recompensa en esta vida, y en la otra estará entre los justos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmccclxviii{[Recuerda] cuando Lot dijo a su pueblo: ``Cometen una inmoralidad que no tiene precedente en el universo.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmccclxix{¿Tienen relaciones homosexuales con hombres, asaltan a los viajeros y cometen toda clase de actos reprobables en sus reuniones?" Pero la respuesta de su pueblo fue: ``Envíanos el castigo de Dios, si es que dices la verdad".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmccclxx{Dijo [Lot]: ``¡Señor mío! Sálvame de este pueblo corrupto".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmccclxxi{Cuando Mis [ángeles] emisarios se presentaron ante Abraham para albriciarle [el nacimiento de su hijo], dijeron: ``Destruiremos a la población de esa ciudad, porque su gente comete injusticias".\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmccclxxii{Dijo [Abraham]: ``Pero Lot está allí". Respondieron [los ángeles]: ``Nosotros conocemos mejor [que tú] quién está en ella. Lo salvaremos a él y a su familia, excepto a su mujer, que se contará entre los condenados".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmccclxxiii{Cuando Mis emisarios se presentaron ante Lot, este [pensando que eran viajeros] se intranquilizó [por lo que su pueblo pudiera hacerles] y se apenó, pero ellos le dijeron: ``No temas ni te apenes; te salvaremos a ti y a tu familia, excepto a tu mujer, que se contará entre los condenados.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmccclxxiv{Haremos descender sobre la población de esta ciudad un castigo del cielo por haberse pervertido".\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmccclxxv{Dejé [vestigios] de ella como un signo claro, para que reflexionaran.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmccclxxvi{[Recuerda que] a Madián [le envié] a su hermano Jetró [como Profeta], quien les dijo: ``¡Oh, pueblo mío! Adoren solo a Dios y tengan esperanza en el Día del Juicio final, y no obren mal en la Tierra, sembrando corrupción".\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmccclxxvii{Pero lo desmintieron y fueron sorprendidos por un sismo estrepitoso, y amanecieron caídos de bruces [muertos] en sus propias casas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmccclxxviii{[Recuerda que] al pueblo de ‘Ad y Zamud [también los aniquilé], como pueden ver claramente en [lo que queda de] sus casas. El demonio les hizo ver como buenas sus malas obras, y los apartó del sendero [recto], a pesar de que eran gente con percepción.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmccclxxix{[Recuerda] a Qarún, al Faraón y a Hamán. Moisés se presentó ante ellos con las evidencias, pero actuaron con arrogancia en la tierra [de Egipto y se negaron a creer]. Sin embargo, no pudieron escapar de Mi [castigo].\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmccclxxx{A cada uno [de ellos] los aniquilé según sus pecados. A unos les envié un viento huracanado, a otros los sorprendió un estrépito, a otros hice que se los tragara la tierra, y a otros hice que se ahogaran. Dios no fue injusto con ellos, sino que ellos lo fueron consigo mismos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmccclxxxi{Quienes tomaron en lugar de Dios otros protectores, son como la araña que teje su propio refugio, siendo que el refugio más frágil es la telaraña. ¡Si supieran!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmccclxxxii{Dios conoce lo que ellos invocan en lugar de Él, porque Él es el Poderoso, el Sabio.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccclxxxiii{Estos son ejemplos que doy a la gente, pero solo los comprenden quienes reflexionan.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmccclxxxiv{Dios creó los cielos y la Tierra con un fin justo y verdadero. En ello hay un signo para los creyentes.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmccclxxxv{Recita lo que se te ha revelado del Libro y cumple con la oración, porque la oración preserva de cometer actos inmorales y reprobables. Tener presente a Dios [en el corazón durante la oración] es lo más importante. Dios sabe lo que hacen.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccclxxxvi{Debatan con la Gente del Libro con buenas maneras, excepto con aquellos que cometen injusticias. Digan: ``Creemos en lo que nos ha sido revelado a nosotros así como en lo que les fue revelado a ustedes. El Dios de ustedes y nuestro Dios es uno, y a Él entregamos nuestra voluntad [como musulmanes]".\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccclxxxvii{Te he revelado el Libro [¡oh, Mujámmad!], y entre los que recibieron Mi revelación en el pasado hay quienes creen en él [el Corán], al igual que algunos de los habitantes de La Meca. Pero solo los que se niegan a creer pueden negar Mis signos.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccclxxxviii{Tú no sabías leer ningún tipo de escritura cuando te fue revelado [el Corán], ni tampoco escribir con tu diestra, porque de haber sido así hubieran podido sembrar dudas los que inventan mentiras.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccclxxxix{[El Corán] Es un conjunto de mensajes claros [grabados] en los corazones de quienes han sido agraciados con el conocimiento, y solo los injustos pueden negar Mis signos.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcccxc{Dijeron [los que se niegan a creer]: ``¿Por qué no le han sido concedidos milagros de su Señor?" Diles [¡oh, Mujámmad!]: ``Dios es Quien dispone de los milagros, yo solo debo advertirles con claridad".\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmcccxci{¿Acaso no les es suficiente que te haya sido revelado el Libro que se les recita? En él hay misericordia y conciencia para la gente que cree.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmcccxcii{Di: ``Dios es suficiente testigo entre ustedes y yo. [Él] conoce cuanto hay en los cielos y en la Tierra. Quienes crean lo falso y rechacen a Dios serán los que pierdan".\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcccxciii{Te piden que apresures el castigo [con el que les adviertes]. Y de no haber sido porque está predestinado, ya los hubiera azotado. Este les llegará sorpresivamente sin que lo adviertan.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcccxciv{Te piden que apresures el castigo [con el que les adviertes]. Pero sabe que el Infierno está aguardando a los que se niegan a creer.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcccxcv{El día que el castigo los envuelva por arriba y debajo de sus pies, [Dios] les dirá: ``Sufran las consecuencias de sus propias obras".\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcccxcvi{¡Oh, siervos Míos que han creído! Mi tierra es amplia, adórenme solo a Mí.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcccxcvii{Toda alma probará el sabor de la muerte, y luego ante Mí han de comparecer.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcccxcviii{A quienes hayan creído y hecho obras de bien los alojaré en mansiones del Paraíso, bajo las cuales corren ríos, y donde morarán por toda la eternidad. ¡Qué placentera será la recompensa de los que obran [el bien],\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcccxcix{que tuvieron paciencia y se encomendaron a su Señor!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcd{¡Cuántos animales existen que no almacenan sus provisiones! Pero Dios los sustenta, y asimismo a ustedes. Él todo lo oye, todo lo sabe.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcdi{Si les preguntas [a los idólatras] quién creó los cielos y la Tierra, y sujetó al Sol y a la Luna [a una órbita], responderán: ``¡Dios!" ¿Cómo, entonces, es que se desvían [del monoteísmo]?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmcdii{Dios concede Su sustento en abundancia a quien quiere de Sus siervos y se lo restringe [a quien Él quiere]. Dios conoce todas las cosas.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmcdiii{Si les preguntas [a los idólatras] quién hace descender agua del cielo con la que da vida a la tierra muerta [por la sequía], responderán: ``¡Dios!" Di: ``¡Todas las alabanzas pertenecen a Dios!" Pero la mayoría [de la gente] no razona.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmcdiv{La vida en este mundo no es más que distracción y diversión, la vida del más allá es la vida verdadera. ¡Si supieran!\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmcdv{Cuando suben a un barco [y son azotados por una tempestad] invocan solo a Dios con sinceridad, pero cuando los pongo a salvo llevándolos a la costa, vuelven a dedicar actos de adoración a sus ídolos.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmcdvi{¡Que no agradezcan por cuanto les he concedido y que solo disfruten! ¡Ya verán [la consecuencia de su decisión]!\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmcdvii{¿Acaso no ven que he dispuesto [para ellos] un territorio sagrado y seguro, mientras que a su alrededor se cometen todo tipo de injusticias? ¿Acaso creen en la falsedad y niegan las gracias de Dios?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmcdviii{¿Quién puede ser más injusto que aquel que inventa mentiras acerca de Dios o desmiente la Verdad cuando le llega? ¿Acaso no es el Infierno el destino de los que se niegan a creer [cuando la verdad se les hace evidente]?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmcdix{A quienes se esfuercen por Mi causa los guiaré por Mis caminos. Dios está con los que hacen el bien.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmcdx{\basmalahes Álif. Lam. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcdxi{Los bizantinos fueron derrotados\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcdxii{en el territorio [árabe] más bajo, pero después de esta derrota, ellos [los bizantinos] vencerán\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcdxiii{dentro de tres a nueve años. Todo ocurre por voluntad de Dios, tanto la anterior derrota [de los bizantinos] como su victoria futura. Ese día los creyentes se alegrarán\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcdxiv{por la victoria de Dios. Él concede la victoria a quien quiere, Él es el Poderoso, el Misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcdxv{Esta es la promesa de Dios, y Dios no falta a Su promesa, pero la mayoría de la gente no lo sabe.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcdxvi{Conocen solo lo superficial de la vida mundanal, y viven despreocupados por la otra vida.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcdxvii{¿Acaso no reflexionan sobre sí mismos? Dios ha creado los cielos, la Tierra y lo que hay en ellos con un fin justo y verdadero, y con un plazo determinado. Pero mucha gente no cree que habrá de comparecer ante su Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcdxviii{¿Acaso no han viajado por el mundo y visto cómo fue el final de los pueblos antiguos? Eran [imperios] más poderosos, cultivaron la tierra [en forma asombrosa] y tenían construcciones más avanzadas que las suyas. Sin embargo, cuando se les presentaron los Mensajeros con las evidencias, los desmintieron. Dios no fue injusto con ellos, sino que ellos lo fueron consigo mismos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcdxix{Finalmente, el destino de quienes habían cometido maldades fue el peor, porque desmintieron los signos de Dios y se burlaron de ellos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcdxx{Dios origina la creación y luego la reproduce, y ante Él regresarán.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcdxxi{El día que llegue la Hora los pecadores serán presa de la desesperación.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcdxxii{Pero sus ídolos no intercederán por ellos, [y por el contrario, los ídolos] se desentenderán de quienes los adoraban.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcdxxiii{El día que llegue la Hora, ese día se dividirán [en dos grupos]:\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcdxxiv{Quienes hayan creído y obrado rectamente morarán en los jardines del deleite.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcdxxv{Pero quienes no hayan creído y hayan desmentido Mis signos y la existencia de la otra vida, sufrirán eternamente un tormento.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcdxxvi{Así que glorifiquen a Dios al anochecer y al amanecer.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcdxxvii{Él merece ser alabado en los cielos y en la Tierra, [alábenlo] por la tarde y al mediodía.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcdxxviii{[Dios] hace surgir lo vivo de lo muerto y lo muerto de lo vivo, y da vida a la tierra árida. De la misma manera serán resucitados.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcdxxix{Entre Sus signos está haberlos creado de polvo. Luego se convierten en seres humanos que se multiplican [poblando la Tierra].\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcdxxx{Entre Sus signos está haber creado cónyuges de entre ustedes para que encuentren sosiego, y dispuso entre ustedes amor y misericordia. En ello hay signos para quienes reflexionan.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcdxxxi{Entre Sus signos está la creación de los cielos y de la Tierra, la diversidad de sus lenguas y colores. En esto hay signos para quienes comprenden.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcdxxxii{Entre Sus signos está [haber creado] la noche para que descansen y el día para que procuren Su favor. En esto hay signos para un pueblo que escucha.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcdxxxiii{Entre Sus signos está hacer que el relámpago sea motivo de temor y anhelo, y el agua que hace descender del cielo para dar vida a la tierra árida. En eso hay signos para un pueblo que razona.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcdxxxiv{Entre sus Signos está que el cielo y la Tierra se sostengan por Su voluntad. Luego, cuando Él los convoque [el Día de la Resurrección] saldrán de la tierra.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcdxxxv{A Él pertenece cuanto hay en los cielos y en la Tierra, todo Le obedece.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcdxxxvi{Él es Quien origina la creación y luego la reproduce, y ello Le es aún más fácil [que crear por primera vez]. Suya es la descripción más sublime en los cielos y en la Tierra. Él es el Poderoso, el Sabio.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcdxxxvii{[Dios] les propone un ejemplo tomado de su propia vivencia: ``¿Aceptarían acaso que algunos de entre la servidumbre compartieran con ustedes los bienes que les he concedido, que [repentinamente] tuvieran partes iguales, o que tuvieran ustedes que temerles como temen a sus adversarios?" Así es como aclaro los signos para quienes razonan.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcdxxxviii{Sin embargo, los injustos siguen sus pasiones ciegamente sin basarse en conocimiento alguno. ¿Quién podría guiar a quien Dios ha extraviado? No habrá quién lo pueda socorrer.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcdxxxix{Conságrate al monoteísmo, que es la inclinación natural con la que Dios creó a la gente. La religión de Dios es inalterable y esta es la forma de adoración verdadera, pero la mayoría de la gente lo ignora.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcdxl{Arrepiéntanse ante Dios, tengan temor [de Dios], cumplan con la oración y no sean de los que Le atribuyen divinidades [a Dios en la adoración],\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcdxli{no sean de esos que dividieron su religión y formaron sectas, cada facción se contenta con lo que sigue.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcdxlii{Cuando una desgracia azota a la gente, invocan a su Señor arrepentidos. Pero cuando los agracia con Su misericordia, un grupo de ellos atribuye divinidades a su Señor [en la adoración]\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcdxliii{y niegan cuanto les he concedido. ¡Disfruten temporalmente, que ya verán!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcdxliv{¿Acaso les he hecho descender algún conocimiento que justifique lo que ellos Me asocian?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcdxlv{Cuando agracio a la gente con una misericordia se alegran, pero cuando los alcanza una desgracia a causa de lo que cometieron con sus propias manos, se desesperan.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcdxlvi{¿Acaso no ven que Dios concede abundante sustento a Quien quiere y lo restringe [a quien quiere]? En eso hay signos para quienes creen.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmcdxlvii{Da a los parientes, al pobre y al viajero insolvente, lo que es su derecho. Eso es lo mejor para quienes anhelan [contemplar] el Rostro de Dios. Esos serán quienes tengan éxito.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmcdxlviii{Todo lo que presten con algún interés, esperando beneficiarse de los bienes ajenos, no tendrá recompensa de Dios. En cambio, aquellos que den en caridad anhelando el rostro de Dios, serán quienes tengan multiplicada la recompensa.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmcdxlix{Dios es Quien los crea, los sustenta, los hace morir y luego los resucita. ¿Acaso hay alguno de los ídolos que asocian [a Dios] que pueda hacer algo de eso? ¡Glorificado sea Dios! Dios está por encima de lo que Le asocian.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmcdl{Se puede ver la devastación en la Tierra y en el mar como consecuencia de las acciones del ser humano. Han de padecer [el resultado de] lo que cometieron, quizás así recapaciten.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmcdli{Diles: ``Viajen por el mundo y observen cuál fue el final de los pueblos antiguos. La mayoría Le asociaban ídolos a Dios [en la adoración]".\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmcdlii{Conságrate al monoteísmo auténtico, antes de que llegue el día ineludible que Dios determinó. Ese día serán divididos.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmcdliii{Quienes se hayan negado a creer sufrirán las consecuencias de su incredulidad, mientras que quienes hayan obrado rectamente habrán preparado su propio terreno [en el Paraíso].\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmcdliv{Dios recompensará con Su gracia a quienes hayan creído y obrado rectamente. Él no ama a los que se niegan a creer [cuando les llega el Mensaje].\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmcdlv{Entre Sus signos están los vientos que Él envía para traerles lluvias y agraciarlos con Su misericordia, y para que naveguen los barcos con Su voluntad y puedan procurar el sustento; deberían agradecerle.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmcdlvi{Antes de ti envié Mensajeros a los pueblos, que se presentaron ante ellos con las evidencias [pero los desmintieron]. Retribuí a los pecadores con lo que merecían. Es un deber para Mí auxiliar a los creyentes.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmcdlvii{Dios es Quien envía los vientos para que estos reúnan las nubes, extendiéndolas y fragmentándolas por el cielo como Él quiere. Luego ves que la lluvia cae de entre ellas. Cuando los siervos [azotados por la sequía] reciben la lluvia, se alegran.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmcdlviii{A pesar de que antes de que descendiera [la lluvia] estaban abatidos, sin esperanzas.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcdlix{Observa las huellas de la misericordia de Dios, cómo da vida a la tierra después de haber estado muerta por la sequía. Él es Quien resucitará a los muertos, porque es sobre toda cosa Poderoso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmcdlx{Pero si [en su lugar] les hubiese enviado un viento que secara sus sembrados, se volverían ingratos como incrédulos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmcdlxi{Tú no puedes hacer que los muertos oigan ni que los sordos [que no quiere oír] escuchen la prédica si la rechazan dándole la espalda.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcdlxii{Tampoco puedes guiar a los ciegos [de corazón] que están extraviados. Tú solo puedes hacer que escuchen quienes creen en Mis signos y se someten a Dios [siendo musulmanes].\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcdlxiii{Dios es Quien los crea débiles [en la infancia], luego los fortalece [en la juventud], y finalmente los debilita nuevamente con la vejez. Él crea lo que quiere porque es el Sabio, el Poderoso.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcdlxiv{El día que llegue la Hora [del Día del Juicio], los pecadores jurarán haber permanecido en la vida mundanal tan solo una hora. Así solían engañarse.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcdlxv{Pero aquellos a los que se les concedió el conocimiento y la fe les dirán: ``En realidad han permanecido el tiempo que Dios decretó hasta el Día de la Resurrección. Sepan que este es el Día de la Resurrección, que ignoraban".\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcdlxvi{Ese día, ninguna excusa servirá a los injustos y no se les dará ninguna posibilidad [de volver a la vida mundanal].\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcdlxvii{He citado en este Corán todo tipo de ejemplos. Pero aún si te hubieras presentado ante ellos con un milagro, hubieran dicho: ``Solo son unos farsantes".\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcdlxviii{Así es como Dios sella los corazones de los que no quieren conocer [la verdad].\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcdlxix{Ten paciencia, que lo que Dios promete se cumple, y no permitas que te hagan flaquear los que no están convencidos [de la Resurrección].\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcdlxx{\basmalahes Álif. Lam. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcdlxxi{Estos son los versículos de un Libro sabio,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcdlxxii{que es guía y misericordia para quienes hacen el bien.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcdlxxiii{[Los que hacen el bien son aquellos que] hacen la oración, pagan el zakat y tienen certeza de la existencia de la otra vida.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcdlxxiv{Esos son quienes siguen la guía de su Señor y serán los bienaventurados.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcdlxxv{Entre la gente hay quienes se dedican, sin conocimiento [ni argumentos] a promover palabras vanas con el propósito de desviar a los demás del sendero de Dios, y se burlan [de la palabra de Dios]. Ellos tendrán un castigo humillante.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcdlxxvi{Cuando se les recitan Mis versículos les dan la espalda con soberbia, como si fueran sordos y no las hubieran oído. Anúnciales [¡oh, Mujámmad!] un castigo doloroso.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcdlxxvii{En cambio, quienes crean y hagan obras de bien serán recompensados con los Jardines de las Delicias.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcdlxxviii{Morarán en ellos por toda la eternidad. La promesa de Dios siempre se cumple. Él es el Poderoso, el Sabio.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcdlxxix{[Dios] creó los cielos sin columnas visibles, afirmó la Tierra con montañas para proporcionarles un lugar estable que no se sacuda [con temblores], diseminó en ella toda clase de animales, e hizo descender del cielo la lluvia para que brote generosamente toda clase de vegetación.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcdlxxx{Esa es la creación de Dios, muéstrenme qué han creado sus dioses. Los injustos [que adoran a otros en lugar de Dios] están en un claro extravío.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcdlxxxi{Agracié a Luqmán con la sabiduría [y le dije]: ``Sé agradecido con Dios, pues quien agradece lo hace en beneficio propio, mientras que el ingrato debe saber que Dios no precisa del agradecimiento [de las personas] y es digno de toda alabanza".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcdlxxxii{[Recuerda] cuando Luqmán exhortó a su hijo diciéndole: ``¡Oh, hijito! No dediques actos de adoración a otro que Dios, pues la idolatría es una gran injusticia".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcdlxxxiii{Le he ordenado al ser humano hacer el bien a sus padres. Su madre lo lleva [en el vientre] soportando molestia tras molestia, y su destete es a los dos años. Sean agradecidos conmigo y con sus padres, pero sepan que ante Mí comparecerán al final.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcdlxxxiv{Si tus padres se esfuerzan por hacer que caigas en la idolatría de dedicar actos de adoración a otro que Dios, lo cual es algo que no te he enseñado, no los obedezcan pero trátenlos con respeto. Sigan el camino de los piadosos, pues ante Mí comparecerán y les informaré de lo que hacían.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcdlxxxv{``¡Oh, hijito! Sabe que aunque una mala acción fuera del peso de un grano de mostaza, y estuviera escondida bajo una roca o en [algún otro lugar de] los cielos o de la Tierra, Dios la sacará a la luz [y les preguntará por ella]. Dios es Sutil, y está bien informado de lo que hacen.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcdlxxxvi{¡Oh, hijito! Haz la oración, ordena el bien y condena el mal, y sé paciente ante la adversidad, porque esas son cualidades de la entereza.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcdlxxxvii{No rechaces a la gente y no andes por la Tierra como un arrogante. Dios no ama a los presumidos ni a los engreídos.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcdlxxxviii{Sé modesto en tu andar y habla sereno, que el ruido más desagradable es el rebuzno del asno".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcdlxxxix{¿Acaso no ven que Dios puso al servicio de ustedes cuanto hay en los cielos y en la Tierra, y los colmó de Sus bendiciones, algunas de las cuales ven y otras no? A pesar de esto, entre la gente hay quienes discuten acerca de Dios sin conocimiento, guía ni libro revelado.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcdxc{[A estos] cuando se les dice: ``Sigan lo que Dios ha revelado", responden: ``Nosotros seguimos la tradición de nuestros padres". ¿[La seguirían] Incluso si el demonio los arrastrara al castigo del Infierno?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcdxci{Quien entregue su voluntad a Dios y haga obras de bien, se habrá aferrado al asidero más firme. Todo vuelve a Dios para ser juzgado.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcdxcii{No sientas pena por la incredulidad de los que se niegan a creer, ellos comparecerán ante Mí y les informaré lo que cometieron. Dios conoce lo que esconden los corazones.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcdxciii{Los dejaré que gocen un tiempo breve y luego los llevaré a un castigo riguroso.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcdxciv{Si les preguntas [a los idólatras]: ``¿Quién creó los cielos y la Tierra?" Responderán: ``¡Dios!" Diles: ``¡Alabado sea Dios!" Pero la mayoría de la gente lo ignora.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcdxcv{A Dios pertenece cuanto existe en los cielos y en la Tierra, y Él es el Opulento, el digno de alabanza.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcdxcvi{Si todos los árboles que hay sobre la Tierra se convirtieran en plumas [para escribir] y el mar junto a otros siete mares se convirtieran en tinta, no bastarían para escribir las Palabras de Dios. Dios es Poderoso, Sabio.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcdxcvii{La creación de todos ustedes y su resurrección es [tan fácil para Dios] como si fuera la de un solo ser. Dios todo lo oye, todo lo ve.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcdxcviii{¿Acaso no ven que Dios inserta la noche en el día y el día en la noche, y sometió al Sol y a la Luna haciendo que cada uno recorra [su órbita] hasta un plazo prefijado? Dios está bien informado de lo que hacen.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcdxcix{Dios es la Verdad, y todo lo que invocan fuera de Él es falso. Dios es el Sublime, el Supremo.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmd{¿Acaso no ven que los barcos navegan en el mar por la gracia de Dios? Es una muestra de Sus signos. En ello hay señales para quien es perseverante y agradecido.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdi{[Sucede que] cuando olas como montañas los envuelven [durante una tormenta en el mar], invocan a Dios y prometen adorarlo solo a Él; pero cuando [Dios] los pone a salvo llevándolos a tierra firme, algunos de ellos solo cumplen parte de su promesa. Sepan que solo niegan Mis signos los pérfidos y los ingratos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdii{¡Oh, gente! Teman a su Señor y [teman] el día en el que ningún padre pueda cargar las faltas de su hijo y ningún hijo pueda cargar las faltas de su padre. Lo que Dios promete se cumple. Que no los seduzcan los placeres de la vida mundanal ni los engañe el Seductor [el demonio], alejándolos de Dios.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdiii{Solo Dios sabe cuándo llegará la hora [el Día del Juicio], cuándo hará descender lluvia y qué encierra el útero; nadie sabe qué le deparará el día siguiente ni en qué tierra ha de morir. Dios lo sabe todo y está bien informado de lo que ustedes hacen.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdiv{\basmalahes Álif. Lam. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdv{Este libro sin duda es una revelación del Señor del Universo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdvi{Sin embargo, dicen [los que rechazan el Mensaje]: ``Él lo ha inventado". Pero el Corán es la verdad que procede de tu Señor, para que adviertas a un pueblo al que no se le ha presentado advertidor alguno antes de ti, y así se encaminen.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdvii{Dios es Quien creó los cielos, la tierra y todo lo que existe entre ambos en seis eras, luego se estableció sobre el Trono. No tienen fuera de Él protector ni intercesor alguno. ¿Acaso no van a recapacitar?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdviii{[Dios] decreta todos los asuntos desde el cielo a la Tierra, que luego ascienden a Él en un día que equivale a mil años de los que ustedes cuentan.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdix{Él es Quien conoce lo oculto y lo manifiesto. Él es el Poderoso, el Misericordioso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdx{quien perfeccionó todo lo que ha creado, y comenzó la creación del ser humano del barro.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdxi{Luego hizo que su descendencia surgiera de una gota de esperma insignificante.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdxii{Luego lo forma y le insufla el espíritu. Él los ha dotado de oído, vista e intelecto, pero poco es lo que Le agradecen.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdxiii{Dicen [quienes niegan la Resurrección]: ``¿Acaso después que nos hayamos convertido en polvo, podremos ser creados nuevamente?" Ellos no creen que vayan a comparecer ante su Señor.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdxiv{Diles: ``Tomará sus almas el ángel de la muerte, que fue encargado para ello, y luego comparecerán ante su Señor".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdxv{Y verás [¡oh, Mujámmad!] cuando los pecadores inclinen sus cabezas ante su Señor y digan: ``¡Oh, Señor nuestro! Ahora hemos oído y visto [cuál es la verdad]. Permítenos retornar a la vida mundanal para que obremos rectamente; ahora estamos convencidos".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdxvi{Si hubiera querido habría impuesto a todas las personas la guía. Pero se ha de cumplir Mi designio: ``He de llenar el Infierno de yinnes y seres humanos [que rechazaron el Mensaje].\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdxvii{Sufran [el castigo] por haber relegado su encuentro de este día, Yo también los relegaré. Sufran el castigo eterno por lo que han cometido".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdxviii{Solo creen en Mis signos quienes se prosternan cuando se les recitan [mis versículos], glorifican a su Señor y no se comportan con soberbia,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdxix{se levantan de sus lechos para invocar a su Señor con temor y anhelo [de Su respuesta], y dan en caridad parte de lo que les he proveído.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdxx{Nadie sabe la alegría que les espera [a los creyentes] como recompensa por sus obras.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdxxi{¿Acaso el creyente y el pecador son iguales? No lo son.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdxxii{Quienes crean y obren rectamente obtendrán los jardines del Paraíso como morada en recompensa por sus obras.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdxxiii{Pero quienes desobedezcan [a Dios] tendrán como morada el Fuego. Cada vez que quieran escapar de él, serán devueltos al castigo y se les dirá: ``Sufran el tormento del Fuego por haber desmentido [a los Profetas y su Mensaje]".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdxxiv{Pero les haré probar un castigo inmediato en esta vida antes de que los azote el castigo mayor [del Infierno], quizás así recapaciten.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdxxv{¿Acaso hay alguien más injusto que aquel que después de que se le recitan los versículos de Dios se aparta de ellos? He de retribuir a los pecadores con lo que merecen.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdxxvi{Le di a Moisés el Libro e hice de él guía para los Hijos de Israel; y no dudes [¡oh, Mujámmad!] que te encontrarás con él.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdxxvii{Hice de algunos de ellos líderes ejemplares para guiar [a la gente] por Mi voluntad, siempre que sean pacientes y tengan certeza de Mis signos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdxxviii{Tu Señor juzgará entre ellos el Día de la Resurrección acerca de lo que discrepaban.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdxxix{¿Acaso no se les ha evidenciado [a quienes no creen en este Mensaje] cuántas civilizaciones destruí, siendo que ellos ahora pueden observar sus ruinas? En eso hay signos para que reflexionen.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdxxx{¿Acaso no ven cómo envío la lluvia a la tierra árida, y con ella hago brotar los sembrados de los que comen ellos mismos y también sus rebaños? ¿Acaso no recapacitan?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdxxxi{Y preguntan [a los creyentes]: ``¿Cuándo llegará el Día del Juicio, si es que dicen la verdad?"\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdxxxii{Diles: ``Cuando llegue el Día del Juicio ya no les servirá creer a los que rechazaron el Mensaje, ni tendrán otra oportunidad".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdxxxiii{Apártate de ellos y aguarda [pacientemente el designio de Dios], y sabe que ellos seguirán acechándote.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdxxxiv{\basmalahes ¡Oh, Profeta! Teme a Dios y no obedezcas a los que niegan la verdad y a los hipócritas. Dios lo sabe todo, es Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdxxxv{Sigue lo que te ha sido revelado por tu Señor. Dios está bien informando de lo que hacen.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdxxxvi{Encomiéndate a Dios, porque Dios es suficiente como protector.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdxxxvii{Dios no puso dos corazones en el interior del hombre. Dios no ha hecho que aquellas esposas que hayan repudiado diciendo ``eres tan ilícita para mí como el cuerpo de mi madre" sean [realmente] sus madres, como tampoco ha hecho que sus hijos adoptivos sean [realmente] hijos suyos: estas son solo expresiones [equivocadas] de sus bocas, Dios es quien expresa la verdad [absoluta] y guía al sendero [recto].\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdxxxviii{Llámenlos [a sus hijos adoptivos] por el apellido de sus padres verdaderos, porque eso es lo más justo ante Dios; pero si no conocen a sus padres, mejor digan que ellos son sus hermanos en la religión y sus protegidos. No será considerado un pecado si lo hubieran hecho por error, pero sí será un pecado en caso de que lo hicieran intencionadamente. Dios es Perdonador, Misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdxxxix{El Profeta es más amado para los creyentes que ellos mismos; las esposas del Profeta [deben ser respetadas como si fueran] sus madres; y según el Libro de Dios [el Corán], los parientes son quienes tienen derecho a la herencia, algunos en mayor proporción que otros, y no los creyentes y los emigrados, pero aun así pueden testar a favor de ellos. Esto ha sido decretado y registrado en el Libro.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdxl{Celebré una alianza con todos los Profetas, la misma que celebro contigo [¡oh, Mujámmad!], con Noé, Abraham, Moisés y Jesús, hijo de María. Tomé de ellos un compromiso firme,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdxli{para preguntarles [el Día del Juicio] a los veraces acerca de su veracidad [si cumplieron con ese compromiso]. Dios tiene preparado para los que negaron la verdad un castigo doloroso.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdxlii{¡Oh, creyentes! Recuerden las mercedes con las que Dios los agració, cuando [en la batalla de Al Jandaq] los cercó un ejército, y envié contra ellos una tempestad y un ejército [de ángeles] que no podías ver. Dios ve todo cuanto hacen.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdxliii{[Recuerda] cuando los atacaron por la parte alta y por la parte baja [del valle], el terror desencajó sus miradas, se subieron sus corazones hasta la garganta, y tuvieron malos pensamientos sobre Dios [pensando que no socorrería a los creyentes].\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdxliv{Allí fueron probados los creyentes, y fueron sacudidos por una fuerte conmoción.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdxlv{Dijeron los hipócritas y los que tenían su corazón enfermo de dudas: ``Dios y Su Mensajero solo nos han hecho promesas falsas".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdxlvi{Cuando un grupo de ellos [de los hipócritas] dijo: ``¡Oh, gente de Yazrib! Esto es perjudicial para ustedes. ¡Mejor regresen [y no combatan]! Y un grupo de ellos pidió autorización al Profeta diciendo: ``Nuestras casas quedaron desprotegidas", pero no estaban desprotegidas, sino que solo querían huir.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdxlvii{Si [los incrédulos] hubieran entrado [a Medina] por sus flancos y les hubieran pedido colaboración [contra los creyentes], lo habrían aceptado fácilmente.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdxlviii{Se habían comprometido ante Dios a que no abandonarían el campo de batalla; serán preguntados por el pacto que tomaron con Dios.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdxlix{Diles [¡oh, Mujámmad!]: ``De nada les servirá huir, si es que pretenden huir de la muerte o de que se los mate. Aunque pudieran [escapar en esta oportunidad] no disfrutarán de la vida mundanal sino poco tiempo".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdl{Diles: ``¿Quién los protegerá de Dios, si Él quisiera un mal para ustedes, o [quién puede impedir] que los colme con Su misericordia si así Lo desea? No encontrarán, fuera de Dios, quién los ayude ni quién los pueda defender".\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdli{Dios conoce a quienes pretenden desanimar [a los creyentes] de entre ustedes, y a quienes dicen a sus hermanos [que salieron a combatir]: ``Vuelvan con nosotros", [estos hipócritas] no quieren participar del enfrentamiento.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdlii{Se niegan a prestar todo tipo de ayuda, y cuando se apodera de ellos el temor [por cobardía] los ves que te observan con los ojos desorbitados, como aquel que está en la agonía de la muerte. Pero cuando el temor cesa, se dirigen a ustedes con lenguas afiladas, ávidos por obtener parte del botín. Estos no son creyentes, y Dios hará vanas sus obras [por su falta de fe] pues esto es algo fácil para Él.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdliii{Ellos pensaban que los aliados no se habían marchado, y si estos aliados hubieran regresado [otra vez para combatirlos], habrían deseado estar en el desierto con los beduinos y preguntar de lejos acerca de la suerte de los musulmanes; y aunque hubieran estado con ustedes, poco es lo que habrían participado en la batalla [por desgano].\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdliv{En el Mensajero de Dios hay un bello ejemplo para quienes tienen esperanza en Dios, [anhelan ser recompensados] en el Día del Juicio y recuerdan frecuentemente a Dios.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdlv{Cuando los creyentes vieron a los aliados dijeron: ``Esto es lo que nos prometieron Dios y Su Mensajero, y la promesa de Dios y Su Mensajero es verdadera". Eso no hizo sino acrecentarles la fe y la aceptación [de las órdenes de Dios].\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdlvi{Entre los creyentes hay hombres que cumplieron el compromiso que tomaron con Dios. Algunos ya han fallecido, otros esperan que les llegue su hora y no han cambiado de compromiso.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdlvii{Dios [decidió probarlos en la fe] para recompensar a los sinceros por su sinceridad y castigar a los hipócritas, si Él quiere, o perdonarlos. Dios es Perdonador, Misericordioso.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdlviii{Dios frustró a los incrédulos que, llenos de ira, no alcanzaron lo que se proponían, e hizo que los creyentes no entraran en combate. Dios es Fuerte, Poderoso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdlix{Luego hizo salir de sus fortalezas a la gente del Libro que había ayudado [a los idólatras], e infundió el terror en sus corazones. Por Su orden unos fueron ejecutados y otros hechos prisioneros.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdlx{[Dios] los hizo heredar sus tierras, sus hogares y sus bienes, y [los hará heredar] otras tierras que todavía ni siquiera han pisado. Dios es sobre toda cosa Poderoso.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdlxi{¡Oh, Profeta!, diles a tus esposas: ``Si prefieren la vida mundanal y sus placeres transitorios, vengan que les daré la parte de los bienes materiales que les corresponden y acordaremos un divorcio decoroso.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdlxii{Pero si prefieren a Dios y a Su Mensajero, y la morada que les aguarda en la otra vida, Dios tiene una magnífica recompensa para quienes de ustedes hagan el bien".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdlxiii{¡Oh, mujeres del Profeta! Quienes de ustedes cometan una deshonestidad evidente, sepan que les será duplicado el castigo. Eso es fácil para Dios.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdlxiv{Pero a quienes de ustedes obedezcan a Dios y a su Mensajero, y obren rectamente, les duplicaré la recompensa y les otorgaré un sustento generoso.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdlxv{¡Oh, mujeres del Profeta! Ustedes no son como las demás mujeres, si tienen temor de Dios, no hablen con voz dulce, de modo que quien tenga su corazón enfermo sienta alguna atracción; hablen recatadamente.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdlxvi{[Preferiblemente] permanezcan en sus casas, [y cuando salgan] no se exhiban provocativamente como lo hacían [las mujeres] en tiempos del paganismo preislámico, y hagan la oración, paguen el zakat y obedezcan a Dios y a Su Mensajero. Dios quiere apartar de ustedes todo pecado, ¡oh, familia del Profeta!, y purificarlos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdlxvii{[Oh, esposas del Profeta] transmitan los versículos de Dios y la sabiduría que se mencionan en sus casas. Dios es Sutil, está informado de todas las cosas.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdlxviii{Dios les tiene reservado Su perdón y una gran recompensa a los musulmanes y las musulmanas, a los creyentes y las creyentes, a los piadosos y las piadosas, a los justos y las justas, a los pacientes y las pacientes, a los humildes y las humildes, a los que hacen caridades y a las que hacen caridades, a los que ayunan y las que ayunan, a los pudorosos y las pudorosas, a los que recuerdan frecuentemente a Dios y a las que recuerdan frecuentemente a Dios.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdlxix{Un verdadero creyente o a una verdadera creyente no deben, cuando Dios y Su Mensajero hayan dictaminado un asunto, actuar en forma contraria. Quien desobedezca a Dios y a Su Mensajero se habrá desviado claramente.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdlxx{Recuerda [¡oh, Mujámmad!] cuando dijiste [a Zaid Ibn Háriza] a quien Dios había agraciado [con el Islam] y tú habías favorecido [liberándolo de la esclavitud]: ``Conserva a tu esposa y teme a Dios"; intentaste ocultar lo que Dios haría manifiesto porque temiste lo que diría la gente, pero Dios es más digno de ser temido. Cuando Zaid termine con el vínculo conyugal, te la concederé en matrimonio para que los creyentes [sepan que] no hay ningún impedimento en casarse con las exesposas de sus hijos adoptivos, si es que estos deciden divorciarse de ellas. Era un asunto decidido.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdlxxi{No hay falta alguna del Profeta por lo que Dios le haya prescrito [y permitido contraer en matrimonio]; ese es el designio de Dios tal como lo fue para [los Profetas] que lo precedieron, y el designio de Dios ha de cumplirse.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdlxxii{Quienes transmiten el Mensaje de Dios y tienen temor de Él, sin temer a nadie salvo a Él, sepan que Dios computa todas las obras.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdlxxiii{Mujámmad no es el padre de ninguno de sus hombres, sino que es el Mensajero de Dios y el sello de los Profetas. Dios lo sabe todo.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdlxxiv{¡Oh, creyentes! Tengan presente a Dios en todo momento,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdlxxv{y glorifíquenlo por la mañana y por la tarde.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdlxxvi{Él es Quien los bendice, y Sus ángeles ruegan [el perdón] por ustedes para [que sigan la guía y] sacarlos de las tinieblas [de la idolatría y el pecado] hacia la luz [del monoteísmo y la obediencia]. Él es compasivo con los creyentes.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdlxxvii{Su saludo el día que se encuentren con Él [en el Paraíso] será: ``¡Que la paz sea contigo!" Dios les tiene reservada una recompensa generosa.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdlxxviii{¡Oh, Profeta! Te he enviado como testigo, albriciador, amonestador,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdlxxix{para que invites [a creer en] Dios con Su anuencia; eres una antorcha luminosa.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdlxxx{Dales a los creyentes la albricia de que recibirán un inmenso favor de Dios.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdlxxxi{No obedezcas a los que niegan la verdad ni a los hipócritas, no hagas caso a sus provocaciones, y encomiéndate a Dios, pues Dios es suficiente como Protector.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdlxxxii{¡Oh, creyentes! Si se casan con las creyentes y luego se divorcian antes de haberlas tocado, no deberán ellas esperar ningún plazo para volver a casarse, pero deben darles a ellas una compensación y completar un divorcio decoroso.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdlxxxiii{¡Oh, Profeta! Te son lícitas las mujeres a las cuales diste la dote, y lo que posee tu diestra que te ha concedido Dios, y tus primas paternas y maternas que emigraron contigo, y la mujer creyente que se ofrece al Profeta [en matrimonio], si es que el Profeta quiere tomarla por esposa; es un permiso exclusivo para ti, no para los demás. Sé bien lo que les prescribí respecto a las esposas y lo que posee su diestra, para que no tengas reparo. Dios es Perdonador, Misericordioso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdlxxxiv{[¡Oh, Mujámmad!] Puedes relegar a quien quieras [de tus esposas y no pasar la noche con la que le corresponde] y estar con la que quieras, o si lo deseas volver con alguna de las que hubieras relegado, no cometes pecado al hacerlo. Esto es más conveniente para que estén alegres, no se entristezcan y se sientan complacidas. Dios bien sabe lo que hay en sus corazones. Dios todo lo sabe, es Tolerante.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdlxxxv{No te será lícito que vuelvas a casarte luego de esta revelación, ni sustituir a una por otra aunque fueran muy hermosas, excepto lo que posea tu diestra. Dios todo lo observa.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdlxxxvi{¡Oh, creyentes! No entren en la casa del Profeta a menos que los invite a comer, y no estén procurando la ocasión [de que los invite]. Si fueran invitados, entren, y cuando hayan terminado de comer, retírense y no se demoren hablando, porque eso incomoda al Profeta y se avergüenza [de pedirles que se retiren]; pero Dios no se avergüenza de [decir] la verdad. Cuando les pidan algo [a las esposas del Profeta], háganlo detrás de una cortina. Esto es más puro para los corazones de ustedes y los de ellas. No deben molestar al Mensajero de Dios ni deben casarse nunca con quienes fueron sus esposas, porque eso es grave ante Dios.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdlxxxvii{Si manifiestan algo o lo ocultan, sepan que Dios está enterado de todas las cosas.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdlxxxviii{No es un pecado [para las creyentes si se quitan el velo] ante sus padres, sus hijos, sus hermanos, los sobrinos de parte de su hermano o de su hermana, las demás mujeres y ante los esclavos. Tengan temor de Dios, porque Dios es testigo de todo.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdlxxxix{Dios bendice al Profeta y Sus ángeles piden [a Dios] que lo bendiga. ¡Oh, creyentes! Pidan bendiciones y paz por él.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdxc{A quienes intenten perjudicar a Dios y a Su Mensajero, Dios los maldecirá en este mundo y en el otro, donde les tiene preparado un castigo humillante.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdxci{Quienes causen daño a los creyentes y a las creyentes sin tener motivo alguno, cometen un pecado evidente.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdxcii{¡Oh, Profeta! Diles a tus mujeres, a tus hijas y a las mujeres de los creyentes, que se cubran con sus mantos; es mejor para que se las reconozca y no sean molestadas. Dios es Perdonador, Misericordioso.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdxciii{Si los hipócritas, aquellos que tienen sus corazones enfermos [de dudas] y los que siembran intrigas en Medina no se abstienen, te daré poder sobre ellos, y en consecuencia no permanecerán mucho como tus vecinos.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdxciv{Porque serán maldecidos dondequiera que se encuentren, y deberán ser apresados y ajusticiados con firmeza.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdxcv{Tal ha sido el proceder de Dios con los que [pecaron de igual manera y] ya han desaparecido. ¡No hallarás cambio alguno en el proceder de Dios!\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdxcvi{Te preguntan acerca de la Hora [del Juicio]. Diles: ``Solo Dios tiene el conocimiento de cuándo será; no sé si la Hora esté cercana".\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdxcvii{Dios maldice a los que rechazan el Mensaje y les ha preparado el Infierno.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdxcviii{Estarán en él por toda la eternidad; no encontrarán quién los proteja ni los auxilie.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdxcix{El día en que sus rostros se hundan en el fuego del Infierno, dirán: ``¡Ojalá hubiéramos obedecido a Dios y al Mensajero!"\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdc{Y dirán: ``¡Oh, Señor nuestro! Seguimos a nuestros líderes y poderosos; fueron ellos quienes nos desviaron del camino [recto].\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdci{¡Señor nuestro! Duplícales a ellos el castigo y maldícelos completamente".\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdcii{¡Oh, creyentes! No sean como quienes calumniaron a Moisés. Dios lo declaró inocente de lo que lo acusaban; él goza ante Dios de un rango elevado.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdciii{¡Oh, creyentes! Tengan temor de Dios y hablen solo con la verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdciv{[Si lo hacen,] Él hará virtuosas sus obras y perdonará sus pecados. Quien obedece a Dios y a Su Mensajero obtendrá un triunfo grandioso.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdcv{Le propuse a los cielos, a la Tierra y a las montañas revelarles el Mensaje, pero se rehusaron a cargar con ello porque sintieron temor. Pero el ser humano aceptó llevar la carga; el ser humano fue injusto [consigo mismo] e ignorante [de las consecuencias de asumir esa responsabilidad].\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdcvi{Dios castigará a los hipócritas y a las hipócritas, a los idólatras y a las idólatras; mientras que Dios perdonará a los creyentes y a las creyentes porque Él es Perdonador, Misericordioso.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdcvii{\basmalahes ¡Alabado sea Dios, a Quien pertenece cuanto hay en los cielos y la Tierra! Suyas serán las alabanzas en la otra vida. Él es el Sabio, el que está bien informado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdcviii{Sabe lo que ingresa en la tierra y lo que surge de ella. Lo que desciende del cielo y lo que sube hacia él. Él es el Misericordioso, el Perdonador.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdcix{Dicen los que se negaron a creer: ``No habrá Día del Juicio". Diles [¡oh, Mujámmad!]: ``¡Sí!, habrá, se los juro por mi Señor, Él es el Conocedor de lo oculto, no se Le escapa el conocimiento de la existencia de una pequeña partícula en los cielos o en la Tierra, ni existe nada menor ni mayor que no esté en un Libro evidente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdcx{[La Resurrección es] para recompensar a los creyentes que obraron correctamente; ellos obtendrán el perdón y un sustento generoso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdcxi{Pero quienes se esfuercen por hacer fracasar Mi Mensaje tendrán el castigo de un suplicio doloroso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdcxii{Quienes recibieron la sabiduría y el conocimiento saben que lo que tu Señor te reveló es la Verdad que guía al sendero del Poderoso, el Loable.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdcxiii{Dicen los que se negaron a creer [burlándose]: ``¿Quieren que les mostremos un hombre [Mujámmad] que anuncia que luego de haber sido desintegrados completamente [en las tumbas] serán resucitados,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdcxiv{inventa mentiras y se las atribuye a Dios, o está loco?" Pero los que no creen en la otra vida sufrirán el castigo porque están sumidos en un extravío profundo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdcxv{¿Es que no observan los cielos y la tierra que los rodea? Si quisiera, haría que se los tragara la tierra, o haría que cayera sobre ellos un castigo del cielo. En eso hay un signo para todo siervo arrepentido.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdcxvi{Concedí a David Mi favor [cuando dije:] ``¡Oh, montañas y pájaros! Glorifiquen con él [a Dios]", y le facilité moldear el hierro.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdcxvii{[Dijo Dios:] ``Haz cotas de malla cuyas argollas tengan una justa medida y obren rectamente [tú y tus seguidores]; Yo observo lo que hacen".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdcxviii{Y a Salomón le sometí el viento para que recorriera la distancia que recorrería en un mes en las mañanas como en las tardes. E hice manar para él una fuente de cobre fundido. [También le sometí] los yinnes que trabajaban para él por orden de su Señor. A quien de ellos se rebelara a Mi voluntad [y desobedeciera a Salomón], le hacía sufrir el castigo del Infierno.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdcxix{Hacían para él todo lo que él deseara: templos elevados, estatuas, cántaros grandes como estanques y calderas enormes. [Les dije:] ``Trabajen con agradecimiento [a Dios por los favores concedidos] ¡oh, familia de David!, pero sepan que pocos de Mis siervos son agradecidos".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdcxx{Cuando decreté para él que muriera, no les advirtió de su muerte sino un insecto de la tierra que carcomió su bastón, y cuando [Salomón] se cayó, se hizo evidente [para la gente] que si los yinnes hubieran tenido conocimiento de lo oculto, no habrían permanecido en el castigo humillante [de seguir trabajando].\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdcxxi{Las moradas de Saba eran un signo [de las gracias de Dios]: poseían dos huertos, uno [en un valle] a la izquierda y otro a la derecha. [Les dije:] ``Coman del sustento de su Señor y agradézcanle. Tienen una buena tierra, y [si son agradecidos, sepan que] su Señor es Perdonador".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdcxxii{Pero se apartaron, entonces envié sobre ellos la inundación [que produjo la ruptura] de las represas [que habían construido], y les cambié sus dos huertos por granjas con frutos amargos, tamarindos y algunos árboles de azufaifo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdcxxiii{Así los castigué por ser desagradecidos, y no castigo así sino al desagradecido.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdcxxiv{Puse entre ellos y las ciudades que había bendecido otras aldeas, e hice que transitaran tranquilos por ellas. [Les dije:] ``¡Viajen por ellas seguros de noche y de día!"\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdcxxv{Dijeron [con arrogancia]: ``¡Señor nuestro! Alarga nuestros viajes". Y se perjudicaron a sí mismos, e hice que se convirtieran en historia y los destruí por completo. Sin duda, en esto hay un signo para todo paciente [ante momentos difíciles] agradecido [de los favores de Dios].\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdcxxvi{Así confirmó Iblís su afirmación: ya que todos lo siguieron excepto un grupo de creyentes.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdcxxvii{[El demonio] no tenía poder sobre ellos, sino [que les susurró] para que se hiciera evidente quién creía en la otra vida y quién de ellos tenía dudas. Tu Señor está atento a todas las cosas.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdcxxviii{Diles [¡oh, Mujámmad! a los idólatras]: ``Invoquen a quien quieran en lugar de Dios, pero sepan que los ídolos no pueden [beneficiar ni perjudicar] ni siquiera en el peso de una partícula, tanto en los cielos como en la Tierra, ni tienen participación alguna [en el poder divino], ni tampoco Él tiene ayudantes de entre ellos".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdcxxix{No se aceptará ninguna intercesión y solo podrán hacerlo aquellos a quienes Él se lo permita, hasta que, cuando el terror se aleje de sus corazones [los ángeles] se preguntarán [unos a otros]: ``¿Qué dijo su Señor?" Responderán: ``La Verdad. Él es el Sublime, el Grande".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdcxxx{Pregúntales [¡oh, Mujámmad! a los idólatras]: ``¿Quién los sustenta de los cielos y la Tierra?" Diles: ``¡Dios!" Uno de nosotros está en el sendero recto y el otro en el error evidente.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdcxxxi{Diles: ``Ustedes no serán interrogados por nuestras faltas, ni nosotros seremos interrogados por las suyas".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdcxxxii{Diles: ``Nuestro Señor nos congregará [el Día del Juicio], luego juzgará entre nosotros con equidad; Él es el verdadero Juez, y Él todo lo sabe".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdcxxxiii{Diles: ``Muéstrenme los [ídolos] que asocian con Él". ¡No existen!, pues Él es Dios, el Poderoso, el Sabio.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdcxxxiv{No te envié [¡oh, Mujámmad!] sino como anunciador de buenas nuevas y amonestador para todos los seres humanos. Pero la mayoría de la gente lo ignora.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdcxxxv{Dicen [los que se negaron a creer]: ``¿Cuándo se cumplirá esta amenaza, si dices la verdad?"\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcxxxvi{Diles: ``Ustedes han sido emplazados para el Día [del Juicio], y no podrán adelantarlo ni retrasarlo siquiera un instante".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcxxxvii{Dicen los que se negaron a creer: ``No creeremos en este Corán ni en los [Libros revelados] anteriores". Pero si vieras [¡oh, Mujámmad!] cuando estén los que cometieron injusticias frente a su Señor, increpándose unos a otros. Dirán los seguidores oprimidos a los [líderes] arrogantes: ``Si no fuera por ustedes hubiéramos sido creyentes".\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcxxxviii{Dirán los [líderes] arrogantes a quienes los siguieron: ``¿Acaso nosotros los apartamos de la guía [por la fuerza], después que les vino? Son unos transgresores [que eligieron libremente el descarrío]".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcxxxix{Dirán quienes seguían a los soberbios líderes [en la incredulidad]: ``No, fueron sus astucias, pues noche y día nos ordenaban que no creyéramos en Dios y que igualáramos a los ídolos con Dios [dedicándoles actos de adoración]". Todos pretenderán esconder su arrepentimiento [por no haber creído en los Mensajeros] cuando vean el castigo [pero se evidenciará en sus rostros]; y pondremos argollas en los cuellos de los que se negaron a creer. ¿No serán acaso castigados por lo que cometieron?\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcxl{No envié un [Profeta como] amonestador a ninguna ciudad sin que dijeran sus líderes y poderosos: ``No creemos en tu Mensaje".\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcxli{Decían también: ``Nosotros tenemos más bienes materiales e hijos que tú, y no seremos castigados".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcxlii{Diles: ``Mi Señor sustenta generosamente a quien quiere y se lo restringe [a quien quiere], pero la mayoría de la gente lo ignora".\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcxliii{Sepan que no son ni sus bienes materiales ni sus hijos los que los acercan a Mí, sino que quienes crean y obren rectamente recibirán una recompensa multiplicada por sus obras, y morarán seguros en habitaciones elevadas [del Paraíso].\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcxliv{En cambio, aquellos que se esfuercen por denigrar Mi Mensaje serán llevados al castigo.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcxlv{Diles: ``Mi Señor aumenta el sustento a quien Él quiere de Sus siervos y se lo restringe [a quien quiere], y todo lo que gasten en caridad, Él se los compensará. Él es el mejor de los sustentadores".\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcxlvi{El día en que congregue a todos [los seres humanos para juzgarlos], preguntará a los ángeles: ``¿Estos [idólatras] eran los que los adoraban?"\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcxlvii{Responderán [los ángeles]: ``¡Alabado seas! Tú eres nuestro Protector, y nosotros no los indujimos a ello, pero [los idólatras en realidad] adoraban a los yinnes, y la mayoría [de los seres humanos] creían en ellos.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdcxlviii{Pero el Día del Juicio no podrán beneficiarse ni perjudicarse unos a otros, y diré a los que cometieron injusticias: ``Sufran el castigo del Fuego que negaban".\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcxlix{Cuando se les recitan Mis versículos evidentes [a los idólatras], dicen: ``Este [el Profeta Mujámmad] no es sino un hombre que pretende apartarlos de lo que sus padres adoraban". Y dicen: ``Este Corán no es más que una mentira inventada". Y dijeron los que se negaron a creer cuando les llegó la verdad: ``No es más que evidente hechicería".\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcl{No les concedí [a los paganos de La Meca] libros en que se basaran [y fundamentaran su idolatría], ni les envié a ningún amonestador antes de ti.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdcli{Ya desmintieron sus antecesores a Mis Mensajeros, y estos incrédulos [deberían recapacitar, pues] no recibieron ni una décima parte de lo que les concedí a sus antecesores. ¡Qué terrible fue el castigo!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdclii{Diles [¡oh, Mujámmad!]: ``Los exhorto a que hagan una cosa [para que se les evidencie la verdad]: Pónganse ante Dios en grupo o individualmente, y reflexionen, pues su compañero no es un loco, sino que es un amonestador que les advierte de un castigo severo".\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcliii{Diles: ``No les he pedido remuneración alguna, mi recompensa ha de dármela Dios; Él es Testigo de todas las cosas".\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdcliv{Diles: ``Mi Señor rechaza lo falso con la verdad, Él conoce lo oculto".\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdclv{Diles: ``Se ha presentado la verdad, y la falsedad no puede comenzar nada nuevo ni repetirlo".\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdclvi{Diles: ``Si me desvío, será en perjuicio propio; pero si sigo la verdadera guía es por lo que mi Señor me reveló. Él todo lo oye y está cerca [de Sus siervos]".\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdclvii{¡Si vieras [¡oh, Mujámmad!] cuando [los incrédulos] se aterroricen [al ver el castigo que les aguarda] y no tengan forma de escapar! Serán tomados desde un lugar cercano [y arrojados al Fuego].\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdclviii{Dirán: ``Ahora creemos en Dios". ¿Pero cómo podrían adoptar la fe desde un lugar lejano?\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdclix{Antes ya habían sido incrédulos [en la vida mundanal] y refutaban lo oculto con falsedades desde una posición lejana [a la verdad].\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdclx{Pero entre ellos y lo que desean se interpondrá una barrera, como ocurrió con los incrédulos que estuvieron antes de ellos, porque estaban indecisos [sobre el Mensaje].\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdclxi{\basmalahes ¡Alabado sea Dios, el Originador de los cielos y de la Tierra! Dispuso que los ángeles fuesen Sus enviados [para transmitir el Mensaje a Sus Profetas], dotados de dos, tres o cuatro alas. [Dios] aumenta en la creación a quien quiere. Dios tiene poder sobre todas las cosas.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdclxii{Nada ni nadie puede impedir que una misericordia de Dios alcance a la gente; pero si Él la retuviese, no hay nada ni nadie que pudiera hacer que les llegara. Él es el Poderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdclxiii{¡Oh, gente! Recuerden las bendiciones que Dios les ha concedido. ¿Acaso hay otro Creador además de Dios que los sustente de lo que hay en el cielo y en la Tierra? No hay nada ni nadie con derecho a ser adorado salvo Dios. ¿Por qué entonces se desvían?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdclxiv{Si te desmienten [¡oh, Mujámmad!], ya antes de ti otros Mensajeros fueron desmentidos. Todos los asuntos vuelven a Dios.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdclxv{¡Oh, gente! La promesa de Dios es verdadera. Que no los alucine la vida mundanal, y que el Seductor no los aparte de Dios.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdclxvi{El demonio es para ustedes un enemigo, tómenlo como un enemigo; él seduce a sus seguidores para que sean de los moradores del Infierno.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdclxvii{Los que rechazan el Mensaje recibirán un castigo severo, mientras que los creyentes que obren rectamente obtendrán el perdón y una gran recompensa.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdclxviii{¿Acaso a quien [el demonio] le hizo ver sus obras malas como buenas [es comparable a quien Dios ha guiado]? Dios decreta el desvío para quien Él quiere y guía a quien quiere. No te apenes [por la incredulidad de quienes te desmienten]. Dios sabe bien lo que hacen.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdclxix{Dios es Quien envía los vientos que conducen las nubes, y con ellas riega un territorio muerto. [Dios] da vida a la tierra árida con las lluvias; de igual manera será la resurrección.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdclxx{Quien desee el poder, debe saber que el poder absoluto pertenece solo a Dios. Hacia Él ascienden las buenas palabras y Él eleva las obras piadosas. Pero quienes se confabulen para hacer el mal tendrán un castigo severo, y sus planes fracasarán.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdclxxi{Dios creó [a Adán] de la tierra, luego [a toda su descendencia] de un óvulo fecundado, luego los hace pares [hombre y mujer]. Ninguna mujer concibe ni da a luz sin que Él tenga conocimiento. A nadie se le alarga ni se le acorta la vida sin que ello conste en un Libro. Eso es fácil para Dios.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdclxxii{Las dos masas de agua no son iguales: una es potable, dulce y agradable para beber; la otra es salobre. De ambas comen carne fresca y obtienen adornos con los que se engalanan. Ven al barco atravesarlas para buscar Su favor: sean agradecidos [con Dios].\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdclxxiii{[Dios] hace que la noche se funda en el día y que el día se funda en la noche, sometió el Sol y la Luna, cada uno transcurre por una órbita prefijada. Él es Dios, su Señor; Suyo es el reino, pero los ídolos que ustedes invocan fuera de Él no poseen absolutamente nada, ni siquiera el pellejo de un hueso de dátil.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdclxxiv{Si ustedes los invocan, no oyen su invocación, y si oyeran no podrían responder. El Día de la Resurrección negarán que los hayan adorado, y no te informará nadie como Dios, Quien está bien informado de todo.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdclxxv{¡Oh, gente! Ustedes son los que necesitan de Dios, mientras que Dios es el que tiene domino absoluto y es digno de toda alabanza.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdclxxvi{Si Él quisiera, los haría desaparecer y crearía a otros seres [creyentes].\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdclxxvii{Eso no sería difícil para Dios.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdclxxviii{Nadie cargará con culpas ajenas. Si [un pecador] pide que le ayuden con su carga [de pecados], nadie podrá ayudarle en nada, aunque fuera su pariente. [¡Oh, Mujámmad!] Solo se beneficia con tus advertencias quien teme a su Señor en su vida privada y practica la oración. Quien se purifica [de la idolatría y el pecado], lo hace en beneficio propio; y ante Dios comparecerán.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdclxxix{No son iguales el ciego y el que ve.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdclxxx{Ni las tinieblas y la luz.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdclxxxi{Ni la frescura de la sombra y el calor del sol.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdclxxxii{No son iguales los vivos y los muertos. Dios hace oír [y aceptar el Mensaje] a quien quiere, pero tú no puedes hacer oír a quienes están [muertos de corazón como los que están muertos] en sus tumbas.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdclxxxiii{Tú solo eres un amonestador.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdclxxxiv{Te he enviado con la Verdad, como albriciador y amonestador; no hubo ninguna nación a la que no se le haya enviado un amonestador.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdclxxxv{Pero si te desmienten, también desmintieron sus antecesores a Mis Mensajeros, que se les presentaron con pruebas y con las escrituras y el Libro luminoso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdclxxxvi{Entonces castigué a los que no creyeron, ¡y qué terrible fue Mi castigo!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdclxxxvii{¿Acaso no observas que Dios hace descender del cielo el agua, y que con ella hace brotar diversas clases de frutos, y que algunas montañas tienen vetas blancas, rojas y negras, de diversos colores,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdclxxxviii{y que los seres humanos, los animales y los rebaños los hay de diversos colores? Los siervos que tienen más temor devocional de Dios son los sabios. Dios es Poderoso, Absolvedor.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdclxxxix{Quienes reciten el Libro de Dios, practiquen la oración y hagan caridades de aquello que les proveí, tanto en público como en secreto, recibirán una recompensa que jamás desaparecerá.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcxc{Dios les retribuirá por sus obras y les concederá aún más de Su bendición, porque Él es Absolvedor, Recompensador.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcxci{Lo que te he revelado del Libro [¡oh, Mujámmad!] es la Verdad que corrobora lo que ya había sido revelado anteriormente. Dios ve y sabe todo lo que hacen Sus siervos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcxcii{Luego hice que heredaran el Libro quienes elegí entre Mis siervos, pero entre ellos hay quienes son injustos consigo mismos [cometiendo pecados], otros que lo ponen en práctica con moderación, y otros que, con el permiso de Dios, se apresuran en hacer el bien. Eso es un favor inmenso.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcxciii{Ingresarán por ello en los Jardines del Edén, allí serán engalanados con pulseras de oro y perlas, y sus vestiduras serán de seda.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcxciv{Y dirán: ``¡Alabado sea Dios, que ha hecho desaparecer toda causa de tristeza! Nuestro Señor es Absolvedor, Recompensador.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcxcv{Nos recompensó con la morada eterna, y por Su gracia no padeceremos allí cansancio ni fatiga".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcxcvi{Pero quienes no hayan creído serán castigados con el fuego del Infierno, [allí] no morirán ni se les aliviará el tormento; así castigo a quienes rechazan [el Mensaje].\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcxcvii{Allí clamarán: ``¡Señor nuestro! Sácanos [del tormento] para que obremos rectamente, y no como lo hicimos". Pero, ¿acaso no les concedí vivir largamente donde podrían haberlo hecho, y no se les presentó un Mensajero [y lo rechazaron]? Sufran el castigo. Los injustos no tendrán quién los defienda.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcxcviii{Dios conoce lo oculto de los cielos y de la Tierra, y sabe bien lo que hay dentro de los corazones.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcxcix{Él es Quien hizo que se sucedieran unos a otros en la Tierra. La incredulidad del que se niegue a creer será en su propia contra; y la incredulidad de los que se nieguen a creer no hará sino hacerlos más detestables ante su Señor, y la incredulidad de los que se nieguen a creer no hará sino aumentarles en perdición.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcc{Diles: ``¿No se fijan en lo que adoran en vez de Dios? Muéstrenme qué han creado de la Tierra, ¿acaso participaron en la creación de los cielos? ¿O les concedí un libro en el que se basan para confirmar la idolatría?" La esperanza que los opresores se dan unos a otros no es más que un engaño.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcci{Dios es Quien contiene a los cielos y la Tierra para que no se desvíen [de su órbita], porque si se desviaran nadie los podría contener más que Él. Él es Tolerante, Absolvedor.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdccii{[Los incrédulos] juraron por Dios que si se les presentaba un [Profeta] amonestador, serían más encaminados que ninguna otra comunidad; pero cuando se les presentó un amonestador, no hicieron sino aumentar su rechazo.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcciii{Fueron soberbios en la Tierra, y se confabularon [para apartar a la gente del camino recto], pero las confabulaciones recayeron sobre ellos mismos. ¿Es que no temen que les suceda como a sus predecesores? No habrá cambios en el designio de Dios.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcciv{¿Acaso no han viajado por el mundo y observaron cuál fue el fin de quienes los precedieron? Eran más poderosos que ellos [y aun así fueron castigados], pues nadie puede huir de Dios, ni en los cielos ni en la Tierra. Él lo sabe todo y tiene poder sobre todas las cosas.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdccv{Si Dios castigara a la gente [inmediatamente] por sus pecados, no dejaría ninguna criatura sobre la faz de la Tierra. Por Su voluntad les da una prórroga hasta un plazo fijado; pero cuando llegue el plazo, Dios [los juzgará porque] está bien enterado de todo lo que hacen.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdccvi{\basmalahes Iá’. Sín.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdccvii{[Juro] por el Corán, que está lleno de sabiduría,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdccviii{que tú [¡oh, Mujámmad!] eres uno de los Mensajeros [de Dios],\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdccix{que está en el sendero recto.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdccx{Esta es una revelación del Poderoso, el Misericordioso,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdccxi{para que amonestes a un pueblo cuyos antepasados no fueron advertidos, y por eso son negligentes.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdccxii{Se ha hecho realidad la palabra de Dios sobre la mayoría de ellos, pues no están dispuestos a creer.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdccxiii{Les pondré en sus cuellos argollas que llegarán a sus barbillas, y sus cabezas quedarán erguidas.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdccxiv{Pondré ante ellos una barrera y otra detrás, y los cubriré con un velo y no podrán ver.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdccxv{Les da lo mismo que los amonestes o no, no creerán.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdccxvi{Solo se beneficia con tu amonestación quien sigue el Mensaje y teme al Compasivo en su intimidad. A ellos anúnciales que obtendrán el perdón y una recompensa generosa.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdccxvii{Yo soy Quien resucita a los muertos, y registro lo que hagan de bien y lo que hagan del mal; todo lo tengo mencionado en un libro claro.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdccxviii{[A quienes te desmienten] menciónales el ejemplo de los habitantes de una ciudad, cuando se presentaron ante ellos los Mensajeros.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdccxix{Les envié dos Mensajeros pero los desmintieron, entonces los reforcé con un tercero. Ellos dijeron [a los habitantes de la ciudad]: ``Hemos sido enviados a ustedes [por Dios]".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdccxx{Respondieron [los incrédulos]: ``Ustedes no son más que seres humanos como nosotros. El Misericordioso no ha revelado nada, ustedes son tan solo unos mentirosos".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdccxxi{Dijeron [los Mensajeros]: ``Nuestro Señor sabe que realmente somos Mensajeros.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdccxxii{Solo somos responsables de transmitir el Mensaje de forma clara".\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdccxxiii{Dijeron [los incrédulos]: ``Tenemos un mal presagio con ustedes, y si no desisten [de condenar la idolatría] los lapidaremos y los torturaremos para causarles mucho dolor".\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdccxxiv{Dijeron [los Mensajeros]: ``Su destino [bueno o malo] depende de ustedes. Pero ustedes, por el solo hecho de que los amonestemos [dirán que les traemos mala suerte]. En realidad son un pueblo de transgresores".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdccxxv{Entonces llegó desde un extremo de la ciudad un hombre corriendo, que dijo: ``¡Oh, pueblo mío! Sigan a los Mensajeros.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdccxxvi{Sigan a quienes no les piden retribución alguna [por transmitirles el conocimiento], y están bien guiados.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdccxxvii{¿Cómo no iba a adorar a Quien me creó, si ante Él comparecerán?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdccxxviii{¿Acaso iba a tomar, en lugar de Él, a ídolos que, si el Compasivo decretara alguna adversidad para mí, su intercesión de nada me valdría ni podrían protegerme?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdccxxix{Si lo hiciera, estaría en un error evidente.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdccxxx{Escúchenme, yo he abrazado la fe en su Señor". [Pero su pueblo lo mató.]\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdccxxxi{Entonces le fue dicho: ``Ingresa al Paraíso". Dijo: ``¡Ojalá mi pueblo supiera\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdccxxxii{que mi Señor me perdonó mis faltas y me honró [con la bienaventuranza]!"\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdccxxxiii{No envié contra su pueblo, después de él, ningún ejército [de ángeles],\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdccxxxiv{pues fue suficiente con un único sonido desgarrador para que fueran aniquilados.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdccxxxv{¡Pobres de esos siervos que cada vez que se presenta ante ellos un Mensajero, se burlan de él!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdccxxxvi{¿Acaso no observan cuántas generaciones que los precedieron he destruido? Esos ya no volverán [a la vida mundanal].\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdccxxxvii{Todos deberán comparecer ante Mí.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdccxxxviii{Un signo [que evidencia cómo es la resurrección] es la tierra árida que revivo [con lluvias] y hago brotar de ella los granos con que se alimentan.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdccxxxix{En ella hay jardines de palmeras y vides, e hice brotar de ella manantiales\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdccxl{para que comieran de sus frutos. No fueron las manos de ustedes las que los crearon. ¿Acaso no van a agradecer [a Dios]?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdccxli{Glorificado sea Aquel que creó todas las especies en pares; las que brotan de la tierra, los seres humanos y otras [criaturas] que desconocen.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdccxlii{Tienen un signo [del poder divino] en la noche que le sucede al día, y quedan entonces a oscuras.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdccxliii{El Sol orbita como le fue designado; ello es un decreto del Poderoso, el que todo lo sabe.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdccxliv{A la Luna le decreté sus fases, hasta que [va menguando y] parece una rama seca de palmera.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdccxlv{No le es posible al Sol alcanzar a la Luna, ni la noche puede adelantarse al día. Cada [astro] circula en su órbita.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdccxlvi{Otro signo [del poder divino] es que a sus padres los transporté en una barca cargada.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdccxlvii{Y creé para ellos otras [barcas] en las que se embarcan.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdccxlviii{Si hubiera querido habría hecho que se ahogaran, y nadie podría haberlos socorrido ni ayudado,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdccxlix{pero por misericordia no lo hice, para que disfrutaran por un tiempo.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdccl{Cuando se les dice: ``Tengan precaución de lo que pueda acontecerles ahora [de castigo en este mundo] y [del castigo] en la otra vida, quizá así alcancen la misericordia [de Dios]".\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdccli{Cada vez que presencian uno de los signos de su Señor, lo rechazan.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcclii{Cuando se les dice: ``Hagan caridades de lo que Dios les ha proveído", dicen los incrédulos a los creyentes: ``¿Acaso tenemos que alimentar a quienes, si Dios quisiera, Él mismo alimentaría?" Están en un error evidente.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdccliii{Y dicen [desafiantes]: ``¿Cuándo se cumplirá esta advertencia, si es verdad lo que dices?"\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdccliv{No esperan sino que un solo clamor los sorprenda mientras están discutiendo.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdcclv{Entonces no tendrán tiempo siquiera para dar una indicación, y tampoco podrán retornar con los suyos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdcclvi{Cuando se sople la trompeta [por segunda vez], saldrán de sus tumbas hacia su Señor.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdcclvii{Dirán: ``¡Ay de nosotros! ¿Qué nos hizo surgir de nuestro lecho?" [Se les dirá:] ``Eso fue lo que les prometió el Misericordioso, los Mensajeros les decían la verdad".\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdcclviii{No habrá más que uno solo soplido [de la trompeta para marcar la resurrección], todos ellos deberán comparecer ante Mí.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdcclix{Ese día ningún alma será tratada injustamente, solo serán juzgados acorde a las obras que realizaron.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdcclx{La gente del Paraíso, ese día, estarán felices disfrutando.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdcclxi{Ellos y sus cónyuges estarán a la sombra, reclinados sobre sofás.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdcclxii{Allí tendrán frutos, y todo lo que pidan.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdcclxiii{``¡La paz sea con ustedes!", serán las palabras del Señor Misericordioso.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdcclxiv{¡Oh, transgresores! Hoy, por lo que hicieron, estarán lejos [de los creyentes].\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdcclxv{¿Acaso no tomaron un compromiso conmigo, ¡oh, hijos de Adán!, de no obedecer ni adorar al demonio, que es un enemigo declarado para ustedes,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdcclxvi{y de que Me adorarían [solo a Mí]? Este es el sendero recto [que debían seguir].\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdcclxvii{Pero él [el demonio] desvió a muchos de ustedes. ¿Por qué no reflexionan?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdcclxviii{Este es el Infierno que se les había prometido.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdcclxix{Ingresen en él hoy por haberse negado a creer.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdcclxx{Hoy sellaré sus bocas y serán sus manos las que me hablen, y sus pies darán testimonio de lo que cometieron.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdcclxxi{Si quisiera los cegaría, pero aunque se precipitaran [por encontrar] el camino, ¿cómo podrían ver?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdcclxxii{Si quisiera los habría inmovilizado en sus lugares y no podrían avanzar ni retroceder.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdcclxxiii{A quien le concedo una vida larga, hago que se vuelva débil [como cuando era pequeño]. ¿Acaso no van a reflexionar?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdcclxxiv{No le enseñé [al Profeta Mujámmad] la poesía, porque no es apropiada para él. [Lo que él recita] es un recuerdo [de Dios] y una recitación clara,\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdcclxxv{una amonestación para quien tenga un corazón vivo, y también una evidencia contra los que se niegan a creer [en él].\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdcclxxvi{¿Acaso no recapacitan en que he creado con Mis manos para ellos los ganados que les pertenecen?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdcclxxvii{Los he hecho dóciles para ellos, les sirven para montar y como alimento,\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdcclxxviii{obtienen de ellos otros beneficios, y [de ellos extraen leche] para beber. ¿Es que no van a ser agradecidos?\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdcclxxix{Pero toman falsas divinidades, en lugar de Dios, para que los socorran.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmdcclxxx{Las divinidades no podrán siquiera socorrerse a sí mismas, y en realidad sus seguidores son soldados a su disposición.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmdcclxxxi{Que no te apene lo que dicen, bien sabemos lo que murmuran [en secreto] y lo que dicen abiertamente.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmdcclxxxii{¿Es que no ve el ser humano [que niega la Resurrección] que lo he creado de un óvulo fecundado? Sin embargo, él insiste en discutir [el poder divino].\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmdcclxxxiii{Y [este incrédulo] nos compara [con un ser creado] olvidando cómo ha sido creado él mismo, y dice: ``¿Quién dará vida a los huesos cuando estén ya carcomidos?"\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmdcclxxxiv{Dile [¡oh, Mujámmad!]: ``Les dará vida Quien los creó por primera vez, pues Él tiene conocimiento de todos los pasos de la creación.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmdcclxxxv{Él es Quien hace que puedan encender fuego del árbol verde".\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmdcclxxxvi{¿Acaso Quien creó los cielos y la Tierra no va a poder crearlos nuevamente? ¡Sí! [Puede] Porque Él es el Creador, el que lo sabe todo.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmdcclxxxvii{Cuando Él decide decretar algo, le dice: ``¡Sé!", y es.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmdcclxxxviii{Glorificado sea Aquel en Cuya mano está la soberanía de todas las cosas, y ante Él retornarán [para ser juzgados].\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmdcclxxxix{\basmalahes Juro por [los ángeles] ordenados en filas,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdccxc{que advierten\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdccxci{y recitan el Mensaje.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdccxcii{Que su divinidad es una sola,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdccxciii{el Señor de los cielos, de la Tierra, de todo cuanto existe entre ellos; el Señor de los amaneceres.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdccxciv{He adornado el cielo más bajo con los astros\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdccxcv{como protección contra todo demonio rebelde,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdccxcvi{para que no puedan escuchar lo que revelo a la asamblea más elevada [de ángeles y para que, si lo intentan,] les sean arrojados [los astros] por todas partes,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdccxcvii{y así ahuyentarlos. Los demonios recibirán un castigo eterno.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdccxcviii{Aquellos que furtivamente alcancen a oír algo de los ángeles serán alcanzados por una centella fulminante.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdccxcix{Pregúntales [a quienes desmienten la Resurrección]: ``¿Acaso creen que la creación del ser humano fue más difícil que la del resto [del universo]?" Los creé de barro pegajoso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdccc{Tú te maravillas, pero ellos se burlan,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdccci{cuando son exhortados no reflexionan,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdcccii{cuando ven un milagro lo ridiculizan\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdccciii{y dicen: ``Esto no es más que hechicería evidente,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdccciv{¿acaso cuando muramos y seamos polvo y huesos, seremos resucitados?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdcccv{¿Acaso nuestros antepasados también [serán resucitados]?"\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdcccvi{Diles [¡oh, Mujámmad!]: ``Sí, y sufrirán una gran humillación".\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdcccvii{Solo bastará que se sople una vez [la trompeta y resucitarán], y entonces comenzarán a observar\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdcccviii{y dirán: ``¡Ay de nosotros! En este día deberemos rendir cuentas [por nuestras obras]".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdcccix{[Se les dirá:] ``Este es el Día del Juicio que negaban".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdcccx{[Se les ordenará a los ángeles:] ``Congreguen a quienes fueron [idólatras y] cometieron injusticias junto con sus pares [en la incredulidad] y a los [ídolos] que adoraban\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdcccxi{en lugar de Dios, luego arréenlos por el camino que los conducirá al Infierno,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdcccxii{pero deténganlos [antes de arrojarlos] porque serán interrogados.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdcccxiii{[Se les preguntará:] ``¿Qué sucede que no se ayudan unos a otros?"\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdcccxiv{Pero ese día estarán entregados,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdcccxv{y comenzarán a reclamarse unos a otros.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdcccxvi{Dirán [a sus ídolos]: ``Ustedes, con su poder, nos forzaron a seguirlos".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdcccxvii{Pero [los ídolos] responderán: ``No, simplemente no creyeron [en Dios y nos idolatraron],\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcccxviii{pues nosotros no teníamos poder alguno sobre ustedes [y eligieron libremente la incredulidad]; eran transgresores.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcccxix{Hoy se cumple la amenaza que Nuestro Señor nos hizo, y sufriremos el castigo [por nuestra incredulidad].\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcccxx{Nosotros solo los sedujimos y ustedes nos siguieron, desviándose igual que nosotros".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcccxxi{[Entonces Dios dirá:] ``Todos ustedes compartirán el castigo.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcccxxii{Eso haré con los pecadores".\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcccxxiii{Cuando se les decía: ``No hay nada ni nadie con derecho a ser adorado salvo Dios", respondían con arrogancia\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcccxxiv{diciendo: ``¿Acaso vamos a dejar a nuestros ídolos por las palabras de un poeta loco?"\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcccxxv{[Dios les dirá:] ``Él se presentó con la Verdad, y corroboró el Mensaje de los Profetas que lo precedieron".\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcccxxvi{Ustedes [que rechazaron el Mensaje] sufrirán un castigo doloroso.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcccxxvii{Pero sepan que solo se les retribuirá por lo que [ustedes mismos] hicieron.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcccxxviii{En cambio, los siervos sinceros de Dios,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcccxxix{ellos tendrán la recompensa prometida:\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdcccxxx{Los frutos que deseen, y serán honrados\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcccxxxi{en los Jardines de las Delicias,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcccxxxii{donde estarán reclinados sobre sofás, unos frente a otros.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdcccxxxiii{Y [bellos sirvientes] circularán entre ellos con una copa de un manantial eterno,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdcccxxxiv{blanco y delicioso para quienes lo beban,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcccxxxv{que no les provocará jaqueca ni embriaguez.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdcccxxxvi{También tendrán mujeres [huríes] de mirar recatado, y de ojos hermosos y grandes,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdcccxxxvii{como si fueran perlas celosamente guardadas.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdcccxxxviii{Y se preguntarán [los creyentes en el Paraíso] unos a los otros.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdcccxxxix{Uno de ellos dirá: ``Yo tenía un compañero [incrédulo]\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdcccxl{que me decía: ¿Acaso tú eres de los que creen en la Resurrección?\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdcccxli{¿Acaso después que muramos y nos convirtamos en tierra y huesos vamos a ser condenados?"\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdcccxlii{Dirá [el creyente a sus compañeros del Paraíso]: ``¿Quieren observar [el Infierno a ver qué ha sido de él]?"\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdcccxliii{Y cuando observe lo verá [a quien era su compañero] en medio del fuego del Infierno.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdcccxliv{Entonces le dirá: ``¡Por Dios! Poco faltó para que me arruinaras,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdcccxlv{y de no ser por la gracia de mi Señor, habría sido uno de los condenados.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdcccxlvi{Ahora no hemos de morir\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdcccxlvii{después de haber pasado por la primera muerte, y no seremos castigados.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdcccxlviii{Este es el éxito grandioso".\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdcccxlix{¡Vale la pena obrar para alcanzarlo!\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdcccl{¿Qué es mejor, esta morada [del Paraíso] o el árbol de Zaqqum?,\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdcccli{el que puse para castigar a los que cometieron injusticias.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdccclii{Es un árbol que crece en lo más profundo del Infierno;\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdcccliii{sus frutos son como cabezas de demonios.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdcccliv{De él comerán y llenarán sus vientres [los condenados].\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdccclv{Luego beberán una mezcla de agua hirviente,\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdccclvi{y serán regresados al fuego.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdccclvii{Ellos [en la vida mundanal] encontraron que sus padres estaban descarriados,\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdccclviii{y aun así siguieron sus pasos.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdccclix{La mayoría de los pueblos que los precedieron también se habían extraviado.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdccclx{Por ello les envié [Profetas] amonestadores.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdccclxi{Pero observa dónde terminaron aquellos que fueron advertidos,\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdccclxii{excepto los siervos fieles a Dios.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmdccclxiii{Cuando Noé Me invocó, ¡y qué mejor que invocar a Quien responde todas las súplicas!,\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmdccclxiv{lo salvé a él y a su familia de la gran angustia,\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmdccclxv{e hice que su descendencia fueran los sobrevivientes.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmdccclxvi{Dejé su historia [como enseñanza] para la posteridad.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmdccclxvii{¡Que la paz sea con Noé entre todas las criaturas!\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmdccclxviii{Así es como recompenso a los que hacen el bien.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmdccclxix{Él era uno de Mis siervos creyentes.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmdccclxx{A los otros [los que no creyeron] los ahogué.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmdccclxxi{Abraham era de los que lo siguieron [a Noé en su fe monoteísta],\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmdccclxxii{cuando invocó a su Señor con un corazón puro\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmdccclxxiii{y dijo a su padre y a su pueblo: ``¿Qué es lo que adoran?\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmdccclxxiv{¿Prefieren la mentira de los dioses en lugar de Dios?\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmdccclxxv{¿Qué opinan del Señor del universo?"\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmdccclxxvi{Entonces echó una mirada a las estrellas,\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmdccclxxvii{y exclamó: ``Estoy enfermo".\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmdccclxxviii{Entonces lo abandonaron dándole la espalda.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmdccclxxix{[Abraham] se dirigió hacia los ídolos [de su pueblo] y dijo: ``¿Por qué no comen?\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmdccclxxx{¿Por qué no pronuncian palabra?"\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmdccclxxxi{Entonces los destrozó con toda su fuerza.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmdccclxxxii{[Cuando los idolatras se enteraron,] se abalanzaron sobre él enfurecidos.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmdccclxxxiii{[Abraham les dijo:] ``¿Acaso adoran lo que ustedes mismos tallan?\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmdccclxxxiv{Dios es Quien los creó a ustedes y a lo que ustedes hacen".\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmdccclxxxv{Dijeron: ``Construiremos una hoguera y te arrojaremos al fuego llameante".\qt@no{97}}
\qt@newcmd\qurantrans@es@mmmdccclxxxvi{Tramaron contra él, pero Dios [desbarató sus planes y] los humilló.\qt@no{98}}
\qt@newcmd\qurantrans@es@mmmdccclxxxvii{Dijo [Abraham]: ``Emigraré a donde mi Señor me ordene. ¡Él me guiará!\qt@no{99}}
\qt@newcmd\qurantrans@es@mmmdccclxxxviii{¡Oh, Señor mío! Concédeme un hijo justo".\qt@no{100}}
\qt@newcmd\qurantrans@es@mmmdccclxxxix{Le anuncié que le daría un niño sensato.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmmdcccxc{Cuando [Ismael] alcanzó la pubertad, [Abraham] le dijo: ``¡Oh, hijito mío! He visto en sueños que te sacrificaba; dime, qué opinas". Le dijo: ``¡Oh, padre mío! Haz lo que te ha sido ordenado; encontrarás, si Dios quiere, que seré de los pacientes".\qt@no{102}}
\qt@newcmd\qurantrans@es@mmmdcccxci{Cuando ambos se resignaron, y [Abraham] lo echó sobre la frente [a Ismael para sacrificarlo],\qt@no{103}}
\qt@newcmd\qurantrans@es@mmmdcccxcii{Lo llamé: ``¡Oh, Abraham!\qt@no{104}}
\qt@newcmd\qurantrans@es@mmmdcccxciii{Has cumplido con lo que viste [en tus sueños]. Así recompenso a los que hacen el bien".\qt@no{105}}
\qt@newcmd\qurantrans@es@mmmdcccxciv{Esa fue una dura prueba.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmmdcccxcv{Pero lo rescaté [a su hijo, ordenando a Abraham que sacrificara en su lugar un cordero] e hiciera una gran ofrenda,\qt@no{107}}
\qt@newcmd\qurantrans@es@mmmdcccxcvi{y dejé su historia [como enseñanza] para la posteridad.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmmdcccxcvii{¡Qué la paz sea con Abraham!\qt@no{109}}
\qt@newcmd\qurantrans@es@mmmdcccxcviii{Así es como recompenso a los que hacen el bien.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmmdcccxcix{Él era uno de Mis siervos creyentes.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmmcm{Lo albricié con [el nacimiento de] Isaac, quien sería un Profeta virtuoso.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmmcmi{Lo bendije a él y a Isaac, y decreté que en su descendencia hubiera quien obrara el bien y quien fuera abiertamente [incrédulo e] injusto consigo mismo.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmmcmii{Agracié a Moisés y a Aarón,\qt@no{114}}
\qt@newcmd\qurantrans@es@mmmcmiii{y los salvé junto con su pueblo de una gran angustia.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmmcmiv{Los socorrí, y fueron ellos los vencedores.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmmcmv{Les concedí un Libro esclarecedor,\qt@no{117}}
\qt@newcmd\qurantrans@es@mmmcmvi{y los guie por el sendero recto.\qt@no{118}}
\qt@newcmd\qurantrans@es@mmmcmvii{Y dejé su historia [como enseñanza] para la posteridad,\qt@no{119}}
\qt@newcmd\qurantrans@es@mmmcmviii{¡Que la paz sea con Moisés y Aarón!\qt@no{120}}
\qt@newcmd\qurantrans@es@mmmcmix{Así es como recompenso a los que hacen el bien.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmmcmx{Ambos eran de Mis siervos creyentes.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmmcmxi{Elías también era de Mis Mensajeros.\qt@no{123}}
\qt@newcmd\qurantrans@es@mmmcmxii{Dijo a su pueblo: ``¿Es que no van a tener temor de Dios?\qt@no{124}}
\qt@newcmd\qurantrans@es@mmmcmxiii{Invocan a Ba‘l, y dejan de lado al mejor de los creadores:\qt@no{125}}
\qt@newcmd\qurantrans@es@mmmcmxiv{Dios, su Señor y el sus antepasados".\qt@no{126}}
\qt@newcmd\qurantrans@es@mmmcmxv{Pero lo desmintieron, y tendrán que comparecer.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmmcmxvi{Excepto los siervos fieles a Dios.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmmcmxvii{Dejé su historia [como enseñanza] para la posteridad.\qt@no{129}}
\qt@newcmd\qurantrans@es@mmmcmxviii{¡Qué la paz sea con Elías!\qt@no{130}}
\qt@newcmd\qurantrans@es@mmmcmxix{Así es como recompenso a los que hacen el bien.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmmcmxx{Él era uno de Mis siervos creyentes.\qt@no{132}}
\qt@newcmd\qurantrans@es@mmmcmxxi{Lot también fue de Mis Mensajeros.\qt@no{133}}
\qt@newcmd\qurantrans@es@mmmcmxxii{Lo salvé a él y a toda su familia,\qt@no{134}}
\qt@newcmd\qurantrans@es@mmmcmxxiii{excepto a su mujer, que se sentenció [a ella misma] junto a los condenados.\qt@no{135}}
\qt@newcmd\qurantrans@es@mmmcmxxiv{Luego aniquilé a los demás.\qt@no{136}}
\qt@newcmd\qurantrans@es@mmmcmxxv{Ustedes [¡oh, incrédulos!] pasan por sus ruinas de día\qt@no{137}}
\qt@newcmd\qurantrans@es@mmmcmxxvi{y de noche. ¿Es que no reflexionan?\qt@no{138}}
\qt@newcmd\qurantrans@es@mmmcmxxvii{Jonás también fue de Mis Mensajeros.\qt@no{139}}
\qt@newcmd\qurantrans@es@mmmcmxxviii{Cuando se fugó en el barco abarrotado,\qt@no{140}}
\qt@newcmd\qurantrans@es@mmmcmxxix{lo echaron a la suerte y él fue el perdedor.\qt@no{141}}
\qt@newcmd\qurantrans@es@mmmcmxxx{Cuando [fue arrojado al mar] una ballena se lo tragó. Jonás cometió un acto reprochable,\qt@no{142}}
\qt@newcmd\qurantrans@es@mmmcmxxxi{y si no fuera porque él era de los que glorifican a Dios,\qt@no{143}}
\qt@newcmd\qurantrans@es@mmmcmxxxii{hubiera permanecido en su vientre hasta el Día de la Resurrección.\qt@no{144}}
\qt@newcmd\qurantrans@es@mmmcmxxxiii{Pero lo arrojé a un lugar desolado, y su piel estaba tan débil\qt@no{145}}
\qt@newcmd\qurantrans@es@mmmcmxxxiv{que ordené crecer una planta de calabaza para que lo cubriera.\qt@no{146}}
\qt@newcmd\qurantrans@es@mmmcmxxxv{Luego lo envié a [una población de] más de cien mil personas\qt@no{147}}
\qt@newcmd\qurantrans@es@mmmcmxxxvi{y todos creyeron, y los dejé disfrutar hasta que la muerte les llegó.\qt@no{148}}
\qt@newcmd\qurantrans@es@mmmcmxxxvii{Pregúntales [¡oh, Mujámmad!, a los idólatras de tu pueblo]: ``¿[Qué argumentos tienen para afirmar] Que tu Señor tiene hijas mujeres y ellos los hijos varones?"\qt@no{149}}
\qt@newcmd\qurantrans@es@mmmcmxxxviii{¿Acaso fueron testigos cuando creé a los ángeles, para afirmar que son de sexo femenino?\qt@no{150}}
\qt@newcmd\qurantrans@es@mmmcmxxxix{Entre las mentiras que inventaron:\qt@no{151}}
\qt@newcmd\qurantrans@es@mmmcmxl{``Dios ha engendrado". Mienten.\qt@no{152}}
\qt@newcmd\qurantrans@es@mmmcmxli{¿Escogió a las hijas sobre los hijos [siendo el creador de ambos]?\qt@no{153}}
\qt@newcmd\qurantrans@es@mmmcmxlii{¿Qué les pasa? ¿Cómo es que juzgan?\qt@no{154}}
\qt@newcmd\qurantrans@es@mmmcmxliii{¿No van a pensar [antes de hablar]?\qt@no{155}}
\qt@newcmd\qurantrans@es@mmmcmxliv{¿O acaso tienen una prueba válida [de lo que afirman]?\qt@no{156}}
\qt@newcmd\qurantrans@es@mmmcmxlv{Traigan entonces el libro, si son veraces.\qt@no{157}}
\qt@newcmd\qurantrans@es@mmmcmxlvi{También inventaron un parentesco entre Dios y los yinnes, pero los yinnes saben bien que comparecerán [ante Dios] para ser juzgados.\qt@no{158}}
\qt@newcmd\qurantrans@es@mmmcmxlvii{¡Glorificado sea Dios! Él está por encima de lo que Le atribuyen.\qt@no{159}}
\qt@newcmd\qurantrans@es@mmmcmxlviii{Excepto los siervos fieles de Dios [que no le asocian nada ni lo describen como no es propio de Él].\qt@no{160}}
\qt@newcmd\qurantrans@es@mmmcmxlix{Ustedes [¡oh, idólatras!] y lo que adoran en lugar de Dios\qt@no{161}}
\qt@newcmd\qurantrans@es@mmmcml{solo podrán desviar\qt@no{162}}
\qt@newcmd\qurantrans@es@mmmcmli{a quien Dios permitió que se desvíe y arda en el fuego del Infierno.\qt@no{163}}
\qt@newcmd\qurantrans@es@mmmcmlii{[Los ángeles dicen:] ``No hay entre nosotros quien no tenga un lugar asignado,\qt@no{164}}
\qt@newcmd\qurantrans@es@mmmcmliii{y nos ordenamos en filas [para adorar a nuestro Señor].\qt@no{165}}
\qt@newcmd\qurantrans@es@mmmcmliv{Todos nosotros Lo glorificamos".\qt@no{166}}
\qt@newcmd\qurantrans@es@mmmcmlv{Solían decir [los idólatras, antes de que tú ¡oh, Mujámmad! fueras enviado a ellos]:\qt@no{167}}
\qt@newcmd\qurantrans@es@mmmcmlvi{``Si nos llegara el Mensaje como les llegó a los pueblos anteriores,\qt@no{168}}
\qt@newcmd\qurantrans@es@mmmcmlvii{sin duda seríamos fervientes siervos de Dios".\qt@no{169}}
\qt@newcmd\qurantrans@es@mmmcmlviii{Pero cuando les llegó lo negaron. ¡Ya verán [el castigo que les aguarda]!\qt@no{170}}
\qt@newcmd\qurantrans@es@mmmcmlix{Fue decretado para Mis siervos Mensajeros\qt@no{171}}
\qt@newcmd\qurantrans@es@mmmcmlx{que serían auxiliados,\qt@no{172}}
\qt@newcmd\qurantrans@es@mmmcmlxi{y que Mi ejército sería el vencedor.\qt@no{173}}
\qt@newcmd\qurantrans@es@mmmcmlxii{Apártate [¡oh, Mujámmad!] de los que rechazan el Mensaje por un tiempo,\qt@no{174}}
\qt@newcmd\qurantrans@es@mmmcmlxiii{y ten paciencia con ellos, que ya pronto verán.\qt@no{175}}
\qt@newcmd\qurantrans@es@mmmcmlxiv{¿Acaso quieren que se precipite Mi castigo?\qt@no{176}}
\qt@newcmd\qurantrans@es@mmmcmlxv{¡Qué terrible despertar les aguardaría a los que fueron advertidos, si Mi castigo se desencadenase sobre ellos [como pretenden]!\qt@no{177}}
\qt@newcmd\qurantrans@es@mmmcmlxvi{Apártate [¡oh, Mujámmad!] de los que rechazan el Mensaje por un tiempo,\qt@no{178}}
\qt@newcmd\qurantrans@es@mmmcmlxvii{y ten paciencia, que ya pronto verán [el castigo que les aguarda].\qt@no{179}}
\qt@newcmd\qurantrans@es@mmmcmlxviii{¡Glorificado sea tu Señor, el dueño del poder absoluto! Él está por encima de lo que Le atribuyen.\qt@no{180}}
\qt@newcmd\qurantrans@es@mmmcmlxix{¡Que la paz sea con todos los Mensajeros!\qt@no{181}}
\qt@newcmd\qurantrans@es@mmmcmlxx{¡Y alabado sea Dios, Señor del universo!\qt@no{182}}
\qt@newcmd\qurantrans@es@mmmcmlxxi{\basmalahes Sad. Juro por el Corán que nos recuerda\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcmlxxii{que los que niegan la verdad están hundidos en la soberbia y la oposición [ciega].\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcmlxxiii{¡Cuántas generaciones destruí antes que ellos! Solo imploraron cuando ya era demasiado tarde para salvarse [del castigo].\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcmlxxiv{Se asombran de que les llegue un amonestador, y dicen los que se niegan a creer: ``Es un hechicero mentiroso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcmlxxv{¿Acaso pretende que en lugar de muchos ídolos adoremos a una sola divinidad? Eso es algo insólito".\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcmlxxvi{Los nobles y poderosos de entre ellos se marcharon diciendo: ``Déjenlo, y sigan [adorando] a sus ídolos, pues él solo pretende obtener poder sobre nosotros.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcmlxxvii{No hemos oído que el último pueblo que recibió una revelación [los cristianos] creyera en esto. Lo que dices es una gran mentira.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcmlxxviii{¿Por qué tendría que haber sido él el elegido entre nosotros para transmitir el Mensaje?" Pero ellos dudan de Mi revelación porque no han sufrido aún ningún castigo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcmlxxix{¿Acaso ellos poseen las llaves de la misericordia de tu Señor, el Poderoso, el Dadivoso?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcmlxxx{¿O les pertenece el reino de los cielos, la Tierra y todo cuanto existe entre ambos? Si es así, que asciendan [al cielo y decidan los asuntos de la creación].\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcmlxxxi{[No te entristezcas, ¡oh, Mujámmad!, por su enemistad.] Ellos son un ejército de aliados [para combatir la Verdad], pero pronto serán derrotados.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcmlxxxii{Ya antes que ellos los pueblos de Noé, de ‘Ad y del Faraón, poseedor de un ejército poderoso, desmintieron [a los Profetas que les envié].\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcmlxxxiii{También lo hicieron los pueblos de Zamud, Lot y los habitantes del bosque. Todos estos eran pueblos poderosos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcmlxxxiv{Todos ellos desmintieron a los Mensajeros, y merecieron Mi castigo.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcmlxxxv{Solo les queda [a los idólatras] esperar el toque de la trompeta [el Día de la Resurrección], y entonces no habrá posibilidad de volver [a este mundo].\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcmlxxxvi{Pero aun así dicen [burlándose desafiantes]: ``¡Señor nuestro! Muéstranos el registro de nuestras obras y adelántanos una parte del castigo antes del Día del Juicio".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcmlxxxvii{Sé paciente [¡oh, Mujámmad!] ante lo que dicen, y recuerda a Mi siervo [el Profeta] David, quien fue dotado con una gran fuerza. Él siempre volvía a Dios en todos sus asuntos y se arrepentía con sinceridad.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcmlxxxviii{Le sometí las montañas, para que junto con él glorificaran las alabanzas al anochecer y al amanecer,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcmlxxxix{también le sometí a las aves que se congregaban en torno a él. Todos [las montañas y las aves] le obedecían.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcmxc{Afiancé su reino, lo agracié con la sabiduría [la profecía] y un juicio certero.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcmxci{Te relataré [¡oh, Mujámmad!] la historia de los dos demandantes, cuando treparon [la pared] del templo.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcmxcii{Cuando se presentaron ante David, este se atemorizó de ellos. Le dijeron: ``No temas, solo somos dos demandantes, uno ha sido injusto con el otro; juzga entre nosotros con equidad, sé imparcial y guíanos hacia el camino correcto.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcmxciii{Este es mi hermano, posee noventa y nueve ovejas, y yo tengo una sola; y me dijo: ‘Deja que yo me haga cargo de ella’, y ahora me supera con sus argumentos [para quedarse con ella]".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcmxciv{Dijo David [sin escuchar al otro demandante]: ``Él ha sido injusto contigo al pedirte que dejes que tu oveja se sume a las de él; muchos socios se perjudican unos a otros, excepto los que creen y obran rectamente; pero, ¡qué pocos son!" David comprendió que quise ponerlo a prueba [mediante este juicio], y pidió perdón a su Señor, se prosternó y se arrepintió.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcmxcv{Lo perdoné, pues es de los más allegados a Mí, y tendrá [en la otra vida] una bella morada [en el Paraíso].\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcmxcvi{¡Oh, David! Te he designado gobernante en la Tierra, juzga con equidad entre la gente y no sigas las pasiones, pues ellas desvían del sendero de Dios; y quienes se desvíen del sendero de Dios sepan que recibirán un castigo severo por haberse olvidado del Día del Juicio.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcmxcvii{No he creado el cielo, la Tierra y todo cuanto hay entre ambos en vano. Eso es lo que creen los que rechazan la verdad, pero, ¡ay de los incrédulos! ¡Qué [castigo les aguarda en] el Infierno!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcmxcviii{¿Acaso sería propio de Mí considerar a los creyentes que obran rectamente igual que a los que siembran la corrupción en la Tierra, o considerar a los que tienen temor de Dios igual que a los inmorales?\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcmxcix{Este Libro que te revelo [¡oh, Mujámmad!] encierra grandes bendiciones, para que mediten sobre sus signos y reflexionen los dotados de intelecto.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmm{Agracié a David con [su hijo] Salomón, quien fue un siervo excelente, pues volvía a Mí en todos sus asuntos y se arrepentía con sinceridad.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmi{Una tarde fueron expuestos delante de él unos hermosos caballos,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmii{[luego de permanecer toda la tarde jugando con ellos descuidó la oración, y entonces Salomón] dijo: ``Cómo he podido preferir éstos caballos al recuerdo de Dios hasta que el Sol se ocultó".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmiii{[Dijo Salomón:] ``Traédmelos". Y acarició sus cuellos y sus patas.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmiv{Puse a prueba a Salomón [despojándolo de su reino] cuando puse en su trono un demonio con figura humana [que disponía de su reino como quería]. Entonces, [Salomón] se dirigió a su Señor\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmv{y exclamó: ``¡Oh, Señor mío! Perdóname y concédeme un reino tan poderoso, que nadie pueda igualarlo después de mí; Tú eres el Dadivoso".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmvi{Entonces puse a su servicio el viento, que corría según su orden adonde él quisiera,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmvii{y a los yinnes, algunos [creyentes] para la construcción, otros como buzos [que extraían perlas],\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmviii{y otros [demonios rebeldes] encadenados unos con otros.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmix{[Le dije:] ``Éste es el reino con el que te he agraciado; haz uso de él como quieras, pues no deberás rendir cuenta de ello".\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmx{Salomón es de Mis allegados, y por eso [en la otra vida] tendrá una bella morada [en el Paraíso].\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmxi{Recuerda a Mi siervo [el Profeta] Job, cuando invocó a su Señor: ``El demonio se aprovecha de mi enfermedad y sufrimiento [para tentarme a ser desagradecido contigo]".\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmxii{[Le dije:] ``Golpea con tu pie [en la tierra], y haré surgir agua fresca para que te laves con ella y también bebas".\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmxiii{Lo agracié con hijos [como los que tenía] y tantos más, como una misericordia mía, para que sea un recuerdo y motivo de reflexión para los dotados de intelecto.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmxiv{[Le ordené:] ``Toma en tu mano un manojo de hierbas y golpea [simbólicamente] con él a tu esposa, para que no perjures". Job fue paciente [ante todas las adversidades]. ¡Qué excelente siervo; volvía a Dios en todos sus asuntos y se arrepentía con sinceridad!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmxv{Recuerda a Mis siervos Abraham, Isaac y Jacob, todos ellos dotados de firmeza y visión.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmxvi{Los distinguí encomendándoles [transmitir el Mensaje y] recordar a la gente la morada de la otra vida.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmxvii{Ellos se cuentan entre los virtuosos que he elegido [para transmitir el Mensaje].\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmxviii{Y recuerda a Ismael, Eliseo y Dhul Kifl; todos ellos también se contaron entre los virtuosos [que elegí para trasmitir el Mensaje].\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmxix{Este es un Mensaje [para toda la humanidad]. Los piadosos tendrán una bella morada\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmxx{en los Jardines del Edén. Todas sus puertas estarán abiertas para ellos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmxxi{Estarán recostados [sobre sofás], y pedirán frutas abundantes y [exquisitas] bebidas,\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmxxii{acompañados de doncellas [huríes] de mirar recatado, que tendrán siempre la misma edad.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmxxiii{Esto es lo que se os ha prometido [¡Oh, creyentes!, como recompensa] para el Día del Juicio.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmxxiv{Ese es Mi sustento, que jamás se agotará.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmxxv{¡Así será! En cambio, para los que cometan injusticias habrá una horrible morada.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmxxvi{Este es el Infierno donde sufrirán. ¡Qué pésima morada!\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmxxvii{¡Esto será así! Sufrirán, y allí solo beberán agua hirviendo y las secreciones de las heridas [de quienes son atormentados en el Infierno].\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmxxviii{También recibirán otros castigos similares.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmxxix{[Dirán los ángeles guardianes del Infierno a los líderes de la incredulidad:] ``Este es otro grupo [de sus seguidores] que se precipitará con ustedes [al Infierno]". [Dirán los líderes:] ``Hoy no hay bienvenida para ellos porque arderán en el fuego del Infierno".\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmxxx{Dirán [los seguidores]: ``Tampoco hay bienvenida para ustedes, pues fueron quienes nos arrastraron [al Infierno]". ¡Qué pésima morada [para todos ellos]!\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmxxxi{Dirán [los seguidores]: ``¡Oh, Señor nuestro! Duplícales el castigo del Fuego a quienes nos arrastraron a esto".\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmxxxii{Dirán [los líderes de la incredulidad]: ``¿Qué sucede que no vemos a las personas que considerábamos los malvados?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmxxxiii{¿Acaso nos equivocamos al burlarnos de ellos? ¿O es que están [con nosotros en el Infierno] pero no los vemos?"\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmxxxiv{Así será la disputa entre los moradores del Infierno.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmxxxv{Diles [¡oh, Mujámmad!]: ``Solo soy un amonestador. No existe nada ni nadie con derecho a ser adorado salvo Dios, el Único, el Victorioso,\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmxxxvi{Señor de los cielos, de la Tierra, y de todo cuanto existe entre ellos, el Poderoso, el Remisorio".\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmxxxvii{Diles: ``Lo que les he transmitido es un Mensaje sublime,\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmxxxviii{pero lo rechazan.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmxxxix{[Antes de la revelación] yo no tenía conocimiento acerca de la corte elevada [de ángeles] cuando discutían [sobre la creación de Adán].\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmxl{Me ha sido revelado que soy un amonestador que habla claro."\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmxli{Recuerda [¡oh, Mujámmad!] cuando tu Señor dijo a los ángeles: ``Voy a crear un hombre de barro.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmxlii{Y cuando lo haya plasmado y haya soplado en él su espíritu, hagan una reverencia [en obediencia a Mí] ante él".\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmxliii{Todos los ángeles hicieron la reverencia.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmxliv{Excepto Iblís, quien fue soberbio y se contó entre los incrédulos.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmxlv{Dijo Dios: ``¡Iblís! ¿Qué te impide hacer una reverencia ante lo que creé con Mis dos manos? ¿Te niegas a hacerlo por soberbia o porque te crees un ser superior?"\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmxlvi{Dijo [Iblís]: ``Yo soy superior a él. A mí me creaste de fuego, mientras que a él lo creaste de barro".\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmxlvii{Dijo Dios: ``Sal de aquí, pues te maldigo.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmxlviii{Y esta maldición pesará sobre ti hasta el Día del Juicio".\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmxlix{Dijo [Iblís]: ``¡Oh, Señor mío! Permíteme vivir hasta el Día de la Resurrección".\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmml{Dijo Dios: ``Te concedo la prórroga que Me pides,\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmli{hasta el día cuyo término está prefijado".\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmlii{Dijo [Iblís]: ``¡Juro por Tu poder que los descarriaré a todos,\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmliii{excepto a quienes de Tus siervos hayas protegido!"\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmliv{Dijo Dios: ``La verdad es [lo que he jurado], y la verdad declaro:\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmlv{He de llenar el Infierno contigo y todos los que te sigan".\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmlvi{Diles [¡oh, Mujámmad!]: ``Yo no les pido ninguna remuneración a cambio [de transmitirles el Mensaje], ni soy de los que inventan mentiras.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmlvii{El Corán es un Mensaje para toda la humanidad.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmlviii{Y dentro de poco tiempo verán lo que en él se anuncia".\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmlix{\basmalahes La revelación de este Libro proviene de Dios, el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmlx{Te he revelado el Libro [¡oh, Mujámmad!] con la Verdad; adora solo a Dios rindiéndole culto sincero.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmlxi{¿Acaso no se le debe rendir culto sincero a Dios? Aquellos que toman a otros como protectores [y objeto de adoración] fuera de Él, dicen: ``Solo los adoramos para que nos acerquen a Dios [e intercedan por nosotros]". Dios juzgará entre ellos [y los creyentes] acerca de lo que discrepan. Dios no guía a quien es mentiroso y niega la verdad.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmlxii{Si Dios hubiera querido tomar a alguien como hijo, hubiera elegido a quien quisiera de entre Su creación. ¡Glorificado sea! Él es Dios, el Único, el Victorioso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmlxiii{Creó los cielos y la Tierra con un fin justo y verdadero. Él enrolla [envuelve] la noche en el día, y envuelve el día en la noche, y sometió al Sol y a la Luna haciendo que cada uno recorra su órbita por un plazo prefijado. ¿Acaso Él no es el Poderoso, el Perdonador?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmlxiv{Él los creó a partir de un solo ser, luego de él creó a su pareja, y los agració con ocho ganados en parejas. Los creó en los vientres de sus madres en períodos sucesivos y en tres tinieblas [el vientre, el útero y la placenta]. Él es Dios, su Señor; Él posee el dominio completo. No hay nada ni nadie con derecho a ser adorado salvo Él. ¿Cómo entonces dedican actos de culto a otras deidades?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmlxv{Si no creen, sepan que Dios no necesita de ustedes. No Le agrada la incredulidad de Sus siervos, pero si son agradecidos [creyendo en Su unicidad], Lo complacerán. Sepan que nadie cargará con los pecados ajenos; luego comparecerán ante su Señor y Él les informará sobre lo que hayan realizado. Él bien sabe cuanto hay en los corazones.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmlxvi{Cuando al ser humano le acontece una desgracia, invoca a su Señor y se vuelve a Él [pidiéndole que lo auxilie]; pero luego, cuando Él le concede una gracia, olvida que Lo había invocado antes e iguala a sus ídolos con Dios [dedicándoles actos de adoración y súplicas], descarriando a otros de Su sendero. Dile [a quien se comporte de esta manera]: ``Disfruta por poco tiempo de tu incredulidad, pues serás de los moradores del Infierno".\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmlxvii{¿Acaso se puede comparar a [ese incrédulo] con quien se prosterna e inclina [en oración] consagrándose en la noche, está consciente de la otra vida y anhela la misericordia de su Señor? Dile: ``¿Acaso son iguales los que tienen conocimiento y los que no tienen conocimiento?" Solo reflexionan los dotados de entendimiento.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmlxviii{Diles: ``¡Oh, siervos creyentes! Tengan temor de su Señor, y sepan que quienes obren bien en este mundo recibirán una bella recompensa, y que la Tierra de Dios es amplia. La recompensa para quienes sean pacientes y perseverantes no tendrá límite".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmlxix{Diles: ``Me ha sido ordenado adorar solamente a Dios, y rendirle culto sincero,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmlxx{y me ha sido ordenado que sea el primero en someterse a Él".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmlxxi{Diles: ``Pero yo temo, si desobedezco [las órdenes de] mi Señor, el castigo en un día difícil [el Día del Juicio]".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmlxxii{Diles: ``Yo adoro solamente a Dios, y Le rindo culto sincero.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmlxxiii{Adoren lo que quieran en lugar de Él. Los desdichados serán los que se descarríen a sí mismos y a su gente el Día de la Resurrección [ingresando al Infierno]. ¿Acaso no es esta la mayor ruina?"\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmlxxiv{Serán cubiertos por encima y por debajo por nubes de fuego. Así atemoriza Dios a Sus siervos. ¡Oh, siervos Míos! Tengan temor de Mí [y crean].\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmlxxv{Quienes se aparten de los ídolos negándose a adorarlos y se vuelvan a Dios, serán los bienaventurados. Albricia [¡oh, Mujámmad!] a Mis siervos\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmlxxvi{que escuchan todo lo que se dice, pero siguen lo mejor [la palabra de Dios y Su Mensajero]. Ellos son los guiados por Dios, son los dotados de entendimiento.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmlxxvii{¿Acaso tú podrás salvar [guiando] a quien [en virtud de su libre albedrio] Dios ha decretado que sea de los moradores del Infierno? ¿O es que puedes rescatar a quien ha sido condenado al Fuego?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmlxxviii{Pero quienes hayan tenido temor de su Señor, morarán en la otra vida en habitaciones elevadas, y sobre ellos habrá otras habitaciones [donde estarán quienes hayan alcanzado grados más elevados], todas construidas de oro y plata, [en jardines] donde correrán ríos. Ésta es la promesa de Dios, y Dios no falta a Su promesa.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmlxxix{¿Acaso no ves que Dios hace descender el agua del cielo, y luego hace que surja como manantiales en la tierra, y hace brotar con ella cultivos de diversos colores que se secan y puedes ver que se tornan amarillentos y finalmente se convierten en heno? En eso hay un motivo de reflexión para los dotados de entendimiento.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmlxxx{¿Acaso se puede comparar a aquel a quien Dios abrió su corazón al Islam y está colmado por la luz de su Señor [con quien se niega a creer]? ¡Cuán desdichados son quienes tienen el corazón endurecido al Mensaje de Dios! Ellos están en un desvío evidente.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmlxxxi{Dios ha revelado el mejor de los Mensajes, que es un Libro armonioso [sin contradicciones] que reitera [las enseñanzas]. Su recitación hace erizar la piel de quienes tienen temor de su Señor. [Los creyentes] cuando recuerdan a Dios, su piel y sus corazones se apaciguan. Ésta es la guía de Dios, con la que Él encamina a quien quiere; pero sepan que para quien Dios decreta el desvío, no habrá nadie que lo pueda guiar.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmlxxxii{¿Acaso aquel que se resguarda del terrible castigo del Día de la Resurrección [se equipara con quien se siente seguro contra él]? A los que cometieron injusticias se les dirá [el Día del Juicio]: ``Sufran [el castigo por] lo que obraron".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmlxxxiii{Otras personas en la antigüedad desmintieron [a los Mensajeros], pero fueron sorprendidos por el castigo desde donde menos lo esperaban.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmlxxxiv{Dios los hizo sufrir la humillación en la vida mundanal, y el castigo de la otra vida será mayor; si lo supieran.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmlxxxv{He expuesto en el Corán toda clase de ejemplos para que reflexionen.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmlxxxvi{Este Corán ha sido revelado en idioma árabe y sin contradicciones, para que tengan temor de Dios.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmlxxxvii{Dios da un ejemplo sobre [la idolatría:] ¿Acaso son iguales un hombre que tiene muchos amos asociados que discrepan entre sí, y un hombre al servicio de un solo amo? ¡Alabado sea Dios! [No se equiparan] Pero la mayoría de los seres humanos lo ignoran.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmlxxxviii{Tú [¡oh, Mujámmad!] has de morir y ellos también han de morir [pues ningún ser creado es inmortal].\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmlxxxix{Luego, el Día de la Resurrección ante su Señor discutirán [intentando excusarse].\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmxc{¿Acaso existe alguien más injusto que quien inventa mentiras sobre Dios y desmiente la Verdad cuando se le presenta? El Infierno será la morada de los que rechazan la verdad.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmxci{Quien les ha traído la Verdad [el Profeta Mujámmad] y aquellos que creyeron en él y lo siguieron, son los piadosos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmxcii{Ellos tendrán cuanto deseen junto a su Señor. Esa será la recompensa de los que hacen el bien.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmxciii{Dios les perdonará las peores faltas que hubieran cometido, y los recompensará por las mejores buenas obras que hayan realizado.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmxciv{¿Acaso Dios no es suficiente [como Protector] para Su siervo? Pero ellos [los idólatras] intentan atemorizarte con sus ídolos [a los cuales adoran] en lugar de Él. Y a quien Dios permite que se desvíe nadie lo podrá guiar.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmxcv{A quien Dios decretó que siguiera la guía, no habrá nadie que lo pueda desviar. ¿Acaso no es Dios Poderoso y el dueño de la retribución [que merecen]?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmxcvi{Si les preguntas [a los idólatras:] ``¿Quién creó los cielos y la Tierra?" Te responderán: ``¡Dios!" Diles: ``¿Acaso no han pensado qué es aquello que invocan en vez de Dios? ¿Si Dios quisiera azotarme con algún daño, acaso sus ídolos me podrían librar de él? ¿O si deseara Dios cubrirme con Su misericordia, podrían ellos impedirlo?" Diles: ``Me es suficiente con Dios. Quienes confíen verdaderamente en Dios, que se encomienden a Él".\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmxcvii{Diles: ``¡Oh, pueblo mío! Obren como quieran, que yo obraré [acorde a lo que me ha sido revelado]. Ya sabrán\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmxcviii{a quién le corresponde el castigo humillante, y quién recibirá un castigo eterno [en la otra vida]".\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmxcix{[¡Oh, Mujámmad!] Te he revelado el Libro con la Verdad para [que se lo transmitas a] la gente. Quien siga la guía lo hará en beneficio propio, pero quien se desvíe lo hará en detrimento propio. Sabe que tú no eres responsable de lo que ellos hagan.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmc{Dios toma las almas en el momento de la muerte, y durante el sueño las de quienes aún no les ha llegado su hora. Retiene aquellas de quienes decretó su muerte, y devuelve las otras hasta [que se cumpla] el plazo prefijado [para su muerte]. En esto hay signos para quienes reflexionan.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmci{Sin embargo [los idólatras] toman [ídolos como] intercesores ante Dios. Diles: ``¿Lo hacen a pesar de que ellos no pueden hacer nada, ni tampoco entienden?"\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcii{Diles: ``Dios es Quien autoriza toda intercesión. A Él pertenece el reino de los cielos y la Tierra; ante Él comparecerán".\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmciii{Cuando se menciona a Dios como única divinidad, los corazones de los que se niegan a creer en el más allá sienten rechazo, pero cuando se mencionan a otros [ídolos] en lugar de Él, entonces se alegran.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmciv{Di: ``¡Oh, Dios! Tú eres el Creador de los cielos y de la Tierra, el conocedor de lo oculto y lo manifiesto; Tú juzgarás entre Tus siervos sobre lo que solían discutir [sobre sus creencias]".\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcv{Si los que cometen injusticias [idolatrías] poseyeran todo cuanto hay en la Tierra y otra cantidad semejante, querrían entregarlo como rescate para salvarse del castigo el Día de la Resurrección; pero Dios ya les mostrará lo que no se imaginan.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcvi{Se les mostrarán las obras malas que cometieron, y el castigo del que se burlaban los rodeará.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcvii{Cuando al ser humano le sucede una desgracia Me invoca; y luego, cuando le concedo una gracia, dice: ``La gracia que se me ha concedido es porque me lo merecía debido a mi capacidad". Esto es una prueba [de Dios], pero la mayoría lo ignora.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcviii{Así dijeron sus ancestros, y [cuando los sorprendió el castigo] no los beneficiaron en absoluto las riquezas que habían obtenido.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcix{Los azotó el castigo por lo que cometieron; los opresores serán castigados por sus malas obras, y no lo podrán evitar.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcx{¿Acaso no saben que Dios concede un sustento abundante a quien Él quiere y se lo restringe a quien quiere? En esto hay signos para los que creen.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcxi{Di: ``¡Oh, siervos míos que están sumidos en el pecado [perjudicándose a sí mismos]! No desesperen de la misericordia de Dios. Dios tiene poder para perdonar todos los pecados. Él es el Perdonador, el Misericordioso".\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcxii{Arrepiéntanse ante su Señor y sométanse a Él como musulmanes, antes de que los sorprenda el castigo, y entonces no sean socorridos.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcxiii{Sigan los preceptos que les han sido revelados [en el Corán] por su Señor, antes de que repentinamente les llegue el castigo, sin que se den cuenta,\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcxiv{[y entonces] digan: ``¡Qué pena! Ahora estoy perdido por haber desobedecido las órdenes de Dios, y realmente me contaba entre quienes se burlaban [del castigo]".\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcxv{O digan: ``¡Cómo desearía que Dios me hubiera guiado para contarme entre los piadosos!"\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcxvi{O digan, cuando vean el castigo: ``Si pudiera tener otra oportunidad [en la vida mundanal], entonces me contaría entre los que hacen el bien".\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcxvii{[Pero Dios dirá:] ``Ya se les presentaron Mis signos evidentes [en el Corán] y los desmintieron, fueron arrogantes y los rechazaron".\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcxviii{El Día de la Resurrección verás que los rostros de quienes desmintieron a Dios estarán ensombrecidos. ¿Acaso no es el Infierno la morada para los soberbios?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcxix{Dios salvará a los piadosos y les concederá el triunfo [ingresándolos al Paraíso], y no los alcanzará el castigo ni la tristeza.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcxx{Dios es el Creador de todas las cosas, y Él es su Custodio.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcxxi{A Él pertenecen las llaves de los cielos y de la Tierra. Quienes no crean en los signos de Dios serán los perdedores.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcxxii{Diles [¡oh, Mujámmad! a los idólatras]: ``¿Cómo pretenden que adore a sus ídolos en vez de Dios, ¡oh, ignorantes!?"\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcxxiii{Se te ha revelado [¡oh, Mujámmad!], y también a los [Profetas] que te precedieron, que si dedicas actos de adoración a otro que Dios, tus obras se perderán y te contarás entre los perdedores.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcxxiv{Adora solo a Dios y sé de los agradecidos.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcxxv{[Los idólatras] no han valorado a Dios en Su verdadera magnitud. El Día de la Resurrección contendrá toda la Tierra en Su puño, y los cielos estarán plegados en Su diestra. ¡Glorificado y enaltecido sea Dios! Él está por encima de lo que Le asocian.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcxxvi{Será soplada la trompeta y todos los que estén en los cielos y en la Tierra perecerán, excepto quien Dios quiera; luego será soplada por segunda vez y [todos resucitarán] poniéndose de pie [para ser juzgados]. Entonces verán.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcxxvii{La Tierra se iluminará con la luz de su Señor, el registro de las obras se expondrá, se hará comparecer a los Profetas y a los testigos, y [la gente] será juzgada con justicia y nadie será oprimido.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcxxviii{Será juzgada cada alma acorde a sus obras, y Él es Quien mejor sabe cuanto hicieron.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcxxix{Los que se negaron a creer serán arriados en grupos hacia el Infierno, y cuando lleguen a él, serán abiertas sus puertas y sus [ángeles] guardianes les dirán: ``¿Acaso no se les presentaron Mensajeros que les transmitieron los signos de su Señor, y les advirtieron sobre la comparecencia de este día?" Responderán: ``¡Sí! Pero [debido a que los desmentimos] se cumplirá el designio de Dios de castigar a los incrédulos".\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcxxx{Se les dirá: ``Entren por las puertas del Infierno, y morarán allí por toda la eternidad". ¡Qué pésima morada tendrán los soberbios!\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcxxxi{Pero quienes hayan tenido temor de su Señor, serán conducidos al Paraíso en grupos, y cuando lleguen a él, serán abiertas sus puertas y sus [ángeles] guardianes les dirán: ``Con ustedes sea la paz, bienvenidos. Ingresen en él por toda la eternidad".\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcxxxii{Exclamarán: ``¡Alabado sea Dios!, Quien cumplió Su promesa y nos hizo heredar la tierra del Paraíso, para establecernos donde queramos. ¡Qué excelente la recompensa de los que obraron el bien!"\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcxxxiii{Verás a los ángeles, alrededor del Trono, glorificando las alabanzas de su Señor. [El Día del Juicio] se juzgará a la creación con total justicia, y se exclamará: ``¡Alabado sea Dios, Señor del universo!"\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcxxxiv{\basmalahes Ha’. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcxxxv{La revelación de este Libro proviene de Dios, el Poderoso, el que todo lo sabe.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcxxxvi{El Perdonador de los pecados, el que acepta el arrepentimiento, es severo en el castigo y es generoso al conceder Sus gracias. No hay otra divinidad salvo Él, y ante Él han de comparecer.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcxxxvii{No disputan los signos de Dios sino los que se niegan a creer. Que no te deslumbre la aparente prosperidad de sus negocios por la zona, ya que\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcxxxviii{antes que ellos el pueblo de Noé y los aliados también habían desmentido [el Mensaje]. Toda nación se complotó contra su Mensajero. Le discutían con argumentos falsos para destruir la Verdad, y por eso los castigué. ¡Qué terrible fue Mi castigo!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcxxxix{Así fue como se cumplió el designio de tu Señor sobre los que se negaron a creer: que ellos serían los moradores del Fuego.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcxl{Los [ángeles] que portan el Trono, y los que están a su alrededor, glorifican con alabanzas a su Señor, creen en Él y piden el perdón para los creyentes diciendo: ``¡Señor nuestro! Tú lo abarcas todo con Tu misericordia y sabiduría. Perdona a quienes se arrepienten y siguen Tu camino, y presérvalos del castigo del Fuego.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcxli{¡Señor nuestro! Introdúcelos en los Jardines del Edén que les prometiste, junto a sus padres, esposas y descendientes que fueron piadosos y creyentes. Tú eres el Poderoso, el Sabio.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcxlii{Presérvalos de cometer pecados. Tú te apiadarás, cuando llegue el Día del Juicio, de aquel que haya sido preservado de cometer pecados. Ese será el triunfo grandioso".\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcxliii{Pero a los que se negaron a creer se les dirá: ``La aversión de Dios por ustedes es mayor que el odio que sentirán por ustedes mismos [al ser arrojados al Fuego], ya que fueron invitados a la fe pero la rechazaron".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcxliv{Dirán: ``¡Oh, Señor nuestro! Nos diste la muerte dos veces y nos diste la vida dos veces, reconocemos nuestros pecados; ¿existe alguna forma de salir [del castigo del Infierno]?"\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcxlv{[Se les dirá:] ``Este tormento es porque, cuando se los invitó a adorar a un Dios Único, no creyeron; pero cuando se los invitaba a dedicarle actos de adoración a otros [ídolos] junto a Dios, entonces sí creyeron. El juicio corresponde a Dios, el Sublime, el Supremo.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcxlvi{Él es Quien les muestra Sus signos y les envía la lluvia del cielo como sustento, pero no reflexiona en ello sino quien retorna [a Dios] arrepentido.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcxlvii{Invoquen a Dios y adórenlo con sinceridad, aunque eso disguste a los que se niegan a creer.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcxlviii{Él posee los atributos más sublimes, Señor del Trono. Concede la revelación con Su Mensaje a quien Él quiere de Sus siervos, para que adviertan sobre el día de la comparecencia.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcxlix{Ese día saldrán [de las tumbas] y nada estará oculto a Dios. [Él preguntará:] ``¿Quién es el soberano hoy?" [Y Él mismo responderá:] ``Solo Dios, el Único, el Victorioso".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcl{Hoy cada alma será juzgada por lo que haya realizado. Hoy no se cometerá injusticia alguna. Dios es rápido en ajustar cuentas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcli{Adviérteles [¡oh, Mujámmad!] sobre la inminencia del Día [del Juicio], donde los corazones se les subirán hasta las gargantas por la angustia. Los que cometieron injusticias no tendrán ningún amigo ni intercesor que sea escuchado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmclii{[Dios] conoce las miradas pérfidas y lo que esconden los corazones.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcliii{Dios juzga con la verdad, y los que invocan en lugar de Él no pueden juzgar nada. Dios todo lo oye, todo lo ve.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcliv{¿Acaso no viajan por el mundo y observan cuál fue el final de sus antecesores? Tenían más poder y dejaron más vestigios sobre la Tierra [que ustedes], pero Dios los castigó [destruyéndolos] por sus pecados, y nadie pudo protegerlos de Dios.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmclv{Esto [fue lo que merecieron] porque se les presentaron sus Mensajeros con las pruebas claras, pero los rechazaron y entonces Dios los castigó. Él es Fortísimo y severo al castigar.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmclvi{Envié a Moisés con Mis signos y pruebas evidentes.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmclvii{[Lo envié] ante el Faraón, Hamán y Qarún, pero le dijeron: ``Eres un hechicero mentiroso".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmclviii{Pero cuando se les presentó con Mi Verdad, dijeron: ``Maten a los hijos de quienes creyeron en él, y dejen con vida a sus mujeres". Pero los planes de los incrédulos fueron en vano.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmclix{Dijo el Faraón [con soberbia]: ``Déjenme, yo mataré a Moisés, y que invoque a su Señor [para que me lo impida]; temo que cambie la religión de ustedes o que siembre la corrupción en la Tierra".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmclx{Dijo Moisés: ``Me amparo en mi Señor y Señor de ustedes, de todo arrogante que no crea del Día del Juicio".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmclxi{Dijo un hombre creyente de la familia del Faraón, que ocultaba su fe: ``¿Matarán a un hombre solo porque dice: ‘Dios es mi Señor’, siendo que les ha presentado milagros de su Señor? Si se trata de un mentiroso, sobre él recaerá su mentira; pero si dice la verdad, los azotará una parte del castigo conque los amenaza. Dios no guía a quien se extralimita y miente.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmclxii{¡Oh, pueblo mío! A ustedes les pertenece el reino hoy, y son quienes dominan en la tierra [de Egipto]. ¿Pero quién nos defenderá del castigo de Dios, si Él lo desencadena sobre nosotros?" Dijo el Faraón: ``No les propongo sino lo que considero correcto, y no los guío sino por el buen camino".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmclxiii{Pero dijo el hombre que creía [de la familia del Faraón]: ``¡Oh, pueblo mío! Temo que les ocurra lo mismo que a los aliados [incrédulos que se complotaron contra sus Mensajeros],\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmclxiv{como ocurrió al pueblo de Noé, ‘Ad y Zamud, y los que les sucedieron [que fueron aniquilados]. Dios no es injusto con Sus siervos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmclxv{¡Oh, pueblo mío! Temo que [sean castigados] el día de la convocatoria.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmclxvi{Ese día pretenderán huir, pero no tendrán quien los proteja del castigo de Dios. Sepan que a quien Dios abandona en el desvío, no habrá nadie que lo pueda guiar".\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmclxvii{Se les presentó [el Profeta] José antes [que Moisés] con milagros evidentes, pero ustedes permanecieron dudando sobre lo que les mostró [y no creyeron], hasta que cuando murió, dijeron: ``Dios no enviará ningún Mensajero luego de él". Así extravía Dios a quien excede los límites y duda [de Su Mensaje],\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmclxviii{los que discuten los milagros de Dios sin haber recibido un argumento válido, por lo que acrecientan la aversión de Dios y de los creyentes hacia ellos. Así es como Dios sella el corazón de todo arrogante, opresor.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmclxix{Dijo el Faraón: ``¡Oh, Hamán! Constrúyeme una torre para que pueda ascender.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmclxx{Ascender a los cielos y ver a quién adora Moisés, aunque creo que [Moisés] miente". Así fue como [el demonio] le hizo ver al Faraón como buenas sus malas acciones, y logró que se extraviara completamente. Los planes del Faraón fracasaron.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmclxxi{Dijo el [hombre] creyente [de la familia del Faraón]: ``¡Oh, pueblo mío! Síganme, que los guiaré por el camino recto.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmclxxii{¡Oh, pueblo mío! En esta vida mundanal hay solo placeres temporales, mientras que la otra vida es la morada de la eternidad.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmclxxiii{Quien haga una maldad, será castigado acorde a lo cometido, pero quien haga obras buenas y sea creyente, varón o mujer, ingresará al Paraíso y será recompensado sin medida.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmclxxiv{¡Oh, pueblo mío! ¿Qué sucede que los invito a la salvación y ustedes me invitan al Infierno?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmclxxv{Me proponen negar la unicidad de Dios y que dedique actos de adoración a otros [ídolos], pero no tengo conocimiento [que algo merezca ser adorado salvo Él]. Yo los invito a creer en el Poderoso, el Perdonador.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmclxxvi{No hay duda de que aquello a lo que me invitan carece de fundamento en esta vida y en la otra; todos compareceremos ante Dios, y quienes exceden los límites serán los moradores del Infierno.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmclxxvii{Ya se acordarán de esto que les digo, pero [me refugio en Dios y] confío mis asuntos a Él. Dios ve bien lo que hacen Sus siervos".\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmclxxviii{Dios lo protegió de las maldades que tramaron contra él, mientras que el Faraón y sus seguidores fueron azotados por un castigo terrible.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmclxxix{[En la tumba] el fuego los alcanzará por la mañana y por la tarde, pero el día que llegue la Hora [del Juicio, se les ordenará a los ángeles:] ``Arreen al Faraón y sus seguidores al castigo más severo".\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmclxxx{Cuando [los incrédulos] discutan en el Infierno, dirán los más débiles a los soberbios [líderes de la incredulidad]: ``Nosotros fuimos sus seguidores, ¿no pueden librarnos de una parte del [castigo del] Infierno?"\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmclxxxi{Dirán los soberbios: ``Todos nosotros estamos [siendo castigados] en él, Dios juzgó entre Sus siervos [y nadie puede aminorar el tormento]".\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmclxxxii{Quienes están en el tormento dirán a los [ángeles] guardianes del Infierno: ``Rueguen a su Señor para que nos alivie el castigo [aunque sea] un solo día".\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmclxxxiii{Dirán [los ángeles]: ``¿Acaso no se les presentaron Mensajeros con milagros evidentes?" Responderán: ``Claro que sí [pero no les creímos]". Les dirán entonces [los ángeles]: ``Rueguen ustedes", pero las súplicas de los que se negaron a creer serán en vano.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmclxxxiv{Les daré Mi socorro a Mis Mensajeros y a los creyentes en esta vida y también en el Día del Juicio, cuando comparezcan los [ángeles] testigos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmclxxxv{En ese día no los beneficiarán las excusas a los que cometieron injusticias, serán maldecidos y tendrán la peor morada.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmclxxxvi{Concedí a Moisés la guía, e hice que los Hijos de Israel heredaran el Libro [de la Tora],\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmclxxxvii{como guía y motivo de reflexión para los dotados de entendimiento.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmclxxxviii{Sé paciente y perseverante, porque la promesa de Dios es verdadera; pide el perdón de tus faltas y glorifica con alabanzas a tu Señor por la tarde y al amanecer.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmclxxxix{[Los que se niegan a creer] discuten los milagros de Dios sin pruebas válidas, porque sus corazones están colmados de soberbia, y sabe que no lograrán sus propósitos [de vencerte, ¡oh, Mujámmad!]. Refúgiate en Dios, Él todo lo oye, todo lo ve.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcxc{La creación de los cielos y de la Tierra es más grandiosa que la creación de los seres humanos, pero la mayoría de ellos lo ignoran.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcxci{No es propio comparar al que puede ver [la verdad] con quien no puede verla, ni comparar al creyente que obra rectamente con el perverso [que obra el mal]. ¡Qué poco reflexionan!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcxcii{La hora [del Juicio] llegará, no hay duda sobre ello, aunque la mayoría de los seres humanos no crean.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcxciii{Su Señor dice: ``Invóquenme, que responderé [sus súplicas]". Pero quienes por soberbia se nieguen a adorarme, ingresarán al Infierno humillados.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcxciv{Dios es Quien creó la noche para que descansen en ella, y el día luminoso para que puedan ver [y procurar el sustento]. Dios es el poseedor del favor inmenso que concede a los seres humanos, pero la mayoría no Le agradece.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcxcv{Aquel [que los agracia] es Dios, su Señor, el Creador de todas las cosas, no hay nada ni nadie con derecho a ser adorado salvo Él, ¿cómo es que rehúsan [adorarlo a Él y adoran falsas divinidades]?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcxcvi{Así también fueron apartados [del camino recto] quienes rechazaron los signos de Dios.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcxcvii{Dios es Quien hizo de la Tierra un lugar habitable y del cielo un techo, los dotó de una bella figura y los sustenta con cosas beneficiosas. Él es Dios, su Señor. Bendito sea Dios, Señor del Universo.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcxcviii{Él es el Viviente, no hay nada ni nadie con derecho a ser adorado salvo Él; invóquenlo solamente a Él. Alabado sea Dios, Señor del universo.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcxcix{Diles [¡oh, Mujámmad!]: ``Me ha sido prohibido adorar a aquellos [ídolos] que invocan en lugar de Dios, me han llegado milagros evidentes de mi Señor y se me ordenó someterme al Señor del universo.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcc{Él es Quien los creó del polvo, y después de un óvulo fecundado que se transforma en un embrión, luego los hace surgir [al mundo] como niños para que alcancen la madurez, y luego los hace llegar a ancianos, aunque algunos fallecen antes, y así se cumple el plazo de vida que se les había prefijado para que reflexionen.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcci{Él es Quien da la vida y da la muerte, y cuando decreta algo dice: ``¡Sé!", y es.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmccii{¿Acaso no observaste [¡oh, Mujámmad!] a quienes discuten los milagros de Dios, cómo se desvían?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcciii{Quienes desmienten el Libro [revelado] y lo que envié junto a Mis Mensajeros ya sabrán [el castigo que les aguarda],\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcciv{cuando se les coloquen argollas en sus cuellos y sean arriados con cadenas\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmccv{al agua hirviendo, y luego ardan en el fuego.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmccvi{Se les dirá entonces: ``¿Dónde están aquellos [ídolos] que idolatraban junto\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmccvii{a Dios?" Responderán: ``Se desvanecieron. [Reconocemos que] no invocábamos en realidad a nada [que nos pueda beneficiar hoy]". Así es como Dios deja que se desvíen los que se niegan a creer.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmccviii{[Los ángeles dirán:] ``Este [castigo que reciben] es porque ustedes se regocijaban sin razón en la Tierra [siguiendo creencias falsas], y porque eran insolentes.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmccix{Ingresen [al castigo] por las puertas del Infierno, donde permanecerán por toda la eternidad". ¡Qué pésima será la morada de los soberbios!\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmccx{Sé paciente y perseverante [¡oh, Mujámmad!], pues la promesa de Dios es verdadera. Sea que te muestre algo de lo que tengo preparado o que te haga morir [antes de que sean castigados], ante Mí comparecerán.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmccxi{Envié otros Mensajeros antes de ti, de algunos de ellos te he relatado su historia, y de otros no te relaté su historia. Todo Mensajero que se presentó con algún milagro fue con la anuencia de Dios. Pero cuando llegue el designio de Dios, estarán perdidos los que atribuían falsedades [a Dios].\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmccxii{Dios es Quien creó para ustedes los rebaños, para que usaran como montura a algunos y de otros comieran.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmccxiii{Obtienen de ellos otros beneficios, y pueden satisfacer mediante ellos sus necesidades [de viajar a zonas lejanas]. Sobre ellos [en los viajes terrestres] y en los barcos se transportan.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmccxiv{Dios les muestra Sus milagros [que prueban Su unicidad]. ¿Cuál de los milagros de Dios negarán?\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmccxv{¿Acaso no viajan por el mundo y observan cuál fue el final de sus antecesores? Eran más numerosos que ellos, más poderosos, y dejaron más vestigios en la Tierra. Pero de nada les valió lo que poseían.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmccxvi{Cuando se les presentaron sus Mensajeros con los milagros, se mostraron soberbios y orgullosos de [las creencias] que habían heredado [y no les creyeron]; entonces les fue enviado un castigo por haberse burlado.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmccxvii{Pero al ver Mi castigo, dijeron: ``Creemos solo en Dios, y renegamos de lo que adorábamos junto a Él".\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmccxviii{Pero de nada les sirvió creer cuando vieron Mi castigo. Así es el designio de Dios, que alcanzó a quienes los precedieron. Los que se negaron a creer habrán perdido toda posibilidad [de salvación].\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmccxix{\basmalahes Ha’. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmccxx{Esta es una revelación descendida por el Compasivo, el Misericordioso,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmccxxi{un Libro en que los signos son explicados detalladamente. Expresado en idioma árabe para gente que comprende.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmccxxii{Albricia, pero también advierte. La mayoría le da la espalda y no quieren oír.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmccxxiii{Dicen: ``Nuestros corazones son insensibles a lo que nos invitas, nuestros oídos son sordos, y entre tú y nosotros hay un velo. Haz lo que quieras, que nosotros haremos lo que queramos".\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmccxxiv{Diles [¡oh, Mujámmad!]: ``Soy un hombre igual que ustedes, pero me fue revelado que su divinidad es una sola. Sigan el camino recto que Él ha establecido y pidan Su perdón". ¡Ay de los idólatras,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmccxxv{los que no pagan el zakat ni creen en la otra vida!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmccxxvi{Los que crean y obren rectamente recibirán una recompensa ininterrumpida.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmccxxvii{Diles: ``¿Cómo es que no creen en Quien creó la Tierra en dos días e inventan ídolos a los que adoran como si tuvieran poderes igual que Él? Él es el Señor del universo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmccxxviii{Dispuso sobre la Tierra montañas firmes, la bendijo y determinó el sustento en cuatro eras completas, para los que preguntan.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmccxxix{Luego se dirigió al cielo, el cual era nebuloso, y le dijo al cielo y a la Tierra: ‘¿Vendrán a mí de buen grado o por la fuerza?’ Respondieron: ‘Iremos a Ti de buen grado’.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmccxxx{Creó siete cielos en dos días, y le inspiró a cada cielo su función. Embelleció el cielo de este mundo con estrellas luminosas, como protección. Éste es el decreto del Poderoso, el que todo lo sabe".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmccxxxi{Pero si se apartan, diles: ``Les advierto que podrían caer fulminados como ‘Ad y Zamud".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmccxxxii{Cuando se les presentaron los Mensajeros, uno después de otro [con el mismo argumento] diciéndoles: ``No adoren sino a Dios". Respondían: ``Si nuestro Señor hubiera querido nos habría enviado un ángel. No creemos en su Mensaje".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmccxxxiii{En cuanto a ‘Ad, actuaron con soberbia y cometieron injusticias en la tierra. Dijeron: ``¿Acaso existe alguien más poderoso que nosotros?" ¿Acaso no sabían que Dios es Quien los creó y que Él es más poderoso que ellos? Pero rechazaron Mis signos.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmccxxxiv{Les envié un fortísimo viento gélido en días terribles, para hacerles sufrir el castigo humillante en esta vida; pero el castigo de la otra vida será más humillante aún, y no tendrán quién los socorra.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmccxxxv{Y en cuanto a Zamud, les aclaré cuál era la verdadera senda, pero prefirieron la ceguera a la guía. Entonces los azotó un castigo fulminante por lo que habían cometido.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmccxxxvi{Pero salvé a quienes habían creído y tenían temor de Dios.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmccxxxvii{El día que sean congregados los enemigos de Dios y conducidos al Infierno,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmccxxxviii{y estén a punto de ser arrojados en él, entonces atestiguarán contra ellos sus propios oídos, ojos y pieles todo lo que cometieron.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmccxxxix{Dirán a sus pieles: ``¿Por qué atestiguan contra nosotros?" Les responderán: ``Nos hizo hablar Dios, Quien hace hablar a todas las cosas". Sepan que Él los creó la primera vez, y que ante Él volverán.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmccxl{No pudieron esconderse de los oídos, los ojos y la piel que atestiguarán en su contra. Pensaban que Dios ignoraba gran parte de lo que hacían.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmccxli{Eso que pensaban de su Señor es lo que los ha llevado a la ruina, y ahora son de los perdedores.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmccxlii{Y aunque tengan paciencia, el Infierno será su morada; y aunque supliquen ser excusados, no serán excusados.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmccxliii{Y les asigné compañeros, que les embellecieron lo que habían cometido y lo que iban a cometer. Entonces merecieron el castigo al igual que otras naciones anteriores de seres humanos y de yinnes que fueron destruidas. Ellos fueron los verdaderos perdedores.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmccxliv{Dicen los que se negaron a creer: ``No presten atención al Corán cuando es recitado, y eleven la voz parloteando, así se saldrán con la suya".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccxlv{Les haremos sufrir un castigo severo a los que se negaron a creer, retribuyéndolos por todo el mal que hicieron.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmccxlvi{Este es el tormento que merecen los enemigos de Dios: el Infierno, donde morarán por toda la eternidad como castigo por haber negado Mis signos.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmccxlvii{Dirán los que se negaron a creer: ``¡Oh, Señor nuestro! Déjanos ver a los yinnes y a los seres humanos que nos extraviaron para que los pongamos bajo nuestros pies, y así sean ellos de los que estén más abajo".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmccxlviii{Quienes digan: ``Nuestro Señor es Dios" y obren correctamente, los ángeles descenderán sobre ellos [y les dirán:] ``No teman ni estén tristes. Bienaventurados sean porque tendrán el Paraíso que les fue prometido.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccxlix{Nosotros somos sus protectores en la vida mundanal y en la otra, tendrán allí todo cuanto deseen y se les concederá todo lo que pidan\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccl{como reconocimiento del Absolvedor, Misericordioso".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmccli{Quién puede expresar mejores palabras que aquel que invita a la gente a creer en Dios, obra rectamente y dice: ``¡Yo soy de los musulmanes!"\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcclii{No es lo mismo obrar el bien que obrar el mal. Responde con una buena actitud, y verás que aquel con quien tenías enemistad se convierte en un amigo ferviente.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmccliii{Esto no lo logran sino los que tienen paciencia; no lo logran sino los que son muy afortunados.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmccliv{Si el demonio te susurra para hacer el mal, busca refugio en Dios, porque Él todo lo oye, todo lo sabe.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcclv{Entre Sus signos están la noche y el día, el Sol y la Luna. Si realmente es a Él a Quien adoran, entonces no se prosternen ante el Sol ni ante la Luna, sino que prostérnense ante Dios, ya que Él es Quien los ha creado.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcclvi{Pero si se muestran soberbios, sepan que los que están próximos a su Señor Lo glorifican durante la noche y durante el día, y no se cansan de hacerlo.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcclvii{Entre Sus signos está que puedes ver la tierra sin vegetación, pero cuando hace descender el agua sobre ella, vibra y reverdece. Aquel que le da vida es Quien resucitará a los muertos. Él es sobre toda cosa Poderoso.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcclviii{Quienes niegan Mis signos no pueden ocultarse de Mí. ¿Acaso quienes sean arrojados al Infierno serán mejores el Día de la Resurrección que quienes sean salvos? Hagan lo que quieran, pero sepan que Él ve todo lo que hacen.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcclix{Quienes se negaron a creer en el Mensaje cuando les llegó, sepan que este es un Libro sublime.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcclx{No pueden introducírsele mentiras ni puede ser adulterado, porque es una revelación proveniente de un Sabio, Loable.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcclxi{No dicen de ti [¡oh, Mujámmad!] sino lo que ya había sido dicho sobre los Mensajeros que te precedieron. Tu Señor es el poseedor del perdón y el poseedor de un castigo doloroso.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcclxii{Si hubiera revelado el Corán en otro idioma habrían dicho [los incrédulos de entre tu pueblo]: ``¿Por qué no fue explicado detalladamente en forma clara?" ¡Qué! ¿Una revelación no árabe para un Profeta árabe? Diles: ``Este Libro es guía y salud para los creyentes; pero de los que se niegan a creer sus oídos son sordos y no comprenden. [Se comportan] como si se los llamara de un lugar muy lejano.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcclxiii{Le revelé el Libro a Moisés, pero discreparon sobre él. Si no hubiera sido porque tu Señor lo había decretado, se les habría adelantado el castigo. Ellos tienen sobre el Corán una seria duda.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcclxiv{Quien obre rectamente lo hará en beneficio propio, y quien obre el mal se perjudicará a sí mismo. Tu Señor no es injusto con Sus siervos.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcclxv{Solo Él sabe cuándo llegará la Hora. No surge ningún fruto de su cáliz, ni concibe ninguna mujer o da a luz sin que Él tenga total conocimiento de ello. El día que los llame [y pregunte a los idólatras]: ``¿Dónde están los socios [en la divinidad] que Me atribuían?" Responderán: ``Anunciamos que ninguno de nosotros sigue atestiguando eso".\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcclxvi{Los abandonará aquello que solían invocar, y sabrán que no tienen escapatoria.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcclxvii{El hombre no se cansa de pedir más y más bienestar, pero si le sucede alguna desgracia se desanima y se desespera.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcclxviii{Si lo agracio con Mi misericordia después de que sufriera una desgracia, dice: ``Esto es lo que me merecía, y no creo que la Hora del Juicio llegue jamás; pero si compareciera ante mi Señor, seguro que Él me concedería lo más bello que existe". Pero ya les informaré a los que se negaron a creer todo lo que hicieron, y los haré sufrir un castigo terrible.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcclxix{Cuando agracio a la persona se aparta y se vuelve soberbio. Pero si lo azota un mal, entonces no deja de suplicar.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcclxx{Diles: ``¿Acaso han considerado qué les pasaría si este es un Libro que proviene de Dios y ustedes se niegan a creer en él?". No existe nadie más desviado que quien persiste obstinado en el error.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcclxxi{Los haré ver Mis signos en los horizontes y en ellos mismos, hasta que se les haga evidente la Verdad. ¿Acaso no es suficiente tu Señor como Testigo de todo?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcclxxii{¿Aún siguen dudando de la comparecencia ante su Señor? ¿No abarca Él todas las cosas?\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcclxxiii{\basmalahes Ha’. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcclxxiv{‘Ain. Sin. Qaf.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcclxxv{[¡Oh, Mujámmad!] Dios te ha descendido la revelación, así como también a los [Mensajeros] que te precedieron. Dios es el Poderoso, el Sabio.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcclxxvi{A Él pertenece cuanto hay en los cielos y en la Tierra. Él es el Sublime, el Grandioso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcclxxvii{Los cielos están casi por hendirse desde arriba [por la grandiosidad de Dios] y los ángeles glorifican con alabanzas a su Señor y piden perdón por quienes están en la Tierra. ¿Acaso no es Dios el Absolvedor, el Misericordioso?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcclxxviii{Quienes tomaron a otros [como divinidades y objeto de adoración] en lugar de Dios, deben saber que Dios tiene registradas todas sus obras; pero tú [¡oh, Mujámmad!] no eres responsable de lo que ellos hagan.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcclxxix{Te he revelado el Corán en idioma árabe para que amonestes a la madre de las ciudades y a todos los que habitan en sus alrededores. Para que adviertas acerca del día de la reunión [para el Juicio Final], sobre el cual no existe duda alguna. [Luego del Juicio,] un grupo irá al Paraíso y otro al Infierno.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcclxxx{Si Dios quisiera habría decretado que todos formaran una sola nación [con un credo único], pero agracia a quien quiere con Su misericordia, mientras que los opresores no tendrán protector alguno ni socorredor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcclxxxi{¿Acaso toman a los ídolos como protectores en lugar de Dios? Dios es el Protector, Él resucitará a los muertos, porque tiene poder sobre todas las cosas [y por eso es que solo Él es Quien merece ser adorado].\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcclxxxii{En aquello en que disputen, su juicio debe remitirse a Dios. Dios es mi Señor, a Él me encomiendo y a Él me vuelvo arrepentido.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcclxxxiii{Es el Originador de los cielos y de la Tierra. Creó cónyuges de entre ustedes mismos [para que encuentren sosiego], y a los rebaños también los creó en parejas, y así es como se multiplican. No hay nada ni nadie semejante a Dios, y Él todo lo oye, todo lo ve.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcclxxxiv{Suyas son las llaves de los cielos y de la Tierra, concede Su sustento a quien Él quiere con abundancia o se lo restringe a quien quiere. Él lo sabe todo.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcclxxxv{Les he legislado la misma religión [monoteísta] que le había encomendado a Noé, y que te he revelado a ti [en el Corán] y que le encomendé a Abraham, a Moisés y a Jesús, para que sean firmes en la práctica de la religión, y no creen divisiones. Pero a los idólatras les parece difícil aquello a lo que tú los invitas. Dios elige [para que acepte la fe] a quien quiere, y guía hacia Él a quien se arrepiente.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcclxxxvi{No se dividieron sino después de haberles llegado el conocimiento, por codicia entre ellos [acerca del liderazgo]. Si no fuese por una palabra previa de tu Señor que decidió un plazo prefijado [para el fin del mundo], todo habría sido decidido entre ellos. Quienes heredaron el Libro tienen dudas.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcclxxxvii{Por esto [¡oh, Mujámmad!], invita [a aceptar el Islam] y obra rectamente como te fue ordenado, no sigas sus deseos y diles: ``Creo en los Libros que Dios reveló [en su forma original], y me fue ordenado establecer justicia entre ustedes. Dios es nuestro Señor y también el suyo, nosotros seremos juzgados por nuestras obras y ustedes por las suyas. No hay necesidad de disputas entre nosotros y ustedes. Dios nos reunirá a todos cuando regresemos a Él para ser juzgados".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcclxxxviii{Aquellos que argumentan sobre Dios, luego de que la gente creyó [en el Islam], sepan que sus argumentos carecen de validez ante su Señor. Sobre ellos recaerá la ira [de Dios] y recibirán un castigo severo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcclxxxix{Dios es Quien reveló el Libro con la verdad y la justicia. ¿Y quién sabe? Quizá la Hora esté cercana.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmccxc{Quienes no creen en ella exigen que se adelante. Pero, en cambio, los creyentes sienten temor de ella y saben que es una verdad. ¿No es evidente que quienes discuten sobre cuándo será la Hora [del Juicio] están en un error profundo?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmccxci{Dios es Bondadoso con Sus siervos, sustenta a quien quiere. Él es el Fuerte, el Poderoso.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmccxcii{A aquel que busque obtener la recompensa de la otra vida [a través de obras buenas], se la multiplicaré. Pero a quien solo pretenda obtener bienes materiales en este mundo, se los concederé, pero no obtendrá recompensa alguna en la otra vida.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmccxciii{¿Acaso [los idólatras] tienen divinidades que les han establecido preceptos religiosos que Dios no ha prescrito? Si no fuese porque Dios ha decretado cuándo será el Día del Juicio, ya se los habría juzgado. Los injustos opresores sufrirán un castigo doloroso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmccxciv{Verás [el Día del Juicio a los opresores] aterrorizados [de ser juzgados] por lo que cometieron, pero no podrán evitarlo. En cambio, quienes creyeron y obraron rectamente estarán en jardines del Paraíso junto a su Señor, donde se les concederá lo que deseen; este es el favor inmenso.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmccxcv{Esta [es la recompensa] con la que Dios albricia a Sus siervos que creen y obran rectamente. Diles [¡oh, Mujámmad!]: ``No les pido ninguna remuneración, solo que amen al prójimo". A quien realice una buena obra le aumentaré con un bien mayor. Dios es Absolvedor, Agradecido.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmccxcvi{Algunos dicen: ``[Mujámmad] ha inventado mentiras acerca de Dios", pero si fuera así Dios habría sellado su corazón. Dios hace que se desvanezca lo falso y que prevalezca la Verdad por Su palabra. Él conoce cuanto encierran los pechos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmccxcvii{Él es Quien acepta el arrepentimiento de Sus siervos, perdona sus pecados y está bien enterado de cuanto hacen.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmccxcviii{Él responde [las súplicas] a quienes creen y obran rectamente, y les aumenta su favor. En cambio, los que se niegan a creer tendrán un castigo severo.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccxcix{Si Dios les hubiera dado a Sus siervos un sustento sin límites, se habrían extralimitado en la Tierra; pero les concede [el sustento] en la justa medida [para cada uno]. Él lo sabe todo y lo ve todo.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmccc{Él es Quien hizo descender la lluvia beneficiosa cuando habían caído en la desesperación, esparciendo Su misericordia. Él es el Protector, el Digno de alabanza.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmccci{Entre Sus signos está la creación de los cielos, de la Tierra y de todas las criaturas que diseminó en ella. Él tiene poder para congregarlos a todos cuando quiera.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcccii{Si los aflige una desgracia, es consecuencia de [los pecados] que sus propias manos han cometido, a pesar de que Dios les perdona muchas faltas [por Su gracia].\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccciii{No hay lugar en la Tierra al que puedan escapar de Dios. No tienen protector ni socorredor fuera de Dios.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccciv{Entre los signos [de Su misericordia] están los barcos que navegan en el mar, grandes como montañas.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcccv{Pero cuando quiere, calma el viento y permanecen inmóviles en la superficie. En esto hay signos para todo perseverante, agradecido [con Dios].\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcccvi{O podría hacerlos naufragar a causa de sus pecados, pero Dios perdona muchas de las faltas.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcccvii{Ya sabrán quienes disputan sobre Mis signos que no tendrán escapatoria.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcccviii{Lo que se les ha concedido [de bienes materiales] es parte de los placeres transitorios de esta vida mundanal. Pero la recompensa que Dios tiene reservada [en el Paraíso] será mejor y más duradera, para quienes crean y se encomienden a su Señor,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcccix{para quienes evitan los pecados graves y las obscenidades, y cuando se enojan saben perdonar;\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcccx{para quienes responden a su Señor, cumplen con la oración prescrita, se consultan para resolver sus asuntos y con lo que les he concedido hacen caridades,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcccxi{y cuando son víctimas de una injusticia son solidarios unos con otros [para restablecer la justicia].\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcccxii{La ofensa debe ser retribuida por una pena equivalente, pero quienes sepan perdonar serán recompensados por Dios. Él no ama a los injustos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcccxiii{Quien se defiende cuando es oprimido, no debe ser reprochado.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcccxiv{Los que deben ser reprochados son quienes oprimen a la gente y se comportan con soberbia en la Tierra sin derecho alguno. Esos sufrirán un castigo doloroso.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcccxv{Pero tener paciencia [ante las injusticias] y perdonar, es algo que requiere de gran determinación.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcccxvi{Para quien Dios haya decretado el desvío, no tendrá protector alguno fuera de Él. Cuando los opresores contemplen el castigo los verás decir: ``¿Hay alguna forma de volver [a la vida mundanal y corregir nuestras elecciones]?"\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcccxvii{Podrás verlos expuestos al castigo, sumisos y humillados, mirando con temor [al Infierno]; entonces dirán los creyentes: ``Los perdedores serán quienes se malogren a sí mismos y a sus familias el Día de la Resurrección". ¿Acaso los opresores no recibirán un castigo eterno?\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcccxviii{Tampoco tendrán protectores fuera de Dios que los defiendan. Para quien Dios haya decretado el extravío, no podrá encaminarse jamás.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcccxix{Obedezcan a su Señor antes de que llegue el día en que no puedan evitar [recibir el castigo] de Dios, porque ese día no tendrán refugio alguno ni podrán negar lo que hicieron.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcccxx{Si se niegan a obedecer, sabe [¡oh, Mujámmad!] que no te envié para hacerte responsable de sus obras. Tú solo debes divulgar [el Mensaje]. Cuando agracio a una persona con Mi misericordia, esta se alegra, pero si le alcanza una desgracia como consecuencia de lo que hizo con sus propias manos, entonces la persona se muestra desagradecida.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcccxxi{A Dios pertenece el reino de los cielos y de la Tierra, Él crea lo que quiere, agracia a quien quiere con hijas mujeres y a quien quiere con hijos varones,\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcccxxii{o les concede hijos varones y mujeres, o los hace estériles. Él lo sabe todo, es sobre toda cosa Poderoso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcccxxiii{Dios no habla a las personas excepto por inspiración o tras un velo o enviando un Mensajero [el ángel Gabriel] para transmitirle por Su voluntad lo que Él quiera de la revelación. Él es Sublime, Sabio.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcccxxiv{Te he revelado [oh, Mujámmad] una inspiración Mía [el Corán]. Tú no conocías el Libro [revelado anteriormente] ni la fe [en sus detalles]. Entonces hice que fuera una luz con la que guío a quienes quiero, y tú [¡oh, Mujámmad!] guías al sendero recto,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcccxxv{el sendero de Dios, a Quien pertenece cuanto hay en los cielos y en la Tierra. ¿Acaso no retornan a Dios todos los asuntos?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcccxxvi{\basmalahes Ha’. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcccxxvii{[Juro] por el Libro que clarifica,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcccxxviii{que he revelado el Corán en idioma árabe para que lo puedan comprender,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcccxxix{el cual está registrado en la Escritura Matriz junto a Mí, y es [el Corán un Libro] sublime y sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcccxxx{¿Acaso [creen que] los iba a privar del Mensaje porque son un pueblo de transgresores?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcccxxxi{¿Cuántos Profetas he enviado a los pueblos de la antigüedad?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcccxxxii{Pero siempre que se les presentaba un Profeta se burlaban de él.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcccxxxiii{Destruí pueblos más fuertes que ellos. El ejemplo de lo que sucedió a otros pueblos en la antigüedad es parte del pasado [y aún pueden encontrarse sus vestigios].\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcccxxxiv{Si les preguntas [a los que se niegan a creer y adoran ídolos] quién creó los cielos y la Tierra, te responderán sin duda: ``Los creó el Poderoso, el Sabio".\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcccxxxv{Él ha hecho de la Tierra una cuna, y puso en ella caminos para que pudieran encontrar la guía.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcccxxxvi{Él hace descender agua del cielo en la medida justa, y así vuelve a dar vida a un territorio árido; de la misma manera serán resucitados.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcccxxxvii{Él creó las especies [en parejas], a todas, y puso a su servicio los barcos y los animales que montan,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcccxxxviii{para que se transporten en ellos y agradezcan las mercedes de su Señor. Pero una vez sentados digan: ``Glorificado sea Quien nos lo ha facilitado, ya que nosotros no habríamos sido capaces [por nuestro mero esfuerzo],\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcccxxxix{y ante nuestro Señor hemos de regresar".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcccxl{Pero [los idólatras] atribuyen una parte [de la divinidad] a algunos de Sus siervos. El ser humano es claramente un ingrato.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcccxli{¿Acaso Dios tomaría para Sí hijas de entre Sus criaturas, y a ustedes les dejaría los hijos varones?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcccxlii{[A los que niegan el Mensaje,] cuando se le anuncia a alguno de ellos que ha tenido lo que él atribuye al Misericordioso [una hija mujer], su semblante se ensombrece y mastica su ira.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcccxliii{¿Acaso una niña pequeña criada entre adornos e incapaz de argumentar con coherencia [podría ser parte de la divinidad]?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcccxliv{Y dicen que los ángeles, que están junto al Misericordioso, son hembras. ¿Acaso fueron testigos de su creación? Registraré lo que dicen, y serán interrogados [por ello el Día del Juicio].\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcccxlv{Dicen: ``Si el Misericordioso no hubiera querido, no los adoraríamos [a los ángeles y los ídolos]". Ellos carecen de conocimiento [sobre la voluntad divina], y no hacen sino conjeturar.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcccxlvi{¿Acaso les envié un libro [anterior al Corán] en el que se basan?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcccxlvii{[En realidad carecen de fundamento] y dicen: ``Nosotros vimos a nuestros padres practicar una religión [en la que adoraban a los ídolos], y seguimos sus pasos imitándolos".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcccxlviii{Cada vez que envié a un amonestador a un pueblo, los más ricos y poderosos decían: ``Nosotros vimos a nuestros padres que practicaban una religión [politeísta], y seguimos sus pasos imitándolos".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcccxlix{[Decían los Mensajeros]: ``¿Y si les propongo algo mejor que lo que practicaban sus padres?" Respondían: ``No creemos en tu Mensaje".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcccl{Los castigué [como merecían]. Reflexionen sobre cuál fue el final trágico de los que desmintieron [a los Profetas].\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcccli{[Recuerda, ¡oh, Mujámmad!,] cuando Abraham le dijo a su padre y a su pueblo: ``Yo soy inocente de lo que adoran.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccclii{Yo solo adoro a Quien me creó. Él me guiará".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcccliii{[Dios] hizo que esta [fe monoteísta] perdurara en su descendencia para que siempre pudiera retornar.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcccliv{[A quienes se desviaron] los dejé disfrutar transitoriamente, y también a sus padres, hasta que les llegó la Verdad transmitida por un Mensajero elocuente,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmccclv{Pero cuando se les presentó con la Verdad dijeron [los idólatras]: ``Esto es hechicería, nosotros no creemos en él".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccclvi{Y dijeron también [desdeñando al Profeta]: ``¿Por qué no le fue revelado este Corán [en lugar de a ti] a un hombre distinguido de alguna de las dos ciudades?"\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccclvii{¿Acaso son ellos los encargados de repartir la misericordia de su Señor? Soy Yo Quien concedo el sustento en la vida mundanal y elevo en grados a algunas personas sobre otras, para que así se sirvan y beneficien unos a otros. Sepan que la misericordia de su Señor es mejor que lo que pudieran acaparar [de bienes materiales en esta vida].\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmccclviii{Si no fuera porque los seres humanos terminarían siendo una sola nación [de descarriados materialistas], habría concedido a quienes no creen en el Misericordioso, residencias con techos de plata y escaleras por las que ascendiesen [a sus habitaciones].\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmccclix{Sus casas tendrían puertas y lechos [de plata] para recostarse.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmccclx{Todo estaría adornado con oro. Sin embargo [no lo hago porque] todo eso es solo parte de los placeres transitorios de la vida mundanal, mientras que la otra vida junto a tu Señor [es superior y] está reservada para los piadosos.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmccclxi{A quien deje de recordar al Misericordioso le asignaré un demonio que será su compañero inseparable.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmccclxii{Ellos [los demonios] apartan del camino, pero [los incrédulos] creen que están bien encaminados.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmccclxiii{Y cuando comparezcan ante Mí, dirán [a sus demonios]: ``Ojalá entre nosotros hubiese una distancia como entre el oriente y el occidente. ¡Qué pésimo compañero [fuiste]!"\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmccclxiv{[Se les dirá:] ``De nada les servirá hoy [lamentarse] porque fueron injustos; ahora compartirán el castigo".\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmccclxv{¿Acaso puedes hacer tú [¡oh, Mujámmad!] oír a [quienes se comportan como] los sordos, o guiar a los ciegos [de corazón] y a aquel que está en un claro extravío?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmccclxvi{Aun cuando te haga morir [y no veas el tormento que les tengo reservado], debes saber que los castigaré como se merecen.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmccclxvii{Y también, si te muestro [el castigo] que les he prometido, tengo el poder para hacer con ellos lo que quiera.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmccclxviii{Aférrate a lo que te fue revelado, tú estás en el sendero recto.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmccclxix{[El Corán] es un recuerdo para ti y para tu pueblo. Serán preguntados [si creyeron en él y lo pusieron en práctica o no].\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmccclxx{Y pregunta [a los pueblos que] les envié Mensajeros antes de ti: ``¿Acaso les autoricé que adorasen a otro fuera del Misericordioso?"\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmccclxxi{Envié a Moisés con Mis signos ante el Faraón y su nobleza, y les dijo: ``Soy un Mensajero del Señor del universo".\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmccclxxii{Cuando les presentó Mis signos [los negaron y] se burlaron de ellos.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmccclxxiii{Siempre que les mostraba un Signo, era mayor [y más evidente] que el anterior, [pero como siempre los desmentían] los azoté con el castigo [de las plagas] para que se arrepintieran.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmccclxxiv{Entonces le dijeron [a Moisés]: ``¡Hechicero! Invoca a tu Señor por lo que te ha prometido, [para que nos libere de este tormento y] así seguiremos la guía".\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmccclxxv{Pero cuando aparté de ellos el tormento, no cumplieron su promesa.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmccclxxvi{El Faraón convocó a su pueblo diciendo: ``¡Oh, pueblo mío! ¿Acaso no me pertenece el reino de Egipto, con estos ríos que corren bajo mi palacio? ¿Acaso no ven [mi poderío]?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmccclxxvii{Yo soy mejor que ese, que es una persona indigna y apenas puede expresarse.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmccclxxviii{¿Por qué [si es veraz como pretende] no le fueron concedidos brazaletes de oro, o se presentaron ángeles que lo acompañen [y confirmen sus palabras]?"\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmccclxxix{Así engañó a su pueblo, y lo siguieron porque eran un pueblo de perversos.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmccclxxx{Pero cuando finalmente [rebasaron todos los límites,] me hicieron enojar, y los castigué [como se merecían] ahogándolos a todos.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmccclxxxi{Hice de ellos un ejemplo para que reflexionen en la posteridad.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmccclxxxii{Cuando se mencionó el ejemplo del hijo de María [Jesús], tu pueblo clamó indignado.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmccclxxxiii{Dicen: ``¿Acaso él es mejor que nuestros ídolos?" Solo te hacen esa comparación para discutir, porque son un pueblo contencioso.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmccclxxxiv{Jesús es solo un siervo a quien agracié [con la profecía], y lo envié como ejemplo a los Hijos de Israel.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmccclxxxv{Si quisiera, hubiera puesto en lugar de ustedes a ángeles que se sucedieran unos a otros.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmccclxxxvi{[Diles, ¡oh, Mujámmad!:] ``[El descenso a la Tierra de] Jesús es una prueba de la [proximidad de la] Hora [del Fin del Mundo]. Así que no duden y síganme, que este es el sendero recto.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmccclxxxvii{Tengan cuidado de que no los desvíe el demonio, porque él es su enemigo declarado".\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmccclxxxviii{Cuando Jesús se presentó con las evidencias, dijo [a los Hijos de Israel]: ``He venido con la sabiduría para aclararles sobre lo que discrepaban. Tengan temor de Dios y obedézcanme.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmccclxxxix{Dios es mi Señor y el de ustedes, adórenlo, entonces. Éste es el sendero recto".\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcccxc{Pero los grupos discreparon entre ellos. ¡Ay de los injustos! Porque han de recibir, cierto Día, un castigo doloroso.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcccxci{¿Acaso esperan que la Hora [del Juicio] les llegue por sorpresa, sin que se den cuenta?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcccxcii{Ese día los amigos serán enemigos unos de otros, excepto los que hayan tenido temor de Dios.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcccxciii{[A ellos se les dirá el Día del Juicio:] ``¡Oh, siervos Míos! Hoy no habrán de sentir temor ni tristeza,\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcccxciv{pues creyeron en Mis signos y fueron musulmanes.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcccxcv{Entren al Paraíso, ustedes y sus cónyuges, donde disfrutarán de las delicias.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcccxcvi{Circularán entre ellos bandejas y copas de oro. Allí tendrán todo lo que deseen y deleite sus ojos. En él estarán por toda la eternidad.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcccxcvii{Ese es el Paraíso que han heredado en recompensa por las obras que solían hacer.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcccxcviii{Tendréis muchos frutos para comer.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcccxcix{Mientras que los transgresores estarán en el Infierno por toda la eternidad.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcd{No se les aliviará [el castigo] ni tendrán esperanza [de salir algún día].\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcdi{No seré injusto con ellos, sino que ellos fueron injustos consigo mismos.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmcdii{Y clamarán: ``¡Oh, Málik! Que tu Señor acabe con nosotros [y así dejemos de sufrir]". Pero él les responderá: ``Han de permanecer allí por toda la eternidad".\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmcdiii{[¡Oh, incrédulos!] Les presenté la Verdad [a través del Mensajero], pero la mayoría rechazaba la Verdad.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmcdiv{¿Acaso planeaban algo? Soy Yo Quien determina las cosas.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmcdv{¿Acaso piensan que no escucho sus secretos y murmuraciones? Claro que sí, y Mis [ángeles] enviados registraban sus acciones.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmcdvi{Diles [¡oh, Mujámmad!]: ``Si el Misericordioso tuviera un hijo, yo sería el primero en adorarlo.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmcdvii{¡Glorificado sea el Señor de los cielos y de la Tierra, Señor del Trono! Él está por encima de lo que Le atribuyen".\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmcdviii{Déjalos que hablen en vano y jueguen hasta que les llegue el día con que se los había advertido.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmcdix{Solo Él tiene derecho a ser adorado en el cielo y en la Tierra. Es el Sabio, el Conocedor.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmcdx{Bendito sea a Quien pertenece el reino de los cielos y de la Tierra y todo cuanto hay entre ambos. Él posee el conocimiento de la Hora [del Juicio], y ante Él regresarán.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmcdxi{Aquellos que son invocados en lugar de Dios no poseen la facultad de interceder por nadie. Solo pueden interceder quienes atestiguan la Verdad y tienen conocimiento.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmcdxii{Si les preguntas [a los que se niegan a creer] quién los ha creado, te responderán: ``¡Dios!" ¿Cómo entonces se descarrían?\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmcdxiii{[Dios sabe cuando Lo invocas] diciendo: ``¡Oh, Señor! Este es un pueblo que no cree".\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmcdxiv{Apártate de ellos y [no respondas a sus ofensas, sino que] di: ``¡Paz!", ya habrán de saber [cuál será su destino].\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmmcdxv{\basmalahes Ha’. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcdxvi{[Juro] por el Libro clarificador,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcdxvii{que he revelado en una noche bendita: ¡Les he advertido!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcdxviii{En ella se decreta sabiamente cada asunto.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcdxix{Todo sucede por Mi designio. He enviado [Profetas y libros sagrados]\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcdxx{como una misericordia de tu Señor. Él todo lo oye, todo lo sabe.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcdxxi{Señor de los cielos y de la Tierra, y de lo que existe entre ambos. ¿Acaso no tienen certeza de eso?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcdxxii{No hay nada ni nadie con derecho a ser adorado salvo Dios; Él da la vida y da la muerte. Él es su Señor y el de sus ancestros.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcdxxiii{Pero ellos juegan con las dudas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcdxxiv{Aguarda el día en que el cielo traiga un humo visible\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcdxxv{que cubrirá a la gente. Ese será un castigo doloroso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcdxxvi{[Dirán los que se negaron a creer:] ``¡Oh, Señor nuestro! Aparta de nosotros el castigo, somos creyentes".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcdxxvii{De qué les servirá recapacitar entonces, si cuando se les presentó un Mensajero con pruebas evidentes\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcdxxviii{lo rechazaron y dijeron: ``Fue aleccionado o es un loco".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcdxxix{Los libraré del castigo por un tiempo, pero reincidirán.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcdxxx{El día que acometa con el máximo rigor, les infligiré un castigo doloroso.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcdxxxi{Antes de ellos probé al pueblo del Faraón, cuando se les presentó un Mensajero noble,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcdxxxii{[que les dijo:] ``Dejen en libertad a los siervos de Dios para que puedan marcharse conmigo. Yo he sido enviado para ustedes como un Mensajero leal.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcdxxxiii{No sean soberbios con Dios. Les he presentado pruebas evidentes.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcdxxxiv{Me refugio en mi Señor y el suyo para que no me injurien.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcdxxxv{Si no creen en mí, déjenme en paz".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcdxxxvi{Pero invocó a su Señor diciendo: ``Éste es un pueblo de criminales".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcdxxxvii{[Entonces Dios le respondió:] ``Marcha con Mis siervos por la noche, pero sabe que ellos van a perseguirlos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcdxxxviii{Deja el mar [luego de que se haya abierto para ti] tal como está, que el ejército será ahogado.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcdxxxix{Cuántos huertos y manantiales abandonaron,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcdxl{cultivos y hermosas residencias,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmcdxli{y una comodidad de la que disfrutaban.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcdxlii{Así fue. Pero se lo di en herencia a otro pueblo.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcdxliii{No lloraron por ellos ni el cielo ni la Tierra. Tampoco fueron perdonados.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcdxliv{Salvé a los Hijos de Israel de un tormento humillante\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmcdxlv{que les infligía el Faraón. Él era soberbio y transgresor.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmcdxlvi{[Al pueblo de Israel,] basado en un conocimiento, lo elegí entre sus contemporáneos,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcdxlvii{y les concedí signos que representaban una prueba clara en su fe.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcdxlviii{Pero ellos dicen:\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcdxlix{``Solo moriremos una vez, y no seremos resucitados.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcdl{Resucita a nuestros padres, si es que eres veraz".\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcdli{¿Acaso ellos son mejores que los pueblos que he destruido, como el pueblo de Tubba’ y los que los precedieron? Todos ellos fueron criminales.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcdlii{No he creado a los cielos, la Tierra y todo lo que hay entre ellos como un simple juego.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcdliii{Los creé con un fin justo y verdadero, pero la mayoría de la gente lo ignora.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcdliv{El Día del Juicio es una cita establecida para todos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcdlv{Ese día no podrán los familiares ayudarse entre sí, nadie recibirá socorro,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcdlvi{excepto aquel de quien Dios tenga misericordia. Él es el Poderoso, el Misericordioso.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcdlvii{El árbol de Zaqqum\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcdlviii{será la comida del pecador.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcdlix{Similar al metal fundido, hierve en las entrañas,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcdlx{como si fuera agua hirviente.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcdlxi{[Se les dirá a los ángeles:] ``Tomen [a este transgresor] y arrójenlo al centro del Infierno.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcdlxii{Luego viertan sobre su cabeza el castigo hirviente".\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcdlxiii{¡Súfrelo! [Porque en la vida mundanal pensabas que] eras ``el poderoso" y ``el noble".\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcdlxiv{Esto es sobre lo que dudabas.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcdlxv{Pero los piadosos estarán en una situación segura,\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcdlxvi{en jardines y manantiales.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcdlxvii{Vestirán fina seda y brocado, y se sentarán unos frente a otros.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcdlxviii{Los desposaremos con huríes de grandes ojos.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcdlxix{Allí podrán pedir toda clase de frutas. Estarán en total seguridad.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcdlxx{No experimentarán otra vez la muerte, salvo la que ya conocieron. Él los preservará del castigo infernal.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcdlxxi{Ese es el favor de tu Señor. ¡Ese es el gran éxito!\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcdlxxii{Para facilitar su comprensión lo he revelado [al Corán] en tu lengua, para que reflexionen.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcdlxxiii{Así que espera pacientemente, de la misma manera que ellos están esperando.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcdlxxiv{\basmalahes Ha’. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcdlxxv{Este Libro es una revelación que proviene de Dios, el Poderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcdlxxvi{En los cielos y en la Tierra hay signos para los creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcdlxxvii{También en la creación de ustedes y en la diseminación de los animales [en la faz de la Tierra] hay signos para quienes tienen certeza.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcdlxxviii{En la sucesión de la noche y el día, en las lluvias que Dios envía del cielo como sustento, con las cuales revive la tierra árida, y en los cambios de los vientos hay, sin duda, signos para gente que reflexiona.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcdlxxix{Éstos son versículos de Dios que te recito con la Verdad. ¿En qué otro Mensaje creerán si no creen en Dios y en Sus signos?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcdlxxx{¡Ay de todo mentiroso, pecador!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxi{Que escucha los versículos de Dios cuando se le recitan, pero persiste en su soberbia como si no los hubiera oído. Anúnciales un castigo severo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxii{Cuando escuchan algunos de Mis versículos los toman a burla. Ellos tendrán un castigo humillante,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxiii{los estará aguardando el Infierno y de nada les servirán los bienes materiales que ganaron, ni tampoco los ídolos protectores que tomaron en lugar de Dios. Recibirán un castigo terrible.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxiv{Esta es la Guía, pero quienes se nieguen a creer en los versículos de su Señor tendrán un castigo doloroso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxv{Dios es Quien hizo que el mar estuviera a su servicio, para que los barcos navegaran sobre él por Su designio y así pudieran procurar el sustento. Sean agradecidos con Dios.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxvi{También puso a su servicio cuanto hay en los cielos y en la Tierra como una gracia proveniente de Él. En esto hay signos para gente que reflexiona.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxvii{Diles [¡oh, Mujámmad!] a los creyentes que [tengan paciencia ante las agresiones y] perdonen a quienes no creen en los días de Dios, en que la gente será juzgada acorde a lo que merece.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxviii{Quien obre el bien lo hará en beneficio propio, pero quien obre el mal lo hará en detrimento propio. Sepan que ante su Señor será el retorno.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxix{Le di a los Hijos de Israel el Libro, la sabiduría, la profecía y un sustento generoso, y los distinguí entre sus contemporáneos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcdxc{Les concedí pruebas claras, pero discreparon a pesar de haberles llegado la revelación, por simples envidias entre ellos. Tu Señor juzgará entre ellos el Día de la Resurrección sobre lo que discrepaban.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcdxci{A ti [¡oh, Mujámmad!] te he revelado una legislación para que la apliques y no sigas las pasiones de quienes no saben,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcdxcii{porque ellos no te beneficiarán en nada ante Dios. Los opresores se alían unos con otros, pero Dios es el Protector de los piadosos.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcdxciii{Ésta revelación es luz para la gente. Una guía y una misericordia para quienes tienen certeza.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcdxciv{¿Acaso quienes obran mal piensan que los igualaré, tanto en esta vida como en la otra, con quienes creen y obran rectamente? ¡Qué mal juzgan!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcdxcv{Dios creó los cielos y la Tierra con un fin justo y verdadero. Toda alma será juzgada acorde a sus obras, y nadie será oprimido.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcdxcvi{¿Acaso no reparas en aquel que sigue sus pasiones como si estas fueran una divinidad? Dios decretó por Su conocimiento divino que se extraviaría, y por ello selló sus oídos y su corazón, y puso un velo sobre sus ojos. ¿Quién lo puede guiar fuera de Dios? ¿Acaso no recapacitan?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcdxcvii{Dicen: ``Solo existe esta vida. Viviremos y moriremos una sola vez. El tiempo es quien acaba con nosotros". Pero no poseen un conocimiento certero sobre lo que dicen y no hacen más que conjeturar.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcdxcviii{Cuando se les recitan Mis claros versículos, su único argumento es: ``Resuciten a nuestros ancestros, si son veraces".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcdxcix{Diles: ``Dios es Quien les da la vida y les da la muerte, y luego los resucitará para un día del que no hay dudas". Pero la mayoría de la gente lo ignora.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmd{A Dios pertenece la soberanía de los cielos y de la Tierra. El día que llegue la Hora, ese día perderán los seguidores de la falsedad.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdi{Y verás ese día a todas las naciones arrodilladas. Cada una de ellas será convocada para rendir cuentas según su libro. [Se les dirá:] ``Hoy serán juzgados de acuerdo a sus obras".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdii{He aquí Mi Libro, que habla sobre ustedes con la verdad. Yo había ordenado registrar todo lo que hacían.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdiii{A quienes creyeron y obraron rectamente, su Señor los introducirá en Su misericordia. Ese es el éxito verdadero.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdiv{En cambio, a los que se negaron a creer [se les dirá:] ``¿Acaso no se les recitaron Mis versículos?" Pero respondieron con soberbia y fueron gente criminal.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdv{Cuando se les dijo: ``La promesa de Dios es verdadera y no hay duda sobre la Hora". Respondieron [irónicamente]: ``No comprendemos qué es la Hora, nos parece una mera fantasía y no nos convence".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdvi{Pero se verá el resultado de sus malas obras, y merecerán el castigo del que se burlaban.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdvii{Se dirá: ``Hoy los desconoceré tal como ustedes se desentendieron de la comparecencia de este día. Su morada será el Infierno y no habrá quién los socorra.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdviii{Este es el resultado de haber ridiculizado los versículos de Dios y haberse dejado seducir por los placeres [prohibidos] de la vida mundanal. Hoy no serán sacados del tormento, y no se les tendrá consideración".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdix{Solo Dios merece ser alabado. Es el Señor de los cielos, el Señor de la Tierra y el Señor de los universos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdx{Suya es la majestuosidad en los cielos y en la Tierra, y Él es el Poderoso, el Sabio.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdxi{\basmalahes Ha’. Mim.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdxii{Este Libro es una revelación que proviene de Dios, el Poderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdxiii{No creé los cielos y la Tierra y lo que hay entre ambos sino con la verdad y por un plazo determinado. Pero los que se niegan a creer rechazan las advertencias.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdxiv{Diles [¡oh, Mujámmad!]: ``Aquellos [dioses y divinidades] que ustedes invocan en lugar de Dios, ¿acaso crearon algo en la Tierra o fueron partícipes [en la creación] de los cielos? Presenten ante Mí algún Libro revelado antes de este o algún vestigio de un [antiguo] conocimiento [que avale la idolatría] si es que dicen la verdad.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdxv{¿Existe alguien más extraviado que aquellos que invocan en lugar de Dios a quienes jamás les responderán sus súplicas porque no son conscientes de ellas?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdxvi{Cuando la gente sea congregada [el Día del Juicio, los ídolos] serán sus enemigos y rechazarán la adoración de la que fueron objeto.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdxvii{Cuando se les recitan Mis versículos esclarecedores de la verdad, los que se niegan a creer dicen acerca de la Verdad que les ha llegado: ``Esto es hechicería".\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdxviii{O dicen: ``Él [Mujámmad] lo inventó". Diles [¡oh, Mujámmad!]: ``Si lo hubiese inventado, ustedes no podrían defenderme del castigo de Dios. Él bien sabe lo que dicen [sobre el Corán]. Dios basta como testigo entre nosotros. Él es el Absolvedor, el Misericordioso".\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdxix{Diles: ``Yo no soy el primero de los Mensajeros [de Dios], y tampoco sé qué será de mí o de ustedes. Yo solo sigo lo que me es revelado, y no soy sino un amonestador que habla claro".\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdxx{Diles: ``¿Por qué no creen [en el Corán] que Dios reveló, siendo que un sabio de los Hijos de Israel atestiguó su veracidad y creyó en él? Pero ustedes actuaron con soberbia. Sepan que Dios no guía a un pueblo de injustos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdxxi{Dicen los que se niegan a creer acerca de los creyentes: ``Si [el Mensaje] fuera un bien, no se nos habrían anticipado [en seguirlo]". Y como no siguen la guía [del Corán] exclaman: ``Esto es una mentira muy antigua".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdxxii{Antes [del Corán] fue revelado el Libro de Moisés como guía y misericordia. Este es un Libro revelado en lengua árabe que corrobora [las revelaciones anteriores], y en él se advierte a los injustos y se albricia a los que hacen el bien.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdxxiii{Quienes digan: ``¡Nuestro Señor es Dios!, y luego obren correctamente, no tienen de qué sentir temor ni estar tristes [en el Día del Juicio Final]\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdxxiv{porque serán los compañeros del Paraíso, en el que vivirán por toda la eternidad como recompensa por sus obras.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdxxv{Le he ordenado al ser humano hacer el bien a sus padres. Su madre lo ha llevado [en el vientre] con esfuerzo, y con dolor lo dio a luz. El período del embarazo y la lactancia dura treinta meses. Cuando alcance la madurez, al llegar a los cuarenta años, debe decir [en súplica]: ``¡Oh, Señor mío! Haz que sepa agradecerte los favores que nos has concedido, tanto a mí como a mis padres, y que pueda realizar obras buenas que Te complazcan. Concédeme una descendencia piadosa. Me arrepiento a Ti [de mis pecados] y soy de los musulmanes".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdxxvi{A ellos les aceptaré las mejores obras que hayan realizado, y les perdonaré sus faltas. Ellos serán la gente del Paraíso, [en cumplimiento a] una promesa verdadera que se les había hecho.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdxxvii{Diferente es la situación de aquel que dice a sus padres [creyentes]: ``¡Ufa, déjenme en paz! Me dicen que seré resucitado, cuando ya han pasado muchas generaciones [y ninguna ha sido resucitada]". Y mientras estos, implorando a Dios [que lo guíe], dicen: ``¡Ay de ti! Ten fe, pues la promesa de Dios es verdadera"; él les responde: ``Estas no son más que fábulas de nuestros ancestros".\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdxxviii{Esos merecerán [el castigo de Dios], al igual que las naciones [que no creyeron] de yinnes y de seres humanos en la antigüedad. Ellos serán los perdedores.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdxxix{Cada uno tendrá un grado diferente acorde a sus obras, y se lo retribuirá acorde a ellas. Pero nadie será oprimido.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdxxx{El día que los que se negaron a creer sean expuestos al Infierno se les dirá: ``Consumieron las gracias que se les concedió en la vida mundanal dedicándose solo a los placeres. Hoy recibirán un castigo humillante por haber sido soberbios en la Tierra sin derecho alguno, y por haber sido desobedientes [a Dios]".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdxxxi{Y recuerda [¡oh, Mujámmad!] al hermano de la tribu de ‘Ad, [el Profeta Hud] cuando advirtió a su pueblo en las dunas [donde habitaban]. Todos los Mensajeros que fueron enviados, antes y después de él, decían a sus pueblos: ``No adoren sino a Dios, temo que los azote el castigo de un día terrible".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdxxxii{Dijeron: ``¿Has venido a nosotros para convencernos de que nos alejemos de nuestros dioses? Haz que se desencadene sobre nosotros aquello con que nos amenazas, si es que dices la verdad".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdxxxiii{Dijo [el Profeta Hud]: ``Solo Dios sabe cuándo llegará [ese día], yo solo les transmito el Mensaje con el que fui enviado, pero veo que son un pueblo que se comporta como los ignorantes".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdxxxiv{Y cuando vieron algo como una nube que se acercaba a sus valles, dijeron: ``Esta es una nube que nos trae lluvia". [Pero su Mensajero les dijo:] ``No, es el castigo que reclamaban: un viento que encierra un castigo doloroso\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdxxxv{y destruye todo por orden de su Señor". Cuando amaneció, solo podían verse sus moradas [vacías]; así castigo a los transgresores.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdxxxvi{Les había concedido mayor fortaleza que a ustedes, y los había dotado de oído, vista y entendimiento. Pero de nada les sirvieron sus oídos, sus ojos y su inteligencia, pues negaron los signos de Dios y merecieron el castigo del que se burlaban.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdxxxvii{Destruí en el pasado pueblos que había a su alrededor, después de haberles enviado todo tipo de signos para que recapacitaran.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdxxxviii{Pero aquellos ídolos que adoraban como divinidades en lugar de Dios se desvanecieron y no los auxiliaron, pues solo eran una falsedad que ellos habían inventado.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdxxxix{Y cuando envié [¡oh, Mujámmad!] a un grupo de yinnes para que escucharan la recitación [del Corán]. Cuando llegaron dijeron [a sus compañeros]: ``¡Guarden silencio [para que podamos escuchar]!" Y luego que culminaste [con la recitación], retornaron a su pueblo para advertirles.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdxl{Dijeron: ``¡Oh, pueblo nuestro! Hemos oído un Libro revelado después de Moisés, que corrobora los Mensajes anteriores y guía hacia la Verdad y el camino recto.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdxli{¡Oh, pueblo nuestro! Si obedecen al Mensajero de Dios y creen en él, su Señor les perdonará sus faltas y los salvará de un castigo doloroso.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdxlii{Pero sepan que quien no obedezca al Mensajero de Dios no podrá escapar [del castigo de Dios], ni tendrá fuera de Él protector alguno. Esos están en un error evidente".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdxliii{¿Acaso no ven que Dios, Quien creó los cielos y la Tierra sin agotarse, también tiene poder para resucitar a los muertos? Él es sobre toda cosa Poderoso.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdxliv{El día que los que se negaron a creer sean arrojados al Infierno se les dirá: ``¿Acaso no es esto real?" Responderán: ``¡Sí! ¡Oh, Señor nuestro!" Dirá [Dios]: ``Sufran entonces el castigo que negaban".\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdxlv{Ten paciencia [¡oh, Mujámmad!] como la tuvieron los Mensajeros con más determinación, y no te impacientes con ellos. El día que [los que se negaron a creer] vean aquello con lo que se les había amenazado, pensarán que estuvieron en la tumba solo un instante del día. Esta es una notificación. ¿A quién le alcanza el castigo sino a la gente perversa?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdxlvi{\basmalahes Dios invalidará las obras de quienes no crean y alejen a la gente del sendero de Dios.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdxlvii{En cambio, a quienes tengan fe, obren rectamente y crean en lo que fue revelado a Mujámmad, que es la Verdad proveniente de su Señor, Él les perdonará sus pecados e infundirá paz en sus corazones.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdxlviii{Esto es así porque quienes se negaron a creer siguen lo falso, mientras que los creyentes siguen la Verdad de su Señor. Así es como Dios expone ejemplos a la gente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdxlix{Cuando tengan que enfrentarse en combate a los que se negaron a creer, golpéenlos en el cuello; y cuando estén fuera de combate aprésenlos. Luego, libérenlos con benevolencia o pidan un rescate, [esa debe ser la actitud] hasta que cese la guerra. [Sepan que] si Dios hubiera querido, Él mismo los hubiera derrotado, pero quiso ponerlos a prueba [y que se enfrentaran] unos contra otros. Quien caiga en combate por la causa de Dios, sus obras no habrán sido en vano.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdl{[Dios] los guiará, infundirá paz en sus corazones\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdli{y los introducirá en el Paraíso que ya les había dado a conocer.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdlii{¡Oh, creyentes! Si auxilian a Dios, Él los auxiliará y afirmará sus pasos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdliii{En cambio, a los que se niegan a creer les aguarda la desgracia y sus obras habrán sido en vano,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdliv{porque repudiaron lo que Dios descendió en la revelación, y como consecuencia sus obras se perderán.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdlv{¿Por qué no viajan por el mundo y observan cómo terminaron sus antecesores? Dios los destruyó; y sepan que todos los que se niegan a creer tienen un destino similar.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdlvi{Eso es porque Dios solo es protector de los creyentes, mientras que los que se niegan a creer no tienen protector alguno.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdlvii{Dios introducirá a los creyentes que obran rectamente en jardines por donde corren ríos. En cambio, los que se niegan a creer gozarán transitoriamente y comerán como lo hacen los rebaños, pero tendrán el Infierno por morada.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdlviii{Muchas ciudades fueron más poderosas que la que te expulsó [¡oh, Mujámmad!], e igualmente las destruí y no tuvieron quién los auxiliara.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdlix{¿Acaso quien se aferra a una evidencia clara de su Señor puede compararse con quien [seducido por el demonio] ve sus obras malas como buenas y sigue sus pasiones?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdlx{Así es la descripción del Paraíso que le fue prometido a los piadosos: hay ríos de agua que no se contaminan, ríos de leche que siempre tendrá buen sabor, ríos de vino que será un deleite para quienes lo beban, y ríos de miel pura. Tendrán en él todas las frutas que deseen. Su Señor los perdonará. ¿Acaso quien disfrutará de estas gracias puede compararse con quien morará eternamente en el Infierno y beberá agua hirviendo que carcomerá sus intestinos?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdlxi{Algunos te escuchan [¡oh, Mujámmad!], pero cuando se retiran les dicen [burlándose] a los que fueron agraciados con el conocimiento: ``¿Qué es lo que acaba de decir?" Estos son a quienes Dios ha sellado sus corazones [con la incredulidad], y solo siguen sus pasiones.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdlxii{Pero a quienes siguen la guía, Él les incrementará su fe y su piedad.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdlxiii{¿Acaso los que se niegan a creer esperan que los sorprenda la Hora? Ya se evidenciaron algunas señales que indican su proximidad, y de nada les servirá creer cuando esta llegue.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdlxiv{Debes saber que no hay nada ni nadie con derecho a ser adorado salvo Dios, e implórale el perdón de tus faltas y las de los creyentes y las creyentes. Dios conoce bien lo que hacen dentro y fuera de sus hogares.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdlxv{Algunos creyentes dicen: ``¿Por qué no desciende un capítulo [del Corán donde se prescriba combatir]?" Pero cuando es revelado un capítulo [del Corán] con preceptos obligatorios, y se menciona en él la guerra, ves a aquellos cuyos corazones están enfermos mirarte como si estuvieran en la agonía de la muerte. Sería mejor para ellos\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdlxvi{cumplir con los preceptos y no pedir que se prescribiera la guerra. Porque cuando llegue el momento de combatir, lo mejor será que obedezcan a Dios con sinceridad.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdlxvii{¿Si les fuera dada autoridad, acaso no sembrarían la corrupción en la Tierra y cortarían los lazos familiares?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdlxviii{A ellos Dios los ha maldecido haciendo que se comporten como sordos y ciegos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdlxix{¿Acaso no meditan en el Corán, o es que sus corazones están cerrados con cerrojos?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdlxx{Aquellos que reniegan de su fe después de habérseles evidenciado la guía, es porque el demonio los seduce y les da falsas esperanzas.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdlxxi{Este descarrío es porque [los hipócritas] dijeron a quienes odian lo que Dios reveló [a Mujámmad]: ``Les obedeceremos en algunos asuntos". Pero Dios conoce sus secretos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdlxxii{¡Qué terrible será cuando los ángeles tomen sus almas y los golpeen en el rostro y la espalda!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdlxxiii{Eso será su merecido por haber seguido lo que Dios detesta y haberse apartado de lo que Le complace. Sus obras habrán sido en vano.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdlxxiv{¿Acaso piensan aquellos cuyos corazones están enfermos que Dios no sacará a la luz su resentimiento?\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdlxxv{Si hubiera querido te los habría identificado y los hubieras reconocido por sus signos, pero aun así los reconocerás por el tono de sus palabras. Dios conoce sus obras [y los juzgará acorde a ellas].\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdlxxvi{Los probaremos para distinguir quiénes de ustedes son los que verdaderamente luchan por la causa de Dios y se mantienen pacientes [en la fe]. Sepan que sacaremos a la luz lo que esconden en sus corazones.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdlxxvii{Los que se niegan a creer, extravían [a la gente] del sendero de Dios y se oponen al Mensajero después de habérseles evidenciado la guía, no podrán perjudicar a Dios en nada y sus obras serán en vano.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdlxxviii{¡Oh, creyentes! Obedezcan a Dios y obedezcan al Mensajero. No hagan vanas sus obras.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdlxxix{A los que se nieguen a creer, se opongan al camino de Dios y mueran en la incredulidad, Dios no ha de perdonarlos.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdlxxx{No cedan [ante el enemigo] invitándolo a un acuerdo [por cobardía]. Ustedes [cuando tienen fe y defienden una causa justa] obtendrán la victoria. Dios está con ustedes. Él no dejará de premiar sus obras.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdlxxxi{La vida mundanal es juego y diversión. Pero si creen y son piadosos obtendrán su recompensa. Dios no les exige todos sus bienes.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdlxxxii{Si se los exigiera, se mostrarían avaros y se manifestaría su rechazo.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdlxxxiii{Se los invita a contribuir por la causa de Dios, pero entre ustedes hay quienes se muestran avaros. El avaro solo se perjudica a sí mismo. Porque Dios es el Rico y ustedes son los pobres. Si no creen, Dios los cambiará por otro pueblo que no será como ustedes.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdlxxxiv{\basmalahes Te he concedido [¡oh, Mujámmad!] una victoria evidente.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdlxxxv{Dios te perdonará [¡oh, Mujámmad!] las faltas que cometiste y las que pudieses cometer, completará Su gracia sobre ti, te afianzará en el sendero recto,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdlxxxvi{y te dará un auxilio grandioso.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdlxxxvii{Él es Quien hizo descender el sosiego en los corazones de los creyentes para aumentarles fe a la fe que ya tenían. A Dios pertenecen los ejércitos de los cielos y de la Tierra; y Dios lo sabe todo, es Sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdlxxxviii{[Dios] introducirá por toda la eternidad a los creyentes y a las creyentes en jardines por donde corren ríos, y les perdonará sus pecados. Este es un éxito grandioso ante Dios.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdlxxxix{En cambio, a los hipócritas y las hipócritas, y a los idólatras y las idólatras que pensaban mal de Dios, los castigará; la ira de Dios recaerá sobre ellos y los maldecirá, y les tiene reservado el castigo del Infierno. ¡Qué horrible destino!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdxc{A Dios pertenecen los ejércitos de los cielos y de la Tierra. Dios es Poderoso, Sabio.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdxci{Te he enviado [¡oh, Mujámmad!] como testigo [de la unicidad divina], albriciador y amonestador.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdxcii{Crean en Dios y en Su Mensajero, asistan y honren [al Profeta], y glorifiquen [a Dios] por la mañana y por la tarde.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdxciii{Quienes te juran fidelidad en realidad están jurando fidelidad a Dios, pues la mano de Dios está sobre sus manos. Quien no cumpla con el juramento solo se perjudicará a sí mismo; en cambio, quien respete lo pactado con Dios recibirá una recompensa grandiosa.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdxciv{[¡Oh, Mujámmad!] Los beduinos que no participaron [del viaje a La Meca y del pacto de Hudaibiiah] dirán: ``Nos mantuvieron ocupados nuestros bienes materiales y nuestras familias, pídele a Dios que nos perdone". Pero solo dicen con sus lenguas lo que no sienten sus corazones. Diles: ``Si Dios quisiera perjudicarlos o beneficiarlos, nadie podría impedirlo. Dios sabe lo que hacen".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdxcv{Creyeron que el Mensajero y los creyentes jamás regresarían a sus familias. Eso es lo que el demonio infundió en sus corazones, y por eso pensaron mal. Son gente que se ha arruinado a sí misma.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdxcvi{Quien no crea en Dios y en Su Mensajero sepa que el castigo del Infierno está reservado para los incrédulos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdxcvii{A Dios pertenece el reino de los cielos y de la Tierra, perdona a quien Él quiere y castiga a quien Él quiere. Dios es Absolvedor, Misericordioso.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdxcviii{Cuando salgan en busca del botín, quienes no participaron [de la expedición a La Meca] dirán: ``Déjennos participar de la expedición". Pretenden cambiar el designio de Dios. Diles [¡oh, Mujámmad!]: ``No participarán de ella, pues así lo decretó Dios". Entonces responderán: ``En realidad nos tienen envidia", pero es poco lo que comprenden.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdxcix{Diles a los beduinos que no participaron [en la expedición a La Meca]: ``Se los convocará para luchar contra un pueblo militarmente poderoso, puede que combatan o que ellos se rindan. Si obedecen, Dios les concederá una bella recompensa. Pero si desertan, como lo hicieron anteriormente, les dará un castigo doloroso [en el Más Allá]".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdc{No hay nada que reprochar al ciego, al lisiado y al enfermo [que no participan en las expediciones militares]. Quien obedezca a Dios y a Su Mensajero, Él lo introducirá en jardines por donde corren ríos. Pero a quien deserte, Dios le dará un castigo doloroso.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdci{Dios quedó complacido con los creyentes cuando te juraron fidelidad bajo el árbol. [Él] sabía [la fe] que había en sus corazones e hizo descender el sosiego sobre ellos y los recompensó con una victoria cercana,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcii{donde obtuvieron un botín cuantioso. Dios es Poderoso, Sabio.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdciii{Dios les ha prometido que obtendrán muchos botines, y por eso les adelantó este [en Jaibar]. [Él] los ha protegido de las manos [opresoras] de alguna gente para que sean ustedes un signo para los creyentes, y los guiará por el sendero recto.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdciv{Y [también les ha prometido] otras victorias que no tienen capacidad de conseguir, pero que Dios les tiene reservadas. Dios tiene poder sobre todas las cosas.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcv{Sepan que aun cuando los que se negaron a creer los hubieran combatido [en Hudaibiiah], habrían huido vencidos, pues no hubieran encontrado quién los protegiera ni los defendiera.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcvi{Ese es el proceder de Dios que ha regido siempre en el pasado [de socorrer a los creyentes]. No encontrarás que el proceder de Dios cambie.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcvii{Él es Quien los protegió de las manos de sus enemigos y los protegió a ellos de las manos de ustedes en el valle de La Meca, después de haberles dado la victoria sobre ellos. Dios vio lo que hicieron.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcviii{Ellos son los que se negaron a creer y no los dejaron llegar a la Mezquita Sagrada, impidiendo que los animales [que llevaban para sacrificarlos como ofrenda en La Meca] llegaran a su destino. De no haber sido porque podrían haber cometido un grave pecado si atacaban La Meca, matando o hiriendo sin darse cuenta a algunos hombres y mujeres creyentes que no conocían y que habitaban en ella, Dios se los habría permitido. Dios alcanza con Su misericordia a quien Él quiere. Si les hubiera sido posible diferenciarlos unos de otros, les habríamos hecho infligir un castigo doloroso a los que se negaron a creer.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcix{Cuando los que se negaron a creer cerraron sus corazones con una arrogancia similar a la de la época de la ignorancia [previa al Islam], Dios hizo descender el sosiego sobre Su Mensajero y sobre los creyentes, y los hizo mantenerse leales al compromiso, pues eran los más merecedores y los más dignos de él. Dios lo sabe todo.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcx{Dios hará realidad la visión que tuvo Su Mensajero [en sueños] y ustedes entrarán en la Mezquita Sagrada, si Dios quiere, algunos con las cabezas rasuradas y otros con el cabello recortado, sin temer absolutamente nada. Dios sabe lo que ustedes ignoran. Él les concederá, además, una victoria cercana.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcxi{Él es Quien les envió a Su Mensajero con la guía y la práctica de adoración verdadera, para que prevalezca sobre todas las demás. Dios es suficiente como testigo.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcxii{Mujámmad es el Mensajero de Dios. [Los creyentes] que están con él son severos con los que se niegan a creer, pero misericordiosos entre ellos. Los verás [rezando] inclinados y prosternados, anhelando alcanzar la misericordia de Dios y Su complacencia. En sus rostros se encuentran las huellas de la prosternación. Así fueron descritos en la Tora; mientras que en el Evangelio se los compara con una semilla que germina, brota, se fortalece, cobra grosor y se afirma en su tallo, causando alegría a los sembradores. Para que se indignen los que se niegan a creer. A los que crean y obren rectamente, Dios les ha prometido el perdón y una recompensa grandiosa.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcxiii{\basmalahes ¡Oh, creyentes! No se pongan a ustedes mismos por encima de Dios y Su Mensajero, y tengan temor de Dios; Dios todo lo oye, todo lo sabe.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcxiv{¡Oh, creyentes! No levanten sus voces sobre la voz del Profeta, y no hablen con él del mismo modo que hablan entre ustedes, pues sus obras se podrían malograr sin que se dieran cuenta.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcxv{Quienes bajan sus voces cuando están en presencia del Mensajero de Dios son aquellos a los que Dios purificó sus corazones, infundiendo en ellos el temor devocional. Ellos recibirán perdón y una recompensa magnífica.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcxvi{La mayoría de los que te llaman con insistencia [¡oh, Mujámmad!] desde afuera de tu morada, no razonan.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcxvii{Mejor sería que esperaran pacientemente hasta que tú salgas; pero [sepan que] Dios es Absolvedor, Misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdcxviii{¡Oh, creyentes! Si una persona que transgrede se les presenta con alguna noticia, corroboren su veracidad, no sea que perjudiquen a alguien por ignorancia y luego se arrepientan de lo que hayan hecho.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcxix{Sepan que entre ustedes está el Mensajero de Dios, y que si los obedeciera en la mayoría de los asuntos habrían caído en la perdición. Dios les ha infundido el amor por la fe, embelleciéndola en sus corazones, y los hizo aborrecer la incredulidad, la corrupción y la desobediencia. ¡Esos son los bien guiados!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcxx{Ese es el favor y la gracia que Dios les ha concedido. Dios todo lo sabe, es Sabio.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdcxxi{Si dos grupos de creyentes combaten entre sí, intenten reconciliarlos. Si uno de los dos actúa abusivamente contra el otro, combatan al grupo opresor hasta que respete las leyes de Dios, pero si lo hace, entonces reconcilien a ambos grupos con equidad. Sean justos, que Dios ama a quienes establecen justicia.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdcxxii{Los creyentes son hermanos entre sí; reconcilien a sus hermanos y tengan temor de Dios para que Él les tenga misericordia.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdcxxiii{¡Oh, creyentes! No se burlen unos de otros, porque pudiera ser que los que son blancos de las burlas sean mejores que los que se están burlando. Que las mujeres no se burlen de otras mujeres, porque es posible que las que son el blanco de las burlas sean mejores que las que se burlan. No difamen ni pongan apodos ofensivos. ¡Qué malo es comportarse como un corrupto luego de haber sido agraciado con la fe! Quienes no se arrepientan… esos son los injustos.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdcxxiv{¡Oh, creyentes! Eviten sospechar demasiado [de la actitud de los demás] pues algunas sospechas son un pecado. Y no se espíen, ni hablen mal del ausente, porque es tan repulsivo como comer la carne muerta de su hermano. ¿Acaso alguien desearía hacerlo? Por supuesto que les repugnaría. Tengan temor de Dios, porque Dios es Indulgente, Misericordioso.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdcxxv{¡Oh, seres humanos! Los he creado a partir de un hombre y de una mujer, y los congregué en pueblos y tribus para que se reconozcan los unos a los otros. El mejor de ustedes ante Dios es el de más piedad. Dios todo lo sabe y está bien informado de lo que hacen.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdcxxvi{Los beduinos dicen: ``Somos creyentes". Diles [¡oh, Mujámmad!]: ``Todavía no son verdaderos creyentes. Mejor digan que han aceptado el Islam, pues la fe no ha ingresado completamente en sus corazones. Sepan que si obedecen a Dios y a Su Mensajero, sus obras no habrán sido en vano [y serán recompensados por ellas]; Dios es Absolvedor, Misericordioso".\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxxvii{Los verdaderos creyentes son quienes creen en Dios y en Su Mensajero, y luego no vacilan; quienes luchan por la causa de Dios con sus bienes materiales y sus personas. Esos son los sinceros.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxxviii{Diles [¡oh, Mujámmad!]: ``¿Acaso pretenden decirle a Dios en qué creen? Dios conoce cuanto hay en los cielos y en la Tierra. Dios lo sabe todo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxxix{Piensan que te han hecho un favor al abrazar el Islam. Diles [¡oh, Mujámmad!]: ``No me mencionen su conversión al Islam como si fuera un favor hacia mí. Porque si fueron sinceros, fue Dios Quien les hizo el favor de guiarlos a la fe".\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxxx{Dios conoce lo oculto de los cielos y de la Tierra. Dios ve todo lo que hacen.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxxxi{\basmalahes Qaf. [Juro] por el glorioso Corán,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcxxxii{pero los que se niegan a creer se asombran que haya surgido un amonestador de entre ellos mismos, y dicen: ``¡Esto es algo asombroso!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcxxxiii{¿Acaso cuando hayamos muerto y nos hayamos convertido en polvo [seremos resucitados]? ¡Eso es imposible!"\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcxxxiv{Yo sé lo que la tierra consumirá de ellos. Todo lo tengo registrado en un libro protegido.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcxxxv{Desmintieron la verdad cuando les llegó y se encuentran en un estado de confusión.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdcxxxvi{¿Acaso no observan el cielo por encima de ellos, cómo lo he erigido y embellecido, y que no tiene ninguna imperfección?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcxxxvii{¿Y a la tierra, cómo la he extendido, fijado en ella montañas firmes, y he hecho brotar en ella vegetales de toda especie?,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcxxxviii{como evidencia y recuerdo para todo siervo arrepentido.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdcxxxix{Hago descender del cielo agua bendita, con la que hago brotar jardines y el grano de la cosecha,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdcxl{y palmeras esbeltas cubiertas de racimos [de dátiles],\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdcxli{como sustento para los siervos. Así como doy vida con la lluvia a la tierra árida, así los resucitaré.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdcxlii{Antes que ellos ya lo habían hecho el pueblo de Noé, los habitantes de Rass y Zamud,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdcxliii{y los habitantes de ‘Ad, el pueblo del Faraón y los hermanos de Lot,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdcxliv{y los habitantes de los valles boscosos y el pueblo de Tubba’. Todos desmintieron a sus Mensajeros, y entonces se cumplió Mi advertencia.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxlv{¿Acaso fallé al crearlos por primera vez? Pero a pesar de eso dudan de una nueva creación.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxlvi{Creé al ser humano y sé cuáles son sus debilidades. Estoy más cerca de él que su propia vena yugular.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxlvii{[Sabe que] dos ángeles escriben todas sus obras, sentados uno a su derecha y el otro a su izquierda,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxlviii{no pronuncia palabra alguna sin que a su lado esté presente un ángel observador que la registre.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxlix{Le llegará la agonía de la muerte con la verdad. ¡De ella era que huía!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcl{La trompeta será inevitablemente soplada. Ese es un día prometido.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcli{Cada hombre se presentará acompañado por un ángel que lo conduzca y otro que será testigo de sus obras.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdclii{[Se le dirá:] ``Fuiste indiferente a este [día]. Hoy te quito el velo que cubría tu vista y ahora puedes ver".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcliii{El que lo acompañó durante su vida dirá: ``Esto es lo que he registrado".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcliv{[Dios dirá a los ángeles:] ``Arrojen al Infierno a todo aquel que se haya negado obstinadamente a creer,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdclv{a aquel que se negó a hacer el bien, violó la ley, sembró la duda\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdclvi{y asoció divinidades a Dios [en la adoración]. ¡Arrójenlo al castigo severo!"\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdclvii{Dirá el que le susurró toda su vida: ``¡Oh, Señor nuestro! Yo no lo desvié, sino que él estaba en un profundo extravío".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdclviii{Dirá: ``No discutan ante Mí, ya les había advertido sobre esto.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdclix{Mi designio es irrevocable, pero Yo no soy injusto con Mis siervos.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdclx{Ese día le diré al Infierno: ``¿Ya te has llenado?" Y exclamará: ``No. ¿Aún hay más?"\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdclxi{Y el Paraíso será presentado a los piadosos, y no estará distante.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdclxii{[Será dicho:] ``Esto es lo que se había prometido para todos los que vuelven a Dios, son cumplidores,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdclxiii{tienen temor del Compasivo en privado, y se presentan con un corazón obediente.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdclxiv{Ingresen al Paraíso en paz, este día comienza la eternidad.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdclxv{Tendrán en él cuanto anhelen, y les tengo reservada una recompensa aun mayor".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdclxvi{¿A cuántas generaciones más poderosas que ellos he destruido en la antigüedad? Recorrieron tierras buscando escapar, pero, ¿acaso se puede escapar?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdclxvii{En esto hay un motivo de reflexión para quienes tienen uso de razón y prestan oído con una mente consciente.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdclxviii{Creé los cielos y la Tierra y todo cuanto existe entre ambos en seis eras, sin sufrir cansancio.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdclxix{Ten paciencia [¡oh, Mujámmad!] ante sus palabras ofensivas, y glorifica con alabanzas a tu Señor antes de la salida del Sol y antes del ocaso,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdclxx{y glorifícalo por la noche, y después de cada prosternación.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdclxxi{Mantente siempre alerta del día que convoque el pregonero desde un lugar cercano;\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdclxxii{ese día todos escucharán el soplido que anuncia la verdad. Ese será el Día de la Resurrección.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdclxxiii{Yo doy la vida y la muerte, y a Mí será el retorno.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdclxxiv{Ese día la tierra se abrirá, y saldrán [de las tumbas] presurosos. Eso es fácil para Mí.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdclxxv{Sé muy bien lo que dicen de ti [¡oh, Mujámmad!]. Pero tú no puedes forzarlos a creer, solo exhórtalos con el Corán, que quien tema Mi amenaza recapacitará.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdclxxvi{\basmalahes [Juro] por los vientos que soplan,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdclxxvii{por las nubes cargadas de lluvias,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdclxxviii{por los barcos que navegan con facilidad,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdclxxix{por los ángeles que trasmiten las órdenes [de Dios],\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdclxxx{que lo que se les ha anunciado [el Día de la Resurrección] es una verdad,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdclxxxi{y que el juicio es inevitable.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdclxxxii{Y [juro] por el cosmos surcado de [planetas en] órbitas\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdclxxxiii{que ustedes [¡oh, idólatras!] tienen creencias contradictorias [con la verdad]\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdclxxxiv{de la que solo se distancian quienes están desviados en su pensamiento.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdclxxxv{¡Pobres aquellos que solo conjeturan sobre lo que no pueden comprobar!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdclxxxvi{Los que están sumidos en la ignorancia,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdclxxxvii{y preguntan: ``¿Cuándo será el Día del Juicio?"\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdclxxxviii{Ese día serán atormentados con el Fuego.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdclxxxix{[Les será dicho:] ``Sufran su tormento, esto es lo que pedían que les llegara con rapidez."\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxc{Los piadosos, en cambio, morarán en jardines con manantiales.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxci{Disfrutarán lo que Su Señor les conceda, porque en la vida mundanal hacían el bien,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxcii{dormían poco por las noches,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxciii{pedían perdón a Dios antes del despuntar del alba,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxciv{y daban de su dinero lo que era derecho para el mendigo y el indigente.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcxcv{En la Tierra hay signos para quienes tienen certeza interior.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcxcvi{También en ustedes mismos. ¿Es que no ven?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcxcvii{En el cielo se encuentra [la fuente de] su sustento y lo que les fue prometido.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcxcviii{[Juro] por el Señor del cielo y de la Tierra que [lo que se les ha prometido] es tan cierto como que pueden hablar.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcxcix{Te relataremos la historia de los huéspedes honorables de Abraham:\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcc{Cuando se presentaron ante él dijeron: ``¡Paz!" Y [Abraham] respondió: ``¡Paz!, gente desconocida".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcci{Y rápidamente se fue a preparar con su familia el mejor de sus terneros,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdccii{y se los ofreció [asado]. Pero [al ver que no comían] les dijo: ``¿Acaso no van a comer?",\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcciii{y sintió temor de ellos. Pero le dijeron: ``No temas", y le albriciaron que tendría un hijo dotado de sabiduría.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcciv{Entonces, su mujer dio un grito de sorpresa y, abofeteándose el rostro, dijo: ``¡Pero si ya soy una anciana estéril!"\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdccv{Le dijeron: ``Así lo ha decretado tu Señor, y Él es el Sabio, el que lo sabe todo".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdccvi{Dijo [Abraham]: ``¡Oh, emisarios! ¿Cuál es su misión?"\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdccvii{Dijeron: ``Fuimos enviados a un pueblo de criminales\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdccviii{para castigarlos con piedras de arcilla cocida,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdccix{marcadas por orden de tu Señor para los trasgresores.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdccx{Pero debemos sacar de allí a los creyentes".\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdccxi{Solo había un hogar de creyentes.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdccxii{Allí dejé un signo para que reflexionen quienes tienen temor del castigo doloroso.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdccxiii{También en la historia de Moisés. Porque lo envié ante el Faraón con una autoridad clara.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdccxiv{Pero él y sus partidarios lo rechazaron y le dijeron: ``Eres un hechicero o un loco".\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdccxv{Entonces, lo castigué a él y a sus partidarios ahogándolos en el mar; él fue el culpable.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdccxvi{Y también en el pueblo de ‘Ad. Envié contra ellos un viento devastador,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdccxvii{que todo lo que alcanzaba lo transformaba en polvo.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdccxviii{También en el pueblo de Zamud. Se les dijo: ``Disfruten transitoriamente".\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdccxix{Pero cuando desobedecieron las órdenes de su Señor fueron fulminados por un rayo mientras lo veían venir,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdccxx{y ni siquiera pudieron ponerse de pie ni defenderse.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdccxxi{El pueblo de Noé [también fue castigado] porque era gente perversa.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdccxxii{Yo soy Quien construí el universo con [Mi] poder [creador]; y soy Yo quien lo expande continuamente.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdccxxiii{Extendí la Tierra [haciéndola propicia para habitar], y con qué excelencia lo he hecho.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdccxxiv{Y todo lo he creado en parejas, para que reflexionen.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdccxxv{[Diles ¡oh, Mujámmad!:] ``Corran hacia Dios, [y sepan que] yo soy un amonestador que habla claro.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdccxxvi{No dediquen actos de adoración a otros que Dios, Yo soy para ustedes un amonestador que habla claro".\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdccxxvii{En la antigüedad, cada vez que llegaba un Mensajero lo acusaban de hechicero o loco.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdccxxviii{Pareciera que se hubieran transmitido esas palabras unos a otros. Pero en realidad son gente transgresora.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmdccxxix{Aléjate de ellos [¡oh, Mujámmad!], y sabe que no serás reprochado.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmdccxxx{Y hazles recordar, porque el recuerdo beneficia a los creyentes.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmdccxxxi{No he creado a los yinnes y a los seres humanos sino para que Me adoren.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmdccxxxii{No pretendo de ellos ningún sustento ni quiero que Me alimenten,\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmdccxxxiii{ya que Dios es el Sustentador, el Fuerte, el Firme.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmdccxxxiv{Los injustos recibirán su castigo al igual que sus antepasados, así que no Me apresuren.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmdccxxxv{¡Cuán desdichados serán los que negaron la verdad el día que se les ha prometido!\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmdccxxxvi{\basmalahes [Juro] por el monte,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdccxxxvii{por el Libro escrito\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdccxxxviii{en un pergamino desplegado,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdccxxxix{por la casa frecuentada,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdccxl{por la bóveda elevada,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccxli{por el mar que se desborda,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdccxlii{que el castigo de tu Señor es inevitable\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdccxliii{y no hay quién lo pueda impedir.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccxliv{El día que el cielo se agite intensamente\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccxlv{y las montañas se muevan,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccxlvi{¡Cuán desdichados serán ese día los que rechazaron la verdad!,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccxlvii{aquellos que en su ignorancia se burlaban.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccxlviii{El día que sean empujados al fuego del Infierno,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccxlix{[se les dirá:] ``Este es el Fuego que desmentían.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccl{¿Acaso les parece esto una hechicería, o es que no ven?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccli{Entren en él, lo soporten o no, será igual. Solo se los castiga por lo que obraron".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcclii{En cambio, los piadosos morarán en jardines y deleite.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdccliii{Disfrutando lo que su Señor les conceda. Su Señor los salvó del castigo del Infierno.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccliv{``Coman y beban para satisfacerse, como recompensa por sus obras".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcclv{Estarán recostados sobre sofás distribuidos en líneas, y los desposaremos con huríes de grandes ojos.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcclvi{Los creyentes y sus descendientes que los hayan seguido en la fe serán reunidos, sin que se pierda ninguna de sus obras. Toda persona es responsable de sus propias acciones.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcclvii{Los agraciaremos con tanta fruta y carne como la que deseen.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcclviii{Se pasarán unos a otros una copa que no incitará a frivolidades ni pecados.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcclix{Serán rodeados por sirvientes, bellos como perlas guardadas.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcclx{Y [los bienaventurados] se preguntarán unos a otros.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcclxi{Dirán: ``Cuando estábamos viviendo junto a nuestra familia, teníamos temor,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcclxii{pero Dios nos agració y nos preservó del tormento del Fuego.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcclxiii{A Él le suplicábamos, pues Él es el Bondadoso, el Misericordioso".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcclxiv{Llama al Mensaje [¡oh, Mujámmad!], tú no eres, por la gracia de tu Señor, un adivino ni un loco.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcclxv{O te acusan diciendo: ``Es un poeta, esperemos a que le llegue la muerte".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdcclxvi{Diles: ``Sigan esperando, que yo esperaré junto a ustedes".\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdcclxvii{¿Son sus mentes las que los llevan a decir esto o son gente que transgrede los límites?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdcclxviii{También dicen: ``Él lo ha inventado". Pero la verdad es que no creen.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdcclxix{¡Que presenten ellos un libro semejante, si es verdad lo que dicen!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdcclxx{¿Acaso surgieron de la nada o son ellos sus propios creadores?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdcclxxi{¿O crearon los cielos y la Tierra? No tienen certeza de nada.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdcclxxii{¿Acaso poseen los tesoros de tu Señor o tienen autoridad absoluta?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdcclxxiii{¿O tienen una escalera para escuchar los designios de Dios? Quien de ellos logre escuchar, que traiga una prueba clara.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdcclxxiv{¿Acaso a Dios Le pertenecen las hijas mujeres y a ellos los hijos varones?\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdcclxxv{¿O acaso tú [¡oh, Mujámmad!] les pides una retribución que hace que se vean abrumados por las deudas?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdcclxxvi{¿O tienen el conocimiento de lo oculto y lo han registrado?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdcclxxvii{¿O es que quieren tenderte una trampa? Los que se niegan a creer son quienes han caído en una trampa.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdcclxxviii{¿O acaso tienen otra divinidad además de Dios? ¡Glorificado sea Dios de cuanto Le asocian!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcclxxix{Si vieran caer parte del cielo dirían: ``Son solo nubes acumuladas".\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcclxxx{Déjalos, que ya les llegará el día en que quedarán paralizados de terror.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxi{Ese día no los beneficiarán en nada sus argucias y nadie los auxiliará.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxii{Los injustos sufrirán, además de este, otros castigos, pero la mayoría no lo sabe.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxiii{Ten paciencia con los designios de tu Señor, y sabe que te encuentras bajo Mis ojos. Glorifica con alabanzas a tu Señor cuando te levantes [a orar],\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxiv{por la noche y al ocultarse las estrellas.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxv{\basmalahes [Juro] por la estrella cuando desaparece\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxvi{que su compañero no se ha extraviado ni está en un error,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxvii{ni habla de acuerdo a sus pasiones.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxviii{Él solo trasmite lo que le ha sido revelado.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxix{Aquello que le enseñó el dotado de poder\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccxc{y fortaleza, cuando se le presentó en su forma verdadera\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdccxci{en lo más elevado del horizonte,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdccxcii{y luego descendió y se acercó a él,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccxciii{hasta una distancia de dos arcos o menos aún.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccxciv{Entonces [Dios] le inspiró a Su siervo la revelación.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccxcv{El corazón no desmintió lo que había visto.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccxcvi{¿Le van a discutir sobre lo que vio?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccxcvii{Sepan que ya lo había visto en otro descenso,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccxcviii{junto al azufaifo que demarca el límite,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccxcix{donde se encuentra el jardín de la residencia eterna.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccc{Cuando al azufaifo lo cubrió lo que lo cubrió,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdccci{y su mirada no se desvió ni se propasó.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcccii{Porque contempló algunos de los signos más sublimes de su Señor.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccciii{¿Cómo es que adoran a [los ídolos] Lat, a ‘Uzza\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdccciv{y a Manat, la tercera?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcccv{Para ustedes los hijos varones y para Dios las hijas mujeres.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcccvi{Esa es una división injusta.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcccvii{[Esos tres ídolos] son solo nombres que ustedes y sus padres han inventado, porque Dios no les dio autoridad alguna para ello. [Los idólatras] solo siguen suposiciones impulsados por sus propias pasiones, a pesar de haberles llegado la guía de su Señor.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcccviii{¿Acaso cree el ser humano que obtendrá todo cuanto ambiciona?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcccix{A Dios le pertenecen esta vida y la otra.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcccx{¿Cuántos ángeles hay en los cielos cuya intercesión no servirá de nada, salvo que Dios lo permita en favor de quien Él quiera y de quien esté complacido?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcccxi{Quienes no creen en la otra vida, le dan a los ángeles nombres femeninos\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcccxii{sin tener ningún conocimiento sobre ello. Solo siguen conjeturas, pero las conjeturas carecen de valor frente a la Verdad.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcccxiii{Apártate de quienes rechazan Mi Mensaje y no desean sino [el materialismo de] la vida mundanal.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcccxiv{Ese es el único conocimiento que les interesa alcanzar. Tu Señor bien sabe quién se extravía de Su camino y quién se encamina.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdcccxv{A Dios pertenece cuanto hay en los cielos y en la Tierra, y Él castigará a quienes obren el mal y retribuirá con una hermosa recompensa a los que hagan el bien,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdcccxvi{aquellos que evitan los pecados graves y las obscenidades, y no cometen más que faltas leves. Tu Señor es inmensamente indulgente. Él los conoce bien, ya que los creó de la tierra y luego hizo que fueran embriones en el vientre de sus madres. No se elogien a sí mismos, Él bien sabe quién es realmente piadoso.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdcccxvii{¿Has visto que quien rechaza [el Islam],\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdcccxviii{da poco en caridad y es tacaño?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdcccxix{¿Acaso tiene conocimiento de lo oculto y puede ver [lo que sucederá en el Más Allá]?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdcccxx{¿No le han informado de lo que contienen las páginas reveladas a Moisés\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdcccxxi{y a Abraham, el fiel cumplidor?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdcccxxii{Que nadie cargará con pecados ajenos,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdcccxxiii{que el ser humano no obtendrá sino el fruto de sus esfuerzos,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdcccxxiv{que sus esfuerzos se verán,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdcccxxv{que será retribuido con una recompensa total,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdcccxxvi{y que ante tu Señor se ha de comparecer finalmente.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdcccxxvii{Él es Quien hace reír y hace llorar,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcccxxviii{Él es Quien causa la muerte y la vida,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcccxxix{Él ha creado la pareja: el macho y la hembra,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcccxxx{de una gota de esperma eyaculada.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxi{Él es Quien los creará por segunda vez.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxii{Él es Quien concede la riqueza y la pobreza,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxiii{Él es el Señor de Sirio,\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxiv{Él destruyó al antiguo pueblo de ‘Ad\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxv{y al pueblo de Zamud, de los que no quedó nadie.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxvi{También lo hizo antes con el pueblo de Noé, pues ellos eran más injustos y transgresores.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxvii{Y a la ciudad que cayó al revés,\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxviii{y la cubrió lo que la cubrió.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxix{¿Cuál de las bendiciones de tu Señor pondrás en duda [oh, ser humano]?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmdcccxl{Él es un Profeta como los que lo precedieron.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmdcccxli{La llegada es inminente,\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmdcccxlii{pero nadie, salvo Dios, tiene conocimiento de cuándo ocurrirá.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmdcccxliii{¿De este mensaje se sorprenden?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmdcccxliv{¿Ríen en vez de llorar?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmdcccxlv{¿Permanecen distraídos?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmdcccxlvi{¡Prostérnense ante Dios y adórenlo solo a Él!\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmdcccxlvii{\basmalahes El Día del Juicio está próximo, y la Luna se parte en dos.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcccxlviii{Pero cuando contemplaron el signo, se rehusaron a creer y dijeron: ``Esto es un hechizo persistente".\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcccxlix{Desmintieron y siguieron sus inclinaciones. Pero todo tiene un desenlace definitivo.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcccl{Ya han recibido suficiente información disuasiva.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcccli{Una sabiduría sublime [de Dios], pero las advertencias han sido en vano,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccclii{así que apártate de ellos. El día que un pregonero les convoque para algo terrible,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcccliii{saldrán de las tumbas con la mirada baja, como si fueran langostas desorientadas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcccliv{acudiendo presurosos a la llamada del pregonero. Los que se negaron a creer exclamarán: ``¡Hoy será un día difícil!"\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccclv{Pero antes que ellos ya se había negado a creer el pueblo de Noé. Desmintieron a Mi siervo y dijeron: ``Es un demente", y lo amenazaron.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccclvi{Entonces [Noé] invocó a su Señor: ``¡Me han vencido, Te pido ayuda!"\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccclvii{Entonces abrí las puertas del cielo con un agua torrencial,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccclviii{también hice brotar agua de la tierra y se encontraron las aguas, por un mandato que había sido decretado.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccclix{Pero a él lo transporté en una embarcación construida con tablas y clavos,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccclx{que navegó bajo la protección de Mis ojos. Así recompensé a quien había sido rechazado.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccclxi{Hice que la embarcación se preservara para que fuera un signo. Pero, ¿habrá alguien que reflexione?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccclxii{¡Qué severos fueron Mi castigo y Mi advertencia!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdccclxiii{He hecho el Corán fácil de comprender y memorizar. Pero, ¿habrá alguien que reflexione?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdccclxiv{[En la antigüedad] el pueblo de ‘Ad se negó a creer, ¡y qué severos fueron Mi castigo y Mi advertencia!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccclxv{Envié sobre ellos un viento glacial y tempestuoso en un día interminable,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdccclxvi{que levantaba a la gente como si fueran troncos de palmeras arrancados de raíz.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdccclxvii{¡Qué severos fueron Mi castigo y Mi advertencia!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdccclxviii{He hecho el Corán fácil de entender y memorizar. Pero, ¿habrá alguien que lo reflexione?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdccclxix{El pueblo de Zamud desmintió las advertencias.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdccclxx{Dijeron: ``¿Acaso vamos a seguir a un ser humano igual a nosotros? Si lo hiciéramos, estaríamos extraviados y delirantes.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdccclxxi{¿Por qué le habría sido concedido el Mensaje solo a él de entre todos nosotros? Es un mentiroso arrogante".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdccclxxii{¡Pero ya sabrán mañana quién es el verdadero mentiroso arrogante!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdccclxxiii{Les envié la camella como una prueba: ``Obsérvalos y ten paciencia,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdccclxxiv{e infórmales que el agua debe compartirse, y que deberán respetar su turno".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdccclxxv{Pero ellos llamaron a uno de sus compañeros, quien la mató.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdccclxxvi{¡Y qué severos fueron Mi castigo y Mi advertencia!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdccclxxvii{Les envié una sola explosión [desde el cielo] y quedaron como hierba pisoteada por el ganado.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdccclxxviii{He hecho el Corán fácil de entender y memorizar. Pero, ¿habrá alguien que lo reflexione?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdccclxxix{El pueblo de Lot desmintió la advertencia.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdccclxxx{Les envié una tormenta de piedras, salvo a la familia de Lot, a quienes salvé al amanecer\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxi{como una gracia de Mi parte, porque así retribuyo a quienes son agradecidos.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxii{[Lot] les había advertido de Mi rigor, pero dudaron de las advertencias\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxiii{y le demandaron [a Lot] que les entregara a sus huéspedes, y entonces cegué sus ojos. ¡Sufran Mi castigo y Mi advertencia!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxiv{Y por la mañana los sorprendió un castigo decretado.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxv{¡Sufran Mi castigo y Mi advertencia!\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxvi{Hemos hecho el Corán fácil de entender y memorizar. Pero, ¿habrá alguien que reflexione?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxvii{Mi advertencia le llegó al Faraón [y su pueblo],\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxviii{pero desmintieron todos Mis signos, y los castigué con un castigo severo, como solo puede hacer el Todopoderoso, el Omnipotente.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxix{¿Acaso los que se niegan a creer entre ustedes son mejores que estos? ¿O tienen alguna Escritura que les proporcione inmunidad?\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcccxc{¿Es por ello que dicen: ``Somos un grupo invencible"?\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcccxci{Pero todos ellos serán vencidos y huirán.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcccxcii{Mas la Hora será su cita, y ese día será más terrible y amargo aún.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcccxciii{Los que hacen el mal están en un estado de extravío y locura.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcccxciv{El día que sean arrojados de cara al fuego [se les dirá:] ``¡Sufran el tormento del Infierno!"\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcccxcv{He creado todas las cosas en su justa medida.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcccxcvi{Y Mi orden es dada solo una vez, y ejecutada en un abrir y cerrar de ojos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdcccxcvii{Ya destruí en el pasado a quienes desmintieron como ustedes. Pero, ¿habrá alguien que reflexione?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdcccxcviii{Todo cuanto obraron se encuentra registrado en el libro de sus obras.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdcccxcix{Y todo cuanto ocurre, importante o insignificante, está escrito.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcm{Los piadosos estarán entre jardines y ríos,\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcmi{en un lugar honorable, junto al Soberano Todopoderoso.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcmii{\basmalahes El Compasivo\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcmiii{enseñó el Corán,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcmiv{creó al ser humano\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcmv{y le enseñó a hablar con elocuencia.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcmvi{El Sol y la Luna siguen una órbita precisa,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcmvii{y las hierbas y los árboles se prosternan [ante Dios].\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcmviii{Elevó el cielo, y estableció la balanza de la justicia\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcmix{para que no transgredan el equilibrio [de la equidad].\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcmx{Pesen con equidad y no cometan fraude en la balanza.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcmxi{Preparó la Tierra para Sus criaturas.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcmxii{En ella hay árboles frutales, palmeras con racimos [de dátiles],\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcmxiii{semillas y plantas aromáticas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcmxiv{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcmxv{Creó al ser humano de arcilla como la cerámica,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcmxvi{y creó a los yinnes de fuego puro.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcmxvii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcmxviii{El Señor de los dos nacientes y los dos ponientes.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcmxix{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcmxx{Hizo que las dos grandes masas de agua se encuentren,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcmxxi{pero dispuso entre ambas una barrera que no transgreden.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcmxxii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcmxxiii{De ambas se extraen perlas y corales.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcmxxiv{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcmxxv{Suyas son las embarcaciones que sobresalen en el mar como montañas.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcmxxvi{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcmxxvii{Todo cuanto existe en la Tierra perecerá,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmcmxxviii{y solo el rostro de tu Señor perdurará por siempre, el Majestuoso y el Noble.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcmxxix{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcmxxx{Lo invocan suplicando todos los que habitan en los cielos y en la Tierra. Todos los días se encuentra atendiendo los asuntos [de Su creación].\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcmxxxi{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmcmxxxii{Me encargaré de los que cargan con el libre albedrío.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmcmxxxiii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcmxxxiv{¡Oh, yinnes y seres humanos! Si pueden traspasar los confines del cielo y de la Tierra, háganlo. Pero sepan que solo podrán traspasarlos con autorización [de Dios].\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcmxxxv{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcmxxxvi{[Si lo intentaran,] llamaradas de fuego y cobre fundido les serían lanzadas y no podrían defenderse.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcmxxxvii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcmxxxviii{El cielo se hendirá y se pondrá al rojo vivo como la lava.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcmxxxix{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcmxl{Ese día no será necesario preguntarles por sus pecados a los seres humanos ni a los yinnes.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcmxli{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcmxlii{Los pecadores serán reconocidos por su aspecto, y se les tomará por la frente y por los pies.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcmxliii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcmxliv{Este es el Infierno que desmentían los criminales.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcmxlv{No dejarán de ir y venir entre el fuego y un agua hirviente.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcmxlvi{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcmxlvii{Para quien haya tenido temor de comparecer ante su Señor habrá dos jardines.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcmxlviii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcmxlix{[Jardines] frondosos.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcml{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcmli{En cada uno habrá dos manantiales.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcmlii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcmliii{En cada uno habrá dos especies de cada fruta.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcmliv{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcmlv{Estarán reclinados en sofás tapizados de brocado, y la fruta de ambos jardines estará al alcance de la mano.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcmlvi{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcmlvii{Habrá en ellos mujeres de mirar recatado, que no fueron tocadas antes por ningún ser humano ni tampoco un yinn.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcmlviii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcmlix{Ellas serán de una belleza semejante al rubí y al coral.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcmlx{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcmlxi{¿Acaso la recompensa del bien no es el bien mismo?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcmlxii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcmlxiii{Además de esos dos, habrá otros dos jardines.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcmlxiv{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcmlxv{De profundo verdor.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcmlxvi{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcmlxvii{En ambos habrá dos manantiales brotando.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcmlxviii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcmlxix{Habrá frutas, datileras y granadas.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcmlxx{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcmlxxi{Y también habrá buenas y hermosas [mujeres].\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcmlxxii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcmlxxiii{Huríes, retiradas en bellas moradas.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcmlxxiv{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcmlxxv{Que no fueron tocadas antes por ningún ser humano ni tampoco un yinn.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcmlxxvi{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcmlxxvii{[Los bienaventurados] estarán reclinados sobre cojines verdes y hermosas alfombras.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmcmlxxviii{¿Acaso pueden negar alguna de las gracias que les ha concedido su Señor?\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmcmlxxix{¡Bendito sea el nombre de tu Señor, el poseedor de la majestuosidad y la generosidad!\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmcmlxxx{\basmalahes Cuando sobrevenga el suceso\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxi{no habrá quién pueda evitarlo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxii{Algunos serán humillados y otros serán honrados.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxiii{Cuando la Tierra se sacuda violentamente\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxiv{y las montañas caigan desmoronadas\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxv{convirtiéndose en polvo disperso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxvi{serán divididos en tres grupos:\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxvii{Los compañeros de la derecha. ¡Qué afortunados serán los compañeros de la derecha!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxviii{Los compañeros de la izquierda. ¡Qué desafortunados serán los compañeros de la izquierda!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxix{Y los adelantados. ¡Estos serán los primeros!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcmxc{Serán los allegados [a Dios],\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcmxci{estarán en los Jardines de las Delicias.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcmxcii{Muchos de ellos serán de las primeras generaciones\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcmxciii{y muy pocos de las últimas.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcmxciv{Tendrán lechos incrustados con oro y piedras preciosas,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcmxcv{y se recostarán en ellos, unos enfrente de otros.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcmxcvi{Circularán entre ellos sirvientes eternamente jóvenes,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcmxcvii{con vasos, jarros y una copa llenados en un manantial puro,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcmxcviii{que no provocará jaqueca ni embriaguez.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcmxcix{Tendrán las frutas que elijan,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmm{y la carne de ave que les apetezca.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmi{Habrá huríes de ojos hermosos,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmii{como si fueran perlas ocultas.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmiii{En recompensa por las obras buenas que solían hacer.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmiv{No oirán frivolidades ni incitación al pecado,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmv{tan solo la palabra: ``¡Paz!, ¡paz!"\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmvi{Los compañeros de la derecha. ¡Qué afortunados serán los compañeros de la derecha!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmvii{Estarán entre azufaifos sin espinas,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmviii{y árboles cargados de frutos,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmix{de sombra extensa.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmx{Habrá agua de continuo fluir\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmxi{y frutos abundantes,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmxii{que no se agotarán y siempre estarán al alcance de sus manos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmxiii{[Reposarán] en camas elevadas.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmxiv{Las creé [a las mujeres del Paraíso] de manera especial,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmxv{vírgenes,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmxvi{amorosas y siempre con la misma edad.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmxvii{Esto es para los compañeros de la derecha.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmxviii{Muchos de ellos serán de las primeras generaciones,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmxix{y muchos serán de las últimas generaciones.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmxx{¡Pero qué desafortunados serán los compañeros de la izquierda!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmxxi{Atormentados por un viento abrasador y un líquido hirviente,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmxxii{a la sombra de un humo negro,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmxxiii{que no será fresca ni agradable.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmxxiv{Porque se entregaron a los lujos superfluos,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmxxv{se aferraron al más terrible pecado\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmxxvi{y preguntaban burlándose: ``¿Acaso cuando muramos y ya seamos tierra y huesos, vamos a ser resucitados?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmxxvii{¿Y nuestros ancestros también?"\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmxxviii{Respóndeles: ``Los primeros y los últimos\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmxxix{serán congregados en un día ya establecido.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmxxx{Luego, ¡oh, extraviados y desmentidores!,\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmxxxi{han de comer del árbol del Zaqqum\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmxxxii{con el que llenarán sus vientres,\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmmxxxiii{y luego beberán un líquido hirviente\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmmxxxiv{como beben los camellos sedientos que no pueden saciar su sed".\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmmxxxv{Esa será su morada el Día del Juicio.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmmxxxvi{Yo los creé, ¿por qué no aceptan la verdad?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmmxxxvii{¿Por qué no reflexionan en lo que eyaculan?\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmmxxxviii{¿Lo han creado ustedes o soy Yo el creador?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmmxxxix{Yo he decretado cuándo morirá cada uno de ustedes y nadie podría impedirme\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmmxl{aniquilarlos y sustituirlos [por otra generación], y resucitarlos [el Día del Juicio] conforme a un proceso que desconocen.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmmxli{Si reconocen que fueron creados por primera vez, ¿por qué no reflexionan?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmmxlii{¿No han observado sus cultivos?\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmmxliii{¿Ustedes los hacen germinar, o soy Yo Quien los hace germinar?\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmmxliv{Si quisiera los convertiría en pasto seco y entonces se lamentarían,\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmmxlv{[y dirían:] ``Hemos sido castigados,\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmmxlvi{y quedamos en la ruina".\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmmxlvii{¿No han observado el agua que beben?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmmxlviii{¿Ustedes la hacen descender de las nubes o soy Yo Quien la hago descender?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmmxlix{Si quisiera la habría hecho salobre, ¿por qué no son agradecidos?\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmml{¿No han observado el fuego que encienden?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmmli{¿Ustedes han creado el árbol con el que lo encienden o soy Yo el creador?\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmmlii{He creado el fuego para que reflexionen, y para beneficio de los viajeros.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmmliii{Glorifica el nombre de tu Señor, el Grandioso.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmmliv{¡Juro por las estrellas cuando desaparecen!\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmmlv{Lo cual, si supieran, es un juramento grandioso.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmmlvi{Que este es un Corán Noble,\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmmlvii{preservado en un libro custodiado,\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmmlviii{que solo pueden tocar los purificados.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmmlix{Es una revelación descendida por el Señor del universo.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmmlx{¿A este Mensaje son indiferentes?\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmmlxi{¿Y agradecen lo que reciben de Dios negando la Verdad?\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmmlxii{Entonces, cuando [el alma] llegue hasta la garganta,\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmmlxiii{y ustedes estén mirándolo,\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmmlxiv{pero Yo estoy más cerca que ustedes de él, aunque no lo vean;\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmmlxv{si es verdad como dicen que no serán juzgados,\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmmlxvi{devuélvanle el alma, si es que son sinceros.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmmlxvii{Si [el agonizante] es uno de los adelantados\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmmlxviii{tendrá descanso, plenitud y el Jardín de las Delicias.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmmmlxix{Y si es de los compañeros de la derecha:\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmmmlxx{``La paz sea contigo, pues eres de los compañeros de la derecha".\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmmmlxxi{Pero si es de los que negaron la Verdad, de los extraviados,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmmmlxxii{será atormentado con un líquido hirviente\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmmmlxxiii{y luego será arrojado al fuego del Infierno.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmmmlxxiv{esta es la Verdad sobre la que no hay duda.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmmmlxxv{¡Glorifica el nombre de tu Señor, el Grandioso!\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmmmlxxvi{\basmalahes Todo cuanto hay en los cielos y en la Tierra glorifica a Dios. Él es el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmlxxvii{Suyo es el reino de los cielos y de la Tierra. Él da la vida y la muerte. Es sobre toda cosa Poderoso.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmlxxviii{Él es el Primero y el Último, el Manifiesto y el Oculto. Él conoce todas las cosas.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmlxxix{Él es Quien creó los cielos y la Tierra en seis eras. Luego, se estableció sobre el Trono. Sabe lo que ingresa en la tierra y cuanto sale de ella, lo que desciende del cielo y lo que asciende a él. Está con ustedes dondequiera que estén. Dios bien ve cuanto hacen.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmlxxx{Suyo es el reino de los cielos y de la Tierra. Y a Dios retornan todos los asuntos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmlxxxi{Hace que la noche suceda al día y que el día suceda a la noche. Él conoce todo lo que encierran los corazones.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmlxxxii{Crean en Dios y en Su Mensajero. Hagan caridad de los bienes de los que Él los ha hecho responsables. Quienes hayan creído y hecho caridades recibirán una gran recompensa.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmlxxxiii{¿Qué les sucede que no creen en Dios, siendo que el Mensajero los invita a creer en su Señor y ya tenía un pacto con ustedes? Si es que son creyentes.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmlxxxiv{Él es Quien desciende a Su siervo signos evidentes para extraerlos de las tinieblas a la luz. Dios es con ustedes Compasivo, Misericordioso.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmlxxxv{¿Qué les sucede que no aportan a la causa de Dios, siendo que los cielos y la Tierra Le pertenecen a Él? No son iguales quienes hayan aportado y combatido antes de la liberación. Ellos tendrán un rango mayor que quienes hayan aportado y combatido después de la liberación. Pero a todos les ha prometido Dios una hermosa recompensa. Dios está bien informado de cuanto hacen.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmlxxxvi{¿Quién le dará a Dios un préstamo generoso, para que Él se lo multiplique y lo recompense ampliamente?\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmlxxxvii{Ese día verás la luz de los creyentes y de las creyentes irradiar delante de ellos y a su derecha. [Les será dicho]: ``¡Hoy son bienaventurados, tendrán jardines por donde corren ríos, en donde vivirán por toda la eternidad! ¡Ese es el triunfo grandioso!"\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmlxxxviii{El día que los hipócritas y las hipócritas digan a los creyentes: ``¡Aguarden, para que nos podamos iluminar con su luz!" Se les dirá: ``¡Apártense y busquen otra luz!" Entonces se levantará un muro entre ellos que tendrá una puerta. Detrás estará la misericordia de Dios y ante ellos Su castigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmlxxxix{Los llamarán: ``¿Acaso no estábamos con ustedes?" Responderán: ``¡Sí! Pero sucumbieron a la tentación, estaban vacilantes y dudaron. Se dejaron seducir por las falsas esperanzas hasta que les llegó la orden de Dios. Finalmente el Seductor los engañó acerca de Dios.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmxc{Hoy no será aceptado ningún rescate por ustedes ni por los que se negaron a creer. Su morada será el Infierno, porque es lo que merecen. ¡Qué pésimo destino!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmxci{¿Acaso no es hora de que los creyentes subyuguen sus corazones al recuerdo de Dios y a la Verdad que ha sido revelada, y que no sean como quienes recibieron el Libro anteriormente? A estos, a medida que transcurría el tiempo, se les endurecía el corazón. Muchos de ellos eran corruptos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmxcii{Sepan que Dios da vida a la tierra árida. Les explico estos signos para que reflexionen.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmxciii{A los [hombres] que dan caridad y a las [mujeres] que dan caridad, que aportaron con sus bienes a la causa de Dios, les será multiplicado y serán recompensados generosamente.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmxciv{Quienes creen en Dios y en Sus Mensajeros son los veraces para Dios, los que mueren dando testimonio [de su fe]. Ellos recibirán su recompensa y su luz. Pero los que se negaron a creer y desmintieron Mis signos, morarán en el fuego del Infierno.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmxcv{Sepan que la vida mundanal es juego, diversión, encanto, ostentación y rivalidad en riqueza e hijos. Es como la lluvia que genera plantas que alegran a los sembradores con su verdor, pero luego las ven amarillearse hasta convertirse en heno. En la otra vida, ustedes recibirán un castigo severo o el perdón de Dios y Su complacencia. La vida mundanal no es más que un disfrute ilusorio.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmxcvi{¡Apresúrense a alcanzar el perdón de su Señor y así obtener un Paraíso tan vasto como el cielo y la Tierra, el cual está reservado para quienes creen en Dios y en Sus Mensajeros! Esa es la bendición de Dios, y Él se la concede a quien quiere. Dios es poseedor de una bendición grandiosa.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmxcvii{No sucede ninguna desgracia en la Tierra, ni a ustedes los azota adversidad alguna sin que esté registrada en un libro antes de que suceda. Eso es fácil para Dios.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmxcviii{No se depriman por lo que pierdan y no se regocijen con arrogancia por lo que se les ha concedido. Dios no ama a los arrogantes, jactanciosos,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmxcix{que son mezquinos e incitan a la gente a ser avara. Quien rechace sepa que Dios prescinde de todas las criaturas, y Él es el Opulento, el Loable.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmc{Envié a Mis Mensajeros con las pruebas evidentes e hice descender con ellos el Libro y la balanza de la justicia para que la gente establezca la equidad. Hice descender el hierro, en el que hay gran poder y beneficio para la gente. Para que Dios distinga a quienes se esfuercen sinceramente por Su causa y la de Sus Mensajeros. Dios es Fortísimo, Poderoso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmci{Envié a Noé y a Abraham, y agracié a la descendencia de ambos con la profecía y el Libro. Entre sus descendientes hubo quienes siguieron la guía, aunque muchos de ellos fueron corruptos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcii{Después de ellos envié a Mis Mensajeros: a Jesús, hijo de María, le revelé el Evangelio, e infundí en los corazones de quienes lo siguieron la compasión y la misericordia. Ellos establecieron el monacato sin que se los hubiera prescrito, solo por deseo de satisfacer a Dios, pero aun así no lo observaron como debían. A quienes de ellos hayan creído los recompensaré, pero muchos fueron corruptos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmciii{¡Oh, creyentes! ¡Tengan temor de Dios y crean en Su Mensajero! Les multiplicará Su misericordia, les dará una luz para el camino y los perdonará. Dios es Absolvedor, Misericordioso.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmciv{Que la Gente del Libro sepan que carecen de privilegios ante Dios. Los favores están en manos de Dios, y Él los concede a quien quiere. Dios es el poseedor del favor inmenso.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcv{\basmalahes Dios oyó las palabras de quien reclamaba ante ti [¡oh, Mujámmad!] acerca de su esposo y se quejaba por su aflicción ante Dios, y Dios escuchaba su diálogo porque Dios todo lo oye, todo lo ve.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcvi{Quienes digan a sus mujeres: ``¡Eres para mí tan ilícita como mi madre!" Sepan que ellas no son sus madres. Sus madres son solo quienes los han dado a luz. Lo que dicen es reprobable y falso, pero Dios es Remisorio, Absolvedor.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcvii{Quienes repudien a su mujer diciéndole: ``¡Eres para mí tan ilícita como mi madre!", y luego se retracten, deberán liberar a un esclavo antes de poder cohabitar. Así es como se los escarmienta. Sepan que Dios está bien informado de cuanto hacen.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcviii{Pero quien no pueda hacerlo, deberá ayunar dos meses consecutivos antes de poder cohabitar. Quien no pueda, deberá alimentar a sesenta pobres. Esto es para que crean [con sinceridad] en Dios y en Su Mensajero [y aprendan a respetar a la mujer]. Estos son los preceptos de Dios. Pero los que se nieguen a creer recibirán un castigo doloroso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcix{Los que combatan a Dios y a Su Mensajero serán derrotados como quienes los precedieron. He revelado signos evidentes, y por eso quienes se nieguen a creer recibirán un castigo humillante.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcx{El día que Dios los resucite a todos, les informará cuanto hicieron. Dios registró sus obras, mientras que ellos las olvidaron. Dios es testigo de todo.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxi{¿Acaso no ves que Dios conoce cuanto hay en los cielos y en la Tierra? No hay confidencia entre tres sin que Él sea el cuarto, ni entre cinco sin que Él sea el sexto. Siempre, sean menos o más, Él estará presente dondequiera que se encuentren. El Día de la Resurrección les informará sobre lo que hicieron. Dios tiene conocimiento de todas las cosas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxii{¿Acaso no ves a aquellos a los que se les habían prohibido los conciliábulos, pero igualmente persisten en hacerlo en secreto? Se confabulan para la maldad, la enemistad y la desobediencia al Mensajero. Cuando se presentan ante ti [¡oh, Mujámmad!] no te saludan como Dios ha ordenado que lo hagan, y se dicen ente ellos [en tono burlón]: ``¿Por qué será que Dios no nos castiga por lo que decimos?" Será suficiente el Infierno al que serán arrojados. ¡Qué pésimo destino!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxiii{¡Oh, creyentes! Cuando hablen en secreto no lo hagan para cometer una maldad, crear una enemistad o desobedecer al Mensajero, sino que hablen en secreto para acordar actos de benevolencia y piedad. Tengan temor de Dios, que ante Él comparecerán.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxiv{Las confabulaciones son obras del demonio para entristecer a los creyentes. Pero, en realidad, no podrán hacerles ningún daño, salvo que Dios lo permita. Que a Dios se encomienden los creyentes.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxv{¡Oh, creyentes! Cuando se les dice: ``Hagan un lugar en las reuniones, háganlo, para que Dios les haga a ustedes un lugar". Y si se les dice: ``¡Levántense!" Levántense. Sepan que Dios elevará en grados a los creyentes y a quienes agracie con el conocimiento. Dios sabe cuanto hacen.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcxvi{¡Oh, creyentes! Cuando quieran consultar en privado al Mensajero, antes de presentarse hagan una caridad. Esto es mejor para ustedes porque los purifica. Pero si no pueden, sepan que Dios es Absolvedor, Misericordioso.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcxvii{¿Acaso temen no poder ofrecer una caridad antes de consultarlo en privado? Si no pueden hacerlo Dios los absolverá, pero hagan la oración prescrita, paguen el zakat y obedezcan a Dios y a Su Mensajero. Dios está bien informado de cuanto hacen.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcxviii{¿No has reparado en aquellos que tomaron como aliados a un pueblo que cayó en la ira de Dios? No están con unos ni con otros, y juran con mentiras a sabiendas.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcxix{Dios les ha preparado un castigo severo por el mal que cometieron.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcxx{Se escudan en sus falsos juramentos para engañar a la gente, apartándola del sendero de Dios, y por eso recibirán un castigo humillante.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcxxi{Ni sus riquezas ni sus hijos les serán de beneficio alguno ante Dios. Ellos serán los moradores del Infierno, donde sufrirán por toda la eternidad.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcxxii{El día que Dios los resucite a todos, Le jurarán como les juraban a ustedes, creyendo que les servirá de algo. ¿Acaso no son ellos los que mienten?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcxxiii{El demonio los sedujo y los hizo olvidar que recordaran a Dios. Esos son los partidarios del demonio. ¿Acaso no son secuaces del demonio los perdedores?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcxxiv{Quienes se enfrenten a Dios y a Su Mensajero serán los más viles.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcxxv{Dios ha decretado: ``Mis Mensajeros y Yo venceremos". Dios es Fortísimo, Poderoso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcxxvi{No encontrarás ningún pueblo que crea en Dios y en el Día del Juicio que sienta afecto por quienes combaten a Dios y a Su Mensajero, aunque estos sean sus padres, sus hijos, sus hermanos o sus parientes. A ellos [Dios] les ha grabado la fe en sus corazones, los ha fortalecido con Su luz y los ingresará en jardines por donde corren ríos por toda la eternidad. Dios se complace de ellos y ellos de Él. Estos son los aliados de Dios. ¿Acaso no son los aliados de Dios los triunfadores?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcxxvii{\basmalahes Todo lo que hay en los cielos y en la Tierra glorifica a Dios. Él es el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcxxviii{Él es Quien hizo que los que se negaron a creer de la Gente del Libro abandonaran sus hogares en el primer destierro. Ustedes no creían que ellos saldrían, y ellos pensaban que sus fortalezas los protegerían de Dios. Pero Dios los sorprendió de donde menos lo esperaban. Infundió terror en sus corazones, y comenzaron a destruir sus casas con sus propias manos y con las manos de los creyentes. Reflexionen sobre ello, ¡oh, gente que razona!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcxxix{Si Dios no hubiera decretado su destierro, los habría castigado en la vida mundanal. En la otra vida, no obstante, sufrirán el castigo del Infierno\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcxxx{por haberse enfrentado a Dios y a Su Mensajero. Quien se enfrente a Dios debe saber que Dios es severo en el castigo.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcxxxi{[Oh, musulmanes, no sientan pesar,] porque tanto si talaban una palmera o la dejaban en pie, era con el permiso de Dios, con el fin de doblegar a los corruptos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcxxxii{Ustedes no tuvieron la necesidad de emplear caballos ni camellos para contribuir a lo que Dios concedió a Su Mensajero como botín, porque Dios concede a Sus Mensajeros predominio sobre quien quiere. Dios tiene poder sobre todas las cosas.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxxxiii{Lo que Dios concedió de la gente de las aldeas a Su Mensajero pertenece a Dios, al Mensajero, a sus parientes, a los huérfanos, a los pobres y al viajero insolvente, para que la riqueza no sea un privilegio solo de los ricos. Lo que les ha transmitido el Mensajero tómenlo, y cuanto les haya prohibido déjenlo. Tengan temor de Dios, porque Dios es severo en el castigo.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxxxiv{[También le corresponde una parte de dicho botín] a los emigrados pobres que fueron expulsados de sus hogares y despojados de sus bienes cuando buscaban la gracia de Dios y Su complacencia, y apoyaron a Dios y a Su Mensajero. Ellos son los sinceros.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxxxv{Quienes estaban establecidos y aceptaron la fe antes de su llegada, aman a los que emigraron, no sienten envidia alguna en sus corazones por lo que se les ha dado y los prefieren a sí mismos aunque estén en extrema necesidad. Quienes hayan sido preservados de la avaricia serán los triunfadores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxxxvi{Quienes vienen después de ellos imploran: ``¡Oh Señor nuestro! Perdónanos, a nosotros y a nuestros hermanos que nos han precedido en la fe. No infundas en nuestros corazones rencor hacia los creyentes ¡Señor nuestro!, Tú eres Compasivo, Misericordioso".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxxxvii{¿Acaso no observas cuando los hipócritas dicen a sus hermanos de la Gente del Libro que se negaron a creer: ``Si son expulsados, saldremos con ustedes, y jamás obedeceremos a nadie que los quiera dañar. Y si los combaten, los socorreremos"? Dios es testigo de que mienten.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcxxxviii{Si son expulsados, no se irán con ellos. Si son combatidos, no los socorrerán. Y aun si los socorrieran huirían del combate, y de nada les serviría su ayuda.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcxxxix{Ellos les temen más a ustedes en su corazón que a Dios, porque son un pueblo que no comprende [la grandeza de Dios].\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcxl{No combatirán unidos contra ustedes, salvo en aldeas fortificadas o detrás de murallas. Entre ellos hay una fuerte hostilidad. Ustedes piensan que ellos son unidos, pero sus corazones están divididos. Es porque que son gente que no razona.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcxli{Son como sus más cercanos precursores, que sufrieron las consecuencias de su conducta y por ello recibirán un castigo doloroso.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcxlii{Como el demonio cuando le dice al hombre: ``¡Niega la verdad!" Pero cuando este le obedece, dice: ``Yo no soy responsable de ti, yo temo a Dios, Señor del universo".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcxliii{El final de ambos será el Infierno donde sufrirán eternamente. Este es el final de los injustos.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcxliv{¡Oh, creyentes! Tengan temor de Dios, y que cada alma considere cuánto ha obrado para el mañana. Tengan temor de Dios, porque Dios está bien informado de cuanto hacen.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcxlv{No sean como quienes se olvidaron de Dios, y Dios hizo que se olvidaran de sí mismos. Esos son los perversos.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcxlvi{No se equiparan los compañeros del Infierno con los compañeros del Paraíso. Los compañeros del Paraíso son los que triunfan.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcxlvii{Si hubiera hecho descender este Corán sobre una montaña, la habrías visto temblar y derrumbarse por temor a Dios. Así exponemos a la gente los ejemplos para que reflexionen.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcxlviii{Él es Al-lah, no hay otra divinidad salvo Él, el Conocedor de lo oculto y de lo manifiesto. Él es el Compasivo, el Misericordioso.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcxlix{Él es Al-lah, no hay otra divinidad salvo Él, el Soberano Supremo, el Santísimo, el Salvador, el Dispensador de seguridad, el Custodio [de la fe], el Todopoderoso, el Dominador y el Soberbio. ¡Glorificado sea Dios! Está por encima de las divinidades que Le asocian.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcl{Él es Al-lah, el Creador, el Iniciador y el Formador. Suyos son los nombres más sublimes. Todo cuanto existe en los cielos y en la Tierra Lo glorifica. Él es el Poderoso, el Sabio.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcli{\basmalahes ¡Creyentes! Si el abandono de sus hogares [en La Meca] fue sincero por Mi causa y para obtener Mi complacencia, no tomen por confidentes a quienes demuestran ser Mis enemigos, y enemigos suyos, revelándoles secretos [de Estado] como muestra de afecto hacia ellos; porque ellos han negado abiertamente la verdad revelada, han expulsado al Mensajero y los han expulsado a ustedes [de La Meca y de sus hogares], simplemente por haber creído en Dios, su Señor. ¿Cómo pueden confiarles secretos por afecto? Yo bien sé lo que ocultan y lo que manifiestan. Quien obre así se habrá extraviado del camino correcto.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclii{Si ellos tuvieran dominio sobre ustedes, les mostrarían su verdadera enemistad maltratándolos física y verbalmente. Ellos querrían que ustedes dejaran de creer [en el Islam].\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcliii{En nada los beneficiarán sus lazos familiares ni sus hijos, el Día de la Resurrección Dios juzgará entre ustedes. Dios sabe cuanto hacen.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcliv{Tienen un buen ejemplo en Abraham y sus seguidores, cuando dijeron a su pueblo: ``Nosotros somos inocentes de ustedes y de cuanto adoran en lugar de Dios. Negamos que haya verdad en lo que ustedes creen, y comenzará la animadversión y el desacuerdo [en temas de creencia] hasta que no acepten que solamente Dios merece ser adorado". Pero no hagan como Abraham, cuando le dijo a su padre: ``Pediré perdón por ti, pero no puedo hacer nada por ti ante Dios". [Abraham oraba diciendo:] ``¡Oh, Señor nuestro! A Ti nos encomendamos, a Ti pedimos perdón y a Ti volveremos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclv{¡Señor nuestro! No permitas que los que se han negado a creer nos persigan, ni hagas de nosotros una causa por la cual se alejen [del Islam]. Perdónanos, ¡oh, Señor nuestro! Tú eres el Poderoso, el Sabio".\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclvi{En ellos tienen un bello ejemplo quienes anhelan el encuentro con Dios y la recompensa el Día del Juicio. Pero quien se aparte, sepa que Él es el Opulento, el Loable.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclvii{Es posible que Dios haga surgir afecto mutuo entre ustedes y los que ahora son sus enemigos. Dios tiene poder para hacerlo, porque es Perdonador, Misericordioso.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclviii{Dios no les prohíbe hacer el bien y tratar con justicia a quienes no los han combatido por causa de la religión ni los han expulsado de sus hogares, porque Dios ama a los que actúan con justicia.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclix{Dios solo les prohíbe que tomen por aliados a quienes los combaten a causa de la religión y los han expulsado de sus hogares o han contribuido a su expulsión. Sepan que quienes los tomen como aliados estarán cometiendo una injusticia.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclx{¡Oh, creyentes! Cuando mujeres creyentes lleguen como emigrantes, comprueben su fe. Dios conoce su fe. Si corroboran que son creyentes, entonces no las devuelvan a los que se negaron a creer. Ellas no son lícitas para ellos ni ellos lo son para ellas. Devuelvan a sus exmaridos la dote que ellos les hayan dado, y sepan que no hay nada reprochable en que los creyentes se casen con ellas, siempre que les concedan la dote correspondiente. No deben ustedes, por su parte, retener a las mujeres que se niegan a creer, pero pueden exigir que se les devuelva lo que hayan dado como dote, como ellos también tienen derecho a exigirla. Esa es la ley de Dios que prescribió para ustedes. Dios es Sapiente, Sabio.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxi{A aquellos cuyas esposas se hayan ido con los que se negaron a creer y los perjudiquen, denles una compensación acorde a lo que gastaron. Tengan temor de Dios, en Quien ustedes creen.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxii{¡Oh, Profeta! Cuando las mujeres creyentes se presenten ante ti para prestarte juramento de fidelidad, comprometiéndose a no cometer idolatría, no robar, no cometer fornicación ni adulterio, no matar a sus hijos, no decir ninguna calumnia y a no desobedecerte, tómales el juramento de fidelidad y pide perdón a Dios por ellas. Dios es Absolvedor, Misericordioso.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmclxiii{¡Creyentes! No tomen por aliados a quienes han caído en la ira de Dios, pues habrán perdido toda esperanza en la recompensa de la otra vida, como ocurre también con los que niegan la resurrección de los muertos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmclxiv{\basmalahes Todo cuanto existe en los cielos y en la Tierra glorifica a Dios. Él es el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclxv{¡Creyentes! ¿Por qué dicen una cosa pero hacen otra?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmclxvi{Es aborrecible ante Dios que sus actos no sean coherentes con sus palabras.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmclxvii{Dios ama a quienes luchan por Su causa en filas ordenadas, como si fueran una edificación sólida.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclxviii{[Recuerden] cuando Moisés dijo a su pueblo: ``¡Pueblo mío! ¿Por qué me maltratan a pesar de saber que soy el Mensajero que Dios les ha enviado?" Cuando [su pueblo] se alejó [del Mensaje], Dios desvió sus corazones [alejándolos de la guía]. Dios no guía a los perversos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclxix{Y cuando Jesús, hijo de María, dijo: ``¡Oh, hijos de Israel! Yo soy el Mensajero que Dios les ha enviado para corroborar la Tora y anunciar a un Mensajero que vendrá después de mí llamado Ajmad". Pero cuando les mostró los milagros, dijeron [con incredulidad manifiesta]: ``¡Esto es pura hechicería!"\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclxx{¿Existe alguien más injusto que quien inventa mentiras acerca de Dios cuando es invitado al Islam? Dios no guía a los injustos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclxxi{Pretenden extinguir la luz [del Mensaje] de Dios con las mentiras que pronuncian sus bocas, pero Dios hará que Su luz resplandezca, aunque esto desagrade a los que rechazan el Mensaje.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclxxii{Él es Quien ha enviado a Su Mensajero con la Guía y la religión verdadera para que prevalezca sobre todas las religiones, aunque ello disguste a los idólatras.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclxxiii{¡Creyentes! ¿Quieren que les enseñe un negocio que los salvará del castigo doloroso?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxxiv{[Este buen negocio es que] crean en Dios y en Su Mensajero, contribuyan por la causa de Dios con sus bienes y sus seres, pues ello es lo mejor para ustedes. ¡Si supieran!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxxv{[Si hacen esto, Dios] perdonará sus pecados y los ingresará en jardines por donde corren ríos, donde habitarán en hermosas moradas en los jardines del Edén. ¡Ese es, sin duda, el éxito grandioso!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmclxxvi{También les dará algo que aman: ``Su auxilio y una pronta victoria". Albricia a los creyentes [con la recompensa que recibirán en esta vida y en la otra].\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmclxxvii{¡Creyentes! Socorran [la religión de] Dios como lo hicieron los discípulos de Jesús, el hijo de María, cuando les dijo: ``¿Quiénes me socorrerán en la causa de Dios?" Los discípulos respondieron: ``Seremos los socorredores de [la religión de] Dios". Pero un grupo de los Hijos de Israel creyó [en la profecía de Jesús] y otro grupo rechazó su Mensaje. Entonces di Mi apoyo a los creyentes y así vencieron a sus enemigos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmclxxviii{\basmalahes Todo cuanto existe en los cielos y en la Tierra glorifica a Dios, el Soberano Supremo, el Santísimo, el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclxxix{Es Él Quien eligió de entre los que no sabían leer ni escribir un Mensajero para que les recite Sus preceptos, los purifique y les enseñe el Libro y la sabiduría; antes de ello se encontraban en un extravío evidente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmclxxx{Y [para que Su Mensaje se extienda] a otros que todavía no han llegado. Dios es el Poderoso, el Sabio.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmclxxxi{Este es un favor que Dios concede a quien quiere, porque Dios es el poseedor del favor inmenso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclxxxii{Aquellos a quienes les fue confiada la Tora, pero no practicaron [sus principios], se asemejan al asno que lleva una carga de libros. ¡Qué pésimo es el ejemplo de aquellos que desmienten las enseñanzas de Dios! Dios no guía a los injustos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclxxxiii{Diles: ``¡judíos! Si realmente son los elegidos de Dios y las otras personas no lo son, como pretenden, entonces deseen la muerte, si es que son sinceros".\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclxxxiv{Pero nunca la desearán, por los pecados que cometieron sus manos. Y Dios conoce bien quiénes son injustos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclxxxv{Diles: ``La muerte de la que huyen los alcanzará de igual forma. Luego tendrán que comparecer ante el Conocedor de lo oculto y de lo manifiesto, y Él les informará lo que hacían".\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclxxxvi{¡Creyentes! Cuando sea realizado el llamado a la oración del día viernes, acudan al recuerdo de Dios y abandonen el comercio, es lo mejor para ustedes. ¡Si supieran!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclxxxvii{Cuando haya terminado la oración recorran la tierra, procuren el sustento y recuerden mucho a Dios, que así triunfarán.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxxxviii{Pero a aquellos que si ven un negocio o una diversión corren hacia ello y te dejan [solo] de pie, diles: ``La recompensa que Dios tiene reservada [para los piadosos] es mejor que cualquier diversión o negocio, y [sepan que] Dios es el mejor de los sustentadores".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxxxix{\basmalahes Cuando los hipócritas se presentan ante ti [oh, Mujámmad], dicen: ``Atestiguamos que eres el Mensajero de Dios". Dios bien sabe que eres el Mensajero, pero Él mismo atestigua que los hipócritas son mentirosos.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcxc{[Los hipócritas] se escudan en sus juramentos para apartar [a algunas personas] del sendero de Dios. ¡Qué pésimo es lo que hacen!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcxci{Ello es porque creyeron y luego renegaron, entonces sus corazones fueron sellados y ya no pueden discernir.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcxcii{Cuando los observas te agrada su aspecto, y cuando hablan prestas atención a sus palabras, pues parecen maderos bien afirmados; pero cada vez que se alza la voz se sobresaltan, porque creen que es contra ellos. Ellos son el enemigo, sé precavido con ellos. Dios los destruirá por haberse desviado tanto.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcxciii{Cuando se les dice: ``Vengan, que el Mensajero de Dios pedirá perdón por ustedes", mueven su cabeza [en señal de burla] y los ves evadirte con soberbia.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcxciv{[Oh, Mujámmad!] Lo mismo da que pidas perdón por ellos o que no lo hagas, Dios no los perdonará. Dios no guía a la gente corrupta.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxcv{Ellos dicen: ``No ayuden a los que están con el Mensajero de Dios hasta que lo abandonen". Es a Dios a quien pertenecen los tesoros de los cielos y de la Tierra, pero los hipócritas no lo comprenden.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxcvi{Dicen: ``Si regresamos a la ciudad [de Medina], los más poderosos expulsaremos de ella a los más débiles". Pero el verdadero poder pertenece a Dios, a Su Mensajero y a los creyentes, aunque los hipócritas no lo saben.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxcvii{¡Creyentes! Que las posesiones materiales y los hijos no los distraigan del recuerdo de Dios. Pues quienes se alejen del recuerdo de Dios serán los perdedores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxcviii{Den en caridad parte de lo que les he provisto, antes de que la muerte les sobrevenga y [recién] entonces digan: ``¡Señor mío! Concédeme un poco más de tiempo para poder hacer caridades y ser de los piadosos".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxcix{Pues Dios no retrasará el momento fijado para cada alma cuando este llegue, y [sepan que] Dios está bien informado de cuanto hacen.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcc{\basmalahes Todo cuanto existe en los cielos y en la Tierra glorifica a Dios. Suyo es el reino y Suyas son las alabanzas. Él tiene poder sobre todas las cosas.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcci{Él es Quien los ha creado. Entre ustedes hay quienes rechazan el Mensaje y quienes creen en él. Dios sabe bien cuanto hacen.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccii{Dios creó los cielos y la Tierra con un fin justo y verdadero, y les dio una conformación armoniosa. Ante Él comparecerán para responder por sus obras.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcciii{Dios conoce cuanto existe en los cielos y en la Tierra, conoce lo que ocultan y lo que manifiestan. Dios sabe bien lo que esconden los corazones.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcciv{¿Acaso no les fue relatada la historia de los pueblos de la antigüedad que rechazaron el Mensaje? Sufrieron las consecuencias de su conducta y les espera un castigo doloroso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccv{Los Mensajeros se presentaban ante ellos con las evidencias, pero decían: ``¿Acaso un mortal [igual que nosotros] nos ha de guiar?" Y así se negaron a creer, y se apartaron [de la Verdad]. Pero Dios no necesita de ellos, Él es Autosuficiente, Loable.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccvi{Los que rechazan el Mensaje alegan que no serán resucitados. Diles: ``¡[Juro] por mi Señor que sí! Serán resucitados, y luego se les informará de cuanto hicieron. Sepan que eso es fácil para Dios".\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccvii{Crean en Dios, en Su Mensajero y en la Luz que ha revelado [el Corán]. Dios está bien informado de cuanto hacen.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccviii{Cuando sean congregados para el día de la reunión, ese será el día del desengaño [para los incrédulos]. A quien crea en Dios y haya obrado correctamente, Él le perdonará sus faltas y lo introducirá en jardines por donde corren ríos, donde vivirá eternamente. ¡Ese es el triunfo grandioso!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccix{En cambio, los que rechazaron el Mensaje y desmintieron Mis signos sufrirán en el fuego del Infierno por toda la eternidad. ¡Qué pésimo destino!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccx{Todas las desgracias acontecen con el permiso de Dios. Quien crea en Dios, Él guiará su corazón [y comprenderá que todo es parte del gran designio de Dios]. Dios tiene conocimiento de todas las cosas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxi{Obedezcan a Dios y obedezcan al Mensajero. Pero si se rehúsan, sepan que Mi Mensajero solo tiene la obligación de transmitir el Mensaje con claridad.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxii{¡Al-lah! No existe divinidad excepto Él. Que los creyentes depositen su confianza en Dios.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmccxiii{¡Creyentes! Sus cónyuges o sus hijos pueden convertirse en sus enemigos. Tengan precaución. Pero si pasan por alto [sus faltas], son tolerantes con ellos y los perdonan, sepan que Dios es Perdonador, Misericordioso.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmccxiv{Sus bienes materiales y sus hijos son una tentación, pero Dios tiene junto a Sí una recompensa grandiosa.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmccxv{Tengan temor de Dios tanto como puedan. Escuchen y obedezcan [la revelación], y hagan caridad, porque es lo mejor para ustedes mismos. Sepan que quienes luchen contra su propia avaricia serán los triunfadores.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmccxvi{Si hacen a Dios un préstamo generoso, Él lo devolverá multiplicado y perdonará sus faltas. Dios es Agradecido, Tolerante,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmccxvii{conoce lo oculto y lo manifiesto, Él es el Poderoso, el Sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmccxviii{\basmalahes ¡Oh, Profeta!, [haz saber a los musulmanes que] cuando divorcien a las mujeres, deben hacerlo durante el tiempo señalado. Calculen con atención los días de ese período, y tengan temor de Dios, su Señor. No las expulsen de sus hogares y que ellas tampoco lo abandonen, a menos que hayan cometido una indecencia evidente. Estas son las leyes de Dios. Quien quebrante las leyes de Dios habrá sido injusto consigo mismo. Tú no sabes si Dios, después de esa [primera ruptura], haga surgir una reconciliación.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxix{Cuando estén por finalizar su período de espera, pueden reconciliarse de forma justa o divorciarse definitivamente en términos justos. Háganlo ante dos testigos neutrales de entre ustedes, y cumplan con su testimonio por Dios. Al cumplimiento de estas leyes es que se exhorta a quien cree en Dios y en el Día del Juicio. Sepan que a quien tenga temor de Dios, Él le dará una solución,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxx{y le dará sustento de donde no lo esperaba. Quien deposite su confianza en Dios, sepa que Él le será suficiente. Dios hará que el designio se cumpla, y ha establecido para cada cosa un término y una medida.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxxi{El período de espera para aquellas mujeres que hayan llegado a la menopausia, si tienen dudas [sobre el término del periodo], o aquellas que no menstrúan, es de tres meses. En cambio, el de las embarazadas finalizará cuando den a luz. Sepan que a quien tenga temor de Dios, Él le facilitará sus asuntos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxxii{Estas son las leyes que Dios ha prescrito. A quien tenga temor de Dios, Él le perdonará sus malas obras y le aumentará su recompensa.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxxiii{Denle a la mujer durante ese periodo el mismo nivel de vida que ustedes tienen conforme a sus posibilidades. No la perjudiquen con ánimo de molestarla. Si ella está embarazada, deben mantenerla hasta que dé a luz, y si ambos acuerdan que ella amamante a su hijo, deben mantenerla [hasta que termine la lactancia]. Tengan buen trato y lleguen a un acuerdo de buena manera. Pero si discrepan [sobre la lactancia del hijo], entonces que otra mujer lo amamante [por cuenta del padre].\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxxiv{Que el adinerado mantenga de acuerdo a su abundancia, pero aquel cuyo sustento es escaso que lo haga acorde a lo que Dios le ha provisto. Dios no exige a nadie por encima de sus posibilidades. Dios hará que luego de toda estrechez venga la prosperidad.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxxv{¡A cuántos pueblos que desobedecieron a su Señor y a Sus Mensajeros los hice rendir cuentas en forma severa y los azoté con un castigo nunca visto!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccxxvi{Ellos sufrieron las consecuencias de sus obras. Su final fue la perdición.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccxxvii{[A ellos] Dios les ha preparado un castigo severo. Tengan temor de Dios, ustedes que reflexionan y son creyentes, ya que Dios ha descendido para ustedes el Corán [para que lo tomen como código de vida],\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccxxviii{y les ha enviado un Mensajero que les recita el claro Mensaje de Dios, para sacar de las tinieblas hacia la luz a quienes crean y obren correctamente. A quien crea en Dios y obre piadosamente, Él lo introducirá en jardines por donde corren ríos, en los que vivirán eternamente. ¡Qué hermoso sustento!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxxix{Dios creó siete cielos y la Tierra de manera similar. A través de ellos desciende Su designio para que sepan que Dios tiene poder sobre todas las cosas y que todo lo abarca en Su conocimiento.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxxx{\basmalahes ¡Oh, Profeta! ¿Por qué te prohíbes a ti mismo lo que Dios te ha hecho lícito, pretendiendo con ello complacer a tus esposas? [Sabe que a pesar de ello] Dios es Absolvedor, Misericordioso.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxxxi{Dios les ha prescrito cómo anular y expiar los juramentos [que no van a cumplir]. Dios es su Protector y Él todo lo sabe, es Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxxxii{Cuando el Profeta confió un secreto a una de sus esposas [Hafsah] y ella lo contó [a Aishah], Dios le reveló [al Profeta] lo ocurrido, y él le refirió [a Hafsah] una parte de lo que ella había hecho. Entonces, esta le preguntó: ``¿Quién te lo ha dicho?" Y Él respondió: ``Me lo ha revelado el que todo lo sabe, Él está bien informado de cuanto hacen Sus siervos".\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxxxiii{Ambas deben arrepentirse, pues sus corazones se han apartado [del respeto debido al Profeta]. Pero si siguen confabuladas [por celos] contra él, sepan que Dios es su Protector, y que lo socorrerán el ángel Gabriel y los creyentes virtuosos, y todos los demás ángeles acudirán en su ayuda.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxxxiv{Sepan que si él las divorcia, su Señor le concederá esposas mejores que ustedes, que sean creyentes, que se sometan y obedezcan a Dios, se arrepientan, sean devotas [a Dios] y ayunen, algunas ya antes casadas o vírgenes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxxxv{¡Oh, creyentes! Protéjanse a sí mismos y a sus familias del Fuego [del Infierno], cuyo combustible serán los seres humanos y las piedras, y en el que habrá ángeles rigurosos y severos que no desobedecen a Dios en lo que Él les ordena, sino que ejecutan Sus órdenes.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxxxvi{[El Día del Juicio se les dirá:] ¡Los que rechazaron el Mensaje! Hoy no pretendan excusarse, simplemente recibirán el merecido por lo que hayan hecho.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxxxvii{¡Creyentes! Arrepiéntanse sinceramente ante Dios, puede que así su Señor borre sus faltas y los introduzca en jardines del Paraíso por donde corren ríos. Ese día Dios no avergonzará al Profeta ni a los que creyeron junto a él. Una luz se extenderá delante de ellos y a su derecha, y ellos dirán: ``¡Señor nuestro! Auméntanos nuestra luz y perdónanos. Tú eres sobre toda cosa poderoso".\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccxxxviii{¡Profeta! Haz frente a los que rechazaron el Mensaje y a los hipócritas, y sé riguroso con ellos. [Si no se arrepienten ante Dios] tendrán el Infierno por morada. ¡Qué pésimo destino!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccxxxix{Para los que rechazaron el Mensaje, Dios les plantea como ejemplos los casos de la mujer de Noé y la de Lot: ambas estaban casadas con dos de Mis siervos justos pero no creyeron y [Noé y Lot] no pudieron hacer nada por ellas ante Dios. Y [el Día del Juicio] se les dirá: ``Entren ambas en el Fuego junto con los demás condenados".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccxl{Y para los creyentes como ejemplo plantea el caso de la mujer del Faraón [que era una verdadera creyente] cuando dijo: ``¡Señor mío! Constrúyeme, junto a Ti, una morada en el Paraíso, y sálvame del Faraón y de sus obras abominables. Sálvame de este pueblo opresor".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxli{Y también el ejemplo de María, hija de ‘Imrán, quien preservó su castidad; infundí en ella de Mi Espíritu. Ella creyó en la veracidad de las Palabras de su Señor y en Sus Libros, y fue realmente una mujer devota.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxlii{\basmalahes Bendito sea Aquel en Cuyas manos está el reino y tiene el poder sobre todas las cosas.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxliii{Él es Quien creó la muerte y la vida para probarlos y distinguir quién obra mejor. Él es el Poderoso, el Perdonador.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxliv{Él es Quien creó siete cielos superpuestos. No verás ninguna imperfección en la creación del Misericordioso. Vuelve la vista y observa, ¿acaso ves alguna falla?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxlv{Luego vuelve la vista por segunda vez [buscando fallas en la creación] y tu mirada volverá a ti cansada y derrotada.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxlvi{Embellecí el cielo de este mundo con astros luminosos, dispuestos para castigar a los demonios, y tengo preparado para ellos un fuego abrasador.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxlvii{Para quienes no creen en su Señor les tengo preparado el castigo del Infierno. ¡Qué pésimo destino!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxlviii{Cuando sean arrojados en el Infierno, oirán su fragor mientras hierve,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxlix{a punto de estallar de furia. Cada vez que un grupo sea arrojado en él, sus guardianes les preguntarán: ``¿Acaso no se les presentó un amonestador?"\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccl{Dirán: ``Sí, se nos presentó un amonestador, pero lo desmentimos diciendo: Dios no ha revelado nada y estás en un gran error".\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccli{Y agregarán: ``Si hubiéramos oído o reflexionado, no estaríamos ahora con los condenados al Fuego".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcclii{Entonces reconocerán sus pecados, pero qué lejos están los condenados al fuego de la misericordia de Dios".\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccliii{[En cambio] quienes fueron temerosos de su Señor en privado [cuando solo Él los observaba] serán perdonados y recibirán una gran recompensa.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccliv{Es lo mismo que oculten sus pensamientos o que los divulguen, Él conoce bien lo que hay dentro de los corazones.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcclv{¿Acaso no lo va a saber Quien todo lo creó? Él es el Sutil, el que está bien informado.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcclvi{Él es Quien les ha facilitado la vida sobre la Tierra. Recorran sus caminos y coman del sustento de Dios, que ante Él comparecerán.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcclvii{¿Acaso tienen garantías de que Quien está en el cielo no hará que la tierra los trague durante un terremoto?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcclviii{¿O se sienten seguros de que Quien está en el cielo no los azote con un viento fuerte? ¿Solo así tomarán en serio Mi advertencia?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcclix{Otros [pueblos] en la antigüedad también desmintieron [a los Mensajeros], y qué terrible fue Mi castigo [en respuesta].\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcclx{¿Acaso no contemplan a las aves en las alturas, desplegando y replegando sus alas? Solo el Misericordioso las sostiene, Él ve todas las cosas.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcclxi{¿Qué ejército los podría defender además del Misericordioso? Los que desmienten el Mensaje son presa de una ilusión.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcclxii{¿Quién los sustentará si Él retiene su sustento? Sin embargo, persisten en su insolencia y su arrogante rechazo.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcclxiii{¿Quién está mejor encaminado: el que camina cabizbajo y tropezando o el que camina erguido por el sendero recto?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcclxiv{Diles: ``Él es Quien los creó y Quien los agració con el oído, la vista y el intelecto. Sin embargo, qué poco agradecen".\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcclxv{Diles: ``Él es Quien hizo que se multiplicaran en la Tierra y ante Él comparecerán".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcclxvi{[Los que desmienten el Mensaje] dicen desafiantes: ``¿Cuándo se cumplirá esta amenaza [sobre el Día del Juicio], si es que dicen la verdad?"\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcclxvii{Diles: ``Solo Dios lo sabe, yo no soy sino un amonestador".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcclxviii{Pero cuando los que desmentían el Mensaje vean que comienza [el Día del Juicio], sus rostros estarán sombríos y se les dirá: ``Aquí tienen lo que pedían".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcclxix{Diles: ``Si Dios me hiciera morir a mí y a los que me siguen, o si se apiadara de nosotros, [eso no es lo que debería preocuparlos, sino que lo que deberían preguntarse es:] ¿quién librará a los que niegan el Mensaje del castigo doloroso que les espera?"\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcclxx{Diles: ``Él es el Misericordioso, creemos en Él y en Él depositamos nuestra confianza. Ya verán [el Día del juicio] quién es el que está en un error evidente".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcclxxi{Pregúntales: ``¿Si el agua que tienen dejara de surgir, quién [fuera de Dios] les podría proveer de agua pura?"\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcclxxii{\basmalahes Nun. Juro por la pluma y por [los conocimientos que con ella] se escriben,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcclxxiii{que tú [Oh, Mujámmad], por la gracia de tu Señor, no eres un loco,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcclxxiv{y tendrás una recompensa ilimitada.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcclxxv{Eres de una naturaleza y moral grandiosas.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcclxxvi{Pronto verás, y ellos también lo verán,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcclxxvii{quién es realmente el insensato.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcclxxviii{Tu Señor sabe mejor que nadie quiénes se extravían de Su camino, así como sabe quiénes son los que siguen la guía.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcclxxix{No obedezcas a los que desmienten el Mensaje.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcclxxx{[Los idólatras] desearían que fueras condescendiente con ellos [en sus creencias idolátricas], y así ellos también serían condescendientes contigo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxi{No obedezcas al ser despreciable que jura constantemente [por Dios],\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxii{al difamador que siembra la discordia,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxiii{a quien se niega a hacer el bien, al transgresor, al pecador,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxiv{al arrogante y además falso simulador,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxv{quien solo porque tiene riqueza e hijos\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxvi{rechaza Mis versículos cuando se le recitan, diciendo: ``Son fábulas de los ancestros".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxvii{[Como castigo] le marcaré su nariz.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxviii{[A los que te desmienten] los he puesto a prueba [con la prosperidad], como probé a los dueños del huerto, cuando juraron recoger sus frutos por la mañana\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxix{y no dejar nada a los pobres.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmccxc{Pero un castigo enviado por tu Señor azotó el huerto mientras dormían,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmccxci{dejándolo devastado.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmccxcii{Por la mañana, se despertaron unos a otros.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmccxciii{Dijeron: ``Vayamos temprano a nuestro campo si queremos recoger la cosecha".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmccxciv{Y se pusieron en camino diciéndose unos a otros en voz baja:\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmccxcv{``Hoy no dejaremos entrar a ningún pobre".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmccxcvi{Madrugaron convencidos de que podrían privar a los pobres de su derecho.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmccxcvii{Pero cuando vieron [el huerto devastado] dijeron: ``Seguramente nos hemos equivocado de camino".\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmccxcviii{[Pero al darse cuenta de que sí era su huerto, dijeron:] ``Estamos arruinados".\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmccxcix{Entonces, el más sensato de ellos dijo: ``¿No les había dicho que recordaran?"\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmccc{Dijeron: ``Glorificado sea nuestro Señor, fuimos injustos".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmccci{Y comenzaron a recriminarse unos a otros.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcccii{Dijeron: ``¡Ay de nosotros! Nos comportamos con mucha arrogancia.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmccciii{Puede que nuestro Señor nos conceda algo mejor, regresemos a nuestro Señor con esperanza".\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmccciv{Ese fue su castigo, pero el castigo de la otra vida será aún mayor. ¡Si lo supieran!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmcccv{El Señor agraciará a los piadosos con los Jardines de las Delicias.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmcccvi{¿Acaso iba a tratar por igual a quienes se someten a Dios y a los pecadores?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmcccvii{¿Qué les pasa? ¿Cómo juzgan así?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmcccviii{¿Acaso tienen un libro [revelado] al que consultan,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmcccix{en el que eligen lo que les conviene?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmcccx{¿O creen tener Conmigo un pacto hasta el Día de la Resurrección que Me obligue a concederles lo que quieran?\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmcccxi{Pregúntales: ``¿Quién es el garante de ese pacto?"\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmcccxii{¿Acaso tienen ídolos [que se lo garantizan]? ¡Traigan a sus ídolos, si es verdad lo que dicen!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmcccxiii{El día que se descubra la pierna [divina], manifestándose la gravedad de la situación] y sean invitados a prosternarse, pero no podrán,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmcccxiv{tendrán la mirada abatida, porque fueron invitados a prosternarse cuando podían [pero no lo hicieron].\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmcccxv{Yo me encargaré de quienes desmienten el Mensaje. Los castigaré sin prisa cuando menos lo esperen.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmcccxvi{Los toleraré por un tiempo, pero luego Mi castigo será severo.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmcccxvii{¿Acaso les reclamas una retribución [a cambio de transmitirles el Mensaje], que se sienten agobiados?\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmcccxviii{¿Acaso conocen lo oculto [de la predestinación] y lo escriben?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmcccxix{Ten paciencia ante el designio de tu Señor y no seas como el que fue tragado por la ballena, que Me imploró angustiado.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmcccxx{Si no hubiera sido por la gracia de su Señor, habría sido arrojado a la playa desierta cargando su culpa.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmcccxxi{Pero su Señor lo había escogido para que fuera uno de los piadosos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmcccxxii{[Oh, Mujámmad:] Poco faltó para que los que rechazaron el Mensaje te derribaran con sus miradas [de odio] cuando oyeron la recitación del Corán. Y aunque digan: ``Es un loco",\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmcccxxiii{[lo que recitas] es un Mensaje para que siga toda la humanidad.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmcccxxiv{\basmalahes La exposición de la verdad.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcccxxv{¿Qué es la exposición de la verdad?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcccxxvi{¿Qué te hará comprender lo que es la exposición de la verdad?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcccxxvii{[Los pueblos de] Zamud y ‘Ad desmintieron el evento repentino.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcccxxviii{Zamud fue destruido por una catástrofe.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcccxxix{Y ‘Ad fue aniquilado por un viento gélido\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcccxxx{que los azotó durante siete noches y ocho días ininterrumpidamente. La gente quedó tendida, sin vida, como troncos huecos de palmeras derribadas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxi{¿Acaso ves ahora algún rastro de ellos?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxii{El Faraón, otros pueblos de la antigüedad y los que fueron elevados con sus casas y arrojados al revés, cometieron los pecados más graves,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxiii{desobedecieron al Mensajero que les había enviado su Señor, y por eso Dios los sorprendió con un castigo severo.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxiv{Cuando las aguas lo inundaron todo, salvé en el arca a Noé y a quienes creyeron en él,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxv{para que sea un motivo de reflexión y para que todo oído atento escuche su historia.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxvi{Cuando la trompeta sea soplada una primera vez\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxvii{y la tierra y las montañas sean elevadas y choquen unas contra otras,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxviii{entonces ocurrirá el suceso.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxix{Ese día el cielo se quebrantará en su fragilidad.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcccxl{Los ángeles estarán en sus confines, y ocho serán los que portarán el Trono de tu Señor ese día.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcccxli{Ese día ustedes comparecerán [ante Dios], y ni la más secreta de sus obras quedará oculta.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcccxlii{Quien reciba el libro de sus obras con la mano derecha dirá [a los demás con felicidad]: ``Miren y vean mi libro,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcccxliii{yo sabía que iba a ser juzgado [algún día]".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcccxliv{Tendrá una vida placentera\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcccxlv{en un jardín elevado,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcccxlvi{cuyos frutos estarán al alcance de la mano.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcccxlvii{[Se les dirá:] ``Coman y beban con alegría en recompensa por lo que obraron en los días pasados".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcccxlviii{En cambio, quien reciba el registro de sus obras en la mano izquierda, se dirá a sí mismo: ``Ojalá no se me hubiera entregado mi libro\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcccxlix{ni se me hubiese juzgado.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcccl{Ojalá mi muerte hubiera sido definitiva [y no me hubieran resucitado].\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcccli{De nada me sirve ahora el dinero que tuve.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmccclii{Mi influencia ha desaparecido".\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcccliii{[Dios dirá a los ángeles:] ``Aprésenlo y encadénenlo.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcccliv{Introdúzcanlo en el fuego del Infierno,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmccclv{sujétenlo con una cadena de setenta codos,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmccclvi{porque no creía en Dios, el Grandioso,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmccclvii{ni alentaba a alimentar al pobre.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmccclviii{Hoy no tiene aquí amigo que pueda interceder por él.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmccclix{No tendrá más comida que pus,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmccclx{que solo comerán los pecadores".\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmccclxi{Juro por lo que ven\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmccclxii{y por lo que no puede verse,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmccclxiii{que el Corán es la palabra recitada por un Mensajero noble.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmccclxiv{No es la palabra de un poeta. ¡Qué poco creen!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmccclxv{Ni tampoco la palabra de un adivino. ¡Qué poco reflexionan!\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmccclxvi{Es una revelación que dimana del Señor del universo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmccclxvii{Si [el Profeta] hubiera atribuido algo falsamente a Mi Mensaje,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmccclxviii{lo habría apresado severamente,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmccclxix{luego le habría cortado la arteria vital,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmccclxx{y nadie habría podido impedirlo.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmccclxxi{El Corán es un motivo de reflexión para los que tienen temor de Dios,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmccclxxii{y bien sé que hay entre ustedes quienes desmienten,\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmccclxxiii{pero eso será motivo de pesar para los que rechazan el Mensaje.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmccclxxiv{El Corán es la verdad indubitable.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmccclxxv{¡Glorifica el nombre de tu Señor, el Grandioso!\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmccclxxvi{\basmalahes Alguien pide que se desencadene el castigo prometido\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccclxxvii{para que caiga sobre los que niegan el Mensaje. Cuando ocurra, nadie podrá impedirlo,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccclxxviii{pues procede de Dios, Señor de las vías de ascensión,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccclxxix{por las que ascienden hacia Él los ángeles y las almas; un día que durará cincuenta mil años.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccclxxx{Persevera con profunda paciencia,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxi{porque ellos lo ven lejano [al Día del Juicio],\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxii{pero Yo sé que está cercano.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxiii{El día que el cielo parezca masas de minerales fundidos\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxiv{y las montañas copos de lana,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxv{y nadie pregunte por sus seres amados\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxvi{a pesar de reconocerlos. El pecador querrá salvarse del castigo de ese día ofreciendo como rescate incluso a sus propios hijos,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxvii{a su esposa, a su hermano,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxviii{a sus parientes en quienes se apoyaba,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxix{y a todos los habitantes de la Tierra con tal de salvarse.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcccxc{Pero no le servirá, su castigo será el fuego del Infierno\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcccxci{que le arrancará sus extremidades,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcccxcii{y convocará a quien le dio la espalda y se apartó del Mensaje,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcccxciii{y acumuló bienes materiales con avaricia.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcccxciv{El hombre fue creado impaciente:\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcccxcv{se desespera cuando sufre un mal\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcccxcvi{y se torna mezquino cuando la fortuna lo favorece,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcccxcvii{salvo los orantes devotos\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcccxcviii{que son perseverantes en la oración,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcccxcix{que de su dinero destinan un derecho establecido\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcd{para el que pide ayuda y para el indigente honesto;\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdi{que creen en el Día del Juicio Final,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdii{que tienen temor del castigo de su Señor,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdiii{siendo que nadie está a salvo del castigo de su Señor.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdiv{Los que preservan su sexualidad\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcdv{al ámbito conyugal o lo que posee la diestra, ya que eso no es censurable.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcdvi{Quien traspase este límite, sepa que es un trasgresor.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmcdvii{Y los que devuelven los depósitos que se les confían y respetan los acuerdos que celebran,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmcdviii{que son veraces en sus testimonios\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmcdix{y que cumplen con las oraciones prescritas,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmcdx{estos serán honrados con jardines del Paraíso.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmcdxi{¿Qué les sucede a los que rechazan el Mensaje, que se dirigen hacia ti presurosos\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmcdxii{en grupos, por la derecha y por la izquierda?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmcdxiii{¿Acaso anhelan ser introducidos en los Jardines de las Delicias?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmcdxiv{No lo conseguirán. Los he creado de lo que saben.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmcdxv{¡Pues no! Juro por el Señor de los diferentes levantes y ponientes del Sol que tengo poder\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmcdxvi{para sustituirlos por otros seres mejores que ellos, sin que nadie pueda impedírmelo.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmcdxvii{Déjalos que discutan y jueguen hasta que les llegue el día con que se les ha advertido.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmcdxviii{El día que salgan de las tumbas, presurosos como si corrieran hacia una meta,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmcdxix{con su mirada abatida, cubiertos de humillación. Ese es el día que se les ha advertido.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmcdxx{\basmalahes Envié a Noé a su pueblo [diciéndole]: ``Advierte a tu pueblo antes de que le llegue un castigo doloroso".\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxxi{Dijo [Noé]: ``¡Pueblo mío! Soy un amonestador que Dios les ha enviado para que les hable con claridad,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdxxii{así que adoren y tengan temor de Dios, y obedezcan lo que les indique,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdxxiii{porque si lo hacen Dios perdonará sus pecados y les concederá vivir hasta el plazo prefijado. Pero sepan que cuando el plazo fijado por Dios los alcance, no podrá ser retrasado. ¡Si tan solo supieran!"\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdxxiv{Dijo Noé: ``¡Señor mío! He exhortado a mi pueblo noche y día,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdxxv{pero mi exhortación solo ha servido para que se aparten aún más [de Ti].\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdxxvi{Cada vez que les invité a la guía recta para que Tú los perdonaras, se pusieron los dedos en los oídos, se cubrieron [los ojos] con la ropa, se obstinaron y actuaron con soberbia.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdxxvii{Además, los llamé abiertamente\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdxxviii{y les hablé en público y en privado.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdxxix{Y les dije: ‘Pidan perdón a su Señor, porque Él es Indulgente,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdxxx{así les enviará del cielo bendiciones en abundancia,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxi{y les concederá numerosas propiedades y muchos hijos, como también les concederá jardines y ríos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxii{¿Qué les sucede que no temen la grandeza de Dios?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxiii{Siendo que Él los creó en etapas sucesivas.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxiv{¿Acaso no han visto cómo Dios ha creado siete cielos superpuestos?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxv{Puso en ellos la Luna para que refleje la luz y el Sol [para que la irradie] como lámpara.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxvi{Dios los ha creado de la misma tierra que a las plantas, y como a las plantas los ha hecho brotar de ella.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxvii{Después los hará volver a ella [al morir], y de ella nuevamente los hará resurgir [el Día del Juicio Final].\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxviii{Dios les ha extendido la Tierra\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxix{para que la recorran por sus extensos caminos’".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdxl{Dijo Noé: ``¡Señor mío! Ellos me han desobedecido y han seguido a aquellos a los que tener bienes materiales e hijos [los ha vuelto soberbios y] se han desviado aún más,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcdxli{[sus líderes] conspiraron contra mí un terrible ardid.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcdxlii{Y les dijeron: ‘No abandonen a nuestros ídolos. No abandonen ni a Uadd, ni a Suá’, ni a Iagúz, ni a Ia‘úq ni a Nasr’.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcdxliii{¡Señor mío! Estos [líderes] han extraviado a muchos. ¡Haz que los opresores e injustos se extravíen cada vez más lejos!’"\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcdxliv{A causa de sus pecados murieron ahogados [por el diluvio] y luego [el Día del Juicio] irán al Fuego, ya que encontrarán [que sus ídolos y poderosos] no podrán defenderlos de Dios.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdxlv{Dijo Noé: ``¡Señor mío! No dejes subsistir sobre esta tierra a quienes niegan la verdad.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdxlvi{Porque si los dejas, intentarán por todos los medios extraviar a Tus siervos y no enseñarán a sus hijos sino el pecado y la negación de la verdad.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdxlvii{¡Señor mío! Perdóname y perdona a mis padres, a todo aquel que ingrese a mi casa como creyente, y a todos los hombres y mujeres que crean en Ti. Pero a los injustos opresores, acreciéntales su perdición".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdxlviii{\basmalahes [¡Oh, Mujámmad!] Di: ``Me ha sido revelado que un grupo de yinnes dijeron al escuchar [la recitación del Corán]: ‘Hemos oído una recitación maravillosa\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxlix{que guía al sendero recto. Creemos en la recitación y no caeremos en la idolatría adorando a otro que Dios.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdl{Él, exaltada sea Su grandeza, no ha tomado compañera ni hijo.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdli{No obstante, un malvado entre nosotros decía falsedades acerca de Dios.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdlii{Nosotros creíamos que ni los seres humanos ni los yinnes dirían mentiras acerca de Dios,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdliii{pero había seres humanos que solicitaban protección a los yinnes, siendo que ellos solo acrecentaban su desvío.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdliv{Ellos pensaban, como piensan ustedes, que Dios no iba a resucitar a nadie [de su tumba].\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdlv{Quisimos acceder al cosmos pero lo encontramos lleno de guardianes severos y meteoritos\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdlvi{a pesar que buscábamos posiciones apropiadas del cosmos para escuchar [la revelación], pero todo aquel que intenta ahora escuchar encuentra un meteoro que le acecha.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdlvii{Y [ahora sabemos que los seres creados] no podemos saber si se ha destinado algún mal para quienes están en la Tierra o si su Señor quiere guiarlos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdlviii{Entre nosotros hay quienes son virtuosos [creyentes] y quienes no lo son. Seguimos caminos diferentes.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdlix{Sabemos que no podremos escapar de Dios en la Tierra ni huir de Él.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdlx{Pero cuando oímos la guía creímos, pues quien cree en su Señor no tendrá que temer que le mermen sus méritos ni que lo inculpen injustamente.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdlxi{Entre nosotros [los yinnes] hay quienes aceptaron el Islam, pero también hay quienes se apartaron del sendero recto. Los que aceptaron el Islam son los que siguen la guía verdadera.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdlxii{Los que rechazaron el sendero recto, en cambio, serán combustible para el Infierno’".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdlxiii{Pero si hubieran seguido el sendero recto les habría dado de beber de la abundancia,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdlxiv{para probarlos con ella. Porque quien se aparte del recuerdo de su Señor recibirá un castigo penoso.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdlxv{Los lugares de culto son para adorar solo a Dios, por lo que no deben invocar a nada ni a nadie junto con Dios.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdlxvi{Cuando el siervo de Dios [el Profeta Mujámmad] se levantó para invocarlo, [los yinnes] se agolparon a su alrededor [para oír la recitación].\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdlxvii{Diles [oh, Mujámmad]: ``Solo invoco a mi Señor y no adoro a otro que Dios".\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdlxviii{Diles: ``No tengo poder personal para desviarlos ni para guiarlos por el camino recto".\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcdlxix{Diles: ``Nadie puede protegerme de Dios y no tengo refugio fuera de Él,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcdlxx{solo debo difundir el Mensaje que me ha encargado transmitir". Quien rechace a Dios y a Su Mensajero, sepa que le espera el fuego del Infierno, en el que permanecerá por toda la eternidad.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxi{Y cuando vean lo que se les había prometido sabrán quiénes están realmente desamparados y quiénes son los insignificantes.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxii{Diles: ``No sé si está cerca aquello con que se los ha advertido, o si mi Señor le ha fijado un plazo distante.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxiii{Él es Quien conoce lo oculto y no permite que nadie acceda a él.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxiv{Salvo aquel con quien Él se complace como Mensajero [y le revela asuntos de lo oculto]. Entonces, hace que lo escolten [ángeles] por delante y por detrás\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxv{para cerciorarse que ha transmitido los Mensajes de su Señor. Él tiene completo conocimiento de todo cuanto les sucede y lleva la cuenta exacta de todo".\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxvi{\basmalahes ¡Oh, tú [Mujámmad] que estás arropado!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxvii{Levántate a orar en la noche, salvo una pequeña parte de ella,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxviii{la mitad, o un poco menos,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxix{o un poco más, y recita el Corán claramente y meditando en su significado.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxx{Porque he de transmitirte una revelación de gran peso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxi{Si te levantas a orar en el seno de la noche encontrarás mayor quietud y podrás concentrarte mejor,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxii{pues durante el día tienes muchas ocupaciones.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxiii{Celebra el nombre de tu Señor y conságrate a Él con total devoción.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxiv{Él es el Señor del oriente y del occidente. No hay nada ni nadie con derecho a ser adorado salvo Él. Tómalo como tu protector.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxv{Ten paciencia con lo que dicen [insultándote], pero apártate de ellos discretamente.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxvi{Deja que Yo me ocupe de los que niegan la verdad, los que ahora tienen opulencia. Tenles paciencia brevemente.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxvii{[Porque] dispongo de cadenas y del fuego del Infierno [para castigarlos],\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxviii{de una comida que [por su repugnancia] se atraganta, un castigo doloroso.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxix{El día que la tierra y las montañas convulsionen, y las montañas se conviertan en arena dispersa.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdxc{[¡Oh, gente!] Les he enviado un Mensajero para que dé testimonio de la verdad ante ustedes, tal como antes había enviado un Mensajero al Faraón.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdxci{[Pero] el Faraón desmintió al Mensajero y por eso lo castigué duramente.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdxcii{Si no creen, no podrán librarse del castigo del día terrible [del Juicio], que hará encanecer hasta a los niños.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdxciii{El cosmos se romperá y Su promesa se cumplirá.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdxciv{Esto es una advertencia real; en consecuencia, quien quiera que emprenda un camino hacia su Señor.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdxcv{Tu Señor bien sabe que te levantas a orar casi dos tercios de la noche, otras la mitad o un tercio de ella, así como lo hacen algunos de los creyentes que te siguen. Dios es Quien determina cuánto dura la noche y el día, sabe que no pueden hacerlo siempre, por lo que los perdona aligerando su obligación. Así que reciten durante la oración lo que sepan del Corán. Dios sabe que habrá entre ustedes alguien enfermo [al que se le dificulte la oración], otros que estén de viaje recorriendo la tierra en busca del sustento de Dios, y otros combatiendo por Su causa. Así que reciten durante la oración de lo que sepan del Corán. Cumplan con la oración obligatoria y paguen el zakat. Presten a la causa de Dios generosamente, porque toda obra de bien que hagan será en favor de ustedes, y Dios los recompensará grandemente. Pidan a Dios el perdón [de sus faltas y omisiones] porque Él es Absolvedor, Misericordioso.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdxcvi{\basmalahes ¡Oh, tú [Mujámmad] que te envuelves en un manto!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxcvii{Ponte de pie y advierte.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdxcviii{Proclama la grandeza de tu Señor,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdxcix{purifica tus vestimentas,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmd{apártate de la idolatría,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdi{y no des esperando recibir más a cambio.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdii{Sé paciente [con las dificultades que enfrentarás al divulgar el Mensaje] de tu Señor.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdiii{[Pero ten en cuenta que] cuando se sople la trompeta [y comience el Día del Juicio],\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdiv{ese será un día difícil.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdv{Nada fácil para los que hoy desmienten la verdad.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdvi{[Oh, Mujámmad] Deja que Yo me encargaré de aquel que he creado, y vino al mundo solo,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdvii{a quien concedí abundantes riquezas\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdviii{y numerosos hijos atentos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdix{Y le facilité medios con holgura,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdx{pero aun así anhela más.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdxi{¡No! Porque rechazó Mis signos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdxii{Haré que sus dificultades vayan en aumento.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdxiii{Porque él pensó y decidió [a sabiendas, desmentir el Mensaje].\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdxiv{Fue maldecido por la decisión que tomó.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdxv{¡Sí!, fue maldecido por la decisión que tomó.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdxvi{Luego meditó [cómo desacreditar la revelación],\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdxvii{pero [al no poder encontrar ningún argumento] frunció el ceño y ofuscó el semblante.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdxviii{Luego le dio la espalda [al Mensaje] y se comportó con soberbia,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdxix{diciendo: ``Esto solo es hechicería que impresiona.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdxx{Es la palabra de un mortal".\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdxxi{En consecuencia, lo llevaré al fuego del Infierno.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdxxii{¿Y qué te hará comprender lo que es el fuego del Infierno?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdxxiii{[Es un fuego que] no deja nada sin quemar ni cesa jamás.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdxxiv{Abrasa la piel.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdxxv{Hay diecinueve [ángeles] que lo custodian.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdxxvi{Decreté que los guardianes del Infierno fueran ángeles, y dispuse ese número para probar a los que rechazan la verdad, también para que la Gente del Libro se convenzan y crean, y para que los creyentes fortifiquen su fe y no les queden dudas a ellos ni a la Gente del Libro. También para que aquellos cuyos corazones están enfermos [de duda e hipocresía] y los que niegan la fe se pregunten: ``¿Qué es lo que quiere demostrar Dios con este ejemplo?" Así es como Dios extravía a quien quiere [extraviarse] y guía a quien quiere [guiarse]. Solo Él conoce a todos los que sirven Su causa. Todo esto es motivo de reflexión para la humanidad.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdxxvii{[No es como pretenden los que rechazan la revelación, lo] juro por la Luna,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdxxviii{por la noche cuando desaparece,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdxxix{por la mañana cuando resplandece,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdxxx{que [el Infierno] es uno de los mayores [avisos],\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdxxxi{una advertencia para los seres humanos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdxxxii{Para que cada uno elija [libremente] obrar bien u obrar mal.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdxxxiii{Toda alma será rehén de lo que haya hecho,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdxxxiv{salvo los [bienaventurados] de la derecha.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdxxxv{[Ellos estarán] en jardines y se preguntarán unos a otros\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdxxxvi{acerca de [la situación] de los criminales.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdxxxvii{Y les preguntarán: ``¿Qué fue lo que los llevó al fuego del Infierno?"\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdxxxviii{Ellos responderán: ``Fue que no cumplíamos con la oración,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdxxxix{no dábamos de comer al pobre,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdxl{nos entreteníamos difamando [la revelación] junto a quienes retuercen la lógica para negar la verdad,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdxli{y desmentíamos la existencia del Día del Juicio\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdxlii{hasta que nos alcanzó la muerte [y con ella la certeza]".\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmdxliii{A estos no les beneficiará intercesión alguna.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmdxliv{¿Qué les pasa que se apartan de la amonestación [del Corán]\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmdxlv{como si fueran cebras espantadas\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmdxlvi{huyendo de un león?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmdxlvii{Ellos quisieran que descendieran [del cielo] páginas con un mensaje especial [que les confirmase que Mujámmad es un Mensajero de Dios].\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmdxlviii{Pero no se lo concederemos, porque no tienen temor devocional a la vida del más allá.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmmdxlix{[El Corán] es una exhortación\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmmdl{para que reflexione quien quiera.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmmdli{Pero solo lo harán aquellos para quienes Dios quiera la guía. Solo Él es digno de ser adorado, y solo Él es la fuente del perdón.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmmdlii{\basmalahes Juro por el Día de la Resurrección,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdliii{y juro por el alma que se reprocha a sí misma [cuando comete una falta].\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdliv{¿Acaso cree el ser humano que no volveré a reunir sus huesos?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdlv{¡Claro que sí! Soy capaz incluso de recomponer sus huellas digitales.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdlvi{Pero el ser humano [reniega del Día de la Resurrección y] quiere obrar como un libertino lo que le queda de vida.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdlvii{Y pregunta [burlonamente]: ``¿Cuándo será el día de la Resurrección?"\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdlviii{Pero cuando [llegue ese día y] la vista quede aturdida,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdlix{se eclipse la Luna,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdlx{y se junten el Sol y la Luna,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdlxi{el hombre dirá entonces: ``¿A dónde puedo huir?"\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdlxii{¡Pues no! No habrá refugio [a donde escapar].\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdlxiii{Ese día, todos comparecerán ante tu Señor.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdlxiv{Ese día se le informará al ser humano todo cuanto hizo y dejó de hacer.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdlxv{El ser humano dará testimonio contra sí mismo.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdlxvi{Y aunque intente justificarse [no podrá hacerlo].\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdlxvii{[Oh, Mujámmad] No muevas tu lengua deprisa repitiendo [la revelación],\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdlxviii{porque a Mí me corresponde conservarla [en tu corazón libre de toda tergiversación] para que la recites.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdlxix{Y cuando te la transmita sigue atentamente la recitación.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdlxx{Luego te explicaré claramente su significado.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdlxxi{Pero [los seres humanos] aman la vida pasajera\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdlxxii{y descuidan la vida del más allá.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdlxxiii{Ese día, habrá rostros resplandecientes [de felicidad]\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdlxxiv{contemplando a su Señor.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdlxxv{Pero otros rostros estarán ensombrecidos,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdlxxvi{al conocer la calamidad que caerá sobre ellos.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdlxxvii{Cuando el alma llegue a la garganta [en la agonía de la muerte],\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdlxxviii{y digan [quienes están junto al agonizante]: ``¿Hay alguien que pueda curarlo?"\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdlxxix{El agonizante sabrá que llega el momento de partir [de este mundo],\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdlxxx{y que sus piernas rígidas ya no podrán levantarlo de la agonía de la muerte.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxi{Ese día será conducido hacia su Señor.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxii{Quien no haya aceptado el Mensaje ni haya cumplido con las oraciones,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxiii{sino que desmentía [la verdad] y le daba la espalda\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxiv{y luego iba a los suyos arrogante,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxv{¡ay de él! Ya verá.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxvi{¡Sí! ¡Ay de él! Ya verá.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxvii{¿Acaso cree el ser humano que no será responsable de sus actos?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxviii{¿Acaso no fue un óvulo fecundado por una gota de esperma eyaculada?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxix{¿Y luego un embrión? Dios lo creó y le dio forma armoniosa.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdxc{Y creó de allí la pareja: el hombre y la mujer.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdxci{Quien ha hecho todo esto, ¿acaso no va a ser capaz de resucitar a los muertos?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdxcii{\basmalahes ¿Acaso no hubo un lapso enorme de tiempo en el cual el ser humano no existía y ni siquiera era mencionado?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdxciii{Creé al ser humano de un óvulo fecundado para ponerlo a prueba. Lo agracié con el oído y la vista.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdxciv{Y le mostré el camino [para que libremente elija] ser de los agradecidos o de los ingratos.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdxcv{A los que rechacen el Mensaje les he preparado cadenas, argollas y un fuego abrasador.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdxcvi{Los creyentes sinceros tomarán bebidas dulces en copas aromatizadas,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdxcvii{que brotarán de un manantial siempre accesible del que solo beberán los servidores de Dios.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdxcviii{[Son realmente creyentes] los que cumplen sus promesas y temen el Día del Juicio, cuyo alcance será extensivo.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdxcix{Y, a pesar del amor que tienen por sus bienes materiales, alimentan al pobre, al huérfano y al prisionero.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdc{Dicen: ``Les damos de comer simplemente porque anhelamos el rostro de Dios. En realidad no esperamos de ustedes retribución ni agradecimiento.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdci{Tenemos temor de que nuestro Señor nos castigue el día [del Juicio que será] terrible y penoso".\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcii{Pero Dios los preservará del mal de ese día y los llenará de esplendor y alegría.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdciii{Los retribuirá por su paciencia con el Paraíso y vestimentas de seda.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdciv{[En el Paraíso] estarán reclinados sobre sofás, a salvo del calor ardiente del Sol y la severidad del frío.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcv{Estarán cubiertos por una sombra cercana y fresca de árboles, cuyos frutos serán fáciles de alcanzar.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcvi{Serán servidos con vasijas de plata y copas diáfanas\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcvii{de cristal plateado hechas a su gusto.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcviii{Les servirán en copas aromatizadas una bebida con jengibre\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcix{extraída de una fuente del Paraíso, dulce y siempre accesible.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcx{Rondarán entre los creyentes, sirvientes de juventud eterna. Si los vieras creerías que son perlas esparcidas.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxi{Y al mirar solo encontrarás felicidad y un reino vasto.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxii{[Quienes lo habiten] vestirán de verde satén y de brocado, y llevarán brazaletes de plata. Su Señor les dará de beber una bebida pura.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxiii{[Y se les dirá:] ``Esta es la recompensa. Su esfuerzo ha sido aceptado [por Dios]".\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxiv{[¡Oh, Mujámmad!] Te he revelado el Corán gradualmente [en respuesta a distintas situaciones].\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxv{Espera pacientemente el juicio de tu Señor y no obedezcas al pecador desagradecido.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxvi{Y celebra el nombre de tu Señor por la mañana y por la tarde.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxvii{Y por la noche prostérnate ante Él. Usa gran parte de la noche para glorificarlo.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxviii{Los que rechazan el Mensaje aman la vida efímera y dan la espalda a un día cargado de aflicción [en el que serán juzgados].\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcxix{[No reconocen que] Yo los he creado y les he dado una constitución física fuerte, pero si quisiera podría sustituirlos por otros iguales.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcxx{Esta revelación es para reflexionar. Quien quiera, que tome un camino hacia su Señor.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcxxi{Pero no querrán a menos que quiera Dios, porque Dios todo lo sabe, es Sabio.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcxxii{Él acoge en Su misericordia a quien quiere, pero a los opresores les ha preparado un castigo doloroso.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcxxiii{\basmalahes Juro por los [ángeles] enviados uno tras de otro,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcxxiv{por los [ángeles] encargados de los vientos que soplan violentamente,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcxxv{por los [ángeles] que conducen y extienden las nubes,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcxxvi{por los [ángeles] que distinguen claramente,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcxxvii{por los [Profetas] que transmiten Mensajes\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcxxviii{como aclaración o advertencia [para el Día del Juicio].\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcxxix{Tengan certeza de que aquello con que se les advierte se cumplirá\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcxxx{cuando las estrellas pierdan su luz,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxi{cuando el cielo se resquebraje,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxii{cuando las montañas sean convertidas en polvo\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxiii{y los Mensajeros sean convocados.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxiv{¿Para qué día se los convocará?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxv{Para el Día del Juicio.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxvi{¿Y qué te hará comprender qué es el Día del Juicio?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxvii{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxviii{¿Acaso no destruí otros pueblos antiguos [que rechazaron el Mensaje]?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxix{Luego les siguieron otros pueblos [de desmentidores].\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcxl{Eso es lo que sucede a los pecadores.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcxli{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxlii{¿No los he creado de un líquido insignificante\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxliii{que deposité en un lugar seguro [el útero]\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxliv{por un tiempo determinado?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxlv{Así lo he decretado, y Mi decreto es perfecto.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxlvi{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxlvii{¿Acaso no he hecho de la tierra una morada\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxlviii{para los vivos y los muertos,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxlix{y he puesto en ella montañas elevadas y firmes? ¿Acaso no les he dado de beber agua dulce?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcl{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcli{[Se les dirá:] Diríjanse a lo que desmentían [el Infierno].\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdclii{Diríjanse a la sombra [infernal] ramificada en tres,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcliii{que no protege ni salva de las llamas,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcliv{pues arroja chispas grandes como palacios.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdclv{Chispas que semejan camellos pardos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdclvi{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdclvii{Ese día no hablarán\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdclviii{ni se les permitirá excusarse.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdclix{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdclx{Este es el día de la sentencia. Los he reunido a los primeros y a los últimos.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdclxi{Si creen tener alguna treta [para huir], úsenla ahora.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdclxii{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdclxiii{Pero los que hayan tenido temor de Dios, estarán bajo sombras frescas entre manantiales.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdclxiv{Tendrán las frutas que deseen.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdclxv{[Se les dirá:] ``Coman y beban cuanto quieran como recompensa por lo que obraron".\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdclxvi{Así recompensaré a los que hagan el bien.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdclxvii{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdclxviii{[¡Aquellos que niegan el Mensaje!] Coman y disfruten temporalmente, porque están hundidos en el pecado.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdclxix{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmdclxx{Cuando se les dice: ``Hagan la oración", no la hacen.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmdclxxi{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmdclxxii{¿En qué otro Mensaje fuera de este han de creer?\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmdclxxiii{\basmalahes ¿Sobre qué se preguntan unos a otros?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdclxxiv{Sobre la gran noticia [el Mensaje del Islam]\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdclxxv{acerca de la cual discrepan.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdclxxvi{Pero no es lo que piensan, ya verán [por desmentirla].\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdclxxvii{Indudablemente no es lo que piensan; ya verán.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdclxxviii{¿Acaso no hice de la tierra un lecho,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdclxxix{de las montañas estacas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdclxxx{los cree en parejas [hombre y mujer],\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxi{hice que el sueño sea descanso,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxii{que la noche lo cubra,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxiii{que el día sea para procurar el sustento,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxiv{construí sobre ustedes siete cielos firmes,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxv{puse una lámpara resplandeciente [el Sol],\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxvi{e hice descender de las nubes agua abundante\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxvii{para que broten semillas y plantas\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxviii{y florezcan jardines frondosos?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxix{El Día del Juicio Final ya está determinado.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcxc{Ese día, se soplará la trompeta y ustedes se presentarán en grupos.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcxci{El cielo será abierto, transformándose en un portal.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxcii{Las montañas desaparecerán como si hubieran sido un espejismo.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxciii{El Infierno estará al acecho,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxciv{será la morada de los transgresores\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxcv{que permanecerán en él eternamente.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxcvi{Allí no podrán sentir frescor ni saciar su sed.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxcvii{Solo beberán un líquido hirviente y nauseabundo,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxcviii{como castigo justo por lo que hicieron [en la vida mundanal].\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxcix{Ellos no esperaban tener que rendir cuentas,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcc{y por eso desmintieron abiertamente Mi Mensaje,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcci{pero Yo lo registré todo en un libro.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccii{[Se les dirá a los desmentidores:] ``Sufran las consecuencias, no haré sino aumentarles el castigo".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcciii{En cambio, los piadosos obtendrán la bienaventuranza\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcciv{donde habrá huertos y vides,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccv{compañeras de eterna juventud,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccvi{y copas desbordantes.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccvii{Allí no oirán banalidades ni falsedades.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccviii{Esta es la recompensa de tu Señor, que concederá generosamente.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccix{El Señor de los cielos, de la Tierra y de lo que hay entre ellos, el Compasivo. Nadie puede hablar ante Él excepto con Su permiso.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccx{El día en que el Espíritu junto con los demás ángeles se pongan en fila, nadie hablará, salvo aquel a quien el Compasivo se lo permita, y solo podrá decir la verdad.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccxi{Ese es el día en que se establecerá total justicia. Quien quiera, entonces, que busque refugio en Su Señor.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdccxii{Les he advertido de este castigo inminente. Ese día cada ser humano ha de contemplar sus obras, y entonces dirá quien haya desmentido el Mensaje: ``¡Ojalá fuera polvo [para no ser juzgado]!"\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccxiii{\basmalahes Juro por los [ángeles] que arrancan las almas [de los que desmienten el Mensaje],\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdccxiv{por los [ángeles] que toman suavemente las almas [de los creyentes],\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccxv{por los [ángeles] que viajan por el cosmos,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccxvi{por los [ángeles] que se apresuran [a cumplir su función]\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdccxvii{y por los [ángeles] que cumplen su mandato.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdccxviii{Que el día que sea tocada la trompeta por primera vez [y comience el fin del mundo]\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdccxix{y luego sea tocada por segunda vez [y comience la resurrección],\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdccxx{los corazones se estremecerán\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdccxxi{y las miradas estarán abatidas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdccxxii{Pero a pesar de esto [los que desmienten el Mensaje] dicen: ``¿Acaso seremos resucitados de las tumbas\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdccxxiii{a pesar de habernos convertido en polvo?"\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdccxxiv{Dicen: ``Si sucediera, estaríamos arruinados".\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdccxxv{Pero bastará que la trompeta sea tocada una vez\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdccxxvi{para que todos salgan de sus tumbas.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdccxxvii{¿Acaso has escuchado la historia de Moisés?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdccxxviii{Cuando su Señor lo llamó en el valle sagrado de Tuwa\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdccxxix{[y le dijo:] ``Ve ante el Faraón, pues se ha excedido,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdccxxx{y dile: ‘¿No deseas purificar tu comportamiento?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxi{Yo te enseñaré el sendero de tu Señor para que seas piadoso’".\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxii{Y [Moisés] le mostró [al Faraón] uno de sus grandes milagros.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxiii{Pero el Faraón lo desmintió y rechazó seguirlo.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxiv{Luego le dio la espalda y desobedeció [el Mensaje].\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxv{Y convocó [a su pueblo] y les dijo:\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxvi{``Yo soy su Señor supremo".\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxvii{Por eso Dios lo castigará en la otra vida, pero también en esta.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxviii{En esta historia hay motivo de reflexión para quien tiene temor de Dios.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxix{¿Acaso piensan que ustedes fueron más difíciles de crear que el cielo que Él edificó?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdccxl{Él lo elevó y perfeccionó su construcción.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdccxli{Dios hizo que la noche fuese oscura y que le sucediera la claridad de la mañana.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccxlii{Luego extendió la tierra.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdccxliii{Hizo surgir de ella agua y pasturas.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccxliv{Fijó las montañas.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccxlv{Todo para beneficio de ustedes y de sus rebaños.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccxlvi{El día que suceda la gran calamidad [el fin del mundo]\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccxlvii{el ser humano recordará todo lo que haya hecho,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccxlviii{y será expuesto el fuego del Infierno para que lo vean.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccxlix{Quien se haya extralimitado\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccl{y preferido la vida mundanal,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccli{su morada será el Infierno.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdcclii{En cambio, quien haya tenido conciencia de que comparecerá ante su Señor y haya preservado su alma de seguir sus pasiones,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccliii{su morada será el Paraíso.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdccliv{Te preguntan cuándo será la hora del Juicio Final.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdcclv{Pero tú [¡oh, Mujámmad!] no tienes conocimiento de cuándo será.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdcclvi{Solo tu Señor lo sabe.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdcclvii{Tú solamente eres un advertidor para quienes tienen temor [al Juicio].\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdcclviii{El día que lo vean suceder, les parecerá haber permanecido en la vida mundanal solo el tiempo equivalente a una tarde o una mañana.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdcclix{\basmalahes [¡Oh, Mujámmad!] Frunciste el ceño y le diste la espalda\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcclx{al ciego cuando se presentó ante ti.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcclxi{¿Cómo sabes que no quería purificarse [aprendiendo de ti el conocimiento],\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcclxii{o beneficiarse con tus enseñanzas?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcclxiii{En cambio, al soberbio\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcclxiv{le dedicaste toda tu atención.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcclxv{Pero tú no eres responsable si él rechaza purificarse [de la idolatría, ya que tu obligación solo es transmitir el Mensaje].\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcclxvi{En cambio, aquel que se presentó ante ti con deseos [de aprender],\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcclxvii{teniendo temor de Dios,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcclxviii{te apartaste de él.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcclxix{No lo vuelvas a hacer, porque este Mensaje es para toda la humanidad.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcclxx{Quien quiera, que reflexione y obre acorde a él.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxi{Pues el Mensaje está registrado en páginas honorables,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxii{distinguidas y purificadas,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxiii{en manos de [ángeles] encargados de ejecutar las órdenes de Dios,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxiv{nobles y obedientes.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxv{El ser humano se destruye a sí mismo con su ingratitud.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxvi{¿Acaso no sabe de qué ha sido creado?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxvii{De un óvulo fecundado, que crece en etapas según lo [que Él ha] establecido.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxviii{Luego le facilita el camino.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxix{Luego lo hace morir y ser enterrado.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxx{Finalmente lo resucita cuando Él quiere.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxi{Pero a pesar de esto no cumple con los preceptos que se le ordenan.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxii{El ser humano debería reflexionar sobre su alimento:\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxiii{Hice descender el agua en abundancia,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxiv{luego hice que la tierra brotara.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxv{Hice surgir de ella granos,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxvi{vides, hierbas,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxvii{olivos, palmeras,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxviii{huertos frondosos,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxix{frutos y forraje\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccxc{para beneficio de ustedes y de sus rebaños.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccxci{El día que llegue el estruendo terrible [comenzando el fin del mundo],\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccxcii{el ser humano huirá de su hermano,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccxciii{de su madre y de su padre,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccxciv{de su esposa y de sus hijos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccxcv{Ese día cada uno estará preocupado por sí mismo.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccxcvi{Ese día habrá rostros radiantes,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccxcvii{risueños y felices [por haber alcanzado la salvación].\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdccxcviii{Pero habrá otros rostros ensombrecidos,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccxcix{apesadumbrados [por haber merecido la condena al Infierno].\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdccc{Esos serán los que rechazaron el Mensaje y los transgresores [de la ley].\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdccci{\basmalahes Cuando el Sol se contraiga [y oscurezca],\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccii{cuando las estrellas pierdan su luz,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccciii{cuando las montañas sean pulverizadas,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccciv{cuando las camellas preñadas sean dejadas de lado,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccv{cuando las bestias salvajes sean acorraladas,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccvi{cuando los mares hiervan y se desborden,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccvii{cuando las almas vuelvan a emparejarse [con sus cuerpos],\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccviii{cuando se le pregunte a las niñas que fueron enterradas vivas\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccix{por qué pecado las mataron,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccx{cuando los registros [de las obras] sean repartidos,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxi{cuando la bóveda celeste desaparezca,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxii{cuando el fuego del Infierno sea avivado,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxiii{y cuando el Paraíso sea acercado.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxiv{En ese momento sabrá cada alma el resultado de sus obras.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxv{Juro por los astros\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcccxvi{que recorren sus órbitas,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcccxvii{y [juro] por la noche cuando extiende su oscuridad,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcccxviii{y [juro] por la mañana cuando extiende su luminosidad,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcccxix{que [el Corán] es la palabra [de Dios transmitida] por un emisario noble,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcccxx{dotado de poder y distinción ante el Señor del Trono.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxi{El obedecido [por otros ángeles] y el digno confidente [de la revelación].\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxii{[Sepan que] su compañero [el Profeta Mujámmad] no es un loco,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxiii{lo vio [al ángel Gabriel] en el horizonte claro,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxiv{no oculta nada de lo que le fue revelado.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxv{[El Corán] no es la palabra de un demonio maldito.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxvi{¿A dónde irán [con ese argumento]?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxvii{[El Corán] es un Mensaje para toda la humanidad,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxviii{para que se encamine quien quiera.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxix{Pero sepan que solo se encaminará quien quiera Dios, Señor del universo.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxx{\basmalahes Cuando el cielo se rompa,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxi{cuando los planetas salgan de sus órbitas,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxii{cuando los mares se desborden\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxiii{y cuando las tumbas se abran.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxiv{En ese momento sabrá cada alma lo que hizo de bien y de mal.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxv{¡Oh, seres humanos! ¿Qué fue lo que los engañó para que se apartaran de su Señor Generoso?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxvi{Quien los creó, les dio forma y una conformación armoniosa,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxvii{y les dio la más hermosa figura que quiso para ustedes.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxviii{Pero aun así desmienten el Día del Juicio.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxix{Hay ángeles que registran sus obras,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxl{nobles escribas\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxli{que saben lo que ustedes hacen.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlii{Los piadosos disfrutarán delicias [en esta vida y en el Paraíso],\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxliii{mientras que los pecadores, en cambio, sufrirán tormento [en esta vida y en la otra],\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxliv{y arderán en el Infierno desde el Día del Juicio,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlv{del que no podrán salir.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlvi{¿Qué te hará comprender todo lo que sucederá el Día de la Retribución?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlvii{[¡Reflexiona!] ¿Qué te hará comprender todo lo que sucederá el Día de la Retribución?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlviii{Ese día nadie podrá hacer nada por nadie, porque será Dios Quien decida.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlix{\basmalahes ¡Ay de los tramposos!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccl{Que cuando compran exigen el peso exacto,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcccli{pero cuando venden hacen trampa [dando menos] en el peso y la medida.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccclii{¿Acaso no saben que serán resucitados?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccliii{En un día terrible,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccliv{un día en el que comparecerán los seres humanos ante el Señor del universo.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdccclv{No quedarán impunes como piensan, porque el registro de los pecadores está en un libro ineludible.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdccclvi{¿Y qué te hará saber lo que es un libro ineludible?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdccclvii{Es un libro donde se registran las obras de los pecadores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdccclviii{¡Cuán desdichados serán ese día los que negaron la verdad!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdccclix{Los que desmintieron el Día del Juicio,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdccclx{pues solo lo desmienten los transgresores y los pecadores.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdccclxi{Quienes, cuando les es recitada Mi palabra, dicen: ``Son fábulas de los pueblos antiguos".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdccclxii{Pero no es así, sino que sus corazones están duros, llenos de herrumbre, debido a los pecados que cometieron.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdccclxiii{No es así, sino que ese día no podrán ver a su Señor.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdccclxiv{Luego serán llevados al Infierno,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdccclxv{donde se les dirá: ``Esto es lo que desmentían y rechazaban".\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdccclxvi{En cambio, el registro de los bienaventurados será un libro noble.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdccclxvii{¿Y qué te hará saber lo que es un libro noble?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdccclxviii{Es el libro donde se registran las obras de los que hacen el bien,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdccclxix{que puede ser visto por los [ángeles] cercanos [a Dios].\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdccclxx{Los bienaventurados gozarán las delicias del Paraíso,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxi{recostados en sofás, contemplando.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxii{Reconocerás en sus rostros el resplandor de la dicha.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxiii{Se les dará de beber un néctar sellado,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxiv{cuyo último sorbo deja un sabor a almizcle. ¡Que se esfuercen por alcanzarla los aspirantes!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxv{[El néctar] estará mezclado con agua de Tasnim,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxvi{un manantial del que solo beberán los más cercanos a Dios.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxvii{Los que se abandonan al pecado se ríen [en esta vida] de los creyentes.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxviii{Cuando pasan junto a ellos se hacen gestos [despectivos],\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxix{y cuando regresan a sus hogares se jactan [de ello].\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxx{Cuando ven a los suyos dicen: ``Ellos son unos desviados",\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxi{aunque no les fue encargado velar por ellos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxii{Pero este día los creyentes serán quienes se rían de los que rechazaron la verdad.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxiii{[Los creyentes] estarán reclinados sobre sofás, contemplando [el Rostro de Dios].\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxiv{¿Acaso los que rechazaron la verdad no han recibido una retribución justa por sus propias obras?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxv{\basmalahes Cuando el cielo se resquebraje\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxvi{en cumplimiento de la orden de su Señor, como es debido.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxvii{Cuando la tierra sea aplanada,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxviii{y expulse lo que hay en su seno y quede vacía,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxix{en cumplimiento de la orden de su Señor, como es debido.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccxc{¡Oh, seres humanos! Han de comparecer ante su Señor y ver el resultado de sus obras.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccxci{Quien reciba el registro de sus obras en su mano derecha\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcii{tendrá un juicio fácil,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccxciii{y [una vez terminado] se reunirá jubiloso con su gente [en el Paraíso].\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccxciv{Mientras que quien reciba el registro de sus obras por detrás de su espalda,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcv{suplicará ser destruido definitivamente.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcvi{Pero será arrastrado al castigo del Infierno.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcvii{Él vivía alegre con su familia [despreocupado del más allá]\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcviii{pensando que jamás comparecería [ante Dios].\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcix{Pero sí, su Señor estaba bien informado de lo que hacía.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcm{Juro por el crepúsculo,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmi{por la noche y por las criaturas que habitan en ella,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmii{y por la Luna cuando alcanza el plenilunio,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmiii{que [los seres humanos] pasan de un estado a otro.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmiv{¿Qué es lo que les impide creer?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmv{¿Qué les impide prosternarse cuando se les recita el Corán?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmvi{Los que rechazan la verdad se empeñan en desmentir [el Mensaje].\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmvii{Pero Dios conoce bien lo que ocultan [sus corazones].\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcmviii{Anúnciales un castigo doloroso,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcmix{salvo a quienes crean y obren rectamente, porque ellos recibirán una recompensa inagotable.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcmx{\basmalahes Juro por el cosmos y sus constelaciones,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxi{por el día prometido [el Día del Juicio Final],\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxii{y por el testigo y lo atestiguado,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxiii{que los que arrojaron a los creyentes al foso del fuego fueron maldecidos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxiv{En el foso encendieron un fuego ardiente,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxv{y se sentaron en sus bordes\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmxvi{para presenciar lo que cometían contra los creyentes,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmxvii{cuya única culpa para merecer ese castigo era creer en Dios, el Poderoso, el Loable,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmxviii{a Quien pertenece el reino de los cielos y de la tierra. Dios es testigo de todo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmxix{Quienes persigan a los creyentes y a las creyentes y no se arrepientan [antes de morir], sufrirán en el Infierno un castigo abrasador.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmxx{En cambio, quienes hayan creído y obrado correctamente serán recompensados con jardines por donde corren los ríos. Ese es el triunfo grandioso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmxxi{¡Pero el castigo de tu Señor es severo!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmxxii{Él da origen y reproduce.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmxxiii{Él es el Absolvedor, el Afectuoso.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmxxiv{Señor del Trono, el Majestuoso.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmxxv{Hacedor de Su voluntad.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmxxvi{¿Has escuchado la historia de los ejércitos [criminales]\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmxxvii{del Faraón y del pueblo de Zamud [que desmintieron a los Mensajeros y los destruí]?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmxxviii{Sin embargo, los que niegan la verdad continúan desmintiendo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmxxix{Pero Dios los domina sin que lo sepan.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmxxx{Este es un Corán glorioso\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxi{que está registrado en la Tabla Protegida.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxii{\basmalahes Juro por el cosmos y el astro nocturno.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxiii{¿Y qué puede hacerte comprender lo que es el astro nocturno?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxiv{Es una estrella fulgurante.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxv{Todo ser humano tiene designado un ángel protector que registra sus obras.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxvi{Que medite el hombre de qué fue creado:\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxvii{Fue creado de un líquido seminal\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxviii{que proviene de entre las entrañas [del hombre] y el arco pélvico [de la mujer].\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxix{[Así como lo ha creado la primera vez] Él tiene el poder para resucitarlo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmxl{El día que sean revelados todos los secretos,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmxli{y [el ser humano] no tenga fuerzas [para defenderse] a sí mismo ni auxiliador alguno.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmxlii{Juro por el cielo que devuelve [el agua que sube en forma de lluvias],\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmxliii{y por la tierra que se abre para que broten los cultivos,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmxliv{que el Corán es la Verdad que discrimina [la verdad de la falsedad],\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmxlv{y no es algo trivial.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmxlvi{[Los que niegan la verdad] traman [cizañas],\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmxlvii{pero Yo desbarato sus planes.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmxlviii{Sé tolerante con los que niegan la verdad, y dales un tiempo.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmxlix{\basmalahes Glorifica el nombre de tu Señor, el Altísimo,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcml{Quien creó todas las cosas a la perfección\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmli{y decretó para cada ser su función;\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmlii{Quien hace brotar la hierba,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmliii{y luego la convierte en heno seco.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmliv{[¡Oh, Mujámmad!] Haré que recites [el Corán] y no lo olvides.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmlv{Salvo que Dios quiera, pues Él conoce lo manifiesto y lo oculto.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmlvi{Te dirigiré por el camino de la facilidad.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmlvii{Exhorta [con el Corán], porque el recuerdo es beneficioso.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmlviii{Quien tenga temor de Dios recapacitará [con tu exhortación],\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmlix{pero el negador de la verdad la rechazará\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmlx{y por eso será abrazado por un gran fuego,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmlxi{donde no podrá morir [para descansar del sufrimiento] ni vivir [sin dolor].\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmlxii{¡Será de los bienaventurados quien se purifique [de la idolatría y los pecados],\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmlxiii{recuerde el nombre de su Señor y cumpla con sus oraciones!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmlxiv{Pero [muchos] prefieren la vida mundanal,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmlxv{aunque deben saber que la vida del más allá es superior y eterna.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmlxvi{Este Mensaje se encuentra mencionado en las primeras revelaciones,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmlxvii{en las revelaciones recibidas por Abraham y Moisés.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmlxviii{\basmalahes ¿Te ha llegado la historia sobre el día que todo lo alcanza?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmlxix{Ese día los rostros [de los condenados al Fuego] se verán humillados,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmlxx{abatidos y asfixiados.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxi{Serán llevados a un fuego intenso\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxii{donde les será dado a beber de una fuente de agua hirviente.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxiii{No tendrán otra comida más que espinas\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxiv{que no alimentan ni sacian.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxv{Pero ese día los rostros [de los bienaventurados] estarán radiantes de felicidad.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxvi{Estarán complacidos de sus obras.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxvii{Morarán en un jardín sublime,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxviii{en el que no oirán palabras vanas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxix{En él habrá manantiales,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxx{lechos elevados,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxi{copas al alcance de su mano,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxii{cojines alineados\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxiii{y alfombras extendidas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxiv{¿Acaso no reflexionan [los que niegan la verdad] en la maravillosa creación del camello?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxv{En el cielo, cómo ha sido elevado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxvi{En las montañas, cómo han sido afirmadas.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxvii{Y en la Tierra, cómo ha sido extendida.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxviii{Exhorta a la gente porque esa es tu misión.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxix{No puedes obligarlos a creer.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmxc{Pero sabe que a quien dé la espalda y rechace la verdad\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcmxci{Dios lo someterá al peor de los castigos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcmxcii{Porque todos comparecerán ante Mí,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcmxciii{y seré Yo Quien los juzgue.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcmxciv{\basmalahes Juro por la Aurora,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxcv{por las diez noches,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxcvi{por [las oraciones] pares e impares,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxcvii{y por la noche cuando transcurre.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxcviii{¿Acaso no son estos juramentos [argumentos suficientes sobre el poder de Dios] para los dotados de intelecto?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxcix{¿No has visto cómo tu Señor castigó al pueblo de ‘Ád\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmm{en Iram?, el de las [construcciones con grandes] columnas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmi{que no tenía similar entre los otros pueblos [en su opulencia].\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmii{Y al pueblo de Zamud, que esculpieron sus casas en las montañas rocosas del valle.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmiii{Y al Faraón, el de las estacas.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmiv{Todos ellos fueron tiranos con los pueblos,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmv{sembrando la corrupción.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmvi{Pero como consecuencia de eso tu Señor los azotó con un castigo,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmvii{tu Señor está atento [a las acciones de la gente].\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmviii{El ser humano, cuando su Señor lo agracia, dice: ``Mi Señor me ha honrado [porque lo merezco]".\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmix{En cambio cuando lo pone a prueba restringiendo su sustento, dice: ``Mi Señor me ha despreciado [y no ha tenido en cuenta mis méritos]".\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmx{¡Pero no! No han comprendido el verdadero significado de las pruebas [de la riqueza y la pobreza] y por eso no son generosos con el huérfano\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmxi{ni exhortan unos a otros a alimentar al pobre.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmxii{[En lugar de eso] se apropian codiciosamente de los bienes del prójimo,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmxiii{y son insaciables en su amor [y codicia] por el dinero.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmxiv{¡Basta! [Piensen en cuál será su destino] cuando la Tierra sea golpeada una y otra vez,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmmxv{y llegue su Señor y se presenten los ángeles en fila tras fila,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmmxvi{y sea traído el Infierno. Ese día el hombre recordará sus obras, pero de nada le servirá.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmmxvii{Y dirá lamentándose: ``¡Ojalá hubiera realizado buenas obras para mi vida [del más allá]!"\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmmxviii{Sepan que nadie ha castigado como Él castigará ese día,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmmxix{y nadie ha encadenado como Él encadenará [ese día].\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmmxx{[Le será dicho al creyente:] ``¡Oh, alma que estás en paz con tu Señor!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmmxxi{Vuelve a la vera de tu Señor complacida, porque Dios está complacido contigo,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmmxxii{y únete a Mis siervos piadosos\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmmxxiii{entrando a Mi Paraíso".\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmmxxiv{\basmalahes Juro por esta ciudad [La Meca],\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxxv{en la que tú resides [¡oh, Mujámmad!],\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxxvi{y juro por el progenitor y su descendencia,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxxvii{que creé al ser humano para una vida de continuas dificultades.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxxviii{¿Acaso piensa que nadie tiene poder sobre él?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxxix{Presume diciendo: ``He derrochado una gran fortuna".\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmxxx{¿Acaso cree que nadie lo ve?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmxxxi{¿Acaso no le he dado dos ojos,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmxxxii{una lengua y dos labios,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmxxxiii{y le he mostrado los dos senderos [el del bien y el del mal]?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmxxxiv{Pero no está dispuesto a tomar el camino del esfuerzo.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmxxxv{¿Y qué te hará comprender lo que es el camino del esfuerzo?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmxxxvi{Es liberar [al esclavo] de la esclavitud\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmxxxvii{y dar alimentos en días de hambre\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmxxxviii{al pariente huérfano,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmxxxix{o al pobre hundido en la miseria.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmxl{Y ser, además, de los creyentes que se aconsejan mutuamente ser perseverantes [en el camino del esfuerzo y de la fe] y ser misericordiosos [con el prójimo].\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmxli{Estos son los bienaventurados de la derecha.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmxlii{Mientras que quienes rechacen Mi revelación serán los desventurados de la izquierda\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmxliii{y el fuego se cercará sobre ellos.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmxliv{\basmalahes Juro por el Sol cuando resplandece,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxlv{por la Luna cuando lo refleja,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxlvi{por el día cuando fulgura,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxlvii{por la noche cuando cubre con su oscuridad,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxlviii{por el cosmos y la creación maravillosa que hay en él,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxlix{por la Tierra y su vasta extensión,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmml{por el alma y su armonía,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmli{[Dios] le enseñó [al ser humano] a distinguir entre el pecado y la conciencia de Dios.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlii{¡Será bienaventurado quien purifique su alma [apartándola de los pecados],\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmliii{pero será un desventurado quien la abandone a sus pasiones!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmliv{El pueblo de Zamud rechazó el Mensaje por soberbia.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmlv{Cuando el más opresor de ellos se prestó para matar a la camella.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmlvi{El Mensajero de Dios [Sálih] los previno: ``No maten a la camella de Dios [enviada como milagro] y déjenla abrevar libremente".\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmlvii{Pero desmintieron al Mensajero y mataron a la camella. Entonces, su Señor los destruyó a todos, por lo que cometieron, con un castigo arrasador,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmlviii{sin temor por la magnitud de Su castigo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmlix{\basmalahes Juro por la noche cuando cubre con la oscuridad,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmlx{por el día cuando resplandece,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmlxi{por Quien creó al hombre y a la mujer,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmlxii{que las obras [de las personas] son diversas.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmlxiii{A quien dé caridades, tenga temor [de Dios]\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmlxiv{y crea en los valores más sublimes,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmlxv{le facilitaré el camino del bien.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmlxvi{Pero a quien sea avaro, crea que puede prescindir [de Dios]\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlxvii{y desmienta los valores más sublimes,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmlxviii{no le impediré transitar por el camino de la adversidad.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmlxix{¿De qué le servirán sus bienes materiales cuando muera?\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmlxx{Evidencio la guía,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmlxxi{y a Mí me pertenecen esta vida y la otra.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmlxxii{Les he advertido sobre un fuego abrasador,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmlxxiii{en el que solo ingresarán los desventurados\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmlxxiv{que desmientan y se aparten [del Mensaje].\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmlxxv{Pero el piadoso estará a salvo [de ese fuego],\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmlxxvi{aquel que da parte de su riqueza para purificarse [de la avaricia],\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmlxxvii{no anhelando una retribución ni favor [de otra persona],\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmlxxviii{sino anhelando el Rostro de su Señor, el Altísimo,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmlxxix{y por eso quedará complacido.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmmlxxx{\basmalahes Juro por el resplandor matinal,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxi{por la noche cuando se serena,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxii{que tu Señor no te ha abandonado ni aborrecido [oh, Mujámmad].\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxiii{La vida del más allá será mejor para ti que esta.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxiv{Tu Señor te agraciará y te complacerás.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxv{¿Acaso no te encontró huérfano y te dio amparo,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxvi{y te encontró perdido y te guió,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxvii{y te encontró pobre y te enriqueció?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxviii{No maltrates al huérfano\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxix{ni rechaces al mendigo.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmxc{Y divulga las bendiciones de tu Señor.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmxci{\basmalahes ¿Acaso no he dado sosiego a tu corazón [¡oh, Mujámmad!],\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxcii{te he liberado de la carga\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxciii{que agobiaba tu espalda,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxciv{y he elevado tu renombre?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxcv{Luego de toda dificultad viene la facilidad.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxcvi{Realmente, luego de toda dificultad viene la facilidad.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmxcvii{Cuando cumplas con tus obligaciones dedícate a la adoración,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmxcviii{y a tu Señor anhela con devoción.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmxcix{\basmalahes Juro por la higuera y el olivo,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmc{por el monte Sinaí,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmci{y por esta ciudad segura [La Meca].\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcii{Que he creado al ser humano con la mejor conformación.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmciii{Sin embargo, [a quien rechace el Mensaje] lo degradaré al rango más bajo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmciv{En cambio, a los creyentes que obran rectamente les tengo reservada una recompensa inagotable.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcv{¿Cómo puedes desmentir el Día del Juicio?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcvi{¿Acaso no es Dios el más Justo de los jueces?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcvii{\basmalahes ¡Lee! [¡oh, Mujámmad!] En el nombre de tu Señor, Quien creó todas las cosas.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcviii{Creó al hombre de una célula embrionaria.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcix{¡Lee! Que tu Señor es el más Generoso.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcx{Enseñó la escritura con la pluma\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxi{y le enseñó al hombre lo que este no sabía.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxii{No obstante, el ser humano se excede\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxiii{cuando se cree autosuficiente.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxiv{Pero todos habrán de comparecer ante tu Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxv{¿Qué piensas de quien impide\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmcxvi{a un siervo de Dios realizar sus oraciones?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmcxvii{¿Acaso ha recapacitado que trae la guía\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmcxviii{y exhorta a la piedad?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmcxix{¿Acaso no ves cómo desmiente y rechaza?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmcxx{¿Acaso no sabe que Dios lo ve?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmcxxi{Si no pone fin [a sus agresiones contra los creyentes] lo arrastraré por su frente,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmcxxii{esa frente mentirosa y perversa.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmcxxiii{Que pida auxilio a sus secuaces,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmcxxiv{que llamaré a los ángeles guardianes del Infierno.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmcxxv{¡No! No lo obedezcas, sino que prostérnate [ante Dios] y busca Su proximidad.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmcxxvi{\basmalahes Comencé la revelación [del Corán] en la noche de la predestinación.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxxvii{¿Y qué te hará comprender la importancia de la noche de la predestinación?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxxviii{[Adorar a Dios] la noche de la predestinación es superior en recompensa a hacerlo durante mil meses.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxxix{Esta noche descienden los ángeles y el espíritu [el ángel Gabriel] con órdenes de su Señor para todos los asuntos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxxx{Es una noche de paz y seguridad hasta el comienzo del alba.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxi{\basmalahes No es concebible que los incrédulos, de la Gente del Libro o los idólatras, sean condenados hasta que les haya llegado una evidencia clara,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxii{que sea un Mensajero de Dios, que les recite una revelación purificada [de toda falsedad y contradicción],\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxiii{que contiene preceptos de rectitud y justicia.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxiv{Pero quienes recibieron el Libro con anterioridad [judíos, cristianos y otros] rompieron su unidad [en la fe] cuando les llegó la evidencia clara [a pesar de provenir de la misma fuente divina],\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxv{en la que únicamente se les ordenaba que fueran monoteístas adorando solo a Dios con sinceridad, que realizaran la oración y pagaran el zakat, pues esa es la verdadera religión.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxvi{Quienes se negaron a seguir la verdad, sean Gente del Libro o idólatras, serán castigados eternamente en el fuego del Infierno. Ellos son lo peor entre todos los seres creados.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxvii{En cambio, los que creen y obran rectamente son lo mejor entre todos los seres creados.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxviii{Ellos recibirán como recompensa de su Señor Jardines del Edén por donde corren ríos, en los que estarán eternamente. Dios estará complacido con ellos y ellos lo estarán con Él. Esto es lo que aguarda a quienes hayan tenido temor de Dios.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxix{\basmalahes Cuando la Tierra sea sacudida por el gran terremoto,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxl{y expulse su carga [haciendo surgir a los muertos de sus tumbas],\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxli{y el hombre diga: ``¿Qué le sucede a la Tierra?"\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxlii{Ese día, la Tierra dará testimonio de todo cuanto sucedió sobre ella,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxliii{por orden de su Señor.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxliv{Entonces, los seres humanos acudirán al Día del Juicio en grupos para conocer el resultado de sus obras.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxlv{Quien haya realizado una obra de bien, tan pequeña como un átomo, la encontrará registrada.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxlvi{Y quien haya realizado una mala obra, tan pequeña como un átomo, la encontrará registrada.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxlvii{\basmalahes Juro por los corceles que se lanzan relinchando\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxlviii{y arrancan chispas con sus cascos\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxlix{y sorprenden al amanecer\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcl{levantando una nube de polvo,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcli{e irrumpiendo en las filas del enemigo,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclii{que el ser humano es ingrato con su Señor.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcliii{Y él mismo es testigo de ello,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcliv{porque tiene una codicia apasionada por los bienes materiales.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclv{¿Acaso no sabe que cuando se haga surgir a quienes están en las sepulturas\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclvi{y se evidencie lo que hay en los corazones,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmclvii{ese día su Señor estará bien informado de lo que hicieron?\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmclviii{\basmalahes El evento repentino.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclix{¿Qué es el evento repentino?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclx{¿Y qué te hará comprender la magnitud del evento repentino?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxi{Ese día la gente parecerá mariposas dispersas,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxii{y las montañas copos de lana cardada.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxiii{Aquel cuyas obras buenas sean más pesadas en la balanza\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxiv{gozará de una vida placentera.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxv{En cambio, aquel cuyas obras buenas sean más livianas en la balanza,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxvi{su morada estará en el abismo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclxvii{¿Y qué te hará comprender qué es el abismo?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmclxviii{Es un fuego abrasador.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmclxix{\basmalahes El afán de tener más y más los domina\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxx{hasta que la muerte los sorprenda y entren en la tumba.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxi{¡No deberían comportarse así! Ya se van a enterar [que obrar para la otra vida es superior].\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxii{Una vez más: ¡No deberían comportarse así! Ya se van a enterar [que obrar para la otra vida es superior].\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxxiii{Si hubieran sabido con certeza [el castigo de quienes consumen su vida en el afán de tener más y más, habrían cambiado el rumbo de sus vidas].\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxxiv{Habrán de ver el fuego del Infierno,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxxv{y lo verán con los ojos de la certeza.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxxvi{Luego, ese día [del Juicio] se les preguntará por cada bendición que recibieron [durante la vida mundanal].\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxxvii{\basmalahes Juro por el tiempo\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxxviii{que los seres humanos están en la perdición,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxix{excepto aquellos que crean, obren rectamente, y se aconsejen mutuamente con la verdad y con la paciencia [ante las adversidades].\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxx{\basmalahes ¡Ay del castigo que les aguarda al difamador y al calumniador,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxi{al que acumula bienes materiales y los cuenta una y otra vez,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxii{creyendo que su riqueza lo hará vivir eternamente!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxiii{Por el contrario, serán arrojados en un fuego demoledor.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxiv{¿Y qué te hará comprender lo que es un fuego demoledor?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxv{Es un fuego encendido por Dios\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxvi{cuyo dolor alcanza los corazones.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxvii{El Infierno se cerrará en torno a ellos\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxviii{con columnas inmensas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxix{\basmalahes ¿No has observado lo que hizo tu Señor con el ejército del elefante?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxc{¿No has visto cómo desbarató sus planes [de destruir la Ka‘bah]?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxci{Y envió sobre ellos bandadas de aves\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxcii{que les arrojaron piedras de arcilla dura,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxciii{y los dejó como heno carcomido.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxciv{\basmalahes Le proporcioné seguridad a [la tribu de] Quraish,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxcv{e hice que sus caravanas en invierno [al Yemen] y en verano [a Siria] fueran respetadas.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxcvi{Que adoren y agradezcan, en consecuencia, al Señor de esta Casa [la Ka‘bah],\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxcvii{Quien les concedió el sustento para que no sufrieran hambre y les dio seguridad para protegerlos del peligro.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxcviii{\basmalahes ¿Acaso has observado a quien desmiente el Día del Juicio?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxcix{Es quien rechaza al huérfano\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcc{y no exhorta a alimentar al pobre.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcci{¡Ay de los orantes\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccii{que son negligentes en sus oraciones [realizándolas fuera de su horario],\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcciii{y solo las realizan para hacerse ver,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcciv{y se niegan a prestar hasta la mínima ayuda!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmccv{\basmalahes [¡Oh, Mujámmad!] te he agraciado con la abundancia.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccvi{Reza a tu Señor y sacrifica [los animales en Su nombre].\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccvii{Porque a quien te desdeñe y odie le privaré de todo bien.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccviii{\basmalahes Di: ``¡Oh, incrédulos!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccix{No adoro lo que adoran.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccx{Ni adoran ustedes a Quien yo adoro.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxi{Y jamás adoraré lo que adoran.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxii{Ni adorarán ustedes a Quien yo adoro.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxiii{Ustedes tienen su religión y yo la mía".\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmccxiv{\basmalahes [¡Oh, Mujámmad!] Cuando llegue el socorro de Dios y la victoria,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxv{y veas a la gente ingresar en masa a la religión de Dios,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxvi{glorifica alabando a tu Señor y pide Su perdón; Él es Indulgente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxvii{\basmalahes ¡Maldito sea Abu Lahab y que perezca!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxviii{No le servirán de nada su poder ni sus bienes materiales.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxix{Será arrojado en el fuego llameante\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxx{junto con su mujer, la que acarreaba espinas,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxi{que llevará en su cuello una cuerda de fibras de palmera.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxii{\basmalahes Di: ``Él es Al-lah, Uno.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxiii{Al-lah es el Absoluto.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxiv{No engendró ni fue engendrado.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxv{Y no hay nada ni nadie que sea semejante a Él".\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxvi{\basmalahes Di: ``Me refugio en el Señor del amanecer,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxvii{de todo el mal que existe en lo que Él creó,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxviii{del mal de la oscuridad de la noche cuando se extiende,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxix{del mal de las [hechiceras] sopladoras de nudos,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxx{y del mal del envidioso cuando envidia".\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxi{\basmalahes Di: ``Me refugio en el Señor de los seres humanos,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxii{en el Rey Soberano de los seres humanos,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxiii{en el [único] Dios de los seres humanos,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxiv{de la maldad del [demonio] susurrador que huye [cuando el nombre de Dios es mencionado],\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxv{que susurra en los corazones de los seres humanos,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxvi{y existe entre los yinnes y entre los seres humanos".\qt@no{6}}
%% End of file `qurantext-esiii.translation.def'.
