\qt@newcmd\qurantrans@es@i{¡En el nombre de Alá, el Compasivo, el Misericordioso!\qt@no{1}}
\qt@newcmd\qurantrans@es@ii{Alabado sea Alá, Señor del universo,\qt@no{2}}
\qt@newcmd\qurantrans@es@iii{el Compasivo, el Misericordioso,\qt@no{3}}
\qt@newcmd\qurantrans@es@iv{Dueño del día del Juicio,\qt@no{4}}
\qt@newcmd\qurantrans@es@v{A Ti solo servimos y a Ti solo imploramos ayuda.\qt@no{5}}
\qt@newcmd\qurantrans@es@vi{Dirígenos por la vía recta,\qt@no{6}}
\qt@newcmd\qurantrans@es@vii{la vía de los que Tú has agraciado, no de los que han incurrido en la ira, ni de los extraviados.\qt@no{7}}
\qt@newcmd\qurantrans@es@viii{\basmalahes `lm.\qt@no{1}}
\qt@newcmd\qurantrans@es@ix{Ésta es la Escritura, exenta de dudas, como dirección para los temerosos de Alá,\qt@no{2}}
\qt@newcmd\qurantrans@es@x{que creen en lo oculto, hacen la azalá y dan limosna de lo que les hemos proveído.\qt@no{3}}
\qt@newcmd\qurantrans@es@xi{creen en lo que se te ha revelado a ti y antes de ti, y están convencidos de la otra vida.\qt@no{4}}
\qt@newcmd\qurantrans@es@xii{Ésos son los dirigidos por su Señor y ésos los que prosperarán.\qt@no{5}}
\qt@newcmd\qurantrans@es@xiii{Da lo mismo que adviertas o no a los infieles: no creen.\qt@no{6}}
\qt@newcmd\qurantrans@es@xiv{Alá ha sellado sus corazones y oídos; una venda cubre sus ojos y tendrán un castigo terrible.\qt@no{7}}
\qt@newcmd\qurantrans@es@xv{Hay entre los hombres quienes dicen: «Creemos en Alá y en el último Día», pero no creen.\qt@no{8}}
\qt@newcmd\qurantrans@es@xvi{Tratan de engañar a Alá y a los que creen; pero, sin darse cuenta, sólo se engañan a sí mismos.\qt@no{9}}
\qt@newcmd\qurantrans@es@xvii{Sus corazones están enfermos y Alá les ha agravado su enfermedad. Tendrán un castigo doloroso por haber mentido.\qt@no{10}}
\qt@newcmd\qurantrans@es@xviii{Cuando se les dice: «¡No corrompáis en la tierra!», dicen: «Pero ¡si somos reformadores!»\qt@no{11}}
\qt@newcmd\qurantrans@es@xix{¡No son ellos, en realidad, los corruptores? Pero no se dan cuenta.\qt@no{12}}
\qt@newcmd\qurantrans@es@xx{Cuando se les dice: «¡Creed como creen los demás!», dicen: «¿Es que vamos a creer como creen los tontos?» Son ellos los tontos, pero no lo saben.\qt@no{13}}
\qt@newcmd\qurantrans@es@xxi{Cuando encuentran a quienes creen, dicen: «¡Creemos!» Pero, cuando están a solas con sus demonios, dicen: «Estamos con vosotros, era sólo una broma».\qt@no{14}}
\qt@newcmd\qurantrans@es@xxii{Alá les devolverá la broma y les dejará que persistan en su rebeldía, errando ciegos.\qt@no{15}}
\qt@newcmd\qurantrans@es@xxiii{Ésos son los que han trocado la Dirección por el extravío. Por eso, su negocio no ha resultado lucrativo y no han sido bien dirigidos.\qt@no{16}}
\qt@newcmd\qurantrans@es@xxiv{Son como uno que alumbra un fuego. En cuanto éste ilumina lo que le rodea, Alá se les lleva la luz y les deja en tinieblas: no ven.\qt@no{17}}
\qt@newcmd\qurantrans@es@xxv{Son sordos, mudos, ciegos, no se convierten.\qt@no{18}}
\qt@newcmd\qurantrans@es@xxvi{O como si viniera del cielo una nube borrascosa, cargada de tinieblas, truenos y relámpagos. Se ponen los dedos en los oídos contra el rayo, por temor a la muerte. Pero Alá cerca a los infieles.\qt@no{19}}
\qt@newcmd\qurantrans@es@xxvii{El relámpago les arrebata casi la vista. Cuando les ilumina, caminan a su luz; pero, cuando les oscurece, se detienen. Si Alá hubiera querido, les habría quitado el oído y la vista. Alá es omnipotente.\qt@no{20}}
\qt@newcmd\qurantrans@es@xxviii{¡Hombres! Servid a vuestro Señor, Que os ha creado, a vosotros y a quienes os precedieron. Quizás, así, tengáis temor de Él.\qt@no{21}}
\qt@newcmd\qurantrans@es@xxix{Os ha hecho de la tierra lecho y del cielo edificio. Ha hecho bajar agua del cielo, mediante la cual ha sacado frutos para sustentaros. No atribuyáis iguales a Alá a sabiendas.\qt@no{22}}
\qt@newcmd\qurantrans@es@xxx{Si dudáis de lo que hemos revelado a Nuestro siervo, traed una sura semejante y, si es verdad lo que decís, llamad a vuestros testigos en lugar de llamar a Alá.\qt@no{23}}
\qt@newcmd\qurantrans@es@xxxi{Pero, si no lo hacéis -y nunca podréis hacerlo-, guardaos del fuego cuyo combustible lo constituyen hombres y piedras, y que ha sido preparado para los infieles.\qt@no{24}}
\qt@newcmd\qurantrans@es@xxxii{Anuncia la buena nueva a quienes creen y obran bien: tendrán jardines por cuyos bajos fluyen arroyos. Siempre que se les dé como sustento algún fruto de ellos, dirán: «Esto es igual que lo que se nos ha dado antes». Pero se les dará algo sólo parecido. Tendrán esposas purificadas y estarán allí eternamente.\qt@no{25}}
\qt@newcmd\qurantrans@es@xxxiii{Alá no se avergüenza de proponer la parábola que sea, aunque se trate de un mosquito. Los que creen saben que es la Verdad, que viene de su Señor. En cuanto a los que no creen, dicen: «¿Qué es lo que se propone Alá con esta parábola?» Así extravía Él a muchos y así también dirige a muchos. Pero no extravía así sino a los perversos.\qt@no{26}}
\qt@newcmd\qurantrans@es@xxxiv{Quienes violan la alianza con Alá después de haberla concluido, cortan los lazos que Alá ha ordenado mantener y corrompen en la tierra, ésos son los que pierden.\qt@no{27}}
\qt@newcmd\qurantrans@es@xxxv{¿Cómo podéis no creer en Alá, siendo así que os dio la vida cuando aún no existíais, que os hará morir y os volverá a la vida, después de lo cual seréis devueltos a Él?\qt@no{28}}
\qt@newcmd\qurantrans@es@xxxvi{Él es Quien creó para vosotros cuanto hay en la tierra. Y subió al cielo e hizo de él siete cielos. Es omnisciente.\qt@no{29}}
\qt@newcmd\qurantrans@es@xxxvii{Y cuando tu Señor dijo a los ángeles: «Voy a poner un sucesor en la tierra». Dijeron: «¿Vas a poner en ella a quien corrompa en ella y derrame sangre, siendo así que nosotros celebramos Tu alabanza y proclamamos Tu santidad?» Dijo: «Yo sé lo que vosotros no sabéis».\qt@no{30}}
\qt@newcmd\qurantrans@es@xxxviii{Enseñó a Adán los nombres de todos los seres y presentó éstos a los ángeles diciendo: «Informadme de los nombres de éstos, si es verdad lo que decís».\qt@no{31}}
\qt@newcmd\qurantrans@es@xxxix{Dijeron: «¡Gloria a Ti! No sabemos más que lo que Tú nos has enseñado. Tú eres, ciertamente, el Omnisciente, el Sabio».\qt@no{32}}
\qt@newcmd\qurantrans@es@xl{Dijo: «¡Adán! ¡Infórmales de sus nombres!» Cuando les informó de sus nombres, dijo: «¿No os he dicho que conozco lo oculto de los cielos y de la tierra y que sé lo que mostráis lo que ocultáis?»\qt@no{33}}
\qt@newcmd\qurantrans@es@xli{Y cuando dijimos a los ángeles: «¡Prosternaos ante Adán!». Se prosternaron, excepto Iblis. Se negó y fue altivo: era de los infieles.\qt@no{34}}
\qt@newcmd\qurantrans@es@xlii{Dijimos: «¡Adán! ¡Habita con tu esposa en el Jardín y comed de él cuanto y donde queráis. pero no os acerquéis a este árbol! Si no, seréis de los impíos».\qt@no{35}}
\qt@newcmd\qurantrans@es@xliii{Pero el Demonio les hizo caer, perdiéndolo, y les sacó del estado en que estaban. Y dijimos: «¡Descended! Seréis enemigos unos de otros. La tierra será por algún tiempo vuestra morada y lugar de disfrute».\qt@no{36}}
\qt@newcmd\qurantrans@es@xliv{Adán recibió palabras de su Señor y Éste se volvió a él. Él es el Indulgente, el Misericordioso.\qt@no{37}}
\qt@newcmd\qurantrans@es@xlv{Dijimos: «¡Descended todos de él! Si. pues, recibís de Mí una dirección, quienes sigan Mi dirección no tendrán que. temer y no estarán tristes.\qt@no{38}}
\qt@newcmd\qurantrans@es@xlvi{Pero quienes no crean y desmientan Nuestros signos, ésos morarán en el Fuego eternamente».\qt@no{39}}
\qt@newcmd\qurantrans@es@xlvii{¡Hijos de Israel! Recordad la gracia que os dispensé y sed fieles a la alianza que conmigo concluisteis. Entonces, Yo seré fiel a la que con vosotros concluí. ¡Temedme, pues, a Mí y sólo a Mí!\qt@no{40}}
\qt@newcmd\qurantrans@es@xlviii{¡Creed en lo que he revelado en confirmación de lo que habéis recibido! ¡No seáis los primeros en no creer en ello, ni malvendáis Mis signos! ¡Temedme, pues, a Mí. y sólo a Mí!\qt@no{41}}
\qt@newcmd\qurantrans@es@xlix{¡No disfracéis la Verdad de falsedad, ni ocultéis la Verdad conociéndola!\qt@no{42}}
\qt@newcmd\qurantrans@es@l{¡Haced la azalá, dad el azaque e inclinaos con los que se inclinan!\qt@no{43}}
\qt@newcmd\qurantrans@es@li{¿Mandáis a los hombres que sean piadosos y os olvidáis de vosotros mismos siendo así que leéis la Escritura? ¿Es que no tenéis entendimiento?\qt@no{44}}
\qt@newcmd\qurantrans@es@lii{¡Buscad ayuda en la paciencia y en la azalá! Sí, es algo difícil, pero no para los humildes,\qt@no{45}}
\qt@newcmd\qurantrans@es@liii{que cuentan con encontrar a su Señor y volver a Él.\qt@no{46}}
\qt@newcmd\qurantrans@es@liv{¡Hijos de Israel! Recordad la gracia que os dispensé y que os distinguí entre todos los pueblos.\qt@no{47}}
\qt@newcmd\qurantrans@es@lv{Temed un día en que nadie pueda satisfacer nada por otro, ni se acepte la intercesión ajena, compensación ni auxilio.\qt@no{48}}
\qt@newcmd\qurantrans@es@lvi{Y cuando os salvamos de las gentes de Faraón, que os sometían a duro castigo, degollando a vuestros hijos varones y dejando con vida a vuestras mujeres. Con esto os probó vuestro Señor duramente.\qt@no{49}}
\qt@newcmd\qurantrans@es@lvii{Y cuando os separamos las aguas del mar y os salvamos, anegando a las gentes de Faraón en vuestra presencia.\qt@no{50}}
\qt@newcmd\qurantrans@es@lviii{Y cuando nos dimos cita con Moisés durante cuarenta días. Luego, cuando se fue, cogisteis el ternero, obrando impíamente.\qt@no{51}}
\qt@newcmd\qurantrans@es@lix{Luego, después de eso, os perdonamos. Quizás, así, fuerais agradecidos.\qt@no{52}}
\qt@newcmd\qurantrans@es@lx{Y cuando dimos a Moisés la Escritura y el Criterio. Quizás, así, fuerais bien dirigidos.\qt@no{53}}
\qt@newcmd\qurantrans@es@lxi{Y cuando Moisés dijo a su pueblo: ¡Pueblo! Habéis sido injustos con vosotros mismos al coger el ternero. ¡Volveos a vuestro Creador y mataos unos a otros.! Esto es mejor para vosotros a los ojos de vuestro Creador. Así se aplacará. Él es el Indulgente, el Misericordioso».\qt@no{54}}
\qt@newcmd\qurantrans@es@lxii{Y cuando dijisteis: «¡Moisés! No creeremos en ti hasta que veamos a Alá claramente». Y el Rayo se os llevó, viéndolo vosotros venir.\qt@no{55}}
\qt@newcmd\qurantrans@es@lxiii{Luego, os resucitamos después de muertos. Quizás, así, fuerais agradecidos.\qt@no{56}}
\qt@newcmd\qurantrans@es@lxiv{Hicimos que se os nublara y que descendieran sobre vosotros el maná y las codornices: «¡Comed de las cosas buenas de que os hemos proveído!» No fueron injustos con Nosotros, sino que lo fueron consigo mismos.\qt@no{57}}
\qt@newcmd\qurantrans@es@lxv{Y cuando dijimos: «¡Entrad en esta ciudad, y comed donde y cuando queráis de lo que en ella haya! ¡Entrad por la puerta prosternándoos y decid '¡Perdón!'» Os perdonaremos vuestros pecados y daremos más a quienes hagan el bien.\qt@no{58}}
\qt@newcmd\qurantrans@es@lxvi{Pero los impíos cambiaron por otras las palabras que se les habían dicho e hicimos bajar contra los impíos un castigo del cielo por haber obrado perversamente.\qt@no{59}}
\qt@newcmd\qurantrans@es@lxvii{Y cuando Moisés pidió agua para su pueblo. Dijimos: «¡Golpea la roca con tu vara!» Y brotaron de ella doce manantiales. Todos sabían de cuál debían beber. «¡Comed y bebed del sustento de Alá y no obréis mal en la tierra corrompiendo!»\qt@no{60}}
\qt@newcmd\qurantrans@es@lxviii{Y cuando dijisteis: «¡Moisés! No podremos soportar una sola clase de alimento. ¡Pide a tu Señor de parte nuestra que nos saque algo de lo que la tierra produce: verduras, pepinos, ajos, lentejas y cebollas!» Dijo: «¿Vais a cambiar lo que es mejor por algo peor? ¡Bajad a Egipto y hallaréis lo que pedís!» La humillación y la miseria se abatieron sobre ellos e incurrieron en la ira de Alá. Porque no habían prestado fe a los signos de Alá y habían dado muerte a los profetas sin justificación. Porque habían desobedecido y violado la ley.\qt@no{61}}
\qt@newcmd\qurantrans@es@lxix{Los creyentes, los judíos, los cristianos, los sabeos, quienes creen en Alá y en el último Día y obran bien. ésos tienen su recompensa junto a su Señor. No tienen que temer y no estarán tristes.\qt@no{62}}
\qt@newcmd\qurantrans@es@lxx{Y cuando concertamos un pacto con vosotros y levantamos la montaña por encima de vosotros: «¡Aferraos a lo que os hemos dado y recordad su contenido! Quizás, así, seáis temerosos de Alá».\qt@no{63}}
\qt@newcmd\qurantrans@es@lxxi{Luego, después de eso, os volvisteis atrás y, si no llega a ser por el favor de Alá en vosotros y por Su misericordia, habriáis sido de los que pierden.\qt@no{64}}
\qt@newcmd\qurantrans@es@lxxii{Sabéis, ciertamente, quiénes de vosotros violaron el sábado. Les dijimos: «¡Convertíos en monos repugnantes!»\qt@no{65}}
\qt@newcmd\qurantrans@es@lxxiii{E hicimos de ello un castigo ejemplar para los contemporáneos y sus descendientes, una exhortación para los temerosos de Alá.\qt@no{66}}
\qt@newcmd\qurantrans@es@lxxiv{Y cuando Moisés dijo a su pueblo: «Alá os ordena que sacrifiquéis una vaca». Dijeron: «¿Nos tomas a burla?» Dijo: «¡Alá me libre de ser de los ignorantes!»,\qt@no{67}}
\qt@newcmd\qurantrans@es@lxxv{Dijeron: «Pide a tu Señor de nuestra parte que nos aclare cómo ha de ser ella». Dijo: «Dice que no es una vaca vieja ni joven, sino de edad media. Haced, pues, como se os manda».\qt@no{68}}
\qt@newcmd\qurantrans@es@lxxvi{Dijeron: «Pide a tu Señor de nuestra parte que nos aclare de qué color ha de ser». Dijo: «Dice que es una vaca amarilla de un amarillo intenso, que haga las delicias de los que la miran».\qt@no{69}}
\qt@newcmd\qurantrans@es@lxxvii{Dijeron: «Pide a tu Señor de nuestra parte que nos aclare cómo es, pues todas las vacas nos parecen iguales. Así. si Alá quiere, seremos, ciertamente, bien dirigidos».\qt@no{70}}
\qt@newcmd\qurantrans@es@lxxviii{Dijo: «Dice que es una vaca que no ha sido empleada en el laboreo de la tierra ni en el riego del cultivo, sana, sin tacha». Dijeron: «Ahora has dicho la verdad». Y la sacrificaron, aunque poco faltó para que no lo hicieran.\qt@no{71}}
\qt@newcmd\qurantrans@es@lxxix{Y cuando matasteis a un hombre y os lo recriminasteis, pero Alá reveló lo que ocultabais.\qt@no{72}}
\qt@newcmd\qurantrans@es@lxxx{Entonces dijimos: «¡Golpeadlo con un pedazo de ella!» Así Alá volverá los muertos a la vida y os hará ver Sus signos. Quizás, así, comprendáis.\qt@no{73}}
\qt@newcmd\qurantrans@es@lxxxi{Luego, después de eso, se endurecieron vuestros corazones y se pusieron como la piedra o aún más duros. Hay piedras de las que brotan arroyos, otras que se quiebran y se cuela el agua por ellas, otras que s vienen abajo por miedo a Alá. Alá está atento a lo que hacéis.\qt@no{74}}
\qt@newcmd\qurantrans@es@lxxxii{¿Cómo vais a anhelar que os crean si algunos de los que escuchaban la Palabra de Alá la alteraron a sabiendas, después de haberla comprendido?\qt@no{75}}
\qt@newcmd\qurantrans@es@lxxxiii{Y, cuando encuentran a quienes creen, dicen: «¡Creemos!» Pero, cuando están a solas, dicen. «¿Vais a contarles lo que Alá os ha revelado para que puedan esgrimirlo como argumento contra vosotros ante vuestro Señor? ¿Es que no razonáis?»\qt@no{76}}
\qt@newcmd\qurantrans@es@lxxxiv{¿No saben que Alá conoce lo que ocultan y lo que manifiestan?\qt@no{77}}
\qt@newcmd\qurantrans@es@lxxxv{Hay entre ellos gentiles que no conocen la Escritura, sino fantasías y no hacen sino conjeturar.\qt@no{78}}
\qt@newcmd\qurantrans@es@lxxxvi{¡Ay de aquéllos que escriben la Escritura con sus manos y luego dicen: Esto viene de Alá, para, luego, malvenderlo! ¡Ay de ellos por lo que sus manos han escrito! ¡Ay de ellos por lo que han cometido!\qt@no{79}}
\qt@newcmd\qurantrans@es@lxxxvii{Dicen: «El fuego no nos tocará más que por días contados». Di: «¿Os ha prometido algo Alá? Pues Alá no faltará a Su promesa. ¿O es que decís contra Alá lo que no sabéis?»\qt@no{80}}
\qt@newcmd\qurantrans@es@lxxxviii{¡Pues sí! Quienes hayan obrado mal y estén cercados por su pecado, ésos morarán en el Fuego eternamente.\qt@no{81}}
\qt@newcmd\qurantrans@es@lxxxix{Pero quienes hayan creído y obrado bien, ésos morarán en el Jardín eternamente.\qt@no{82}}
\qt@newcmd\qurantrans@es@xc{Y cuando concertamos un pacto con los hijos de Israel: «¡No sirváis sino a Alá! ¡Sed buenos con vuestros padres y parientes, con los huérfanos y pobres, hablad bien a todos, haced la azalá dad el azaque!» Luego, os desviasteis, exceptuados unos pocos, y os alejasteis.\qt@no{83}}
\qt@newcmd\qurantrans@es@xci{Y cuando concertamos un pacto con vosotros: «¡No derraméis vuestra sangre ni os expulséis de casa unos a otros!» Lo aceptasteis, sois testigos.\qt@no{84}}
\qt@newcmd\qurantrans@es@xcii{Pero sois vosotros los que os matáis y expulsáis a algunos de los vuestros de sus casas, haciendo causa común contra ellos con pecado y violación de la ley. Y, si acuden a vosotros como cautivos, los rescatáis. El haberlos expulsado era ya ilícito. Entonces, ¿es que creéis en parte de la Escritura y dejáis de creer en otra parte? ¿Qué merecen quienes de vosotros tal hacen sino la ignominia en la vid de acá y ser enviados al castigo más duro el día de la Resurrección? Alá está atento a lo que hacéis.\qt@no{85}}
\qt@newcmd\qurantrans@es@xciii{Ésos son los que han comprado la vida de acá a cambio de la otra. No se les mitigará el castigo ni encontrarán quien les auxilie.\qt@no{86}}
\qt@newcmd\qurantrans@es@xciv{Dimos a Moisés la Escritura y mandamos enviados después de él. Dimos a Jesús, hijo de María, las pruebas claras y le fortalecimos con el Espíritu Santo. ¿Es que tenías que mostraros altivos siempre que venía a vosotros un enviado con algo que no deseabais? A unos les desmentisteis, a otros les disteis muerte.\qt@no{87}}
\qt@newcmd\qurantrans@es@xcv{Dicen: «Nuestros corazones están incircuncisos». ¡No! Alá les ha maldecido por su incredulidad. Es tan poco lo que creen...\qt@no{88}}
\qt@newcmd\qurantrans@es@xcvi{Y cuando les vino de Alá una Escritura que confirmaba lo que ya tenían - antes, pedían un fallo contra los que no creían -, cuando vino a ellos lo que ya conocían, no le prestaron fe. ¡Que la maldición de Alá caiga sobre los infieles!\qt@no{89}}
\qt@newcmd\qurantrans@es@xcvii{¡Qué mal negocio han hecho, no creyendo en lo que Alá ha revelado, rebelados porque Alá favoreció a quien Él quiso de Sus siervos, e incurriendo en Su ira una y otra vez! Los infieles tendrán un castigo humillante.\qt@no{90}}
\qt@newcmd\qurantrans@es@xcviii{Y cuando se les dice: «¡Creed en lo que Alá ha revelado!», dicen: «Creemos en lo que se nos ha revelado». Pero no creen en lo que vino después. que es la Verdad, en confirmación de lo que ya tenían. Di: «¿Por qué, pues, si erais creyentes, matasteis antes a los profetas de Alá?»,\qt@no{91}}
\qt@newcmd\qurantrans@es@xcix{Moisés os aportó pruebas claras. pero, ido, cogisteis el ternero, obrando impíamente.\qt@no{92}}
\qt@newcmd\qurantrans@es@c{Y cuando concertamos un pacto con vosotros y levantamos la montaña por encima de vosotros: «¡Aferraos a lo que os hemos dado y escuchad!» Dijeron: «Oímos y desobedecemos». Y, como castigo a su incredulidad, quedó empapado su corazón del amor al ternero. Di: «Si sois creyentes, malo es lo que vuestra fe os ordena».\qt@no{93}}
\qt@newcmd\qurantrans@es@ci{Di: «Si se os reserva la Morada Postrera junto a Alá, con exclusión de otras gentes. entonces ¡desead la muerte. si sois consecuentes!»\qt@no{94}}
\qt@newcmd\qurantrans@es@cii{Pero nunca la desearán por lo que sus manos han cometido. Alá conoce bien a los impíos.\qt@no{95}}
\qt@newcmd\qurantrans@es@ciii{Verás que son los más ávidos de vivir, más aún que los asociadores. Hay entre ellos quien desearía vivir mil años, pero eso no le libraría del castigo. Alá ve bien o que hacen.\qt@no{96}}
\qt@newcmd\qurantrans@es@civ{Di: «Si hay alguien enemigo de Gabriel -él es quien. autorizado por Alá. lo reveló a tu corazón, en confirmación de los mensajes anteriores, como dirección y buena nueva para los creyentes-,\qt@no{97}}
\qt@newcmd\qurantrans@es@cv{si hay alguien enemigo de Alá, de Sus ángeles, de Sus enviados, de Gabriel y de Miguel, Alá, a Su vez, es enemigo de los infieles».\qt@no{98}}
\qt@newcmd\qurantrans@es@cvi{Te hemos revelado, en verdad, signos claros y sólo los perversos pueden negarlos.\qt@no{99}}
\qt@newcmd\qurantrans@es@cvii{¿Es que siempre que conciertan una alianza van algunos de ellos a rechazarla? No, la mayoría no creen.\qt@no{100}}
\qt@newcmd\qurantrans@es@cviii{Y, cuando viene a ellos un Enviado mandado por Alá, que confirma lo que han recibido, algunos de aquéllos a quienes se había dado la Escritura se echan la Escritura de Alá a la espalda, como si no supieran nada.\qt@no{101}}
\qt@newcmd\qurantrans@es@cix{Han seguido lo que los demonios contaban bajo el dominio de Salomón. Salomón no dejó de creer, pero los demonios sí, enseñando a los hombres la magia y lo que se había revelado a los os ángeles, Harut y Marut, en Babel. Y éstos no enseñaban a nadie, que no dijeran que sólo eran una tentación y que, por tanto, no debía dejar de creer. Aprendieron de ellos cómo dividir a un hombre de su esposa. Y con ello no dañaban a nadie sino autorizados por Alá. Aprendieron lo que les dañaba y no les aprovechaba, sabiendo bien que quien adquiría eso no iba a tener parte en la otra vida. ¡Qué mal negocio han hecho! Si supieran...\qt@no{102}}
\qt@newcmd\qurantrans@es@cx{Si hubieran creído y temido a Alá, la recompensa de Éste habría sido mejor. Si supieran...\qt@no{103}}
\qt@newcmd\qurantrans@es@cxi{¡Creyentes! ¡No digáis: «¡Raina!», sino «¡Unzurna!» y escuchad! los infieles tendrán un castigo doloroso.\qt@no{104}}
\qt@newcmd\qurantrans@es@cxii{Los que no creen, tanto gente de la Escritura como asociadores, no desearían que vuestro Señor os enviara bien alguno. Pero Alá particulariza con Su misericordia a quien Él quiere. Alá es el Dueño del favor inmenso.\qt@no{105}}
\qt@newcmd\qurantrans@es@cxiii{Si abrogamos una aleya o provocamos su olvido, aportamos otra mejor o semejante. ¿No sabes que Alá es omnipotente?\qt@no{106}}
\qt@newcmd\qurantrans@es@cxiv{¿No sabes que el dominio de los cielos y de la tierra es de Alá y que no tenéis. fuera de Alá, amigo ni auxiliar?\qt@no{107}}
\qt@newcmd\qurantrans@es@cxv{¿O preferís pedir a vuestro Enviado, como fue Moisés pedido antes? Quien cambie la fe por la incredulidad se ha extraviado del camino recto.\qt@no{108}}
\qt@newcmd\qurantrans@es@cxvi{A muchos de la gente de la Escritura les gustaría hacer de vosotros infieles después de haber sido creyentes, por envidia, después de habérseles manifestado la Verdad. Vosotros, empero, perdonad y olvidad hasta que venga Alá con su orden. Alá es omnipotente.\qt@no{109}}
\qt@newcmd\qurantrans@es@cxvii{Haced la azalá y dad el azaque. El bien que hagáis como anticipo a vosotros mismos, volveréis a encontrarlo junto a Alá. Alá ve bien lo que hacéis.\qt@no{110}}
\qt@newcmd\qurantrans@es@cxviii{Y dicen: «Nadie entrará en el Jardín sino los judíos o los cristianos.» Ésos son sus anhelos. Di: «¡Aportad vuestra prueba, si es verdad lo que decís!»\qt@no{111}}
\qt@newcmd\qurantrans@es@cxix{¡Pues si! Quien se someta a Alá y haga el bien, tendrá su recompensa junto a su Señor. No tiene que temer y no estará triste.\qt@no{112}}
\qt@newcmd\qurantrans@es@cxx{Los judíos dicen: «Los cristianos carecen de base», y los cristianos dicen: «Los judíos carecen de base», siendo así que leen la Escritura. Lo mismo dicen quienes no saben. Alá decidirá entre ellos el día de la Resurrección sobre aquello en que discrepaban.\qt@no{113}}
\qt@newcmd\qurantrans@es@cxxi{¿Hay alguien que sea más impío que quien impide que se mencione Su nombre en las mezquitas de Alá y se empeña en arruinarlas? Hombres así no deben entrar en ellas sino con temor. ¡Que ,¿ sufran ignominia en la vida de acá y terrible castigo en la otra!\qt@no{114}}
\qt@newcmd\qurantrans@es@cxxii{De Alá son el Oriente y el Occidente. Adondequiera que os volváis, allí está la faz de Alá. Alá es inmenso, omnisciente.\qt@no{115}}
\qt@newcmd\qurantrans@es@cxxiii{Dicen: «Alá ha adoptado un hijo». ¡Gloria a Él! ¡No! Suyo es lo que está en los cielos y en la tierra. Todo Le obedece.\qt@no{116}}
\qt@newcmd\qurantrans@es@cxxiv{Es el Creador de los cielos y de la tierra. Y cuando decide algo, le dice tan sólo: «¡Sé!» y es.\qt@no{117}}
\qt@newcmd\qurantrans@es@cxxv{Los que no saben dicen: «¿Por qué Alá no nos habla o nos viene un signo?» Lo mismo decían sus antecesores. Sus corazones son iguales. En verdad, hemos aclarado los signos a gente que está convencida.\qt@no{118}}
\qt@newcmd\qurantrans@es@cxxvi{Te hemos enviado con la Verdad como nuncio de buenas nuevas y como monitor, y no tendrás que responder de los condenados al fuego de la gehena.\qt@no{119}}
\qt@newcmd\qurantrans@es@cxxvii{Ni los judíos ni los cristianos estarán satisfechos de ti mientras no sigas su religión. Di: «La dirección de Alá es la Dirección». Ciertamente, si sigues sus pasiones después e haber sabido tú lo que has sabido. no tendrás amigo ni auxiliar frente a Alá.\qt@no{120}}
\qt@newcmd\qurantrans@es@cxxviii{Aquéllos a quienes hemos dado la Escritura y la leen como debe ser leída. creen en ella. Quienes, en cambio, no creen en ella, ésos son los que pierden.\qt@no{121}}
\qt@newcmd\qurantrans@es@cxxix{¡Hijos de Israel! Recordad la gracia que os dispensé y que os distinguí entre todos los pueblos.\qt@no{122}}
\qt@newcmd\qurantrans@es@cxxx{Temed un día en que nadie pueda satisfacer nada por otro, ni se acepte ninguna compensación ni aproveche ninguna intercesión. ni sea posible auxilio alguno.\qt@no{123}}
\qt@newcmd\qurantrans@es@cxxxi{Y cuando su Señor probó a Abraham con ciertas órdenes. Al cumplirlas, dijo: «Haré de ti guía para los hombres». Dijo: «¿Y de mi descendencia?» Dijo: ``Mi alianza no incluye a los impíos».\qt@no{124}}
\qt@newcmd\qurantrans@es@cxxxii{Y cuando hicimos de la Casa lugar de reunión y de refugio para los hombres. Y: «¡Haced del lugar de Abraham un oratorio!» Y concertamos una alianza con Abraham e Ismael: que purificaran Mi Casa para los que dieran las vueltas, para los que acudieran a hacer un retiro, a inclinarse y a prosternarse.\qt@no{125}}
\qt@newcmd\qurantrans@es@cxxxiii{Y cuando Abraham dijo: «¡Señor! Haz de ésta una ciudad segura y provee de frutos a su población, a aquéllos que crean en Alá y en el último Día». Dijo: «A quienes no crean, es dejaré que gocen por breve tiempo. Luego. les arrastraré al castigo del Fuego. ¡Qué mal fin...!»\qt@no{126}}
\qt@newcmd\qurantrans@es@cxxxiv{Y cuando Abraham e Ismael levantaban los cimientos de la Casa: «¡Señor, acéptanoslo! ¡Tú eres Quien todo lo oye, Quien todo lo sabe!\qt@no{127}}
\qt@newcmd\qurantrans@es@cxxxv{¡Y haz, Señor, que nos sometamos a Ti, haz de nuestra descendencia una comunidad sumisa a Ti, muéstranos nuestros ritos y vuélvete a nosotros! ¡Tú eres, ciertamente, el Indulgente, el Misericordioso!\qt@no{128}}
\qt@newcmd\qurantrans@es@cxxxvi{¡Señor! Suscita entre ellos a un Enviado de su estirpe que les recite Tus aleyas y les enseñe la Escritura y la Sabiduría les purifique! Tú eres, ciertamente, el Poderoso, el Sabio».\qt@no{129}}
\qt@newcmd\qurantrans@es@cxxxvii{¿Quién sino el necio de espíritu puede sentir aversión a la religión de Abraham? Le elegimos en la vida de acá y en la otra vida es, ciertamente, de los justos.\qt@no{130}}
\qt@newcmd\qurantrans@es@cxxxviii{Cuando su Señor le dijo: «¡Sométete!». Dijo: «Me someto al Señor del universo».\qt@no{131}}
\qt@newcmd\qurantrans@es@cxxxix{Abraham ordenó hacer lo mismo a sus hijos varones, y también Jacob: «¡Hijos míos! Alá os ha escogido esta religión. Así, pues, no muráis sino sometidos a Él».\qt@no{132}}
\qt@newcmd\qurantrans@es@cxl{¿Fuisteis, acaso, testigos de lo que dijo Jacob a sus hijos varones cuando iba a morir. «¿A quién serviréis cuando yo ya no esté?» Dijeron: «Serviremos a tu Dios, el Dios de tus padres Abraham, Ismael e Isaac, como a un Dios Uno. Nos sometemos a Él».\qt@no{133}}
\qt@newcmd\qurantrans@es@cxli{Ésa es una comunidad ya desaparecida. Ha recibido lo que merecía, como vosotros recibiréis lo que merezcáis. No tendréis que responder de lo que ellos hacían.\qt@no{134}}
\qt@newcmd\qurantrans@es@cxlii{Dicen: «Si sois judíos o cristianos, estáis en la vía recta». Di: «No, antes bien la religión de Abraham, que fue hanif y no asociador».\qt@no{135}}
\qt@newcmd\qurantrans@es@cxliii{Decid: «Creemos en Alá y en lo que se nos ha revelado, en lo que se reveló a Abraham, Ismael, Isaac, Jacob y las tribus, en lo que Moisés, Jesús y los profetas recibieron de su Señor. No hacemos distinción entre ninguno de ellos y nos sometemos a É».\qt@no{136}}
\qt@newcmd\qurantrans@es@cxliv{Así, pues, si creen en lo mismo que vosotros creéis, estarán en la vía recta. Pero si se desvían, estarán entonces en oposición. Alá te bastará contra ellos. Él e Quien todo lo oye. Quien todo lo sabe».\qt@no{137}}
\qt@newcmd\qurantrans@es@cxlv{¡Tinte de Alá! Y ¿Quién puede teñir mejor que Alá? Somos Sus servidores.\qt@no{138}}
\qt@newcmd\qurantrans@es@cxlvi{Di: «¿Vais a discutir con nosotros sobre Alá. siendo así que Él es nuestro Señor y Señor vuestro? Nosotros respondemos de nuestras obras y vosotros de las vuestras. Y Le servimos sinceramente.\qt@no{139}}
\qt@newcmd\qurantrans@es@cxlvii{¿O diréis que Abraham, Ismael, Isaac, Jacob y las tribus fueron judíos o cristianos?» Di: «¿Quién sabe más? ¿Vosotros o Alá? ¿Hay alguien que sea más impío que quien oculta un testimonio que ha recibido de Alá? Alá está atento a lo que hacéis».\qt@no{140}}
\qt@newcmd\qurantrans@es@cxlviii{Ésa es una comunidad ya desaparecida. Ha recibido lo que merecía como vosotros recibiréis lo que merezcáis. No tendréis que responder de lo que ellos hacían.\qt@no{141}}
\qt@newcmd\qurantrans@es@cxlix{Los necios de entre los hombres dirán: «Qué es lo que les ha inducido a abandonar la alquibla hacia la que se orientaban?» Di: «De Alá son el Oriente y el Occidente. Dirige a quien Él quiere a una vía recta».\qt@no{142}}
\qt@newcmd\qurantrans@es@cl{Hemos hecho así de vosotros un comunidad moderada, para que seáis testigos de los hombres y para que el Enviado sea testigo de vosotros. No pusimos la alquibla hacia la que antes te orientabas sino para distinguir a quien seguía al Enviado de quien le daba la espalda. Ciertamente, es cosa grave, pero no para aquéllos a quienes Alá dirige. Alá no va a dejar que se pierda vuestra fe. Alá es manso para con los hombres, misericordioso.\qt@no{143}}
\qt@newcmd\qurantrans@es@cli{Vemos cómo vuelves tu rostro al cielo. Haremos, pues, que te vuelvas hacia una dirección que te satisfaga. Vuelve tu rostro hacia la Mezquita Sagrada. Dondequiera que estéis, volved vuestro rostro hacia ella. Aquéllos que han recibido la Escritura saben bien que es la Verdad que viene de su Señor. Alá está atento a lo que hacen.\qt@no{144}}
\qt@newcmd\qurantrans@es@clii{Aun si aportas toda clase de signos a quienes han recibido la Escritura., no siguen tu alquibla, ni tú debes seguir la suya, ni siguen unos la alquibla de otros. Y, si sigues sus pasiones, después de haber sabido tú lo que has sabido, entonces, serás de los impíos.\qt@no{145}}
\qt@newcmd\qurantrans@es@cliii{Aquéllos a quienes hemos dado la Escritura la conocen como conocen a sus propios hijos varones. Pero algunos de ellos ocultan la Verdad a sabiendas.\qt@no{146}}
\qt@newcmd\qurantrans@es@cliv{La Verdad viene de tu Señor. ¡No seas, pues, de los que dudan!\qt@no{147}}
\qt@newcmd\qurantrans@es@clv{Todos tienen una dirección adonde volverse. ¡Rivalizad en buenas obras! Dondequiera que os encontréis, Alá os juntará. Alá es omnipotente.\qt@no{148}}
\qt@newcmd\qurantrans@es@clvi{Vengas de donde vengas, vuelve tu rostro hacia la Mezquita Sagrada. Ésta es la Verdad que viene de tu Señor. Alá está atento a lo que hacéis.\qt@no{149}}
\qt@newcmd\qurantrans@es@clvii{Vengas de donde vengas. vuelve tu rostro hacia la Mezquita Sagrada. Estéis donde estéis, volved vuestros rostros hacia ella, de modo que nadie, excepto los que hayan obrado impíamente, puedan alegar nada contra vosotros. Y no les tengáis miedo a ellos, sino a Mí. Así completaré Mi gracia en vosotros. Y quizás. así, seáis bien dirigidos.\qt@no{150}}
\qt@newcmd\qurantrans@es@clviii{Igual que os hemos mandado un Enviado de entre vosotros para que os recite Nuestras aleyas, para que os purifique, para que os enseñe la Escritura y la Sabiduría, para que os enseñe lo que no sabíais.\qt@no{151}}
\qt@newcmd\qurantrans@es@clix{¡Acordaos de Mí, que Yo Me acordaré de vosotros! ¡Dadme las gracias y no Me seáis desagradecidos!\qt@no{152}}
\qt@newcmd\qurantrans@es@clx{¡Vosotros, los que creéis, buscad ayuda en la paciencia y en la azalá! Alá está con los pacientes.\qt@no{153}}
\qt@newcmd\qurantrans@es@clxi{¡Y no digáis de quienes han caído por Alá que han muerto! No, sino que viven. Pero no os dais cuenta...\qt@no{154}}
\qt@newcmd\qurantrans@es@clxii{Vamos a probaros con algo de miedo, de hambre, de pérdida de vuestra hacienda, de vuestra vida, de vuestros frutos. Pero ¡anuncia buenas nuevas a los que tienen paciencia.\qt@no{155}}
\qt@newcmd\qurantrans@es@clxiii{que, cuando les acaece una desgracia, dicen: «Somos de Alá y a Él volvemos»!\qt@no{156}}
\qt@newcmd\qurantrans@es@clxiv{Ellos reciben las bendiciones y la misericordia de su Señor. Ellos son los que están en la buena dirección.\qt@no{157}}
\qt@newcmd\qurantrans@es@clxv{Safa y Marwa figuran entre los ritos prescritos por Alá. Por eso, quien hace la peregrinación mayor a la Casa o la menor, no hace mal en dar las vueltas alrededor de ambas. Y si uno hace el bien espontáneamente, Alá es agradecido, omnisciente.\qt@no{158}}
\qt@newcmd\qurantrans@es@clxvi{Quienes ocultan las pruebas claras y la Dirección que hemos revelado, después de habérselo Nosotros aclarado a los hombres en la Escritura, incurren en la maldición de Alá y de los hombres.\qt@no{159}}
\qt@newcmd\qurantrans@es@clxvii{Pero aquéllos que se arrepientan y se enmienden y aclaren, a ésos Me volveré. Yo soy el Indulgente, el Misericordioso.\qt@no{160}}
\qt@newcmd\qurantrans@es@clxviii{Los que no crean y mueran siendo infieles, incurrirán en la maldición de Alá. de los ángeles y de los hombres, en la de todos ellos.\qt@no{161}}
\qt@newcmd\qurantrans@es@clxix{Eternos en ella, no se les mitigará el castigo, ni les será dado esperar.\qt@no{162}}
\qt@newcmd\qurantrans@es@clxx{Vuestro Dios es un Dios Uno. No hay más dios que Él, el Compasivo, el Misericordioso.\qt@no{163}}
\qt@newcmd\qurantrans@es@clxxi{En la creación de los cielos y de la tierra, en la sucesión de la noche y el día, en las naves que surcan el mar con lo que aprovecha a los hombres, en el agua que Alá hace bajar del cielo, vivificando con ella la tierra después de muerta, diseminando por ella toda clase de bestias, en la variación de los vientos, en las nubes, sujetas entre el cielo y la tierra, hay, ciertamente, signos para gente que razona.\qt@no{164}}
\qt@newcmd\qurantrans@es@clxxii{Hay hombres que, fuera de Alá, toman a otros que equiparan a Él y les aman como se ama a Alá. Pero los creyentes aman a Alá con un amor más fuerte. Si vieran los impíos, cuando vean e castigo, que la fuerza es toda de Alá y que Alá castiga severamente...\qt@no{165}}
\qt@newcmd\qurantrans@es@clxxiii{Cuando los corifeos se declaren irresponsables de sus secuaces, vean el castigo y se rompan los lazos que les unían...\qt@no{166}}
\qt@newcmd\qurantrans@es@clxxiv{Los secuaces dicen: «Si pudiéramos volver, nos declararíamos irresponsables de ellos, como ellos se han declarado de nosotros». Así Alá les mostrará sus obras para pesar de ellos. ¡Nunca saldrán del Fuego!\qt@no{167}}
\qt@newcmd\qurantrans@es@clxxv{¡Hombres! ¡Comed de los alimentos lícitos y buenos que hay en la tierra y no sigáis los pasos del Demonio! Es para vosotros un enemigo declarado.\qt@no{168}}
\qt@newcmd\qurantrans@es@clxxvi{Os ordena lo malo y lo deshonesto y que digáis contra Alá lo que no sabéis.\qt@no{169}}
\qt@newcmd\qurantrans@es@clxxvii{Y cuando se les dice: «¡Seguid lo que Alá ha revelado!», dicen: «¡No! Seguiremos las tradiciones de nuestros padres». Pero ¿y si sus padres eran incapaces de razonar y no estaban bien dirigidos?\qt@no{170}}
\qt@newcmd\qurantrans@es@clxxviii{Los incrédulos son como cuando uno grita al ganado, que no percibe más que una llamada, un grito: son sordos, mudos, ciegos, no razonan.\qt@no{171}}
\qt@newcmd\qurantrans@es@clxxix{¡Creyentes! ¡Comed de las cosas buenas de que os hemos proveído y dad gracias a Alá, si es a Él solo a Quien servís!\qt@no{172}}
\qt@newcmd\qurantrans@es@clxxx{Os ha prohibido sólo la carne mortecina, la sangre. la carne de cerdo y la de todo animal sobre el que se haya invocado un nombre diferente del de Alá. Pero si alguien se ve compelido por la necesidad -no por deseo ni por afán de contravenirno peca. Alá es indulgente, misericordioso.\qt@no{173}}
\qt@newcmd\qurantrans@es@clxxxi{Quienes ocultan algo de la Escritura que Alá ha revelado y lo malvenden, sólo fuego ingerirán en sus entrañas y Alá no les dirigirá la palabra el día de la Resurrección ni les declarará puros. Tendrán un castigo doloroso.\qt@no{174}}
\qt@newcmd\qurantrans@es@clxxxii{Ésos son los que han trocado la Dirección por el extravío. el perdón por el castigo. ¿Cómo pueden permanecer imperturbables ante el Fuego?\qt@no{175}}
\qt@newcmd\qurantrans@es@clxxxiii{Esto es así porque Alá ha revelado la Escritura con la Verdad. Y quienes discrepan sobre la Escritura están en marcada oposición.\qt@no{176}}
\qt@newcmd\qurantrans@es@clxxxiv{La piedad no estriba en que volváis vuestro rostro hacia el Oriente o hacia el Occidente, sino en creer en Alá y en el último Día, en los ángeles, en la Escritura y en los profetas, en dar de la hacienda. por mucho amor que se le tenga, a los parientes, huérfanos, necesitados, viajero, mendigos y esclavos, en hacer la azalá y dar el azaque, en cumplir con los compromisos contraídos, en ser pacientes en el infortunio, en la aflicción y en tiempo de peligro. ¡Ésos son los hombres sinceros, ésos los temerosos de Alá!\qt@no{177}}
\qt@newcmd\qurantrans@es@clxxxv{¡Creyentes! Se os ha prescrito la ley del talión en casos de homicidio: libre por libre, esclavo por esclavo, hembra por hembra. Pero, si a alguien le rebaja su hermano la pena, que la demanda sea conforme al uso la indemnización apropiada. Esto es un alivio por parte de vuestro Señor, una misericordia. Quien, después de esto. viole la ley, tendrá un castigo doloroso.\qt@no{178}}
\qt@newcmd\qurantrans@es@clxxxvi{En la ley del talión tenéis vida, ¡hombres de intelecto! Quizás, así, temáis a Alá.\qt@no{179}}
\qt@newcmd\qurantrans@es@clxxxvii{Se os ha prescrito que, cuando uno de vosotros vea que va a morir dejando bienes, haga testamento en favor de sus padres y parientes más cercanos conforme al uso. Esto constituye un deber para los temerosos de Alá.\qt@no{180}}
\qt@newcmd\qurantrans@es@clxxxviii{Si alguien lo cambia luego de haberlo oído, pecará sólo el que lo cambie. Alá todo lo oye, todo lo sabe.\qt@no{181}}
\qt@newcmd\qurantrans@es@clxxxix{Pero, si alguien teme una injusticia o ilegalidad por parte del testador y consigue un arreglo entre los herederos, no peca. Alá es indulgente, misericordioso.\qt@no{182}}
\qt@newcmd\qurantrans@es@cxc{¡Creyentes!; Se os ha prescrito el ayuno, al igual que se prescribió a los que os precedieron. Quizás, así, temáis a Alá.\qt@no{183}}
\qt@newcmd\qurantrans@es@cxci{Días contados. Y quien de vosotros esté enfermo o de viaje, un número igual de días. Y los que, pudiendo, no ayunen podrán redimirse dando de comer a un pobre. Y, si uno hace el bien espontáneamente, tanto mejor para él. Pero os conviene más ayunar. Si supierais...\qt@no{184}}
\qt@newcmd\qurantrans@es@cxcii{Es el mes de ramadán, en que fue revelado el Corán como dirección para los hombres y como pruebas claras de la Dirección y del Criterio. Y quien de vosotros esté presente ese mes, que ayune en él. Y quien esté enfermo o de viaje, un número igual de días. Alá quiere hacéroslo fácil y no difícil. ¡Completad el número señalado de días y ensalzad a Alá por haberos dirigido! Quizás, así seáis agradecidos.\qt@no{185}}
\qt@newcmd\qurantrans@es@cxciii{Cuando Mis siervos te pregunten por Mí, estoy cerca y respondo a la oración de quien invoca cuando Me invoca. ¡Que Me escuchen y crean en Mí! Quizás, así, sean bien dirigidos.\qt@no{186}}
\qt@newcmd\qurantrans@es@cxciv{Durante el mes del ayuno os es lícito por la noche uniros con vuestras mujeres: son vestidura para vosotros y vosotros lo sois para ellas. Alá sabe que os engañabais a vosotros mismos. Se ha vuelto a vosotros y os ha perdonado. Ahora, pues, yaced con ellas y buscad lo que Alá os ha prescrito. Comed y bebed hasta que, a la alborada, se distinga un hilo blanco de un hilo negro. Luego, observad un ayuno riguroso hasta la caída de la noche. Y no las toquéis mientras estéis de retiro en la mezquita. Éstas son las leyes de Alá, no os acerquéis a ellas. Así explica Alá Sus aleyas a los hombres. Quizás, así, Le teman.\qt@no{187}}
\qt@newcmd\qurantrans@es@cxcv{No os devoréis la hacienda injustamente unos a otros. No sobornéis con ella a los jueces para devorar una parte de la hacienda ajena injusta y deliberadamente.\qt@no{188}}
\qt@newcmd\qurantrans@es@cxcvi{Te preguntan acerca de los novilunios. Di: «Son indicaciones que sirven a los hombres para fijar la época de la peregrinación». La piedad no estriba en que entréis en casa por detrás. sino en que temáis a Alá. ¡Entrad en casa por la puerta y temed a Alá! Quizás, así prosperéis.\qt@no{189}}
\qt@newcmd\qurantrans@es@cxcvii{Combatid por Alá contra quienes combatan contra vosotros, pero no os excedáis. Alá no ama a los que se exceden.\qt@no{190}}
\qt@newcmd\qurantrans@es@cxcviii{Matadles donde deis con ellos, y expulsadles de donde os hayan expulsado. Tentar es más grave que matar. No combatáis contra ellos junto a la Mezquita Sagrada, a no ser que os ataquen allí. Así que, si combaten contra vosotros, matadles: ésa es la retribución de los infieles.\qt@no{191}}
\qt@newcmd\qurantrans@es@cxcix{Pero, si cesan, Alá es indulgente, misericordioso.\qt@no{192}}
\qt@newcmd\qurantrans@es@cc{Combatid contra ellos hasta que dejen de induciros a apostatar y se rinda culto a Alá. Si cesan, no haya más hostilidades que contra los impíos.\qt@no{193}}
\qt@newcmd\qurantrans@es@cci{El mes sagrado por el mes sagrado. Las cosas sagradas caen bajo la ley del talión. Si alguien os agrediera, agredidle en la medida que os agredió. Temed a Alá y sabed que Él está con los que Él temen.\qt@no{194}}
\qt@newcmd\qurantrans@es@ccii{Gastad por la causa de Alá y no os entreguéis a la perdición. Haced el bien. Alá ama a quienes hacen el bien.\qt@no{195}}
\qt@newcmd\qurantrans@es@cciii{Llevad a cabo la peregrinación mayor y la menor por Alá. Pero, si os veis impedidos, ofreced una víctima conforme a vuestros medios. No os afeitéis la cabeza hasta que la víctima llegue al lugar del sacrificio. Si uno de vosotros está enfermo o tiene una dolencia en la cabeza, puede redimirse ayunando, dando limosna u ofreciendo un sacrificio. Cuando estéis en seguridad, quien aproveche para hacer la peregrinación menor, mientras llega el tiempo de la mayor, que ofrezca una víctima según sus posibilidades. Pero, si no encuentra qué ofrecer, deberá ayunar tres días durante la peregrinación mayor y siete a su regreso, esto es, diez completos. Esto atañe a aquél cuya familia no reside en las cercanías de la Mezquita Sagrada. ¡Temed a Alá! ¡Sabed que Alá es severo en castigar!\qt@no{196}}
\qt@newcmd\qurantrans@es@cciv{Ya se sabe cuáles son los meses de la peregrinación. Quien decida hacerla en esos meses se abstendrá durante la peregrinación de comercio carnal, de cometer actos impíos y de discutir. Alá conoce el bien que hacéis. ¡Aprovisionaos! La mejor provisión es el temor de Alá...¡Temedme, pues, hombres de intelecto!\qt@no{197}}
\qt@newcmd\qurantrans@es@ccv{No hacéis mal, si buscáis favor de vuestro Señor. Cuando os lancéis desde Arafat, ¡recordad a Alá junto al Monumento Sagrado! Recordadle... cómo os ha dirigido... cuando erais, ates, de los extraviados.\qt@no{198}}
\qt@newcmd\qurantrans@es@ccvi{¡Haced, luego, como los demás y pedid perdón a Alá! Alá es indulgente, misericordioso.\qt@no{199}}
\qt@newcmd\qurantrans@es@ccvii{Cuando hayáis cumplido vuestros ritos, ¡recordad a Alá como recordáis a vuestros antepasados o con más fervor aún! Hay entre los hombres quienes dicen: «¡Señor! ¡Danos n la vida de acá!» Ésos no tendrán parte en la otra vida.\qt@no{200}}
\qt@newcmd\qurantrans@es@ccviii{Otros dicen: «¡Señor! ¡Danos bien en la vida de acá y en la otra y presérvanos del castigo del Fuego!»\qt@no{201}}
\qt@newcmd\qurantrans@es@ccix{Ésos tendrán parte según sus méritos. Alá es rápido en ajustar cuentas...\qt@no{202}}
\qt@newcmd\qurantrans@es@ccx{¡Recordad a Alá en días determinados! Quien los reduzca a dos días no hace mal; como tampoco quien se demore, si es que teme a Alá. ¡Temed a Alá! ¡Sabed que seréis congregados hacia Él!\qt@no{203}}
\qt@newcmd\qurantrans@es@ccxi{Hay entre los hombres alguno cuya manera de hablar sobre la vida de acá te gusta, que toma a Alá por testigo de lo que su corazón encierra. Es un fogoso discutidor.\qt@no{204}}
\qt@newcmd\qurantrans@es@ccxii{Pero, apenas te vuelve la espalda, se esfuerza por corromper en el país y destruir las cosechas y el ganado. Alá no ama la corrupción.\qt@no{205}}
\qt@newcmd\qurantrans@es@ccxiii{Y. cuando se le dice: «¡Teme a Alá!», se apodera de él un orgullo criminal. Tendrá la gehena como retribución. ¡Qué mal lecho...!\qt@no{206}}
\qt@newcmd\qurantrans@es@ccxiv{Hay entre los hombres quien se sacrifica por deseo de agradar a Alá. Alá es manso con Sus siervos.\qt@no{207}}
\qt@newcmd\qurantrans@es@ccxv{¡Creyentes! ¡Entrad todos en la Paz y no sigáis los pasos del Demonio! Es para vosotros un enemigo declarado.\qt@no{208}}
\qt@newcmd\qurantrans@es@ccxvi{Pero si, después de haber recibido las pruebas claras, cometéis un desliz, sabed que Alá es poderoso, sabio.\qt@no{209}}
\qt@newcmd\qurantrans@es@ccxvii{¿Qué esperan sino que Alá y los ángeles vengan a ellos en un nublado? La cosa está ya decidida. Todo será devuelto a Alá.\qt@no{210}}
\qt@newcmd\qurantrans@es@ccxviii{Pregunta a los Hijos de Israel cuántos signos claros les dimos. Si uno, después de recibir la gracia de Alá, la cambia... Alá es severo en castigar.\qt@no{211}}
\qt@newcmd\qurantrans@es@ccxix{La vida de acá ha sido engalanada a los ojos de los infieles, que se burlan de los que creen. Pero los temerosos de Alá estarán por encima de ellos el día de la Resurrección. Y Alá provee sin medida a quien Él quiere.\qt@no{212}}
\qt@newcmd\qurantrans@es@ccxx{La Humanidad constituía una sola comunidad. Alá suscitó profetas portadores de buenas nuevas, que advertían, y reveló por su medio la Escritura con la Verdad para que decida entre los hombres sobre aquello en que discrepaban. Sólo aquéllos a quienes se les había dado discreparon sobre ella, a pesar de las pruebas claras recibidas, y eso por rebeldía mutua. Alá quiso dirigir a los creyentes hacia la Verdad, sobre la que los otros discrepaban. Alá dirige a quien Él quiere a una vía recta.\qt@no{213}}
\qt@newcmd\qurantrans@es@ccxxi{¿O creéis que vais a entrar en el Jardín antes de pasar por lo mismo que pasaron quienes os precedieron? Sufrieron el infortunio y la tribulación y una conmoción tal que el Enviado y los que con él creían dijeron: «¿Cuándo vendrá el auxilio de Alá?» Sí, el auxilio de Alá está cerca.\qt@no{214}}
\qt@newcmd\qurantrans@es@ccxxii{Te preguntan qué deben gastar. Di «Los bienes que gastéis, que sean para los padres, los parientes más cercanos, los huérfanos, los necesitados y el viajero». Alá conoce perfectamente el bien que hacéis.\qt@no{215}}
\qt@newcmd\qurantrans@es@ccxxiii{Se os ha prescrito que combatáis, aunque os disguste. Puede que os disguste algo que os conviene y améis algo que no os conviene. Alá sabe, mientras que vosotros no sabéis.\qt@no{216}}
\qt@newcmd\qurantrans@es@ccxxiv{Te preguntan si está permitido combatir en el mes sagrado. Di: «Combatir en ese mes es pecado grave. Pero apartar del camino de Alá -y negarle- y de la Mezquita Sagrada y expulsar de ella a la gente es aún más grave para Alá, así como tentar es más grave que matar». Si pudieran, no cesarían de combatir contra vosotros hasta conseguir apartaros de vuestra fe. Las obras de aquéllos de vosotros que apostaten de su fe y mueran como infieles serán vanas en la vida de acá y en la otra. Ésos morarán en el Fuego eternamente.\qt@no{217}}
\qt@newcmd\qurantrans@es@ccxxv{Quienes creyeron y quienes dejaron sus hogares, combatiendo esforzadamente por Alá, pueden esperar la misericordia de Alá. Alá es indulgente, misericordioso.\qt@no{218}}
\qt@newcmd\qurantrans@es@ccxxvi{Te preguntan acerca del vino y del maysir, Di: «Ambos encierran pecado grave y ventajas para los hombres, pero su pecado es mayor que su utilidad». Te preguntan qué deben gastar. Di: «Lo superfluo». Así o explica Alá las aleyas, Quizás, así, meditéis\qt@no{219}}
\qt@newcmd\qurantrans@es@ccxxvii{sobre la vida de acá y la otra. Te preguntan acerca de los huérfanos. Di: «Está bien mejorar su condición; pero, si mezcláis vuestra hacienda con la suya, tratadles como a hermanos». Alá distingue al corruptor del reformador. Y si Alá hubiera querido os habría afligido. Alá es poderoso, sabio.\qt@no{220}}
\qt@newcmd\qurantrans@es@ccxxviii{No os caséis con mujeres asociadoras hasta que crean. Una esclava creyente es mejor que una asociadora, aunque ésta os guste más. No caséis con asociadores hasta que éstos crean. Un esclavo creyente es mejor que un asociador, aunque éste os guste más. Ésos os llaman al Fuego, en tanto que Alá os llama al Jardín y al perdón si quiere, y explica Sus aleyas a los hombres. Quizás, así, se dejen amonestar.\qt@no{221}}
\qt@newcmd\qurantrans@es@ccxxix{Te preguntan acerca de la menstruación. Di: «Es un mal. ¡Manteneos, pues, aparte de las mujeres durante la menstruación y no os acerquéis a ellas hasta que se hayan purificado! Y cuando se hayan purificado, id a ellas como Alá os ha ordenado». Alá ama a quienes se arrepienten. Y ama a quienes se purifican.\qt@no{222}}
\qt@newcmd\qurantrans@es@ccxxx{Vuestras mujeres son campo labrado para vosotros. ¡Venid, pues, a vuestro campo como queráis, haciendo preceder algo para vosotros mismos! ¡Temed a Alá y sabed que Le encontraréis! ¡Y anuncia la buena nueva a los creyentes!\qt@no{223}}
\qt@newcmd\qurantrans@es@ccxxxi{Jurando por Alá, no hagáis de Él un obstáculo que os impida practicar la caridad, ser temerosos de Alá y reconciliar a los hombres. Alá todo lo oye, todo lo sabe.\qt@no{224}}
\qt@newcmd\qurantrans@es@ccxxxii{Alá no tendrá en cuenta la vanidad de vuestros juramentos, pero sí tendrá en cuenta la intención de vuestros corazones. Alá es indulgente, benigno.\qt@no{225}}
\qt@newcmd\qurantrans@es@ccxxxiii{Quienes juren no acercarse a sus mujeres tienen de plazo cuatro meses. Si se retractan,... Alá es indulgente, misericordioso.\qt@no{226}}
\qt@newcmd\qurantrans@es@ccxxxiv{Si se deciden por el repudio,... Alá todo lo oye, todo lo sabe.\qt@no{227}}
\qt@newcmd\qurantrans@es@ccxxxv{Las repudiadas deberán esperar tres menstruaciones. No les es lícito ocultar lo que Alá ha creado en su seno si es que creen en Alá y en el último Día. Durante esta espera, sus esposo tienen pleno derecho a tomarlas de nuevo si desean la reconciliación. Ellas tienen derechos equivalentes a sus obligaciones, conforme al uso, pero los hombres están un grado por encima de ellas. Alá es poderoso, sabio.\qt@no{228}}
\qt@newcmd\qurantrans@es@ccxxxvi{El repudio se permite dos veces. Entonces, o se retiene a la mujer tratándola como se debe o se la deja marchar de buena manera. No os es lícito recuperar nada de lo que les disteis, a menos que las dos partes teman no observar las leves de Alá. Y, si teméis que no observen las leyes de Alá, no hay inconveniente en que ella obtenga su libertad indemnizando al marido. Éstas son las leyes de Alá, no las violéis. Quienes violan las leyes de Alá, ésos son los impíos.\qt@no{229}}
\qt@newcmd\qurantrans@es@ccxxxvii{Si la repudia, ésta ya no le será permitida sino después de haber estado casada con otro. Si este último la repudia. no hay inconveniente en que aquéllos vuelvan a reunirse, si creen que observarán las leyes de Alá. Éstas son las leyes de Alá Las explica a gente que sabe.\qt@no{230}}
\qt@newcmd\qurantrans@es@ccxxxviii{Cuando repudiéis a vuestras mujeres y éstas alcancen su término, retenedlas como se debe o dejadlas en libertad como se debe. ¡No las sujetéis a la fuerza, en violación de las leyes de Alá! Quien esto hace es injusto consigo mismo. ¡No toméis a burla las aleyas de Alá, antes bien recordad la gracia de Alá para con vosotros y lo que os ha revelado de la Escritura y de la Sabiduría, exhortándoos con ello! ¡Temed a Alá y sabed que Alá es omnisciente!\qt@no{231}}
\qt@newcmd\qurantrans@es@ccxxxix{Cuando repudiéis a vuestras mujeres y éstas alcancen su término, no les impidáis que se casen con sus maridos, si se ponen buenamente de acuerdo. A esto se exhorta a quien de vosotros crea en Alá y en el último Día. Esto es más correcto para vosotros y más puro. Alá sabe, mientras que vosotros no sabéis.\qt@no{232}}
\qt@newcmd\qurantrans@es@ccxl{Las madres amamantarán a sus hijos durante dos años completos si desea que la lactancia sea completa. El padre debe sustentarlas y vestirlas conforme al uso. A nadie se le pedirá sino según sus posibilidades. No se dañará a la madre por razón de su hijo, ni al padre. Un deber semejante incumbe al heredero. Y no hay inconveniente en que el padre y la madre quieran, de mutuo acuerdo y luego de consultarse, destetar al niño. Y, si queréis emplear a una nodriza para vuestros hijos, no hacéis mal, siempre que paguéis lo acordado conforme al uso. ¡Temed a Alá y sabed que Alá ve bien lo que hacéis!\qt@no{233}}
\qt@newcmd\qurantrans@es@ccxli{Las viudas que dejéis deben esperar cuatro meses y diez días; pasado ese tiempo, no seréis ya responsables de lo que ellas dispongan de sí mismas conforme al uso. Alá está bien informado de lo que hacéis.\qt@no{234}}
\qt@newcmd\qurantrans@es@ccxlii{No hacéis mal en proponer a tales mujeres casaros con ellas o en ocultarles vuestra intención de hacerlo. Alá sabe que pensaréis en ellas. Pero ¡no les prometáis nada en secreto! ¡Habladas, más bien, como se debe! ¡Y no decidáis concluir el matrimonio hasta que se cumpla el período prescrito de espera! ¡Sabed que Alá conoce lo que hay en vuestras mentes, de modo que cuidado con Él! Pero sabed que Alá es indulgente, benigno.\qt@no{235}}
\qt@newcmd\qurantrans@es@ccxliii{.No hacéis mal en repudiar a vuestras mujeres mientras aún no las hayáis tocado o asignado dote. Proveedles, no obstante, como se debe, el acomodado según sus posibilidades y el pobre según las suyas. Esto constituye un deber para quienes hacen el bien.\qt@no{236}}
\qt@newcmd\qurantrans@es@ccxliv{Y, si las repudiáis antes de tocarlas y luego de haberles asignado dote, pagadles la mitad de lo asignado, a menos que ellas o aquél en cuya mano esté la conclusión del matrimonio renuncien a ello. La renuncia es más conforme al temor de Alá. No os olvidéis de mostraros generosos unos con otros. Alá ve bien lo que hacéis.\qt@no{237}}
\qt@newcmd\qurantrans@es@ccxlv{¡Observad las azalás -sobre todo. la azalá intermedia- y estad con devoción ante Alá!\qt@no{238}}
\qt@newcmd\qurantrans@es@ccxlvi{Si teméis algún peligro, de pie o montados. Y, cuando estéis en seguridad, ¡recordad a Alá... cómo os enseño lo que no sabíais...!\qt@no{239}}
\qt@newcmd\qurantrans@es@ccxlvii{Los que de vosotros mueran dejando esposas deberían testar en favor de ellas para su mantenimiento durante un año sin echarlas. Y, si ellas se van, no se os reprochará lo que ellas hagan honradamente respecto a su persona. Alá es poderoso, sabio.\qt@no{240}}
\qt@newcmd\qurantrans@es@ccxlviii{Hay que proveer a las repudiadas como se debe. Esto constituye un deber para los temerosos de Alá.\qt@no{241}}
\qt@newcmd\qurantrans@es@ccxlix{Así explica Alá Sus aleyas. Quizás, así, razonéis.\qt@no{242}}
\qt@newcmd\qurantrans@es@ccl{¿No has visto a quienes, por millares, dejaron sus hogares por miedo a la muerte? Alá les había dicho: «¡Morid!» Luego, les resucitó. Sí, Alá dispensa Su favor a los hombres, pero la mayoría de los hombres no agradecen.\qt@no{243}}
\qt@newcmd\qurantrans@es@ccli{¡Combatid por Alá y sabed que Alá todo lo oye, todo lo sabe!\qt@no{244}}
\qt@newcmd\qurantrans@es@cclii{¿Quién será el que haga un préstamo generoso a Alá? Alá se lo devolverá multiplicado. Alá cierra y abre. Seréis devueltos a Él.\qt@no{245}}
\qt@newcmd\qurantrans@es@ccliii{¿No has visto a los dignatarios de los Hijos de Israel? Cuando, después de Moisés, dijeron a un profeta suyo: «¡Suscítanos a un rey para que combatamos por Alá!» Dijo: «Puede que no combatáis una vez que se os prescriba el combate». Dijeron: «¿Cómo no vamos a combatir por Alá si se nos ha expulsado de nuestros hogares y de nuestros hijos?» Pero, cuando se les prescribió el combate, volvieron la espalda, salvo unos pocos. Alá conoce bien a los impíos.\qt@no{246}}
\qt@newcmd\qurantrans@es@ccliv{Su profeta les dijo: «Alá os ha suscitado a Saúl como rey». Dijeron: «¿Cómo va él a dominar sobre nosotros si nosotros tenemos más derecho que él al dominio y no se le ha concedido abundancia de hacienda?» Dijo: «Alá lo ha escogido prefiriéndolo a vosotros y le ha dado más ciencia y más cuerpo». Alá da Su dominio a quien Él quiere. Alá es inmenso, omnisciente.\qt@no{247}}
\qt@newcmd\qurantrans@es@cclv{Su profeta les dijo: «El signo de su dominio será que el Arca volverá a vosotros, llevada por los ángeles, con sakina de vuestro Señor y reliquia de lo que dejaron las gentes de Moisés y de Aarón. Ciertamente tenéis en ello un signo, si es que sois creyentes».\qt@no{248}}
\qt@newcmd\qurantrans@es@cclvi{Y, cuando Saúl marchó con los soldados, dijo: «Alá os probará con un arroyo. Quien beba de él no será de los míos. Quien no lo pruebe, será de los míos, a menos que beba una sola vez del hueco de la mano». Y bebieron de él, salvo unos pocos. Y, cuando él y los que creían lo hubieron cruzado, dijeron: «Hoy no podemos nada contra Goliat y sus soldados». Los que contaban con encontrar a Alá dijeron: «¡Cuántas veces una tropa reducida ha vencido a otra considerable con permiso de Al á! Alá está con los que tienen paciencia».\qt@no{249}}
\qt@newcmd\qurantrans@es@cclvii{Y, cuando salieron contra Goliat y sus soldados, dijeron: «¡Señor! ¡Infunde en nosotros paciencia, afirma nuestros pasos, auxílianos contra el pueblo infiel!»\qt@no{250}}
\qt@newcmd\qurantrans@es@cclviii{Y les derrotaron con permiso de Alá. David mató a Goliat y Alá le dio el dominio y la sabiduría, y le enseñó lo que Él quiso. Si Alá no hubiera rechazado a unos hombres valiéndose de otros, la tierra se habría ya corrompido. Pero Alá dispensa Su favor a todos.\qt@no{251}}
\qt@newcmd\qurantrans@es@cclix{Éstas son las aleyas de Alá, que te recitamos conforme a la verdad. Ciertamente, tú eres uno de los enviados.\qt@no{252}}
\qt@newcmd\qurantrans@es@cclx{Éstos son los enviados. Hemos preferido a unos más que a otros. A alguno de ellos Alá ha hablado. Y a otros les ha elevado en categoría. Dimos a Jesús, hijo de María, las pruebas claras, y le fortalecimos con el Espíritu Santo. Si Alá hubiera querido, los que les siguieron no habrían combatido unos contra otros, después de haber recibido las pruebas claras. Pero discreparon: de ellos, unos creyeron y otros o. Si Alá hubiera querido, no habrían combatido unos contra otros. Pero Alá hace lo que quiere.\qt@no{253}}
\qt@newcmd\qurantrans@es@cclxi{¡Creyentes! Dad limosna de lo que os hemos proveído antes de que venga un día en que no sirvan ni comercio ni amistad ni intercesión. Los infieles, ésos son los impíos.\qt@no{254}}
\qt@newcmd\qurantrans@es@cclxii{¡Alá! No hay más dios que El. el Viviente, el Subsistente. Ni la somnolencia ni el sueño se apoderan de Él. Suyo es lo que está en los cielos y en la tierra. ¿Quién podrá interceder ante Él si no es con Su permiso? Conoce su pasado y su futuro, mientras que ellos no abarcan nada de Su ciencia, excepto lo que Él quiere. Su Trono se extiende sobre los cielos y sobre la tierra y su conservación no le resulta onerosa. Él es el Altísimo, el Grandioso.\qt@no{255}}
\qt@newcmd\qurantrans@es@cclxiii{No cabe coacción en religión. La buena dirección se distingue claramente del descarrío. Quien no cree en los taguts y cree en Alá, ese tal se ase del asidero más firme, de un asidero irrompible. Alá todo lo oye, todo lo sabe.\qt@no{256}}
\qt@newcmd\qurantrans@es@cclxiv{Alá es el Amigo de los que creen, les saca de las tinieblas a la luz. Los que no creen, en cambio, tienen como amigos a los taguts, que les sacan de la luz a las tinieblas. Ésos morarán en el Fuego eternamente.\qt@no{257}}
\qt@newcmd\qurantrans@es@cclxv{¿No has visto a quien disputaba con Abraham sobre su Señor porque Alá le había dado el dominio? Cuando Abraham dijo: «Mi Señor es Quien da la vida y da la muerte». Dijo: «Yo doy la vida y doy a muerte». Abraham dijo: «Alá trae el sol por oriente; tráelo tú por Occidente». Así fue confundido el infiel. Alá no dirige al pueblo impío.\qt@no{258}}
\qt@newcmd\qurantrans@es@cclxvi{O como quien pasó por una ciudad en ruinas. Dijo: «¿Cómo va Alá a devolver la vida a ésta después de muerta?» Alá le hizo morir y quedar así durante cien años. Luego, le resucitó y dijo: «¿Cuánto tiempo has permanecido así?» Dijo: «He permanecido un día o parte de un día». Dijo: «No, que has permanecido así cien años. ¡Mira tu alimento y tu bebida! N se han echado a perder. ¡Mira a tu asno! Para hacer de ti un signo para los hombres. ¡Mira los huesos, cómo los componemos y los cubrimos de carne!». Cuando lo vio claro, dijo: «Ahora sé que Alá es omnipotente».\qt@no{259}}
\qt@newcmd\qurantrans@es@cclxvii{Y cuando Abraham dijo: «¡Señor. muéstrame cómo devuelves la vida a los muertos!» Dijo: «¿Es que no crees?» Dijo: «Claro que sí, pero es para tranquilidad de mi corazón». Dijo: «Entonces, coge cuatro aves y despedázalas. Luego, pon en cada montaña un pedazo de ellas y llámalas. Acudirán a ti rápidamente. Sabe que Alá es poderoso, sabio».\qt@no{260}}
\qt@newcmd\qurantrans@es@cclxviii{Quienes gastan su hacienda por Alá son semejantes a un grano que produce siete espigas, cada una de las cuales contiene cien granos. Así dobla Alá a quien Él quiere. Alá es inmenso, omnisciente.\qt@no{261}}
\qt@newcmd\qurantrans@es@cclxix{Quienes gastan su hacienda por Alá sin hacerlo seguir de alarde ni agravio tendrán su recompensa junto a su Señor. No tienen que temer y no estarán tristes.\qt@no{262}}
\qt@newcmd\qurantrans@es@cclxx{Una palabra cariñosa, un perdón valen más que una limosna seguida de agravio. Alá Se basta a Sí mismo, es benigno.\qt@no{263}}
\qt@newcmd\qurantrans@es@cclxxi{¡Creyentes! No malogréis vuestras limosnas alardeando de ellas o agraviando, como quien gasta su hacienda para ser visto de los hombres, sin creer en Alá ni en el último Día. Ese tal es semejante a una roca cubierta de tierra. Cae sobre ella un aguacero y la deja desnuda. No pueden esperar nada por lo que han merecido. Alá no dirige al pueblo infiel.\qt@no{264}}
\qt@newcmd\qurantrans@es@cclxxii{Quienes gastan su hacienda por deseo de agradar a Alá y por su propio fortalecimiento son semejantes a un jardín plantado en una colina. Si cae sobre él un aguacero, da fruto doble; si no cae, rocío. Alá ve bien lo que hacéis.\qt@no{265}}
\qt@newcmd\qurantrans@es@cclxxiii{¿Desearía alguno de vosotros poseer un jardín de palmeras y vides por cuyo bajo fluyeran arroyos, con toda clase de frutos, envejecer mientras sus hijos son aún débiles y que un torbellino de fuego cayera sobre el jardín y éste se incendiara? Así os explica Alá las aleyas. Quizás, así meditéis.\qt@no{266}}
\qt@newcmd\qurantrans@es@cclxxiv{¡Creyentes! ¡Dad limosna de las cosas buenas que habéis adquirido y de lo que, para vosotros, hemos sacado de la tierra! Y no elijáis lo malo para vuestras limosnas, como tampoco vosotros lo tomaríais a menos que tuvierais los ojos cerrados. Sabed que Alá Se basta a Sí mismo, es digno de alabanza.\qt@no{267}}
\qt@newcmd\qurantrans@es@cclxxv{El Demonio os amenaza con la pobreza y os ordena lo deshonesto, mientras que Alá os promete Su perdón y favor. Alá es inmenso, omnisciente.\qt@no{268}}
\qt@newcmd\qurantrans@es@cclxxvi{Concede la sabiduría a quien Él quiere. Y quien recibe la sabiduría recibe mucho bien. Pero no se dejan amonestar sino los dotados de intelecto.\qt@no{269}}
\qt@newcmd\qurantrans@es@cclxxvii{Sea cual sea la limosna que deis, sea cual sea el voto que hagáis, Alá lo conoce. Y los impíos no tendrán quien les auxilie.\qt@no{270}}
\qt@newcmd\qurantrans@es@cclxxviii{Si dais limosna públicamente, es algo excelente. Pero, si la dais ocultamente y a los pobres, es mejor para vosotros y borrará en parte vuestras malas obras. Alá está bien informado de lo que hacéis.\qt@no{271}}
\qt@newcmd\qurantrans@es@cclxxix{No tienes tú por qué dirigirles sino que Alá dirige a quien Él quiere. Lo que hagáis de bien redundará en vuestro propio beneficio. Y no lo hagáis si no es por deseo de agradara Alá. Lo que hagáis de bien os será devuelto y no seréis tratados injustamente.\qt@no{272}}
\qt@newcmd\qurantrans@es@cclxxx{Para los pobres que están en la miseria por haberse dedicado a la causa de Alá y que no pueden desplazarse. El ignorante los cree ricos porque se abstienen. Les reconocerás por su aspecto. No piden a la gente inoportunamente. Y lo que hacéis de bien, Alá lo conoce perfectamente.\qt@no{273}}
\qt@newcmd\qurantrans@es@cclxxxi{Los que gastan su hacienda de noche o de día, en secreto o en público, tendrán su recompensa junto a su Señor. No tienen que temer y no estarán tristes.\qt@no{274}}
\qt@newcmd\qurantrans@es@cclxxxii{Quienes usurean no se levantarán sino como se levanta aquél a quien el Demonio ha derribado con sólo tocarle, y eso por decir que el comercio es como la usura, siendo así que Alá ha autorizado el comercio y prohibido la usura. Quien. exhortado por su Señor. renuncie conservará lo que haya ganado. Su caso está en manos de Alá. Los reincidentes, ésos serán los condenados al Fuego y en él permanecerán para siempre.\qt@no{275}}
\qt@newcmd\qurantrans@es@cclxxxiii{Alá hace que se malogre la usura, pero hace fructificar la limosna. Alá no ama a nadie que sea infiel pertinaz, pecador.\qt@no{276}}
\qt@newcmd\qurantrans@es@cclxxxiv{Los que hayan creído y obrado bien, los que hayan hecho la azalá y dado el azaque tendrán su recompensa junto a su Señor. No tienen que temer y no estarán tristes.\qt@no{277}}
\qt@newcmd\qurantrans@es@cclxxxv{¡Creyentes! ¡Temed a Alá! ¡Y renunciad a los provechos pendientes de la usura, si es que sois creyentes!\qt@no{278}}
\qt@newcmd\qurantrans@es@cclxxxvi{Si no lo hacéis así, podéis esperar guerra de Alá y Su Enviado. Pero, si os arrepentís, tendréis vuestro capital, no siendo injustos ni siendo tratados injustamente.\qt@no{279}}
\qt@newcmd\qurantrans@es@cclxxxvii{Si está en apuro, concededle un respiro hasta que se alivie su situación. Y aún sería mejor para vosotros que le condonarais la deuda. Si supierais...\qt@no{280}}
\qt@newcmd\qurantrans@es@cclxxxviii{Temed un día en que seréis devueltos a Alá. Entonces, cada uno recibirá su merecido. Y no serán tratados injustamente.\qt@no{281}}
\qt@newcmd\qurantrans@es@cclxxxix{¡Creyentes!. Si contraéis una deuda por un plazo determinado, ponedlo por escrito. Que un escribano tome fiel nota en vuestra presencia, sin rehusarse a escribir como Alá le dé a entender. Que escriba. Que el deudor dicte en el temor de Alá, su Señor, y que no deduzca nada. Y si el deudor fuera necio, débil o incapaz de dictar, que dicte su procurador con fidelidad. Llamad, para que sirvan de testigos, a dos de vuestros hombres; s no los hay, elegid a un hombre y a dos mujeres de entre quienes os plazcan como testigos, de tal modo que si una yerra, la otra subsane su error. Que los testigos no se sustraigan cuando se les llame. Que no os repugne subscribir una deuda, sea pequeña o grande, precisando su vencimiento. Esto es más equitativo ante Alá, es más correcto para el testimonio y da menos lugar a dudas. A menos que se trate de una operación concluida entre vosotros sin intermediarios; entonces, no hay inconveniente en que no lo pongáis por escrito. Pero ¡tomad testigos cuando os vendáis algo! ¡Y que no se moleste al escribano ni al testigo! Si lo hacéis, cometeréis una iniquidad. ¡Temed a Alá! Alá os instruye. Alá es omnisciente.\qt@no{282}}
\qt@newcmd\qurantrans@es@ccxc{Y si estáis de viaje y no encontráis escribano, que se deposite una fianza. Si uno confía un depósito a otro, debe el depositario restituir el depósito en el temor de Alá, su Señor. Y no rehuséis deponer como testigos. Quien rehúsa tiene un corazón pecador. Alá sabe bien lo que hacéis.\qt@no{283}}
\qt@newcmd\qurantrans@es@ccxci{De Alá es lo que está en los cielos y en la tierra. Lo mismo si manifestáis lo que tenéis en vosotros que si lo ocultáis, Alá os pedirá cuenta de ello Perdona a quien Él quiere y castiga a quien Él quiere. Alá es omnipotente.\qt@no{284}}
\qt@newcmd\qurantrans@es@ccxcii{El Enviado cree en cuanto le ha sido revelado por su Señor, y lo mismo los creyentes. Todos ellos creen en Alá, en Sus ángeles. en Sus Escrituras y en Sus enviados. No hacemos distinción ente ninguno de Sus enviados. Han dicho: «Oímos y obedecemos. ¡Tu perdón, Señor! ¡Eres Tú el fin de todo!»\qt@no{285}}
\qt@newcmd\qurantrans@es@ccxciii{Alá no pide nada a nadie más allá de sus posibilidades. Lo que uno haya hecho redundará en su propio bien o en su propio mal. ¡Señor! ¡No castigues nuestros olvidos o nuestras faltas! ¡Señor! ¡No nos impongas una carga como la que impusiste a quienes nos precedieron! ¡Señor! ¡No nos impongas más allá de nuestras fuerzas! ¡Y absuélvenos, perdónanos, apiádate d nosotros! ¡Tú eres nuestro Protector! ¡Auxílianos contra el pueblo infiel!\qt@no{286}}
\qt@newcmd\qurantrans@es@ccxciv{\basmalahes `lm.\qt@no{1}}
\qt@newcmd\qurantrans@es@ccxcv{¡Alá! No hay más dios que Él, el Viviente, el Subsistente.\qt@no{2}}
\qt@newcmd\qurantrans@es@ccxcvi{Él te ha revelado la Escritura con la Verdad, en confirmación de los mensajes anteriores. Él ha revelado la Toro y el Evangelio\qt@no{3}}
\qt@newcmd\qurantrans@es@ccxcvii{antes, como dirección para los hombres, y ha revelado el Criterio. Quienes no crean en los signos de Alá tendrán un castigo severo. Alá es poderoso, vengador.\qt@no{4}}
\qt@newcmd\qurantrans@es@ccxcviii{No hay nada en la tierra ni en el cielo que se esconda de Alá.\qt@no{5}}
\qt@newcmd\qurantrans@es@ccxcix{Él es Quien os forma en el seno como quiere. No hay más dios que Él, el Poderoso, el Sabio.\qt@no{6}}
\qt@newcmd\qurantrans@es@ccc{Él es Quien te ha revelado la Escritura. Algunas de sus aleyas son unívocas y constituyen la Escritura Matriz; otras son equívocas. Los de corazón extraviado siguen las equívocas, por espíritu de discordia y por ganas de dar la interpretación de ello. Pero nadie sino Alá conoce la interpretación de ello. Los arraigados en la Ciencia dicen:«Creemos en ello. Todo procede de nuestro Señor». Pero no se dejan amonestar sino los dotados de intelecto.\qt@no{7}}
\qt@newcmd\qurantrans@es@ccci{¡Señor! ¡No hagas que nuestros corazones se desvíen, después de habernos Tú dirigido! ¡Regálanos, de Ti, misericordia! Tú eres el Munífico.\qt@no{8}}
\qt@newcmd\qurantrans@es@cccii{¡Señor! Tú eres quien va a reunir a los hombres para un día indubitable. Alá no falta a Su promesa.\qt@no{9}}
\qt@newcmd\qurantrans@es@ccciii{A quienes no crean, ni su hacienda ni sus hijos les servirán de nada frente a Alá. Ésos servirán de combustible para el Fuego.\qt@no{10}}
\qt@newcmd\qurantrans@es@ccciv{Como ocurrió con la gente de Faraón y con los que les precedieron: desmintieron Nuestros signos y Alá les castigó por sus pecados. Alá castiga severamente.\qt@no{11}}
\qt@newcmd\qurantrans@es@cccv{Di a quienes no creen: «Seréis vencidos y congregados hacia la gehena». ¡Qué mal lecho...!\qt@no{12}}
\qt@newcmd\qurantrans@es@cccvi{Tuvisteis un signo en las dos tropas que se encontraron: la que combatía por Alá y la otra, infiel, que, a simple vista, creyó que aquélla le doblaba en número. Alá fortalece con Su auxilio a quien Él quiere. Sí, hay en ello motivo de reflexión para quienes tienen ojos.\qt@no{13}}
\qt@newcmd\qurantrans@es@cccvii{El amor de lo apetecible aparece a los hombres engalanado: las mujeres, los hijos varones, el oro y la plata por quintales colmados, los caballos de raza, los rebaños los campos de cultivo... Eso es breve disfrute de la vida de acá. Pero Alá tiene junto a Sí un bello lugar de retorno.\qt@no{14}}
\qt@newcmd\qurantrans@es@cccviii{Di: «¿Puedo informaros de algo mejor que eso?» Quienes teman a Alá encontrarán junto a su Señor jardines por cuyos bajos fluyen arroyos y en los que estarán eternamente, esposas purificadas y la satisfacción de Alá. Alá ve bien a Sus siervos,\qt@no{15}}
\qt@newcmd\qurantrans@es@cccix{que dicen: «¡Señor! ¡Nosotros creemos! ¡Perdónanos, pues, nuestros pecados y presérvanos del castigo del Fuego!»,\qt@no{16}}
\qt@newcmd\qurantrans@es@cccx{pacientes, sinceros, devotos, que practican la caridad y piden perdón al rayar el alba.\qt@no{17}}
\qt@newcmd\qurantrans@es@cccxi{Alá atestigua, y con Él los ángeles y los hombres dotados de ciencia, que no hay más dios que Él, Que vela por la equidad. No hay más dios que Él, el Poderoso, el Sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@cccxii{Ciertamente, la Religión, para Alá, es el islam. Aquéllos a quienes se dio la Escritura no se opusieron unos a otros, por rebeldía mutua, sino después de haber recibido la Ciencia. Quien no cree en los signos de Alá,... Alá es rápido en ajustar cuentas.\qt@no{19}}
\qt@newcmd\qurantrans@es@cccxiii{Si disputan contigo, di: «Yo me someto a Alá y lo mismo hacen quienes me siguen». Y di a quienes recibieron la Escritura y a quienes no la recibieron. «¿Os convertís al islam?», Si se convierten , están bien dirigidos; si vuelven la espalda, a ti sólo te incumbe la transmisión. Alá ve bien a Sus siervos.\qt@no{20}}
\qt@newcmd\qurantrans@es@cccxiv{Anuncia un castigo doloroso a quienes no creen en los signos de Alá, matan a los profetas sin justificación y matan a los hombres que ordenan la equidad.\qt@no{21}}
\qt@newcmd\qurantrans@es@cccxv{Ésos son aquéllos cuyas obras son vanas en la vida de acá y en la otra y no tendrán quienes les auxilien.\qt@no{22}}
\qt@newcmd\qurantrans@es@cccxvi{¿No has visto a quienes han recibido una porción de la Escritura ? Se les invita a que acepten la Escritura de Alá para que decida entre ellos, pero algunos vuelven la espalda y se van.\qt@no{23}}
\qt@newcmd\qurantrans@es@cccxvii{Es que han dicho: «El fuego no nos tocará más que por días contados». Sus propias mentiras les han engañado en su religión.\qt@no{24}}
\qt@newcmd\qurantrans@es@cccxviii{¿Qué pasará cuando les reunamos para un día indubitable y cada uno reciba su merecido? Y no serán tratados injustamente.\qt@no{25}}
\qt@newcmd\qurantrans@es@cccxix{Di: «¡Oh, Alá, Dueño del dominio! Tú das el dominio a quien quieres y se lo retiras a quien quieres, exaltas a quien quieres y humillas a quien quieres. En Tu mano está el bien. Eres omnipotente.\qt@no{26}}
\qt@newcmd\qurantrans@es@cccxx{Tú haces que la noche entre en el día y que el día entre en la noche. Tú sacas al vivo del muerto y al muerto del vivo. Tú provees sin medida a quien quieres».\qt@no{27}}
\qt@newcmd\qurantrans@es@cccxxi{Que no tomen los creyentes como amigos a los infieles en lugar de tomar a los creyentes -quien obre así notendrá ninguna participación en Alá-, a menos quetengáis algo que temer de ellos. Al á os advierte quetengáis cuidado con Él. ¡Alá es el fin de todo!\qt@no{28}}
\qt@newcmd\qurantrans@es@cccxxii{Di: «Lo mismo si escondéis lo que tenéis en vuestros pechos que si lo manifestáis, Alá lo conoce». Y conoce lo que está en los cielos y en la tierra. Alá es omnipotente.\qt@no{29}}
\qt@newcmd\qurantrans@es@cccxxiii{El día que cada uno se encuentre frente al bien y el mal que ha hecho, deseará tener bien lejos ese día. Alá advierte que tengáis cuidado con Él. Alá es manso con Sus siervos.\qt@no{30}}
\qt@newcmd\qurantrans@es@cccxxiv{Di: «Si amáis a Alá ,¡seguidme! Alá os amará y os perdonará vuestros pecados. Alá es indulgente, misericordioso».\qt@no{31}}
\qt@newcmd\qurantrans@es@cccxxv{Di: «¡Obedeced a Alá y al Enviado!»Si vuelven la espalda,... Alá no ama a los infieles.\qt@no{32}}
\qt@newcmd\qurantrans@es@cccxxvi{Alá ha escogido a Adán, a Noé, a la familia de Abraham y a la de Imran por encima de todos.\qt@no{33}}
\qt@newcmd\qurantrans@es@cccxxvii{Como descendientes unos de otros. Alá todo lo oye. todo lo sabe.\qt@no{34}}
\qt@newcmd\qurantrans@es@cccxxviii{Cuando la mujer de Imran dijo: «¡Señor! Te ofrezco en voto, a Tu exclusivo servicio, lo que hay en mi seno. ¡Acéptamelo! Tú eres Quien todo lo oye, Quien todo lo sabe».\qt@no{35}}
\qt@newcmd\qurantrans@es@cccxxix{Y cuando dio a luz a una hija, dijo:«¡Señor! Lo que he dado a luz es una hembra -bien sabía Alá lo que había dado a luz- y un varón no es igual que una hembra. Le he puesto por nombre María y la pongo bajo Tu protección contra el maldito Demonio, y también a su descendencia».\qt@no{36}}
\qt@newcmd\qurantrans@es@cccxxx{Su Señor la acogió favorablemente, la hizo crecer bien y la confió a Zacarías. Siempre que Zacarías entraba en el Templo para verla, encontraba sustento junto a ella. Decía:«María!, ¿de dónde te viene eso?» Decía ella:«De Alá. Alá provee sin medida a quien Él quiere».\qt@no{37}}
\qt@newcmd\qurantrans@es@cccxxxi{Entonces, Zacarías invocó a su Señor diciendo: «¡Señor! ¡Regálame, de Ti, una descendencia buena! Tú escuchas a quien Te invoca».\qt@no{38}}
\qt@newcmd\qurantrans@es@cccxxxii{Los ángeles le llamron cuando, de pie, oraba en el Templo: «Alá te anuncia la buena nueva de Juan, en confirmación de una Palabra que procede de Alá, y que será jefe, abstinente, profeta, de l os justos».\qt@no{39}}
\qt@newcmd\qurantrans@es@cccxxxiii{«¡Señor!» dijo, «¿cómo puedo tener un muchacho si soy ya viejo y mi mujer estéril?» Dijo:«Así será. Alá hace lo que Él quiere».\qt@no{40}}
\qt@newcmd\qurantrans@es@cccxxxiv{Dijo: «¡Señor! ¡Dame un signo!»Dijo. «Tu signo será que no podrás hablar a la gente durante tres días sino por señas. Recuerda mucho a tu Señor y glorifícale, al anochecer y al alba».\qt@no{41}}
\qt@newcmd\qurantrans@es@cccxxxv{Y cuando los ángeles dijeron:«¡María! Alá te ha escogido y purificado. Te ha escogido entre todas las mujeres del universo.\qt@no{42}}
\qt@newcmd\qurantrans@es@cccxxxvi{¡María! ¡Ten devoción a tu Señor, prostérnate e inclínate con los que se inclinan!»\qt@no{43}}
\qt@newcmd\qurantrans@es@cccxxxvii{Esto forma parte de las historias referentes a lo oculto, que Nosotros te revelamos. Tú no estabas con ellos cuando echaban suertes con sus cañas para ver quién de ellos iba a encargarse de María. Tú no estabas con ellos cuando disputaban.\qt@no{44}}
\qt@newcmd\qurantrans@es@cccxxxviii{Cuando los ángeles dijeron: «¡María! Alá te anuncia la buena nueva de una Palabra que procede de Él. Su nombre es el Ungido, Jesús, hijo de María, considerado en la vida de acá y en la otra y será de los allegados.\qt@no{45}}
\qt@newcmd\qurantrans@es@cccxxxix{Hablará a la gente en la cuna y de adulto, y será de los justos».\qt@no{46}}
\qt@newcmd\qurantrans@es@cccxl{Dijo ella:«¡Señor! ¿Cómo puedo tener un hijo, si no me ha tocado mortal?» Dijo: «Así será. Alá crea lo que Él quiere. Cuando decide algo, le dice tan sólo: ``¡Sé!" y es.\qt@no{47}}
\qt@newcmd\qurantrans@es@cccxli{Él le enseñara la Escritura, la Sabiduría, la Tora y elEvangelio».\qt@no{48}}
\qt@newcmd\qurantrans@es@cccxlii{Y como enviado a los Hijos de Israel: «Os he traído un signo que viene de vuestro Señor. Voy a crear para vosotros, de la arcilla, a modo de pájaros. Entonces, soplaré en ellos y, con permiso de Alá, se convertirán en pájaros. Con permiso de Alá, curaré al ciego de nacimiento y al leproso y resucitaré a los muertos. Os informaré de lo que coméis y de lo que almacenáis en vuestras casas. Ciertamente, tenéis en ello un signo, si es que sois creyentes.\qt@no{49}}
\qt@newcmd\qurantrans@es@cccxliii{Y en confirmación de la Toraanterior a mí y para declararos lícitas algunas de las cosas que se os han prohibido. Y os he traído un signo que viene de vuestro Señor. ¡Temed, pues, a Alá y obedecedme!\qt@no{50}}
\qt@newcmd\qurantrans@es@cccxliv{Alá es mi Señor y Señor vuestro. ¡Servidle, pues! Esto es una vía recta».\qt@no{51}}
\qt@newcmd\qurantrans@es@cccxlv{Pero, cuando Jesús percibió su incredulidad, dijo: «¿Quiénes son mis auxiliares en la vía que lleva a Alá?» Los apóstoles dijeron: «Nosotros somos los auxiliares de Alá. ¡Creemos en Alá! ¡Sé testigo de nuestra sumisión!\qt@no{52}}
\qt@newcmd\qurantrans@es@cccxlvi{¡Señor! Creemos en lo que has revelado y seguimos al enviado. Inscríbenos, pues, entre los que dan testimonio».\qt@no{53}}
\qt@newcmd\qurantrans@es@cccxlvii{E intrigaron y Alá intrigó también. Pero Alá es el Mejor de los que intrigan.\qt@no{54}}
\qt@newcmd\qurantrans@es@cccxlviii{Cuando Alá dijo: «¡Jesús! Voy a llamarte a Mí, voy a elevarte a Mí, voy a librarte de los que no creen y poner, hasta el día de la Resurrección, a los que te siguen por encima de los que no creen. Luego, volveréis a Mí y decidiré entre vosotros sobre aquello en que discrepabais.\qt@no{55}}
\qt@newcmd\qurantrans@es@cccxlix{A quienes no crean les castigaré severamente en la vida de acá y en la otra. Y no tendrán quienes les auxilien.\qt@no{56}}
\qt@newcmd\qurantrans@es@cccl{En cuanto a quienes crean y obren bien, Él les remunerará debidamente. Alá no ama a los impíos».\qt@no{57}}
\qt@newcmd\qurantrans@es@cccli{Esto te recitamos de las aleyas y de la sabia Amonestación.\qt@no{58}}
\qt@newcmd\qurantrans@es@ccclii{Para Alá, Jesús es semejante a Adán, a quien creó de tierra y a quien dijo:«¡Sé!» y fue.\qt@no{59}}
\qt@newcmd\qurantrans@es@cccliii{La Verdad viene de tu Señor. ¡No seas, pues, de los que dudan!\qt@no{60}}
\qt@newcmd\qurantrans@es@cccliv{Si alguien disputa contigo a este propósito, después de haber sabido tú lo que has sabido, di:«¡Venid! Vamos a llamar a nuestros hijos varones y a vuestros hijos varones, a nuestras mujeres y a vuestra s mujeres, a nosotros mismos y a vosotros mismos. Execrémonos mutuamente e imprequemos la maldición de Alá sobre quienes mientan».\qt@no{61}}
\qt@newcmd\qurantrans@es@ccclv{Ésta es la exposición auténtica. No hay ningún otro dios que Alá. Alá es el Poderoso, el Sabio.\qt@no{62}}
\qt@newcmd\qurantrans@es@ccclvi{Si vuelven la espalda... Alá conoce bien a los corruptores.\qt@no{63}}
\qt@newcmd\qurantrans@es@ccclvii{Di: «¡Gente de la Escritura !Convengamos en una fórmula aceptable a nosotros y a vosotros, según la cual no serviremos sino a Alá, no Le asociaremos nada y no tomaremos a nadie de entre nosotros como Señor fuera de Alá». Y, si vuelven la espalda, decid: «¡Sed testigos de nuestra sumisión!»\qt@no{64}}
\qt@newcmd\qurantrans@es@ccclviii{¡Gente dela Escritura ! ¿Por qué disputáis de Abraham, siendo así que la Tora y el Evangelio no fueron revelados sino después de él? ¿Es que no razonáis?\qt@no{65}}
\qt@newcmd\qurantrans@es@ccclix{¡Mirad cómo sois! Disputabais de lo que conocíais. ¿Vais a disputar de lo que no conocéis? Alá sabe, mientras que vosotros no sabéis.\qt@no{66}}
\qt@newcmd\qurantrans@es@ccclx{Abraham no fue judío ni cristiano, sino que fue hanif, sometido a Alá, no asociador.\qt@no{67}}
\qt@newcmd\qurantrans@es@ccclxi{Los más allegados a Abraham son los que le han seguido, así como este Profeta y los que han creído. Alá es el Amigo de los creyentes.\qt@no{68}}
\qt@newcmd\qurantrans@es@ccclxii{Un grupo de la gente de la Escritura desearía extraviaros; pero a nadie sino a sí mismos extravían y no se dan cuenta.\qt@no{69}}
\qt@newcmd\qurantrans@es@ccclxiii{¡Gente de la Escritura ! ¿Porqué no creéis en los signos de Alá, siendo, como sois, testigos de ellos?\qt@no{70}}
\qt@newcmd\qurantrans@es@ccclxiv{¡Gente de laEscritura ! ¿Por qué disfrazáis la Verdad de falsedad y ocultáis la Verdad conociéndola?\qt@no{71}}
\qt@newcmd\qurantrans@es@ccclxv{Otro grupo de la gente de la Escrituradice: «¡Creed al comenzar el día en lo que se ha revelado a los que creen y dejad de creer al terminar el día! Quizás, así, se conviertan.\qt@no{72}}
\qt@newcmd\qurantrans@es@ccclxvi{Y no creáis sino a quienes siguen vuestra religión». Di: «La Dirección es la dirección de Alá. Que no se dé a otro lo que se os ha dado a vosotros, que no discutan con vosotros ante vuestro Señor». Di: «El favor está en la mano de Alá, Que lo dispensa a quien Él quiere». Alá es inmenso, omnisciente.\qt@no{73}}
\qt@newcmd\qurantrans@es@ccclxvii{Particulariza con Su misericordia a quien Él quiere. Alá es el Dueño del favor inmenso.\qt@no{74}}
\qt@newcmd\qurantrans@es@ccclxviii{Entre la gente de laEscritura hay quien, si le confías un quintal, te lo devuelve y hay quien, si le confías un dinar, no te lo devuelve sino es atosigándole. Y esto es así porque dicen: «No tenemos por qué ser escrupulosos con los gentiles». Mienten contra Alá a sabiendas.\qt@no{75}}
\qt@newcmd\qurantrans@es@ccclxix{¡Pues sí! Si uno cumple su promesa y teme a Alá,... Alá ama quienes le temen.\qt@no{76}}
\qt@newcmd\qurantrans@es@ccclxx{Quienes malvenden la alianza con Alá y sus juramentos no tendrán parte en la otra vida. Alá no les dirigirá la palabra ni les mirará el día de la Resurrección, no les declarará puros y tendrán un castigo doloroso.\qt@no{77}}
\qt@newcmd\qurantrans@es@ccclxxi{Algunos de ellos trabucan con sus lenguas la Escritura para que creáis que está en la Escritura lo que no está en la Escritura, diciendo que viene de Alá, siendo así que n o viene de Alá. Mienten contra Alá a sabiendas.\qt@no{78}}
\qt@newcmd\qurantrans@es@ccclxxii{No está bien que un mortal a quien Alá da la Escritura, el jucio y el profetismo, vaya diciendo a la gente: «¡Sed siervos míos y no de Alá!» Antes bien: «¡Sed maestros, puesto que enseñáis la Escritura y la estudiáis!»\qt@no{79}}
\qt@newcmd\qurantrans@es@ccclxxiii{Alá no os ordena que toméis como señores a los ángeles y a los profetas. ¿Es que iba a ordenaros que fuerais infieles, después de haberos sometido a Él?\qt@no{80}}
\qt@newcmd\qurantrans@es@ccclxxiv{Y cuando Alá concertó un pacto con los profetas: «Cuando venga a vosotros un Enviado que confirme lo que de Mí hayáis recibido comoEscritura y como Sabiduría. habéis de creer en él y auxiliarle». Dijo: «¿Estáis dispuestos a aceptar mi alianza con esa condición?» Dijeron: «Estamos dispuestos». Dijo:«Entonces, ¡sed testigos! Yo también. con vosotros, soy testigo».\qt@no{81}}
\qt@newcmd\qurantrans@es@ccclxxv{Quienes, después de esto, vuelvan la espalda serán los perversos.\qt@no{82}}
\qt@newcmd\qurantrans@es@ccclxxvi{¿Desearían una religión diferente de la de Alá, cuando los que están en los cielos y en la tierra se someten a Él de grado o por fuerza? Y serán devueltos a Él.\qt@no{83}}
\qt@newcmd\qurantrans@es@ccclxxvii{Di «Creemos en Alá y en lo que se nos ha revelado, en lo que se ha revelado a Abraham, Ismael, Isaac, Jacob y las tribus, en lo que Moisés, Jesús y los profetas han recibido de su Señor. No hacemos distinción entre ninguno de ellos y nos sometemos a Él».\qt@no{84}}
\qt@newcmd\qurantrans@es@ccclxxviii{Si alguien desea una religión diferente del islam, no se le aceptará y en la otra vida será de los que pierdan.\qt@no{85}}
\qt@newcmd\qurantrans@es@ccclxxix{¿Cómo va Alá a dirigir a un pueblo que ha dejado de creer después de haber creído, de haber sido testigo de la veracidad del Enviado y de haber recibido las pruebas claras? Alá no dirige al pueblo impío.\qt@no{86}}
\qt@newcmd\qurantrans@es@ccclxxx{Esos tales incurrirán, como retribución, en la maldición de Alá, de los ángeles y de los hombres, en la de todos ellos.\qt@no{87}}
\qt@newcmd\qurantrans@es@ccclxxxi{Eternos en ella, no se les mitigará el castigo, ni les será dado esperar.\qt@no{88}}
\qt@newcmd\qurantrans@es@ccclxxxii{Serán exceptuados quienes, después de eso, se arrepientan y se enmienden. Alá es indulgente, misericordioso.\qt@no{89}}
\qt@newcmd\qurantrans@es@ccclxxxiii{A quienes dejen de creer, después de haber creído, y luego se obstinen en su incredulidad, no se les aceptará el arrepentimiento. Ésos son los extraviados.\qt@no{90}}
\qt@newcmd\qurantrans@es@ccclxxxiv{Si uno que no cree muere siendo infiel, aunque ofrezca como precio de rescate la tierra llena de oro, no se le aceptará. Esos tales tendrán un castigo doloroso y no encontrarán quienes les auxilien.\qt@no{91}}
\qt@newcmd\qurantrans@es@ccclxxxv{No alcanzaréis la piedad auténtica mientras no gastéis algo de lo que amáis. Y Alá conoce bien cualquier cosa que gastáis.\qt@no{92}}
\qt@newcmd\qurantrans@es@ccclxxxvi{Antes de que fuera revelada la Tora, todo alimento era lícito para los Hijos de Israel, salvo lo que Israel se había vedado a sí mismo. Di: «Si es verdad lo que decís., ¡traed la Tora y leedla!»,\qt@no{93}}
\qt@newcmd\qurantrans@es@ccclxxxvii{Quienes, después de eso, inventen la mentira contra Alá, ésos son los impíos.\qt@no{94}}
\qt@newcmd\qurantrans@es@ccclxxxviii{Di: «Alá ha dicho la verdad. Seguid, pues, la religión de Abraham, que fue hanif y no asociador».\qt@no{95}}
\qt@newcmd\qurantrans@es@ccclxxxix{La primera Casa erigida para los hombres es, ciertamente, la de Bakka, casa bendita y dirección para todos.\qt@no{96}}
\qt@newcmd\qurantrans@es@cccxc{Hay en ella signos claros. Es el lugar de Abraham y quien entre en él estará seguro. Alá ha prescrito a los hombres la peregrinación a la Casa, si disponen de medios. Y quien no crea... Alá puede prescindir de las criaturas.\qt@no{97}}
\qt@newcmd\qurantrans@es@cccxci{Di: «¡Gente de la Escritura !¿Por qué no creéis en los signos de Alá? Alá es testigo de lo que hacéis».\qt@no{98}}
\qt@newcmd\qurantrans@es@cccxcii{Di: «¡Gente de la Escritura !¿Por qué desviáis a quien cree del camino de Alá, deseando que sea tortuoso, siendo así que sois testigos? Alá está atento a lo que hacéis».\qt@no{99}}
\qt@newcmd\qurantrans@es@cccxciii{¡Creyentes! Si obedecéis a algunos de los que han recibido la Escritura, harán que, luego de haber creído, no creáis.\qt@no{100}}
\qt@newcmd\qurantrans@es@cccxciv{¿Cómo podéis dejar de creer si se os recitan las aleyas de Alá y Su Enviado se halla entre vosotros? Quien se aferre a Alá será dirigido a una vía recta.\qt@no{101}}
\qt@newcmd\qurantrans@es@cccxcv{¡Creyentes! Temed a Alá con el temor que Le es debido y no muráis sino como musulmanes.\qt@no{102}}
\qt@newcmd\qurantrans@es@cccxcvi{Aferraos al pacto de Alá, todos juntos, sin dividiros. Recordad la gracia que Alá os dispensó cuando erais enemigos: reconcilió vuestros corazones y, por Su gracia, os transformasteis en hermanos; estabais al borde de un abismo de fuego y os libró de él. Así os explica Alá Sus signos. Quizás, así, seáis bien dirigidos.\qt@no{103}}
\qt@newcmd\qurantrans@es@cccxcvii{¡Que constituyáis una comunidad que llame al bien, ordenando lo que está bien y prohibiendo lo que está mal! Quienes obren así serán los que prosperen.\qt@no{104}}
\qt@newcmd\qurantrans@es@cccxcviii{¡No seáis como quienes, después de haber recibido las pruebas claras, se dividieron y discreparon! Esos tales tendrán un castigo terrible\qt@no{105}}
\qt@newcmd\qurantrans@es@cccxcix{el día que unos rostros estén radiantes y otros hoscos. A aquéllos cuyos rostros estén hoscos: «¿Habéis dejado de creer luego de haber creído? Pues ¡gustad el castigo por no haber creído!»\qt@no{106}}
\qt@newcmd\qurantrans@es@cd{En cuanto a aquéllos cuyos rostros estén radiantes, gozarán eternamente de la misericordia de Alá.\qt@no{107}}
\qt@newcmd\qurantrans@es@cdi{Éstas son las aleyas de Alá, que te recitamos conforme a la verdad. Alá no quiere la injusticia para las criaturas.\qt@no{108}}
\qt@newcmd\qurantrans@es@cdii{De Alá es lo que está en los cielos y en la tierra. Todo será devuelto a Alá.\qt@no{109}}
\qt@newcmd\qurantrans@es@cdiii{Sois la mejor comunidad humana que jamás se haya suscitado: ordenáis lo que está bien, prohibís lo que está mal y creéis en Alá. Si la gente de la Escritura creyera, les iría mejor. Hay entre ellos creyentes, pero la mayoría son perversos.\qt@no{110}}
\qt@newcmd\qurantrans@es@cdiv{Os dañarán, pero poco. Y si os combaten, os volverán la espalda. Luego, no seles auxiliará.\qt@no{111}}
\qt@newcmd\qurantrans@es@cdv{Han sido humillados dondequiera que se ha dado con ellos, excepto los protegidos por un pacto con Alá o por un pacto con los hombres. Han incurrido en la ira de Alá y les ha señalado la miseria. Por no haber creído en los signos de Alá y por haber matado a los profetas sin justificación. Por haber desobedecido y violado la ley.\qt@no{112}}
\qt@newcmd\qurantrans@es@cdvi{No todos son iguales. Entre la gente de la Escritura hay una comunidad honrada: durante la noche, recitan las aleyas de Alá y se prosternan,\qt@no{113}}
\qt@newcmd\qurantrans@es@cdvii{creen en Alá y en el último Día, ordenan lo que está bien, prohiben lo que está mal y rivalizan en buenas obras. Esos tales son de los justos.\qt@no{114}}
\qt@newcmd\qurantrans@es@cdviii{No se les desagradecerá el bien que hagan. Alá conoce bien a los que Le temen.\qt@no{115}}
\qt@newcmd\qurantrans@es@cdix{A quienes no crean, ni su hacienda ni sus hijos les servirán de nada frente a Alá. Esos tales morarán en el Fuego eternamente.\qt@no{116}}
\qt@newcmd\qurantrans@es@cdx{Lo que gastan en la vida de acá es semejante a un viento glacial que bate la cosecha de gente que se ha dañado a sí misma y la destruye. No es Alá quien ha sido injusto con ellos, sino que ellos lo han sido consigo mismos.\qt@no{117}}
\qt@newcmd\qurantrans@es@cdxi{¡Creyentes! No intiméis con nadie ajeno a vuestra comunidad. Si no, no dejarán de dañaros. Desearían vuestra ruina. El odio asomó a sus bocas, pero lo que ocultan sus pechos es peor. Os hemos explicado las aleyas. Si razonarais...\qt@no{118}}
\qt@newcmd\qurantrans@es@cdxii{Vosotros, bien que les amáis, pero ellos no os aman. Vosotros creéis en toda la Escritura... Ellos, cuando os encuentran, dicen: «¡Creemos!» pero, cuando están a solas, se muerden las puntas d e los dedos, de rabia contra vosotros. Di:«¡Morid de rabia!» Alá sabe bien lo que encierran los pechos.\qt@no{119}}
\qt@newcmd\qurantrans@es@cdxiii{Si os sucede un bien. les duele; si os hiere un mal, se alegran. Pero, si tenéis paciencia y teméis a Alá, sus artimañas no os harán ningún daño. Alá abarca todo lo que hacen.\qt@no{120}}
\qt@newcmd\qurantrans@es@cdxiv{Y cuando dejaste por la mañana temprano a tu familia para asignar a los creyentes sus puestos de combate. Alá todo lo oye, todo lo sabe.\qt@no{121}}
\qt@newcmd\qurantrans@es@cdxv{Cuando dos de vuestras tropas proyectaron abandonar, a pesar de ser Alá su Amigo. ¡Que los creyentes confíen en Alá!\qt@no{122}}
\qt@newcmd\qurantrans@es@cdxvi{Alá, ciertamente, os auxilió en Badr cuando erais humillados. ¡Temed a Alá! Quizás, así, seáis agradecidos.\qt@no{123}}
\qt@newcmd\qurantrans@es@cdxvii{Cuando decías a los creyentes: «¿No os basta que vuestro Señor os refuerce con tres mil ángeles enviados abajo?\qt@no{124}}
\qt@newcmd\qurantrans@es@cdxviii{¡Pues sí! Si tenéis paciencia y teméis a Alá, si os acometen así de súbito, vuestro Señor os reforzará con cinco mil ángeles provistos de distintivos».\qt@no{125}}
\qt@newcmd\qurantrans@es@cdxix{Alá no lo hizo sino como buena nueva para vosotros y para que, con ello, se tranquilizaran vuestros corazones -la victoria no viene sino de Alá, el Poderoso, el Sabio-,\qt@no{126}}
\qt@newcmd\qurantrans@es@cdxx{para despedazar a los que no creían o derrotarlos y que regresaran, así, decepcionados.\qt@no{127}}
\qt@newcmd\qurantrans@es@cdxxi{No es asunto tuyo si Él se vuelve a ellos o les castiga. Han obrado impíamente.\qt@no{128}}
\qt@newcmd\qurantrans@es@cdxxii{De Alá es lo que está en los cielos y en la tierra. Perdona a quien Él quiere y castiga a quien Él quiere. Alá es indulgente, misericordioso.\qt@no{129}}
\qt@newcmd\qurantrans@es@cdxxiii{¡Creyentes! ¡No usureéis, doblando una y otra vez! ¡Y temed a Alá! Quizás, así, prosperéis.\qt@no{130}}
\qt@newcmd\qurantrans@es@cdxxiv{¡Y temed el fuego preparado para los infieles!\qt@no{131}}
\qt@newcmd\qurantrans@es@cdxxv{¡Y obedeced a Alá y al Enviado!; Quizás, así, se os tenga piedad.\qt@no{132}}
\qt@newcmd\qurantrans@es@cdxxvi{¡Y apresuraos a obtener el perdón de vuestro Señor y un Jardín tan vasto como los cielos y la tierra, que ha sido preparado para los temerosos de Alá,\qt@no{133}}
\qt@newcmd\qurantrans@es@cdxxvii{que dan limosna tanto en la prosperidad como en la adversidad, reprimen la ira, perdonan a los hombres -Alá ama a quienes hacen el bien-,\qt@no{134}}
\qt@newcmd\qurantrans@es@cdxxviii{que, si cometen una indecencia o son injustos consigo mismos, recuerdan a Alá, piden perdón por sus pecados -¿y quién puede perdonarlos pecados sino Alá?- y no reinciden a sabiendas!\qt@no{135}}
\qt@newcmd\qurantrans@es@cdxxix{Su retribución será el perdón de su Señor y jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente. ¡Qué grata es la recompensa de los que obran bien!\qt@no{136}}
\qt@newcmd\qurantrans@es@cdxxx{Antes de vosotros han ocurrido casos ejemplares. ¡Id por la tierra y mirad cómo terminaron los desmentidores!\qt@no{137}}
\qt@newcmd\qurantrans@es@cdxxxi{Ésta es una explicación para los hombres, dirección, exhortación para los temerosos de Alá.\qt@no{138}}
\qt@newcmd\qurantrans@es@cdxxxii{¡No os desaniméis ni estéis tristes, ya que seréis vosotros quienes ganen! Si es que sois creyentes...\qt@no{139}}
\qt@newcmd\qurantrans@es@cdxxxiii{Si sufrís una herida, otros han sufrido una herida semejante. Nosotros hacemos alternar esos días entre los hombres para que reconozca Alá a quienes crean y tome testigos de entre vosotros -Alá no ama a los impíos-,\qt@no{140}}
\qt@newcmd\qurantrans@es@cdxxxiv{para que pruebe Alá a los creyentes y extermine a los infieles.\qt@no{141}}
\qt@newcmd\qurantrans@es@cdxxxv{O ¿creéis que vais a entrar en el Jardín sin que Alá haya sabido quiénes de vosotros han combatido y quiénes han tenido paciencia?\qt@no{142}}
\qt@newcmd\qurantrans@es@cdxxxvi{Sí, deseabais la muerte antes de encontrarla. Ya la habéis visto, pues, con vuestros propios ojos.\qt@no{143}}
\qt@newcmd\qurantrans@es@cdxxxvii{Mahoma no es sino un enviado, antes del cual han pasado otros enviados. Si, pues, muriera o le mataran, ¿ibais a volveros atrás? Quien se vuelva atrás no causará ningún daño A Alá. Y Alá retribuirá a los agradecidos.\qt@no{144}}
\qt@newcmd\qurantrans@es@cdxxxviii{Nadie puede morir sino con permiso De Alá y según el plazo fijado. A quien quiera la recompensa dela vida de acá, le daremos de ella. Y a quien quiera la recompensa de la otra vida, le daremos de ella. Y retribuiremos a los agradecidos.\qt@no{145}}
\qt@newcmd\qurantrans@es@cdxxxix{¡Qué de profetas ha habido, junto a los cuales combatieron muchas miriadas, y no se descorazonaron por los reveses padecidos por Alá, no flaquearon, no cedieron! Alá ama a los tenaces.\qt@no{146}}
\qt@newcmd\qurantrans@es@cdxl{No decían más que:«¡Señor! ¡Perdónanos nuestros pecados y los excesos que hemos cometido! ¡Afirma nuestros pasos! ¡Auxílianos contra el pueblo infiel!»\qt@no{147}}
\qt@newcmd\qurantrans@es@cdxli{Alá les dio la recompensa de la vida de acá y la buena recompensa de la otra. Alá ama a quienes hacen el bien.\qt@no{148}}
\qt@newcmd\qurantrans@es@cdxlii{¡Creyentes! Si obedecéis a quienes no creen, os harán retroceder y regresaréis habiendo perdido.\qt@no{149}}
\qt@newcmd\qurantrans@es@cdxliii{¡No! Alá es vuestro Protector y el Mejor de los auxiliares.\qt@no{150}}
\qt@newcmd\qurantrans@es@cdxliv{Infundiremos el terror en los corazones de los que no crean, por haber asociado a Alá algo a lo que Él no ha conferido autoridad. Su morada será el Fuego. ¡Qué mala es la mansión de los impíos!\qt@no{151}}
\qt@newcmd\qurantrans@es@cdxlv{Alá ha cumplido la promesa que os hizo cuando, con Su permiso, les vencíais, hasta que, por fin, flaqueasteis, discutisteis sobre el particular y desobedecisteis, después de haberos Él dejado ver l a victoria que queríais. -De vosotros unos desean la vida de acá y otros desean la otra vida-. Luego, hizo que os retirarais de ellos para probaros. Ciertamente, os ha perdonado. Alá dispensa su favor a los creyentes.\qt@no{152}}
\qt@newcmd\qurantrans@es@cdxlvi{Cuando subíais sin preocuparos de nadie, mientras que el Enviado os llamaba a retaguardia. Os atribulaba una y otra vez para que no estuvierais tristes por lo que se os había escapado ni por lo que os había ocurrido. Alá está bien informado de lo que hacéis.\qt@no{153}}
\qt@newcmd\qurantrans@es@cdxlvii{Luego, pasada la tribulación, hizo descender sobre vosotros seguridad: un sueño que venció a algunos de vosotros. Otros, en cambio, preocupados tan sólo por su suerte y pensando de Alá equivocadamente, a la manera de los paganos, decían: «¿Tenemos nosotros algo que ver con esto?» Di: «Todo está en manos De Alá». Ocultan para sí lo que no te manifiestan. Dicen: «Si hubiera dependido de nosotros, no habríamos tenido muertos aquí» Di: «También. si os hubierais quedado en casa, la muerte habría sorprendido en sus lechos a aquéllos de quienes estaba ya escrita. Alá ha hecho esto para probar lo que hay en vuestros pechos y purificar lo que hay en vuestros corazones. Alá sabe bien lo que encierran los pechos».\qt@no{154}}
\qt@newcmd\qurantrans@es@cdxlviii{Si algunos de los vuestros huyeron el día que se encontraron los dos ejércitos, fue porque el Demonio les hizo caer por alguna culpa que habían cometido. Pero Alá les ha perdonado ya. Alá es indulgente, benigno.\qt@no{155}}
\qt@newcmd\qurantrans@es@cdxlix{¡Creyentes! ¡No seáis como quienes no creen y dicen de sus hermanos que están de viaje o de incursión: «Si se hubieran quedado con nosotros, no habrían muerto o no les habrían matado»! ¡Haga Alá que les pese esto en sus corazones! Alá da la vida y dala muerte. Alá ve bien lo que hacéis.\qt@no{156}}
\qt@newcmd\qurantrans@es@cdl{Y si sois muertos por Alá o morís de muerte natural, el perdón y misericordia de Alá son mejores que lo que ellos amasan.\qt@no{157}}
\qt@newcmd\qurantrans@es@cdli{Si morís de muerte natural o sois muertos, seréis, si, congregados hacia Alá.\qt@no{158}}
\qt@newcmd\qurantrans@es@cdlii{Por una misericordia venida de Alá, has sido suave con ellos. Si hubieras sido áspero y duro de corazón, se habrían escapado de ti. ¡Perdónales, pues, y pide el perdón de Alá en su favor y consúltales sobre el asunto! Pero, cuando hayas tomado una decisión. confía en Alá. Alá ama a los que confían en Él.\qt@no{159}}
\qt@newcmd\qurantrans@es@cdliii{Si Alá os auxilia, no habrá nadie que pueda venceros. Pero, si os abandona, ,¿quién podrá auxiliaros fuera de Él? ¡Que los creyentes confíen en Alá!\qt@no{160}}
\qt@newcmd\qurantrans@es@cdliv{No es propio de un profeta el cometer fraude. Quien defraude llevará lo defraudado el día de la Resurrección. Luego, cada uno recibirá su merecido. Y no serán tratados injustamente.\qt@no{161}}
\qt@newcmd\qurantrans@es@cdlv{¿Es que quien busca agradar a Alá es como quien incurre en la ira de Alá y tiene por morada la gehena? ¡Qué mal fin...!\qt@no{162}}
\qt@newcmd\qurantrans@es@cdlvi{Estarán por categorías junto a Alá. Alá ve bien lo que hacen.\qt@no{163}}
\qt@newcmd\qurantrans@es@cdlvii{Alá ha agraciado a los creyentes al enviarles un Enviado salido de ellos, que les recita Sus aleyas, les purifica y les enseña la Escritura y la Sabiduría. Antes estaban evidentemente extraviados.\qt@no{164}}
\qt@newcmd\qurantrans@es@cdlviii{¿Cómo, cuando os sobreviene una desgracia, después de haber infligido el doble de aquélla, decís aún:«¿De dónde viene esto?» Di: «De vosotros mismos». Aláes omnipotente.\qt@no{165}}
\qt@newcmd\qurantrans@es@cdlix{Y lo que os pasó el día que se encontraron los dos ejércitos fue porque lo permitió Alá y para que supiera quiénes eran los creyentes\qt@no{166}}
\qt@newcmd\qurantrans@es@cdlx{y quiénes los hipócritas. Se les dijo: «¡Vamos! ¡Combatid por Alá o rechazad al enemigo!» Dijeron: «Si supiéramos combatir, os seguiríamos». Aquel día estaban más cerca de la incredulidad que de la fe. Dicen con la boca lo que no tienen en el corazón. Pero Alá sabe bien lo que ocultan.\qt@no{167}}
\qt@newcmd\qurantrans@es@cdlxi{Son ellos quienes, mientras se quedaban en casa, decían de sus hermanos: «Si nos hubieran escuchado, no les habrían matado». Di: «¡Apartad, pues la muerte de vosotros, si es verdad lo que decís»\qt@no{168}}
\qt@newcmd\qurantrans@es@cdlxii{Y no penséis que quienes han caído por Alá hayan muerto. ¡Al contrario! Están vivos y sustentados junto a su Señor.\qt@no{169}}
\qt@newcmd\qurantrans@es@cdlxiii{contentos por el favor que Alá les ha hecho y alegres por quienes aún no les han seguido, porque no tienen que temer y no estarán tristes,\qt@no{170}}
\qt@newcmd\qurantrans@es@cdlxiv{alegres por una gracia y favor de Alá y porque Alá no deja de remunerar a los creyentes.\qt@no{171}}
\qt@newcmd\qurantrans@es@cdlxv{A quienes escucharon a Alá y al Enviado, luego de la herida recibida, a quienes, entre ellos, hicieron el bien y temieron a Alá, se les reserva una magnífica recompensa.\qt@no{172}}
\qt@newcmd\qurantrans@es@cdlxvi{A aquéllos a quienes se dijo: «La gente se ha agrupado contra vosotros, ¡tenedles miedo!», esto les aumentó la fe y dijeron: «Alá nos basta! ¡Es un protector excelente!»\qt@no{173}}
\qt@newcmd\qurantrans@es@cdlxvii{Y regresaron por una gracia y favor de Alá, sin sufrir mal. Buscaron la satisfacción de Alá. Y Alá es el Dueño del favor inmenso.\qt@no{174}}
\qt@newcmd\qurantrans@es@cdlxviii{Así es el Demonio: hace tener miedo de sus amigos. Pero, si sois creyentes, no tengáis miedo de ellos, sino de Mí.\qt@no{175}}
\qt@newcmd\qurantrans@es@cdlxix{Que no te entristezca ver a quienes se precipitan en la incredulidad. No podrán causar ningún daño a Alá. Alá no quiere darles parte en la otra vida. Tendrán un castigo terrible.\qt@no{176}}
\qt@newcmd\qurantrans@es@cdlxx{Quienes compren la incredulidad con la fe no causarán ningún daño a Alá y tendrán un castigo doloroso.\qt@no{177}}
\qt@newcmd\qurantrans@es@cdlxxi{Que no piensen los infieles que el que les concedamos una prórroga supone un bien para ellos. El concedérsela es para que aumente su pecado. Tendrán un castigo humillante.\qt@no{178}}
\qt@newcmd\qurantrans@es@cdlxxii{No va Alá a dejar a los creyentes en la situación en que os halláis hasta que distinga al malo del bueno. Ni va Alá a enteraros de lo oculto. Pero Alá elige de entre Sus enviados a quien Él quiere. Creed, pues, en Alá y en Sus enviados. Si creéis y teméis a Alá, tendréis una magnífica recompensa.\qt@no{179}}
\qt@newcmd\qurantrans@es@cdlxxiii{Que no crean quienes se muestran avaros del favor recibido de Alá que eso es bueno para ellos. Al contrario, es malo. El día de la Resurrección llevarán a modo de collar el objeto de su avaricia. L a herencia de los cielos y de la tierra pertenece a Alá. Alá está bien informado de lo que hacéis.\qt@no{180}}
\qt@newcmd\qurantrans@es@cdlxxiv{Alá ha oído las palabras de quienes han dicho.«Alá es pobre y nosotros somo ricos». Tomaremos nota de lo que han dicho y de que han matado a los profetas sin justificación. Y les diremos: «¡Gustad el castigo del fuego de la gehena!\qt@no{181}}
\qt@newcmd\qurantrans@es@cdlxxv{Esto es lo que vuestras obras han merecido, que Alá no es injusto con Sus siervos».\qt@no{182}}
\qt@newcmd\qurantrans@es@cdlxxvi{Esos mismos han dicho:«Alá ha concertado una alianza con nosotros: que no creamos en ningún enviado hasta tanto que nos traiga una oblación que el fuego consuma». Di: «Antes de mí, otros enviados os trajeron las pruebas claras y lo que habéis pedido. ¡Por qué, pues, les matasteis, si es verdad lo que decís?»\qt@no{183}}
\qt@newcmd\qurantrans@es@cdlxxvii{Y si te desmienten, también fueron desmentidos otros enviados antes de ti, que vinieron con las pruebas claras, las Escrituras y la Escritura luminosa.\qt@no{184}}
\qt@newcmd\qurantrans@es@cdlxxviii{Cada uno gustará la muerte, pero no recibiréis vuestra recompensa íntegra hasta el día dela Resurrección. Habrá triunfado quien sea preservado del Fuego e introducido en el Jardín. La vida de acá no es más que falaz disfrute.\qt@no{185}}
\qt@newcmd\qurantrans@es@cdlxxix{Seréis, ciertamente, probados en vuestra hacienda y en vuestras personas. Y oiréis, ciertamente, muchas cosas malas de aquéllos que han recibido la Escritura antes de vosotros y de los asociadores ; pero, si sois pacientes y teméis a Alá, eso sí que es dar muestras de resolución.\qt@no{186}}
\qt@newcmd\qurantrans@es@cdlxxx{Cuando Alá concertó un pacto con los que habían recibido la Escritura: «Tenéis que explicársela a los hombres, no se la ocultéis». Pero se la echaron a la espalda y la malvendieron. ¡Qué mal negocio...!\qt@no{187}}
\qt@newcmd\qurantrans@es@cdlxxxi{No creas, no, que quienes se alegran delo que han hecho y gustan de ser alabados por lo que han dejado de hacer, no creas, no, que vayan a librarse del castigo. Tendrán un castigo doloroso.\qt@no{188}}
\qt@newcmd\qurantrans@es@cdlxxxii{El dominio de los cielos y dela tierra pertenece a Alá. Alá es omnipotente.\qt@no{189}}
\qt@newcmd\qurantrans@es@cdlxxxiii{En la creación de los cielos y de la tierra y en la sucesión de la noche y el día hay, ciertamente, signos para los dotados de intelecto.\qt@no{190}}
\qt@newcmd\qurantrans@es@cdlxxxiv{que recuerdan a Alá de pie, sentados o echados, y que meditan en la creación de los cielos y de la tierra:«¡Señor! No has creado todo esto en vano ¡Gloria a Ti! ¡Presérvanos del castigo del Fuego!».\qt@no{191}}
\qt@newcmd\qurantrans@es@cdlxxxv{¡Señor! Tú cubres de oprobio a quien introduces en el Fuego. Los impíos no tendrán quien les auxilie.\qt@no{192}}
\qt@newcmd\qurantrans@es@cdlxxxvi{¡Señor! ;Hemos oído a uno que llamaba a la fe: «¡Creed en Vuestro Señor!» y hemos creído. ¡Señor!¡ Perdónanos nuestros pecados! ¡Borra nuestras malas obras y recíbenos. cuando muramos, entre los justos!\qt@no{193}}
\qt@newcmd\qurantrans@es@cdlxxxvii{¡Y danos, Señor, lo que nos has prometido por Tus enviados y no nos cubras de oprobio el día de la Resurrección! Tú no faltas a Tu promesa.\qt@no{194}}
\qt@newcmd\qurantrans@es@cdlxxxviii{Su Señor escuchó su plegaria: «No dejaré que se pierda obra de ninguno de vosotros, lo mismo si es varón que si es hembra, que habéis salido los unos de los otros. He de borrar las malas obras de quienes emigraron y fueron expulsados de sus hogares, de quienes padecieron por causa Mía, de quienes combatieron y fueron muertos, y he de introducirles en jardines por cuyos bajos fluyen arroyos: recompensa de Alá». Alá tiene junto a Sí la bella recompensa.\qt@no{195}}
\qt@newcmd\qurantrans@es@cdlxxxix{¡Que no te desconcierte ver a los infieles yendo de acá para allá por el país!\qt@no{196}}
\qt@newcmd\qurantrans@es@cdxc{¡Mezquino disfrute! Luego, su morada será la gehena. ¡Qué mal lecho...!\qt@no{197}}
\qt@newcmd\qurantrans@es@cdxci{En cambio, quienes teman a su Señor tendrán jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, como alojamiento que Alá les brinda. Y lo que hay junto a Alá es mejor para los justos.\qt@no{198}}
\qt@newcmd\qurantrans@es@cdxcii{Hay entre la gente de la Escrituraquienes creen en Alá y en la Revelación hecha a vosotros y a ellos. Humildes ante Alá, no han malvendido los signos de Alá. Esos tales tendrán su re compensa junto a su Señor. Alá es rápido en ajustar cuentas.\qt@no{199}}
\qt@newcmd\qurantrans@es@cdxciii{¡Creyentes! ¡Tened paciencia, rivalizad en ella! ¡Sed firmes! ¡Temed a Alá! Quizás así, prosperéis.\qt@no{200}}
\qt@newcmd\qurantrans@es@cdxciv{\basmalahes ¡Hombres! ¡Temed a vuestro Señor, Que os ha creado de una sola persona, de la que ha creado a su cónyuge, y de los que ha diseminado un gran número de hombres y de mujeres! ¡Temed a Alá, en Cuyo nombre os pedís cosas, y respetad la consanguinidad! Alá siempre os observa.\qt@no{1}}
\qt@newcmd\qurantrans@es@cdxcv{Dad a los huérfanos los bienes que les pertenecen. No sustituyáis lo malo por lo bueno. No consumáis su hacienda agregándola a la vuestra. Sería un gran pecado.\qt@no{2}}
\qt@newcmd\qurantrans@es@cdxcvi{Si teméis no ser equitativos con los huérfanos, entonces, casaos con las mujeres que os gusten: dos, tres o cuatro. Pero. si teméis no obrar con justicia, entonces con una sola o con vuestras esclavas. Así, evitaréis mejor el obrar mal.\qt@no{3}}
\qt@newcmd\qurantrans@es@cdxcvii{Dad a vuestras mujeres su dote gratuitamente. Pero, si renuncian gustosas a una parte en vuestro favor, haced uso de ésta tranquilamente.\qt@no{4}}
\qt@newcmd\qurantrans@es@cdxcviii{¡No confiéis a los incapaces la hacienda que Alá os ha dado para subsistir!, ¡sustentadles de ella y vestidles! ¡Y habladles con cariño!\qt@no{5}}
\qt@newcmd\qurantrans@es@cdxcix{Tantead a los huérfanos hasta que alcancen la nubilidad, Cuando los creáis ya maduros, pasadles su hacienda. No la consumáis pródiga y prematuramente antes de que alcancen la mayoría de edad. El rico, que no se aproveche. El pobre, que gaste como es debido. Cuando les entreguéis su hacienda, requerid la presencia de testigos. Alá basta para ajustar cuentas...\qt@no{6}}
\qt@newcmd\qurantrans@es@d{Sea para los hombres una parte de lo que los padres y parientes más cercanos dejen; y para las mujeres una parte de lo que los padres y parientes más cercanos dejen. Poco o mucho, es una parte determinada.\qt@no{7}}
\qt@newcmd\qurantrans@es@di{Si asisten al reparto parientes, huérfanos, pobres, dadles algún sustento de ello y habladles con cariño.\qt@no{8}}
\qt@newcmd\qurantrans@es@dii{Quienes dejen menores de edad y estén intranquilos por ellos, que tengan miedo. Que teman a Alá y digan palabras oportunas.\qt@no{9}}
\qt@newcmd\qurantrans@es@diii{Quienes consuman injustamente la hacienda de los huérfanos, sólo fuego ingerirán en sus entrañas y arderán en fuego de la gehena.\qt@no{10}}
\qt@newcmd\qurantrans@es@div{Alá os ordena lo siguiente en lo que toca a vuestros hijos: que la porción del varón equivalga a la de dos hembras. Si éstas son más de dos, les corresponderán dos tercios de la herencia. Si es hija única. la mitad. A cada uno de los padres le corresponderá un sexto de la herencia, si deja hijos; pero, si no tiene hijos y le heredan sólo sus padres, un tercio es para la madre. Si tiene hermanos, un sexto es para la madre. Esto, luego de satisfacer sus legados o deudas. De vuestros ascendientes o descendientes no sabéis quiénes os son más útiles. Ésta es obligación de Alá. Alá es omnisciente, sabio.\qt@no{11}}
\qt@newcmd\qurantrans@es@dv{A vosotros os corresponde la mitad de lo que dejen vuestras esposas si no tienen hijos. Si tienen, os corresponde un cuarto. Esto, luego de satisfacer sus legados o deudas. Si no tenéis hijos, a ellas les corresponde un cuarto de lo que dejéis. Si tenéis, un octavo de lo que dejéis. Esto. luego de satisfacer vuestros legados o deudas. Si los herederos de un hombre o de una mujer son parientes colaterales y le sobrevive un hermano o una hermana, entonces, les corresponde, a cada uno de los dos, un sexto. Si son más, participarán del tercio de la herencia, luego de satisfacer los legados o deudas, sin dañar a nadie. Ésta es disposición de Alá. Alá es omnisciente, benigno.\qt@no{12}}
\qt@newcmd\qurantrans@es@dvi{Éstas son las leyes de Alá. A quien obedezca a Alá y a Su Enviado, Él le introducirá en jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente. ¡Éste es el éxito grandioso!\qt@no{13}}
\qt@newcmd\qurantrans@es@dvii{A quien, al contrario, desobedezca a Alá y a Su Enviado y viole Sus leyes. Él le introducirá en un Fuego, eternamente. Tendrá un castigo humillante.\qt@no{14}}
\qt@newcmd\qurantrans@es@dviii{.Llamad a cuatro testigos de vosotros contra aquéllas de vuestras mujeres que cometan deshonestidad. Si atestiguan, recluidlas en casa hasta que mueran o hasta que Alá les procure una salida.\qt@no{15}}
\qt@newcmd\qurantrans@es@dix{Si dos de los vuestros la cometen, castigad a ambos severamente. Pero, si se arrepienten y enmiendan, dejadles en paz. Alá es indulgente, misericordioso.\qt@no{16}}
\qt@newcmd\qurantrans@es@dx{.Alá perdona sólo a quienes cometen el mal por ignorancia y se arrepienten en seguida. A éstos se vuelve Alá. Alá es omnisciente, sabio.\qt@no{17}}
\qt@newcmd\qurantrans@es@dxi{Que no espere perdón quien sigue obrando mal hasta que, en el artículo de la muerte, dice: «Ahora me arrepiento». Ni tampoco quienes mueren siendo infieles. A éstos les hemos preparado un castigo doloroso.\qt@no{18}}
\qt@newcmd\qurantrans@es@dxii{¡Creyentes! No es lícito recibir en herencia a mujeres contra su voluntad, ni impedirles que vuelvan a casarse para quitarles parte de lo que les habíais dado, a menos que sean culpables de deshonestidad manifiesta. Comportaos con ellas como es debido. Y si os resultan antipáticas, puede que Alá haya puesto mucho bien en el objeto de vuestra antipatía.\qt@no{19}}
\qt@newcmd\qurantrans@es@dxiii{Y si queréis cambiar de esposa y le habíais dado a una de ellas un quintal, no volváis a tomar nada de él. ¿Ibáis a tomarlo con infamia y pecado manifiesto?\qt@no{20}}
\qt@newcmd\qurantrans@es@dxiv{Y ¿cómo ibais a tomarlo, después de haber yacido y de haber concertado ella con vosotros un pacto solemne?\qt@no{21}}
\qt@newcmd\qurantrans@es@dxv{En adelante. no os caséis con las mujeres con que han estado casados vuestros padres. Sería deshonesto y aborrecible. ¡Mal camino...!\qt@no{22}}
\qt@newcmd\qurantrans@es@dxvi{En adelante, os están prohibidas vuestras madres, vuestras hijas, vuestras hermanas, vuestras tías paternas o maternas, vuestras sobrinas por parte de hermano o de hermana, vuestras madres de leche, vuestras hermanas de leche, las madres de vuestras mujeres, vuestras hijastras que están bajo vuestra tutela, nacidas de mujeres vuestras con las que habéis consumado el matrimonio -si no, no hay culpa-, las esposas de vuestros propios hijos, así como casaros con dos hermanas a un tiempo. Alá es indulgente, misericordioso.\qt@no{23}}
\qt@newcmd\qurantrans@es@dxvii{Y las mujeres casadas, a menos que sean esclavas vuestras. ¡Mandato de Alá! Os están permitidas todas las otras mujeres, con tal que las busquéis con vuestra hacienda, con intención de casaros, no por fornicar. Retribuid, como cosa debida, a aquéllas de quienes habéis gozado como esposas. No hay inconveniente en que decidáis algo de común acuerdo después de cumplir con lo debido. Alá es omnisciente, sabio.\qt@no{24}}
\qt@newcmd\qurantrans@es@dxviii{Quien de vosotros no disponga de los medios necesarios para casarse con mujeres libres creyentes, que tome mujer de entre vuestras jóvenes esclavas creyentes. Alá conoce bien vuestra fe. Salís los unos de los otros. Casaos con ellas con permiso de sus amos y dadles la dote conforme al uso, como a mujeres honestas, no como a fornicadoras o como a amantes. Si estas mujeres se casan y cometen una deshonestidad, sufrirán la mitad del castigo que las mujeres libres. Esto va dirigido a aquéllos de vosotros que tengan miedo de caer en pecado. Sin embargo, es mejor para vosotros que tengáis paciencia. Alá es indulgente, misericordioso.\qt@no{25}}
\qt@newcmd\qurantrans@es@dxix{Alá quiere aclararos y dirigiros según la conducta de los que os precedieron, y volverse a vosotros. Alá es omnisciente, sabio.\qt@no{26}}
\qt@newcmd\qurantrans@es@dxx{Alá quiere volverse a vosotros, mientras que los que siguen lo apetecible quieren que os extraviéis por completo.\qt@no{27}}
\qt@newcmd\qurantrans@es@dxxi{Alá quiere aliviaros, ya que el hombre es débil por naturaleza.\qt@no{28}}
\qt@newcmd\qurantrans@es@dxxii{¡Creyentes! No os devoréis la hacienda injustamente unos a otros. Es diferente si comerciáis de común acuerdo. No os matéis unos a otros. Alá es misericordioso con vosotros.\qt@no{29}}
\qt@newcmd\qurantrans@es@dxxiii{A quien obre así, violando la ley impíamente, le arrojaremos a un Fuego. Es cosa fácil para Alá.\qt@no{30}}
\qt@newcmd\qurantrans@es@dxxiv{Si evitáis los pecados graves que se os han prohibido, borraremos vuestras malas obras y os introduciremos con honor.\qt@no{31}}
\qt@newcmd\qurantrans@es@dxxv{No codiciéis aquello por lo que Alá ha preferido a unos de vosotros más que a otros. Los hombres tendrán parte según sus méritos y las mujeres también. Pedid a Alá de Su favor. Alá es omnisciente.\qt@no{32}}
\qt@newcmd\qurantrans@es@dxxvi{Hemos designado para todos herederos legales de lo que dejen: los padres, los parientes más cercanos, los unidos a vosotros por juramento. Dadles su parte. Alá es testigo de todo.\qt@no{33}}
\qt@newcmd\qurantrans@es@dxxvii{Los hombres tienen autoridad sobre las mujeres en virtud de la preferencia que Alá ha dado a unos más que a otros y de los bienes que gastan. Las mujeres virtuosas son devotas y cuidan, en ausencia de sus maridos, de lo que Alá manda que cuiden. ¡Amonestad a aquéllas de quienes temáis que se rebelen, dejadlas solas en el lecho, pegadles! Si os obedecen, no os metáis más con ellas. Alá es excelso, grande.\qt@no{34}}
\qt@newcmd\qurantrans@es@dxxviii{Si teméis una ruptura entre los esposos, nombrad un árbitro de la familia de él y otro de la de ella. Si desean reconciliarse, Alá hará que lleguen a un acuerdo. Alá es omnisciente, está bien informado.\qt@no{35}}
\qt@newcmd\qurantrans@es@dxxix{¡Servid a Alá y no Le asociéis nada! ¡Sed buenos con vuestros padres, parientes, huérfanos, pobres, vecinos -parientes y no parientes-, el compañero de viaje, el viajero y vuestros esclavos! Alá no ama al presumido, al jactancioso,\qt@no{36}}
\qt@newcmd\qurantrans@es@dxxx{a los avaros y a los que empujan a otros a ser avaros, a los que ocultan el favor que Alá les ha dispensado, -hemos preparado para los infieles un castigo humillante-.\qt@no{37}}
\qt@newcmd\qurantrans@es@dxxxi{a los que gastan su hacienda para ser vistos de los hombres, sin creer en Alá ni en el último Día. Y si alguien tiene por compañero al Demonio, mal compañero tiene...\qt@no{38}}
\qt@newcmd\qurantrans@es@dxxxii{¿Qué les habría costado haber creído en Alá y en el último Día y haber gastado en limosnas parte de aquello de que Alá les ha proveído? Alá les conoce bien.\qt@no{39}}
\qt@newcmd\qurantrans@es@dxxxiii{Alá no hará ni el peso de un átomo de injusticia a nadie. Y si se trata de una obra buena, la doblará y dará, por Su parte, una magnífica recompensa.\qt@no{40}}
\qt@newcmd\qurantrans@es@dxxxiv{¿Qué pasará cuando traigamos a un testigo de cada comunidad y te traigamos a ti como testigo contra éstos?\qt@no{41}}
\qt@newcmd\qurantrans@es@dxxxv{Ese día, los que fueron infieles y desobedecieron al Enviado querrán que la tierra se aplane sobre ellos. No podrán ocultar nada a Alá.\qt@no{42}}
\qt@newcmd\qurantrans@es@dxxxvi{¡Creyentes! No os acerquéis ebrios a la azalá. Esperad a que estéis en condiciones de saber lo que decís. No vayáis impuros -a no ser que estéis de viaje- hasta que os hayáis lavado. Y si estáis enfermos o de viaje, si viene uno de vosotros de hacer sus necesidades, o habéis tenido contacto con mujeres y no encontráis agua, recurrid a arena limpia y pasadla por el rostro y por las manos. Alá es perdonador, indulgente.\qt@no{43}}
\qt@newcmd\qurantrans@es@dxxxvii{¿No has visto a quienes han recibido una porción de la Escritura ? Compran el extravío y quieren que vosotros os extraviéis del Camino.\qt@no{44}}
\qt@newcmd\qurantrans@es@dxxxviii{Alá conoce mejor que nadie a vuestros enemigos. Alá basta como amigo. Alá basta como auxiliar.\qt@no{45}}
\qt@newcmd\qurantrans@es@dxxxix{Algunos judíos alteran el sentido de las palabras y dicen: «Oímos y desobedecemos... ¡Escucha, sin que se pueda oír! ¡Raina!», trabucando con sus lenguas y atacando la Religión. Si dijeran: «Oímos y obedecemos...¡Escucha! ¡Unzurna!», sería mejor para ellos y más correcto. Pero Alá les ha maldecido por su incredulidad. Creen, pero poco.\qt@no{46}}
\qt@newcmd\qurantrans@es@dxl{Vosotros, los que habéis recibido la Escritura, ¡creed en lo que hemos revelado, en confirmación de lo que ya poseíais, antes de que borremos los rasgos de los rostros, antes de que los pongamos del revés o les maldigamos como maldijimos a los del sábado! ¡La orden de Alá se cumple!\qt@no{47}}
\qt@newcmd\qurantrans@es@dxli{Alá no perdona que se Le asocie. Pero perdona lo menos grave a quien Él quiere. Quien asocia a Alá comete un gravísimo pecado.\qt@no{48}}
\qt@newcmd\qurantrans@es@dxlii{¿No has visto a quienes se consideran puros? No, es Alá Quien declara puro a quien Él quiere y nadie será tratado injustamente en lo más mínimo.\qt@no{49}}
\qt@newcmd\qurantrans@es@dxliii{¡Mira cómo inventan la mentira contra Alá! Basta eso como pecado manifiesto.\qt@no{50}}
\qt@newcmd\qurantrans@es@dxliv{¿No has visto a quienes han recibido una porción de la Escritura ? Creen en el chibt y en los taguts y dicen de los infieles: «Éstos están mejor dirigidos que los creyentes».\qt@no{51}}
\qt@newcmd\qurantrans@es@dxlv{A ésos son a quienes Alá ha maldecido, y no encontrarás quien auxilie a quien Alá maldiga.\qt@no{52}}
\qt@newcmd\qurantrans@es@dxlvi{Aunque tuvieran parte en el dominio no darían a la gente lo más mínimo.\qt@no{53}}
\qt@newcmd\qurantrans@es@dxlvii{¿Envidiarán a la gente por el favor que Alá les ha dispensado? Hemos dado a la familia de Abraham la Escritura y la Sabiduría. les hemos dado un dominio inmenso.\qt@no{54}}
\qt@newcmd\qurantrans@es@dxlviii{De ellos, unos creen en ella y otros se apartan de ella. La gehena les bastará como fuego.\qt@no{55}}
\qt@newcmd\qurantrans@es@dxlix{A quienes no crean en Nuestros signos les arrojaremos a un Fuego. Siempre que se les consuma la piel, se la repondremos, para que gusten el castigo. Alá es poderoso, sabio.\qt@no{56}}
\qt@newcmd\qurantrans@es@dl{A quienes crean y obren bien, les introduciremos en jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, para siempre. Allí tendrán esposas purificadas y haremos que les dé una sombra espesa.\qt@no{57}}
\qt@newcmd\qurantrans@es@dli{Alá os ordena que restituyáis los depósitos a sus propietarios y que cuando decidáis entre los hombres lo hagáis con justicia. ¡Qué bueno es aquello a que Alá os exhorta! Alá todo lo oye, todo lo ve.\qt@no{58}}
\qt@newcmd\qurantrans@es@dlii{¡Creyentes! Obedeced a Alá, obedeced al Enviado y a aquéllos de vosotros que tengan autoridad. Y, si discutís por í algo, referidlo a Alá y al Enviado, si es que créis en Alá y en el último Día. Es lo mejor y la solución más apropiada.\qt@no{59}}
\qt@newcmd\qurantrans@es@dliii{¿No has visto a quienes pretenden creer en lo que se te ha revelado a ti y en lo que se ha revelado antes de ti? Quieren recurrir al arbitraje de los taguts, a pesar de que se les ha ordenado no creer en ellos. El Demonio quiere extraviarles profundamente.\qt@no{60}}
\qt@newcmd\qurantrans@es@dliv{Cuando se les dice: «¡Venid a lo que Alá ha revelado, venid al Enviado!», ves que los hipócritas se apartan de ti completamente.\qt@no{61}}
\qt@newcmd\qurantrans@es@dlv{¿Qué harán, entonces, cuando les aflija una desgracia por lo que ellos mismos han cometido y vengan a ti, jurando por Alá: «No queríamos sino hacer bien y ayudar»?\qt@no{62}}
\qt@newcmd\qurantrans@es@dlvi{Esos tales son aquéllos de quienes Alá conoce lo que encierran sus corazones ¡Apártate de ellos, amonéstales, diles palabras persuasivas que se apliquen a su caso!\qt@no{63}}
\qt@newcmd\qurantrans@es@dlvii{No hemos mandado a ningún Enviado sino para, con permiso de Alá, ser obedecido. Si, cuando fueron injustos consigo mismos, hubieran venido a ti y pedido el perdón de Alá, y si el Enviado hubiera también pedido el perdón por ellos, habrían encontrado a Alá indulgente, misericordioso.\qt@no{64}}
\qt@newcmd\qurantrans@es@dlviii{Pero ¡no, por tu Señor! No creerán hasta que te hayan hecho juez de su disputa; entonces, ya no encontrarán en sí mismos dificultad en aceptar tu decisión y se adherirán plenamente.\qt@no{65}}
\qt@newcmd\qurantrans@es@dlix{Si les hubiéramos prescrito: «¡Mataos unos a otros!» o «¡Salid de vuestros hogares!», no lo habrían hecho, salvo unos pocos de ellos. Pero, si se hubieran conformado a las exhortaciones recibidas, habría sido mejor para ellos y habrían salido más fortalecidos.\qt@no{66}}
\qt@newcmd\qurantrans@es@dlx{les habríamos dado entonces, por parte Nuestra, una magnífica recompensa\qt@no{67}}
\qt@newcmd\qurantrans@es@dlxi{y les habríamos dirigido por una vía recta.\qt@no{68}}
\qt@newcmd\qurantrans@es@dlxii{Quienes obedecen a Alá y al Enviado, están con los profetas, los veraces, los testigos y los justos a los que Alá ha agraciado. ¡Qué buena compañía!\qt@no{69}}
\qt@newcmd\qurantrans@es@dlxiii{Así es el favor de Alá. Alá basta como omnisciente.\qt@no{70}}
\qt@newcmd\qurantrans@es@dlxiv{¡Creyentes! ¡Tened cuidado! Acometed en destacamentos o formando un solo cuerpo.\qt@no{71}}
\qt@newcmd\qurantrans@es@dlxv{Hay entre vosotros quien se queda rezagado del todo y, si os sobreviene una desgracia, dice: «Alá me ha agraciado, pues no estaba allí con ellos».\qt@no{72}}
\qt@newcmd\qurantrans@es@dlxvi{Pero, si Alá os favorece, seguro que, dice, como si no existiera ninguna amistad entre vosotros y él: «¡Ojalá hubiera estado con ellos, habría obtenido un éxito grandioso!»\qt@no{73}}
\qt@newcmd\qurantrans@es@dlxvii{¡Que quienes cambian la vida de acá por la otra combatan por Alá! A quien. combatiendo por Alá, sea muerto o salga victorioso, le daremos una magnífica recompensa.\qt@no{74}}
\qt@newcmd\qurantrans@es@dlxviii{¿Por qué no queréis combatir por Alá y por los oprimidos -hombres, mujeres y niños que dicen: «¡Señor! ¡Sácanos de esta ciudad, de impíos habitantes! ¡Danos un amigo designado por Ti! ¡Danos un auxiliar designado por tí!»?\qt@no{75}}
\qt@newcmd\qurantrans@es@dlxix{Quienes creen, combaten por Alá. Quienes no creen, combaten por los taguts. Combatid, pues, contra los amigos del Demonio. ¡Las artimañas del Demonio son débiles!\qt@no{76}}
\qt@newcmd\qurantrans@es@dlxx{¿No has visto a aquéllos a quienes se dijo: «¡Deponed las armas! ¡Haced la azalá y dad el azaque!»? Cuando se les prescribe el combate, algunos de ellos tienen tanto miedo de los hombres como deberían tener de Alá, o aún más, y dicen: «¡Señor! ¿Por qué nos has ordenado combatir? Si nos dejaras para un poco más tarde...» Di: «El breve disfrute de la vida de acá es mezquino. La otra vida es mejor para quien teme a Alá. No se os tratará injustamente en lo más mínimo».\qt@no{77}}
\qt@newcmd\qurantrans@es@dlxxi{Dondequiera que os encontréis, la muerte os alcanzará, aun si estáis en torres elevadas. Si les sucede un bien, dicen: «Esto viene de Alá». Pero, si es un mal, dicen: «Esto viene de ti». Di: «Todo viene de Alá». Pero ¿qué tienen éstos, que apenas comprenden lo que se les dice?\qt@no{78}}
\qt@newcmd\qurantrans@es@dlxxii{Lo bueno que te sucede viene de Alá. Lo malo que te sucede viene de ti mismo. Te hemos mandado a la Humanidad como Enviado. Alá basta como testigo.\qt@no{79}}
\qt@newcmd\qurantrans@es@dlxxiii{Quien obedece al Enviado, obedece a Alá. Quien se aparta... Nosotros no te hemos mandado para que seas su custodio.\qt@no{80}}
\qt@newcmd\qurantrans@es@dlxxiv{Y dicen: «¡Obediencia! Pero, cuando salen de tu presencia, algunos traman de noche hacer otra cosa diferente de lo que tú dices. Alá toma nota de lo que traman de noche. ¡Apártate, pues, de ellos y confía en Alá! ¡Alá basta como protector!\qt@no{81}}
\qt@newcmd\qurantrans@es@dlxxv{¿No meditan en el Corán ? Si hubiera sido de otro que de Alá, habrían encontrado en él numerosas contradicciones.\qt@no{82}}
\qt@newcmd\qurantrans@es@dlxxvi{Cuando se enteran de algo referente a la seguridad o al temor, lo difunden. Si lo hubieran referido al Enviado y a quienes de ellos tienen autoridad, los que deseaban averiguar la verdad habrían sabido si dar crédito o no. Si no llega a ser por el favor que de Alá habéis recibido y por Su misericordia, habríais seguido casi todos al Demonio.\qt@no{83}}
\qt@newcmd\qurantrans@es@dlxxvii{¡Combate, pues, por Alá! Sólo de ti eres responsable. ¡Anima a los creyentes! Puede que Alá contenga el ímpetu de los infieles. Alá dispone de más violencia y es más terrible en castigar.\qt@no{84}}
\qt@newcmd\qurantrans@es@dlxxviii{Quien intercede de buena manera tendrá su parte y quien intercede de mala manera recibirá otro tanto. Alá vela por todo.\qt@no{85}}
\qt@newcmd\qurantrans@es@dlxxix{Si os saludan, saludad con un saludo aún mejor, o devolvedlo igual. Alá tiene todo en cuenta.\qt@no{86}}
\qt@newcmd\qurantrans@es@dlxxx{¡Alá! ¡No hay más dios que Él! Él ha de reuniros para el día indubitable de la Resurreción. Y ¿quién es más veraz que Alá cuando dice algo?\qt@no{87}}
\qt@newcmd\qurantrans@es@dlxxxi{¿Por qué vais a dividiros en dos partidos a propósito de los hipócritas? Alá les ha rechazado ya por lo que han hecho. ¿Es que queréis dirigir a quien Alá ha extraviado? No encontrarás camino para aquél a quien Alá extravía.\qt@no{88}}
\qt@newcmd\qurantrans@es@dlxxxii{Querrían que, como ellos, no creyerais, para ser iguales que ellos. No hagáis, pues, amigos entre ellos hasta que hayan emigrado por Alá. Si cambian de propósito, apoderaos de ellos y matadles donde les encontréis. No aceptéis su amistad ni auxilio,\qt@no{89}}
\qt@newcmd\qurantrans@es@dlxxxiii{a menos que sean aliados de gente con la que os una un pacto, o que vengan a vosotros con el ánimo oprimido por tener que combatir contra vosotros o contra su propia gente. Si Alá hubiera querido, les habría dado poder sobre vosotros y habrían combatido contra vosotros. Si se mantienen aparte, si no combaten contra vosotros y os ofrecen someterse, entonces no tendréis justificación ante Alá contra ellos.\qt@no{90}}
\qt@newcmd\qurantrans@es@dlxxxiv{Hallaréis a otros que desean vivir en paz con vosotros y con su propia gente. Siempre que se les invita a la apostasía, caen en ella. Si no se mantienen aparte, si no os ofrecen someterse, si no deponen las armas, apoderaos de ellos y matadles donde deis con ellos. Os hemos dado pleno poder sobre ellos.\qt@no{91}}
\qt@newcmd\qurantrans@es@dlxxxv{Un creyente no puede matar a otro creyente, a menos que sea por error. Y quien mate a un creyente por error deberá manumitir a un esclavo creyente y pagar el precio de sangre a la familia de la víctima, a menos que ella renuncie al mismo como limosna. Y si la víctima era creyente y pertenecía a gente enemiga vuestra, deberá manumitir a un esclavo creyente. Pero, si pertenecía a gente con la que os une un pacto, el precio de sangre debe pagarse a la familia de la víctima, aparte de la manumisión de un esclavo creyente. Y quien no disponga de medios, ayunará dos meses consecutivos, como expiación impuesta por Alá. Alá es omniscente, sabio.\qt@no{92}}
\qt@newcmd\qurantrans@es@dlxxxvi{Y quien mate a un creyente premeditadamente, tendrá la gehena como retribución, eternamente. Alá se irritará con él, le maldecirá y le preparará un castigo terrible.\qt@no{93}}
\qt@newcmd\qurantrans@es@dlxxxvii{¡Creyentes! cuando acudáis a combatir por Alá, cuidado no digáis al primero que os salude: «¡Tú no eres creyente!», buscando los bienes de la vida de acá. Alá ofrece abundantes ocasiones de obtener botín. Vosotros también erais así antes s Alá os agració! ¡Cuidado, pues, que Alá está bien informado de lo que hacéis!\qt@no{94}}
\qt@newcmd\qurantrans@es@dlxxxviii{Los creyentes que se quedan en casa, sin estar impedidos, no son iguales que los que combaten por Alá con su hacienda y sus personas. Alá ha puesto a los que combaten con su hacienda y sus personas un grado por encima de los que se quedan en casa. A todos, sin embargo, ha prometido Alá lo mejor, pero Alá ha distinguido a los combatientes por encima de quienes se quedan en casa con una magnífica recompensa,\qt@no{95}}
\qt@newcmd\qurantrans@es@dlxxxix{con el rango que junto a Él ocupan, con perdón y misericordia. Alá es indulgente, misericordioso.\qt@no{96}}
\qt@newcmd\qurantrans@es@dxc{Los ángeles dirán a aquéllos a quienes llamen y que han sido injustos consigo mismos: «Cuál era vuestra situación?» Dirán: «Éramos oprimidos en la tierra». Dirán: «¿Es que la tierra de Alá no era vasta como para que pudierais emigrar?» Esos tales tendrán la gehena como morada. ¡;Mal fin...!\qt@no{97}}
\qt@newcmd\qurantrans@es@dxci{Quedan exceptuados los oprimidos -hombres, mujeres y niños-, que no disponen de posibilidades y no son dirigidos por el Camino.\qt@no{98}}
\qt@newcmd\qurantrans@es@dxcii{A éstos puede que Alá les perdone. Alá es perdonador, indulgente.\qt@no{99}}
\qt@newcmd\qurantrans@es@dxciii{Quien emigre por Alá, encontrará en la tierra mucho refugio y espacio. La recompensa de aquél a quien sorprenda la muerte, después de dejar su casa para emigrar a Alá y a Su enviado, incumbe a Alá. Alá es indulgente, misericordioso.\qt@no{100}}
\qt@newcmd\qurantrans@es@dxciv{Cuando estéis de viaje, no hay incoveniente en que abreviéis la azalá, si teméis un ataque de los infieles. Los infieles son para vosotros un enemigo declarado.\qt@no{101}}
\qt@newcmd\qurantrans@es@dxcv{Cuando estés con ellos y les dirijas la azalá, que un grupo se mantenga de pie a tu lado, arma en mano. Cuando se hayan prosternado, que vayan atrás y que otro grupo que aún no haya orado venga y ore contigo. ¡Que tengan cuidado y no dejen las armas de la mano! Los infieles querrían que descuidarais vuestras armas e impedimenta para echarse de improviso sobre vosotros. No hay inconveniente en que dejéis a un lado las armas si la lluvia os molesta o estáis enfermos, pero ¡tened cuidado! Alá ha preparado un castigo humillante para los infieles.\qt@no{102}}
\qt@newcmd\qurantrans@es@dxcvi{Cuando hayáis terminado la azalá recordad a Alá de pie, sentados o echados. Y, si os sentís tranquilos, haced la azalá. La azalá se ha prescrito a los creyentes en tiempos determinados.\qt@no{103}}
\qt@newcmd\qurantrans@es@dxcvii{No dejéis de perseguir a esa gente. Si os cuesta, también a ellos, como a vosotros, les cuesta, pero vosotros esperáis de Alá lo que ellos no esperan. Alá es omnisciente, sabio.\qt@no{104}}
\qt@newcmd\qurantrans@es@dxcviii{Te hemos revelado la Escritura con la Verdad para que decidas entre los hombres como Alá te dé a entender. ¡No abogues por los traidores!\qt@no{105}}
\qt@newcmd\qurantrans@es@dxcix{¡Pide perdón a Alá! Alá es indulgente, misericordioso.\qt@no{106}}
\qt@newcmd\qurantrans@es@dc{¡No discutas defendiendo a los que obran deslealmente consigo mismos! Alá no ama al que es traidor contumaz, pecador.\qt@no{107}}
\qt@newcmd\qurantrans@es@dci{Se esconden de los hombres, pero no pueden esconderse de Alá, Que está presente cuando traman de noche algo que no Le satisface. Alá abarca todo lo que hacen.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcii{¡Mirad cómo sois! Discutís en favor de ellos en la vida de acá, pero ¿quién va a defenderles contra Alá el día de la Resurrección? ¿Quién será entonces su protector?\qt@no{109}}
\qt@newcmd\qurantrans@es@dciii{Quien obra mal o es injusto consigo mismo, si luego pide perdón a Alá, encontrará a Alá indulgente, misericordioso.\qt@no{110}}
\qt@newcmd\qurantrans@es@dciv{Quien peca, peca, en realidad, en detrimento propio. Alá es omnisciente, sabio.\qt@no{111}}
\qt@newcmd\qurantrans@es@dcv{Quien comete una falta o un pecado y acusa de ello a un inocente, carga con una infamia y con un pecado manifiesto.\qt@no{112}}
\qt@newcmd\qurantrans@es@dcvi{Si no llega a ser por el favor de Alá en ti y por Su misericordia, algunos de ellos habrían preferido extraviarte. Pero sólo se extravían a sí mismos y no pueden, en modo alguno, dañarte. Alá te ha revelado la Escritura y la Sabiduría y te ha enseñado lo que no sabías. El favor de Alá en ti es inmenso.\qt@no{113}}
\qt@newcmd\qurantrans@es@dcvii{En muchos de sus conciliábulos no hay bien, salvo cuando uno ordena la limosna, lo reconocido como bueno o la , reconciliación entre los hombres. A quien haga esto por deseo de agradar a Alá, le daremos una magnífica recompensa.\qt@no{114}}
\qt@newcmd\qurantrans@es@dcviii{A quien se separe del Enviado después de habérsele manifestado claramente la Dirección y siga un camino diferente del de los creyentes, le abandonaremos en la medida que él abandone y le arrojaremos a la gehena. ¡Mal fin...!\qt@no{115}}
\qt@newcmd\qurantrans@es@dcix{Alá no perdona que se Le asocie. Pero perdona lo menos grave a quien Él quiere. Quien asocia a Alá está profundamente extraviado.\qt@no{116}}
\qt@newcmd\qurantrans@es@dcx{En lugar de invocarle a Él, no invocan sino a deidades femeninas. No invocan más que a un demonio rebelde.\qt@no{117}}
\qt@newcmd\qurantrans@es@dcxi{¡Que Alá le maldiga! Ha dicho: «He de tomar a un número determinado de Tus siervos,\qt@no{118}}
\qt@newcmd\qurantrans@es@dcxii{he de extraviarles, he de inspirarles vanos deseos, he de ordenarles que hiendan las orejas del ganado y que alteren la creación de Alá!» Quien tome como amigo al Demonio, en lugar de tomar a Alá, está manifiestamente perdido.\qt@no{119}}
\qt@newcmd\qurantrans@es@dcxiii{Les hace promesas y les inspira vanos deseos, pero el Demonio no les promete sino falacia.\qt@no{120}}
\qt@newcmd\qurantrans@es@dcxiv{La morada de esos tales será la gehena y no hallarán medio de escapar de ella.\qt@no{121}}
\qt@newcmd\qurantrans@es@dcxv{A quienes crean y obren bien, les introduciremos en jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, para siempre. ¡Promesa de Alá. verdad! Y ¿quién es más veraz que Alá cuando dice algo?\qt@no{122}}
\qt@newcmd\qurantrans@es@dcxvi{Esto no depende de lo que vosotros anheléis ni de lo que anhele la gente de la Escritura. Quien obre mal será retribuido por ello y no encontrará, fuera de Alá, amigo ni auxiliar.\qt@no{123}}
\qt@newcmd\qurantrans@es@dcxvii{El creyente, varón o hembra, que obre bien, entrará en el Jardín y no será tratado injustamente en lo más mínimo.\qt@no{124}}
\qt@newcmd\qurantrans@es@dcxviii{¿Quién es mejor, tocante a religión. que quien se somete a Alá, hace el bien y sigue la religión de Abraham, que fue hanif ? Alá tomó a Abraham como amigo.\qt@no{125}}
\qt@newcmd\qurantrans@es@dcxix{De Alá es lo que está en los cielos y en la tierra. Alá todo lo abarca.\qt@no{126}}
\qt@newcmd\qurantrans@es@dcxx{Te consultan a propósito de las mujeres. Di: «Alá os da a conocer Su parecer sobre ellas, aparte de lo que ya se os ha recitado en la Escritura a propósito de las huérfanas a las que aún no habéis dado la parte que les corresponde y con las que deseáis casaros, y a propósito de los niños débiles, y que tratéis con equidad a los huérfanos. Alá conoce perfectamente el bien que hacéis.\qt@no{127}}
\qt@newcmd\qurantrans@es@dcxxi{Y si una mujer teme malos tratos o aversión por parte de su marido, no hay inconveniente en que se reconcilien, pues es mejor la reconciliación. El ánimo es propenso a la codicia, pero si hacéis bien a otros y teméis a Alá,... Alá está bien informado de lo que hacéis.\qt@no{128}}
\qt@newcmd\qurantrans@es@dcxxii{No podréis ser justos con vuestras mujeres, aun si lo deseáis. No seáis, pues, tan parciales que dejéis a una de ellas como en suspenso. Si ponéis paz y teméis a Alá,... Alá es indulgente, misericordioso.\qt@no{129}}
\qt@newcmd\qurantrans@es@dcxxiii{Si se separan, Alá enriquecerá a cada uno con Su abundancia. Alá es inmenso, sabio.\qt@no{130}}
\qt@newcmd\qurantrans@es@dcxxiv{De Alá es lo que está en los cielos y en la tierra. Hemos ordenado a quienes, antes de vosotros, recibieron la Escritura, y a vosotros también, el temor de Alá. Si no creéis,... de Alá es lo que está en los cielos y en la tierra. Alá Se basta a Sí mismo es digno de alabanza.\qt@no{131}}
\qt@newcmd\qurantrans@es@dcxxv{De Alá es lo que está en los cielos y en la tierra. Alá basta como protector.\qt@no{132}}
\qt@newcmd\qurantrans@es@dcxxvi{¡Hombres! Si Él quisiera, os haría desaparecer y os sustituiría por otros. Alá es capaz de hacerlo.\qt@no{133}}
\qt@newcmd\qurantrans@es@dcxxvii{Quien desee la recompensa de la vida de acá, sepa que Alá dispone de la recompensa de la vida de acá y de la otra. Alá todo lo oye, todo lo ve.\qt@no{134}}
\qt@newcmd\qurantrans@es@dcxxviii{¡Creyentes! Sed íntegros en la equidad, cuando depongáis como testigos de Alá, aun en contra vuestra, o de vuestros padres o parientes más cercanos. Lo mismo si es rico que si es pobre, Alá está más cerca de él. No sigáis la pasión faltando a la justicia. Si levantáis falso testimonio u os zafáis,... Alá está bien informado de lo que hacéis.\qt@no{135}}
\qt@newcmd\qurantrans@es@dcxxix{¡Creyentes! Creed en Alá, en Su Enviado, en la Escritura que ha revelado a Su Enviado y en la Escritura que había revelado antes. Quien no cree en Alá, en Sus ángeles, en Sus Escrituras, en Sus enviados y en el último Día, ese tal está profundamente extraviado.\qt@no{136}}
\qt@newcmd\qurantrans@es@dcxxx{A quienes crean y luego dejen de creer, vuelvan a creer y de nuevo dejen de creer, creciendo en su incredulidad, Alá no está para perdonarles ni dirigirles por un camino.\qt@no{137}}
\qt@newcmd\qurantrans@es@dcxxxi{Anuncia a los hipócritas que tendrán un castigo doloroso.\qt@no{138}}
\qt@newcmd\qurantrans@es@dcxxxii{Toman a los infieles como amigos, en lugar de tomar a los creyentes. ¿Es que buscan en ellos el poder? El poder pertenece en su totalidad a Alá.\qt@no{139}}
\qt@newcmd\qurantrans@es@dcxxxiii{Él os ha revelado en la Escritura : «Cuando oigáis que las aleyas de Alá no son creídas y son objeto de burla, no os sentéis con ellos mientras no cambien de tema de conversación; si no, os haréis como ellos». Alá reunirá a los hipócritas y a los infieles, todos juntos, en la gehena.\qt@no{140}}
\qt@newcmd\qurantrans@es@dcxxxiv{Están a la expectativa, a ver cómo os va. Cuando tenéis éxito con la ayuda de d Alá, dicen: «Pues ¿no estábamos con vosotros?» Pero, si los infieles obtienen un éxito parcial, dicen: «¿No tuvimos ocasión de venceros y, en cambio, os defendimos contra los creyentes?» Alá decidirá entre vosotros el día de la Resurrección. Alá no permitirá que los infieles prevalezcan sobre los creyentes.\qt@no{141}}
\qt@newcmd\qurantrans@es@dcxxxv{Los hipócritas tratan de engañar a Alá, pero es Él Quien les engaña. Cuando se disponen a hacer la azalá lo hacen perezosamente, sólo para ser vistos de los hombres, apenas piensan en Alá.\qt@no{142}}
\qt@newcmd\qurantrans@es@dcxxxvi{Vacilantes, no se pronuncian por unos ni por otros. No encontrarás camino para aquél a quien Alá extravía.\qt@no{143}}
\qt@newcmd\qurantrans@es@dcxxxvii{¡Creyentes! No toméis a los infieles como amigos, en lugar de tomar a los creyentes. ¿Queréis dar a Alá un argumento manifiesto en contra vuestra?\qt@no{144}}
\qt@newcmd\qurantrans@es@dcxxxviii{Los hipócritas estarán en lo más profundo del Fuego y no encontrarás quien les auxilie,\qt@no{145}}
\qt@newcmd\qurantrans@es@dcxxxix{salvo si se arrepienten, se enmiendan, se aferran a Alá y rinden a Alá un culto sincero. Éstos estarán en companía de los creyentes y Alá dará a los creyentes una magnífica recompensa.\qt@no{146}}
\qt@newcmd\qurantrans@es@dcxl{¿Por qué va Alá a castigaros si sois agradecidos y creéis? Alá es agradecido, omnisciente.\qt@no{147}}
\qt@newcmd\qurantrans@es@dcxli{A Alá no le gusta la maledicencia en voz alta, a no ser que quien lo haga haya sido tratado injustamente. Alá todo lo oye, todo lo sabe.\qt@no{148}}
\qt@newcmd\qurantrans@es@dcxlii{Que divulguéis un bien o lo ocultéis, que perdonéis un agravio... Alá es perdonador, poderoso.\qt@no{149}}
\qt@newcmd\qurantrans@es@dcxliii{Quienes no creen en Alá ni en Sus enviados y quieren hacer distingos entre Alá y Sus enviados, diciendo: «¡Creemos en unos, pero en otros no!», queriendo adoptar una postura intermedia,\qt@no{150}}
\qt@newcmd\qurantrans@es@dcxliv{ésos son los infieles de verdad. Y para los infieles tenemos preparado un castigo humillante.\qt@no{151}}
\qt@newcmd\qurantrans@es@dcxlv{Pero a quienes crean en Alá y en Sus enviados, sin hacer distingos entre ellos, Él les remunerará. Alá es indulgente, misericordioso.\qt@no{152}}
\qt@newcmd\qurantrans@es@dcxlvi{La gente de la Escritura te pide que les bajes del cielo una Escritura. Ya habían pedido a Moisés algo más grave que eso, cuando dijeron: «¡Muéstranos a Alá claramente!» Como castigo a su impiedad el Rayo se los llevó. Luego, cogieron el ternero, aun después de haber recibido las pruebas claras. Se lo perdonamos y dimos a Moisés una autoridad manifiesta.\qt@no{153}}
\qt@newcmd\qurantrans@es@dcxlvii{Levantamos la montaña por encima de ellos en señal de pacto con ellos y les dijimos: «¡Prosternaos al entrar por la puerta!» Y les dijimos: «¡No violéis el sábado!» Y concertamos con ellos un pacto solemne.\qt@no{154}}
\qt@newcmd\qurantrans@es@dcxlviii{por haber violado su pacto, por no haber creído en los signos de Alá, por haber matado a los profetas sin justificación y por haber dicho: «Nuestros corazones están incircuncisos». ¡No! Alá los ha sellado por su incredulidad, de modo que tienen fe, pero poca.\qt@no{155}}
\qt@newcmd\qurantrans@es@dcxlix{por su incredulidad por haber proferido contra María una enorme calumnia,\qt@no{156}}
\qt@newcmd\qurantrans@es@dcl{y por haber dicho: «Hemos dado muerte al Ungido, Jesús, hijo de María, el enviado de Alá», siendo así que no le mataron ni le crucificaron, sino que les pareció así. Los que discrepan acerca de él, dudan. No tienen conocimiento de él, no siguen más que conjeturas. Pero, ciertamente no le mataron,\qt@no{157}}
\qt@newcmd\qurantrans@es@dcli{sino que Alá lo elevó a Sí. Alá es poderoso, sabio.\qt@no{158}}
\qt@newcmd\qurantrans@es@dclii{Entre la gente de la Escritura no has nadie que no crea en Él antes de su muerte. Él día de la Resurrección servirá de testigo contra ellos.\qt@no{159}}
\qt@newcmd\qurantrans@es@dcliii{Prohibimos a los judíos cosas buenas que antes les habían sido lícitas, por haber sido impíos y por haber desviado a tantos del camino de Alá.\qt@no{160}}
\qt@newcmd\qurantrans@es@dcliv{por usurear, a pesar de habérseles prohibido, y por haber devorado la hacienda ajena injustamente. A los infieles de entre ellos les hemos preparado un castigo doloroso.\qt@no{161}}
\qt@newcmd\qurantrans@es@dclv{Pero a los que, de ellos, están arraigados en la Ciencia, a los creyentes, que , creen en lo que se te ha revelado a ti y a otros antes de ti, a los que hacen la azalá, a los que dan el azaque, a los que creen en Alá y en el último Día, a ésos les daremos una magnífica recompensa.\qt@no{162}}
\qt@newcmd\qurantrans@es@dclvi{Te hemos hecho una revelación, como hicimos una revelación a Noé y a los profeta que le siguieron. Hicimos una revelación a Abraham, Ismael, Isaac, Jacob, as tribus, Jesús, Job, Jonás, Aarón y Salomón. Y dimos a David Salmos.\qt@no{163}}
\qt@newcmd\qurantrans@es@dclvii{Te hemos contado previamente de algunos enviados, de otros no -con Moisés Alá habló de hecho-,\qt@no{164}}
\qt@newcmd\qurantrans@es@dclviii{enviados portadores de buenas nuevas y que advertían, para que los hombres no pudieran alegar ningún pretexto ante Alá después de la venida de los enviados. Alá es poderoso, sabio.\qt@no{165}}
\qt@newcmd\qurantrans@es@dclix{Pero Alá es testigo de que lo que El te ha revelado lo ha revelado con Su ciencia. Los ángeles también son testigos, aunque basta Alá como testigo.\qt@no{166}}
\qt@newcmd\qurantrans@es@dclx{Los que no creen y desvían a otros del camino de Alá están profundamente extraviados.\qt@no{167}}
\qt@newcmd\qurantrans@es@dclxi{A los que no crean y obren impíamente Alá nunca les perdonará ni les dirigirá por otro camino\qt@no{168}}
\qt@newcmd\qurantrans@es@dclxii{que el camino de la gehena, en la que estarán eternamente, para siempre. Es cosa fácil para Alá.\qt@no{169}}
\qt@newcmd\qurantrans@es@dclxiii{¡Hombres! Ha venido a vosotros el Enviado con la Verdad que viene de vuestro Señor. Creed, pues, será mejor para vosotros. Si no creéis... De Alá es lo que está en los cielos y en la tierra. Alá es omnisciente, sabio.\qt@no{170}}
\qt@newcmd\qurantrans@es@dclxiv{¡Gente de la Escritura ! ¡No exageréis en vuestra religión! ¡No digáis de Alá sino la verdad: que el Ungido, Jesús, hijo de María, es solamente el enviado de Alá y Su Palabra, que Él ha comunicado a María, y un espíritu que procede de Él! ¡Creed, pues, en Alá y en Sus enviados! ¡No digáis ``Tres'! ¡Basta ya, será mejor para vosotros! Alá es sólo un Dios Uno. ¡Gloria a Él Tener un hijo...Suyo es lo que está en los cielos y en la tierra... ¡Alá basta como protector!\qt@no{171}}
\qt@newcmd\qurantrans@es@dclxv{El Ungido no tendrá a menos ser siervo de Alá, ni tampoco los ángeles allegados. A todos aquéllos que tengan a menos servirle y hayan sido altivos les congregará hacia Sí.\qt@no{172}}
\qt@newcmd\qurantrans@es@dclxvi{En cuanto a quienes hayan creído y obrado bien, Él les dará, por favor, Su recompensa y aún más. Pero a quienes hayan tenido a menos servirle y hayan sido altivos, les infligirá un castigo doloroso. No encontrarán, fuera de Alá, amigo ni auxiliar.\qt@no{173}}
\qt@newcmd\qurantrans@es@dclxvii{¡Hombres! Os ha venido de vuestro Señor una prueba. Y os hemos hecho bajar una Luz manifiesta.\qt@no{174}}
\qt@newcmd\qurantrans@es@dclxviii{A quienes hayan creído en Alá y se hayan aferrado a Él, les introducirá en Su misericordia y favor y les dirigirá a Sí por una vía recta.\qt@no{175}}
\qt@newcmd\qurantrans@es@dclxix{Te piden tu parecer. Di: «Alá os da el Suyo a propósito de los parientes colaterales. Si un hombre muere sin dejar hijos, pero sí una hermana, ésta heredará la mitad de lo que deja, y si ella muere sin dejar hijos, él heredará todo de ella. Si el difunto deja dos, éstas heredarán los dos tercios de lo que deje. Si tiene hermanos, varones y hembras, a cada varón le corresponderá tanto como a dos hembras juntas. Alá os aclara esto para que no os extraviéis. Alá es omnisciente».\qt@no{176}}
\qt@newcmd\qurantrans@es@dclxx{\basmalahes ¡Creyentes! ¡Respetad vuestros compromisos! La bestia de los rebaños os está permitida, salvo lo que se os recita. La caza no os está permitida mientras estéis sacralizados. Alá decide lo que Él quiere.\qt@no{1}}
\qt@newcmd\qurantrans@es@dclxxi{¡Creyentes! No profanéis las cosas sagradas de Alá, ni el mes sagrado, ni la víctima, ni las guirnaldas, ni a los que se dirigen a la Casa Sagrada, buscando favor de su Señor y satisfacerle. Podéis cazar cuando dejáis de estar sacralizados. Que el odio que tenéis a gente que hace poco os apartaba de la Mezquita Sagrada no os incite a violar la ley. Ayudaos unos a otros a practicar la piedad y el temor de Alá, no el pecado y la violación de la ley. ¡Y temed a Alá! Alá castiga severamente...\qt@no{2}}
\qt@newcmd\qurantrans@es@dclxxii{Os está vedada la carne mortecina, la sangre, la carne de cerdo, la de animal sobre el que se haya invocado un nombre diferente del de Alá, la de animal asfixiado o muerto a palos, de una caída, de una cornada, la del devorado parcialmente por las fieras -excepto si aún lo sacrificáis vosotros-, la del inmolado en piedras erectas. Consultar la suerte valiéndose de flechas es una pervesidad. Hoy quienes no creen han desesperado de vuestra religión. ¡No les tengáis, pues, miedo a ellos, sino a Mí! Hoy os he perfeccionado vuestra religión, he completado Mi gracia en vosotros y Me satisface que sea el islam vuestra religión. Si alguien se ve compelido durante un hambre, sin intención de pecar,...Alá es indulgente, misericordioso.\qt@no{3}}
\qt@newcmd\qurantrans@es@dclxxiii{Te preguntan qué les está permitido. Di: «Os están permitidas las cosas buenas. Podéis comer de lo que os cojan los animales de presa que habéis adiestrado para la caza, tal como Alá os ha enseñado. ¡Y mencionad el nombre de Alá sobre ello! ¡Y temed a Alá». Alá es rápido en ajustar cuentas.\qt@no{4}}
\qt@newcmd\qurantrans@es@dclxxiv{Hoy se os permiten las cosas buenas. Se os permite el alimento de quienes han recibido la Escritura, así como también se les permite a ellos vuestro alimento. Y las mujeres creyentes honestas y las honestas del pueblo que, antes que vosotros, había recibido la Escritura, si les dais la dote tomándolas en matrimonio, no como fornicadores o como amantes. Vanas serán las obras de quien rechace la fe y en la otra vida será de los que pierdan.\qt@no{5}}
\qt@newcmd\qurantrans@es@dclxxv{¡Creyentes! Cuando os dispongáis a hacer la azalá, lavaos el rostro y los brazos hasta el codo, pasad las manos por la cabeza y lavaos los pies hasta el tobillo. Si estáis en estado de impureza legal, purificaos. Y si estáis enfermos o de viaje, si viene uno de vosotros de hacer sus necesidades, o habéis tenido contacto con mujeres y no encontráis agua, recurrid a arena limpia y pasadla por el rostro y por las manos. Alá no quiere imponeros ninguna carga, sino purificaros y completar Su gracia en vosotros. Quizás, así seáis agradecidos.\qt@no{6}}
\qt@newcmd\qurantrans@es@dclxxvi{Recordad la gracia que Alá os dispensó y el pacto que concluyó con vosotros cuando dijisteis: «Oímos y obedecemos». ¡Temed a Alá! Alá sabe bien lo que encierran los pechos.\qt@no{7}}
\qt@newcmd\qurantrans@es@dclxxvii{¡Creyentes! ¡Sed íntegros ante Alá cuando depongáis con equidad! ¡Que el odio a una gente no os incite a obrar injustamente! ¡Sed justos! Esto es lo más próximo al temor de Alá. ¡Y temed a Alá! Alá está bien informado de lo que hacéis.\qt@no{8}}
\qt@newcmd\qurantrans@es@dclxxviii{Alá ha prometido a quienes crean y obren bien perdón y una magnífica recompensa.\qt@no{9}}
\qt@newcmd\qurantrans@es@dclxxix{Quienes no crean y desmientan Nuestros signos morarán en el fuego de la gehena.\qt@no{10}}
\qt@newcmd\qurantrans@es@dclxxx{¡Creyentes! Recordad la gracia que Alá os dispensó cuando una gente habría preferido poneros las manos encima y Él se lo impidió. ¡Y temed a Alá! ¡Que los creyentes confíen en Alá!\qt@no{11}}
\qt@newcmd\qurantrans@es@dclxxxi{Alá concertó un pacto con los Hijos de Israel. Suscitamos de entre ellos a doce jefes. Y Alá dijo: «Yo estoy con vosotros. Si hacéis la azalá, dais el azaque, creéis en Mis enviados y les auxiliáis, si hacéis un préstamo generoso a Alá, he de borrar vuestras malas obras e introduciros en jardines por cuyos bajos fluyen arroyos. Quien de vosotros, después de eso, no crea se habrá extraviado del camino recto».\qt@no{12}}
\qt@newcmd\qurantrans@es@dclxxxii{Por haber violado su pacto les hemos maldecido y hemos endurecido sus corazones. Alteran el sentido de las palabras; olvidan parte de lo que se les recordó. Siempre descubrirás en ellos alguna traición, salvo en unos pocos. ¡Borra sus faltas, perdónales! Alá ama a quienes hacen el bien.\qt@no{13}}
\qt@newcmd\qurantrans@es@dclxxxiii{Concertamos un pacto con quienes decían: «Somos cristianos». Pero olvidaron parte de lo que se les recordó y, por eso,. provocamos entre ellos enemistad y odio hasta el día de la Resurrección. Pero ya les informará Alá de lo que hacían.\qt@no{14}}
\qt@newcmd\qurantrans@es@dclxxxiv{¡Gente de la Escritura ! Nuestro Enviado ha venido a vosotros, aclarándoos mucho de lo que de la Escritura habíais ocultado y revocando mucho también. Os ha venido de Alá una Luz, una Escritura clara,\qt@no{15}}
\qt@newcmd\qurantrans@es@dclxxxv{por medio de la cual Alá dirige a quienes buscan satisfacerle por caminos de paz y les saca, con Su permiso, de las tinieblas a la luz, y les dirige a una vía recta.\qt@no{16}}
\qt@newcmd\qurantrans@es@dclxxxvi{No creen, en realidad, quienes dicen: «Alá es el Ungido, hijo de María». Di: «¿Quién podría impedir a Alá que. si Él quisiera, hiciera morir al Ungido, hijo de María, a su madre y a todos los de la tierra?» De Alá es el dominio de los cielos, de la tierra y de lo que entre ellos está. Crea lo que Él quiere. Alá es omnipotente.\qt@no{17}}
\qt@newcmd\qurantrans@es@dclxxxvii{Los judíos y los cristianos dicen: «Somos los hijos de Alá y Sus predilectos». Di: «¿Por qué, pues, os castiga por vuestros pecados? No, sino que sois mortales, de Sus criaturas. Perdona a quien Él quiere y castiga a quien Él quiere». De Alá es el dominio de los cielos y de la tierra y de lo que entre ellos está. Es Él el fin de todo.\qt@no{18}}
\qt@newcmd\qurantrans@es@dclxxxviii{¡Gente de la Escritura ! Nuestro Enviado ha venido a vosotros para instruiros, después de una interrupción de enviados, no sea que dijerais: «No ha venido a nosotros ningún nuncio de buenas nuevas, ni monitor alguno». Así, pues, sí que ha venido a vosotros un nuncio de buenas nuevas y un monitor. Alá es omnipotente.\qt@no{19}}
\qt@newcmd\qurantrans@es@dclxxxix{Y cuando Moisés dijo a su pueblo: «¡Pueblo! Recordad la gracia que Alá os dispensó cuando suscitó de entre vosotros a profetas e hizo de vosotros reyes, dándoos lo que no se había dado a ninguno en el mundo.\qt@no{20}}
\qt@newcmd\qurantrans@es@dcxc{¡Pueblo! ¡Entrad en la Tierra Santa que Alá os destinó y no volváis sobre vuestros pasos; si no, regresaréis habiendo perdido!».\qt@no{21}}
\qt@newcmd\qurantrans@es@dcxci{Dijeron: «¡Moisés! Hay en ella un pueblo de hombres fuertes y no entraremos mientras no salgan de ella. Si salen de ella, entonces, sí que entraremos».\qt@no{22}}
\qt@newcmd\qurantrans@es@dcxcii{Dos de sus hombres, temerosos de Alá, a quienes Alá había agraciado, dijeron: «Entrad contra ellos por la puerta. Una vez franqueada, la victoria será vuestra. Si sois creyentes, ¡confiad en Alá!».\qt@no{23}}
\qt@newcmd\qurantrans@es@dcxciii{Dijeron: «¡Moisés! No entraremos nunca en ella mientras ellos estén dentro. ¡Ve, pues, tú con tu Señor, y combatid, que nosotros nos quedamos aquí!».\qt@no{24}}
\qt@newcmd\qurantrans@es@dcxciv{Dijo: «¡Señor! Yo no puedo más que conmigo y con mi hermano. Haz distinción, pues, entre nosotros y este pueblo perverso».\qt@no{25}}
\qt@newcmd\qurantrans@es@dcxcv{Dijo: «Les estará prohibida durante cuarenta años, tiempo en el que vagarán por la tierra. ¡No te preocupes por este pueblo perverso!».\qt@no{26}}
\qt@newcmd\qurantrans@es@dcxcvi{¡Y cuéntales la historia auténtica de los dos hijos de Adán, cuando ofrecieron una oblación y se le aceptó a uno, pero al otro no! Dijo: «¡He de matarte!». Dijo: «Alá sólo acepta de los que Le temen.\qt@no{27}}
\qt@newcmd\qurantrans@es@dcxcvii{Y si tú pones la mano en mí para matarme, yo no voy a ponerla en ti para matarte, porque temo a Alá, Señor del universo.\qt@no{28}}
\qt@newcmd\qurantrans@es@dcxcviii{Quiero que cargues con tu pecado contra mí y otros pecados y seas así de los moradores del Fuego. Ésa es la retribución de los impíos».\qt@no{29}}
\qt@newcmd\qurantrans@es@dcxcix{Entonces, su alma le instigó a que s matara a su hermano y le mató, pasando a ser de los que pierden.\qt@no{30}}
\qt@newcmd\qurantrans@es@dcc{Alá envió un cuervo, que escarbó la tierra para mostrarle cómo esconder el cadáver de su hermano. Dijo: «¡Ay de mí! ¿Es que no soy capaz de imitar a este cuervo y esconder el cadáver de mi hermano?». Y pasó a ser de los arrepentidos.\qt@no{31}}
\qt@newcmd\qurantrans@es@dcci{Por esta razón, prescribimos a los Hijos de Israel que quien matara a una persona que no hubiera matado a nadie ni corrompido en la tierra, fuera como si hubiera matado a toda la Humanidad. Y que quien salvara una vida, fuera como si hubiera salvado las vidas de toda la Humanidad. Nuestros enviados vinieron a ellos con las pruebas claras, pero, a pesar de ellas, muchos cometieron excesos en la tierra.\qt@no{32}}
\qt@newcmd\qurantrans@es@dccii{Retribución de quienes hacen la guerra a Alá y a Su Enviado y se dan a corromper en la tierra: serán muertos sin piedad, o crucificados, o amputados de manos y pies opuestos, o desterrados del país. Sufrirán ignominia en la vida de acá y terrible castigo en la otra.\qt@no{33}}
\qt@newcmd\qurantrans@es@dcciii{Quedan exceptuados quienes se arrepientan antes de caer en vuestras manos. Sabed, en efecto, que Alá es indulgente, misericordioso.\qt@no{34}}
\qt@newcmd\qurantrans@es@dcciv{¡Creyentes! ¡Temed a Alá y buscad el medio de acercaros a Él! ¡Combatid por Su causa! Quizás, así, prosperéis.\qt@no{35}}
\qt@newcmd\qurantrans@es@dccv{Si poseyeran los infiles todo cuanto hay en la tierra y otro tanto, y lo ofrecieran como rescate para librarse del castigo del día de la Resurrección, no se les aceptaría Tendrán un castigo doloroso.\qt@no{36}}
\qt@newcmd\qurantrans@es@dccvi{Querrán salir del Fuego, pero no podrán. Tendrán un castigo permanente.\qt@no{37}}
\qt@newcmd\qurantrans@es@dccvii{Al ladrón y a la ladrona, cortadles las manos como retribución de lo que han cometido, como castigo ejemplar de Alá. Alá es poderoso, sabio.\qt@no{38}}
\qt@newcmd\qurantrans@es@dccviii{Si uno se arrepiente, después de haber obrado impíamente y se enmienda, Alá se volverá a él. Alá es indulgente, misericordioso.\qt@no{39}}
\qt@newcmd\qurantrans@es@dccix{¿No sabes que es de Alá el dominio de los cielos y de la tierra? Castiga a quien Él quiere y perdona a quien Él quiere. Alá es omnipotente.\qt@no{40}}
\qt@newcmd\qurantrans@es@dccx{¡Enviado! Que no te entristezcan quienes se precipitan en la incredulidad. Son de los que dicen con la boca: «Creemos», pero no creen de corazón, y de los judíos. Dan oídos a la mentira, dan oídos a otra gente que no ha venido a ti. Alteran el sentido de las palabras y dicen: «Si se os ha dado esto, ¡tomadlo!; pero, si no es esto lo que se os ha dado. ¡guardaos!». Si Alá quiere que alguien sea tentado, tú no puedes hacer nada por él contra Alá. Esos tales son aquéllos cuyos corazones Alá no ha querido purificar. Sufrirán ignominia en la vida de acá y terrible castigo en la otra.\qt@no{41}}
\qt@newcmd\qurantrans@es@dccxi{Dan oído a la mentira y devoran el soborno. Si vienen a ti, decide entre ellos o retírate. Si te retiras, no podrán hacerte ningún daño. Si decides, hazlo con equidad. Alá ama a los que observan la equidad.\qt@no{42}}
\qt@newcmd\qurantrans@es@dccxii{Pero ¿cómo van a hacerte juez teniendo como tienen la Tora, en la que se contiene la decisión de Alá? Luego, después de eso, se retiran. Esos tales no son creyentes.\qt@no{43}}
\qt@newcmd\qurantrans@es@dccxiii{Hemos revelado la Tora, que contiene Dirección y Luz. Los profetas que se habían sometido administraban justicia a los judíos según ella, como hacían los maestros y doctores, según lo que de la Escritura de Alá se les había confiado y de lo cual eran testigos. ¡No tengáis, pues, miedo a los hombres, sino a Mí! ¡Y no malvendáis Mis signos! Quienes no decidan según lo que Alá ha revelado, ésos son los infieles.\qt@no{44}}
\qt@newcmd\qurantrans@es@dccxiv{Les hemos prescrito en ella: «Vida por vida, ojo por ojo, nariz por nariz, oreja por oreja, diente por diente y la ley del talión por las heridas». Y si uno renuncia a ello, le servirá de expiación. Quienes no decidan según lo que Alá ha revelado, ésos son los impíos.\qt@no{45}}
\qt@newcmd\qurantrans@es@dccxv{Hicimos que les sucediera Jesús, hijo de María, en confirmación de lo que ya había de la Tora. Le dimos el Evangelio, que contiene Dirección y Luz, en confirmación de lo que ya había de la Tora y como Dirección y Exhortación para los temerosos de Alá.\qt@no{46}}
\qt@newcmd\qurantrans@es@dccxvi{Que la gente del Evangelio decida según lo que Alá ha revelado en él. Quienes no decidan según lo que Alá ha revelado ésos son los perversos.\qt@no{47}}
\qt@newcmd\qurantrans@es@dccxvii{Te hemos revelado la Escritura con la Verdad, en confirmación y como custodia de lo que ya había de la Escritura. Decide, pues, entre ellos según lo que Alá ha revelado y no sigas sus pasiones, que te apartan de la Verdad que has recibido. A cada uno os hemos dado una norma y una vía. Alá, si hubiera querido, habría hecho de vosotros una sola comunidad, pero quería probaros en lo que os dio. ¡Rivalizad en buenas obras! Todos volveréis a Alá. Ya os informará Él de aquello en que discrepabais.\qt@no{48}}
\qt@newcmd\qurantrans@es@dccxviii{Debes decidir entre ellos según lo que Alá ha revelado. No sigas sus pasiones. ¡Guárdate de ellos, no sea que te seduzcan, desviándote de parte de lo que Alá te ha revelado! Y, si se apartan, sabe que Alá desea afligirles por algunos de sus pecados. Muchos hombres son, ciertamente, perversos.\qt@no{49}}
\qt@newcmd\qurantrans@es@dccxix{¿Es una decisión a la pagana lo que desean? Y ¿quién puede decidir mejor que Alá para gente que está convencida?\qt@no{50}}
\qt@newcmd\qurantrans@es@dccxx{¡Creyentes! ¡No toméis como amigos a los judíos y a los cristianos! Son amigos unos de otros. Quien de vosotros trabe amistad con ellos, se hace uno de ellos. Alá no guía al pueblo impío.\qt@no{51}}
\qt@newcmd\qurantrans@es@dccxxi{Ves a los enfermos de corazón precipitarse a ellos, diciendo: «Tenemos miedo de un revés de fortuna». Pero puede que Alá traiga el éxito u otra cosa de Él y, entonces, se dolerán de lo que habían pensado en secreto.\qt@no{52}}
\qt@newcmd\qurantrans@es@dccxxii{Los creyentes dirán «Son éstos los que juraban solemnemente por Alá que sí, que estaban con vosotros? Sus obras serán vanas y saldrán perdiendo».\qt@no{53}}
\qt@newcmd\qurantrans@es@dccxxiii{¡Creyentes! Si uno de vosotros apostata de su fe... Alá suscitará una gente a la cual Él amará y de la cual será amado, humilde con los creyentes, altivo con los infieles, que combatirán en el camino de Alá y que no temerá la censura de nadie. Éste es el favor de Alá. Lo dispensa a quien Él quiere. Alá es inmenso, omnisciente.\qt@no{54}}
\qt@newcmd\qurantrans@es@dccxxiv{Sólo es vuestro amigo Alá, Su Enviado y los creyentes, que hacen la azalá, dan el azaque y se inclinan.\qt@no{55}}
\qt@newcmd\qurantrans@es@dccxxv{Quien tome como amigo a Alá, a Su Enviado y a los creyentes... Los partidarios de Alá serán los que venzan.\qt@no{56}}
\qt@newcmd\qurantrans@es@dccxxvi{¡Creyentes! No toméis como amigos a quienes, habiendo recibido la Escritura antes que vosotros, toman vuestra religión a burla y a juego, ni tampoco a los infieles. ¡Y temed a Alá, si es que sois creyentes!\qt@no{57}}
\qt@newcmd\qurantrans@es@dccxxvii{Cuando llamáis a la azalá, la toman a burla y a juego, porque son gente que no razona.\qt@no{58}}
\qt@newcmd\qurantrans@es@dccxxviii{Di: «¡Gente de la Erscritura ! ¿Es que no tenéis más motivo para censurarnos que el que creamos en Alá y en la Revelación hecha a nosotros y a los que nos precedieron y que la mayoría seáis unos perversos?».\qt@no{59}}
\qt@newcmd\qurantrans@es@dccxxix{Di: «No sé si informaros de algo peor aún que eso respecto a una retribución junto a Alá. Los que Alá ha maldecido, los que han incurrido en Su ira, los que Él ha convertido en monos y cerdos, los que han servido a los taguts, ésos son los que se encuentran en la situación peor y los más extraviados del camino recto».\qt@no{60}}
\qt@newcmd\qurantrans@es@dccxxx{Cuando vienen a Ti, dicen: «¡Creemos!». Pero entran sin creer y sin creer salen. Alá sabe bien lo que ocultan.\qt@no{61}}
\qt@newcmd\qurantrans@es@dccxxxi{Ves a muchos de ellos precipitarse al pecado y a la violación de la ley y a devorar el soborno. ¡Qué mal está lo que hacen!\qt@no{62}}
\qt@newcmd\qurantrans@es@dccxxxii{¿Por qué los maestros y los doctores no les prohíben sus expresiones pecaminosas y que devoren el soborno? ¡Qué mal está lo que hacen!\qt@no{63}}
\qt@newcmd\qurantrans@es@dccxxxiii{Los judíos dicen: «La mano de Alá está cerrada». ¡Que sus propias manos estén cerradas y sean malditos por lo que dicen! Al contrario, Sus manos están abiertas y Él distribuye Sus dones como quiere. Pero la Revelación que tú has recibido de tu Señor acrecentará en muchos de ellos su rebelión e incredulidad. Hemos suscitado entre ellos hostilidad y odio hasta el día de la Resurrección. Siempre que encienden el fuego de la guerra, Alá se lo apaga. Se dan a corromper en la tierra y Alá no ama a los corruptores.\qt@no{64}}
\qt@newcmd\qurantrans@es@dccxxxiv{Si la gente de la Escritura creyera y temiera a Alá, les borraríamos sus malas obras y les introduciríamos en los jardines de la Delicia.\qt@no{65}}
\qt@newcmd\qurantrans@es@dccxxxv{Si obsevaran la Tora, el Evangelio y la Revelación que han recibido de su Señor, disfrutarían de los bienes del cielo y de la tierra. Hay entre ellos una comunidad que se mantiene moderada, pero ¡qué mal hacen muchos otros de ellos!\qt@no{66}}
\qt@newcmd\qurantrans@es@dccxxxvi{¡Enviado! ¡Comunica la Revelación que has recibido de tu Señor, que, si no lo haces, no comunicas Su mensaje! Alá te í, protegerá de los hombres. Alá no dirige al pueblo infiel.\qt@no{67}}
\qt@newcmd\qurantrans@es@dccxxxvii{Di: «¡Gente de la Escritura ! No hacéis nada de fundamento mientras no observéis la Tora. el Evangelio y la Revelación que habéis recibido de vuestro Señor». Pero la Revelación que tú has recibido de tu Señor acrecentará en muchos de ellos su rebelión e incredulidad. ¡No te aflijas, pues, por el pueblo infiel!\qt@no{68}}
\qt@newcmd\qurantrans@es@dccxxxviii{Los creyentes, los judíos, los sabeos y los cristianos -quienes creen en Alá y en el último Día y obran bien- no tienen que temer y no estarán tristes.\qt@no{69}}
\qt@newcmd\qurantrans@es@dccxxxix{Concertamos un pacto con los Hijos de Israel y les mandamos enviados. Siempre T que un enviado venía a ellos con algo que no era de su gusto, le desmentían o le daban muerte.\qt@no{70}}
\qt@newcmd\qurantrans@es@dccxl{Creían que no iban a ser probados y se portaron como ciegos y sordos. Alá se volvió a ellos, pero muchos de ellos vol- vieron a portarse como ciegos y sordos. Alá ve bien lo que hacen.\qt@no{71}}
\qt@newcmd\qurantrans@es@dccxli{No creen, en realidad, quienes dicen: «Alá es el Ungido, hijo de María», siendo así que el mismo Ungido ha dicho: «¡Hijos de Israel, servid a Alá, mi Señor y Señor vuestro!». Alá veda el Jardín a quien asocia a Alá. Su morada será el Fuego. Los impíos no tendrán quien les auxilie.\qt@no{72}}
\qt@newcmd\qurantrans@es@dccxlii{No creen, en realidad, quienes dicen: «Alá es el tercero de tres». No hay ningún otro dios que Dios Uno y, si no paran de decir eso, un castigo doloroso alcanzará a quienes de ellos no crean.\qt@no{73}}
\qt@newcmd\qurantrans@es@dccxliii{¿No se volverán a Alá pidiéndole, perdón? Alá es indulgente, misericordioso.\qt@no{74}}
\qt@newcmd\qurantrans@es@dccxliv{El Ungido, hijo de María, no es sino un enviado, antes del cual han pasado otros enviados, y su madre, veraz. Ambos tomaban alimentos. ¡ Mira cómo les explicamos los signos! ¡Y mira cómo son desviados!\qt@no{75}}
\qt@newcmd\qurantrans@es@dccxlv{Di: «¿Vais a servir, en lugar de servir a Alá, lo que no puede dañaros ni aprovecharos?» Alá es Quien todo lo oye, Quien todo lo sabe.\qt@no{76}}
\qt@newcmd\qurantrans@es@dccxlvi{Di: «¡Gente de la Escritura ! No exageréis en vuestra religión profesando algo diferente de la Verdad y no sigáis las pasiones de una gente que ya antes se extravió, extravió a muchos y se apartó del recto camino».\qt@no{77}}
\qt@newcmd\qurantrans@es@dccxlvii{Los Hijos de Israel que no creyeron fueron maldecidos por boca de David y de Jesús, hijo de María, por haber desobedecido y violado la ley.\qt@no{78}}
\qt@newcmd\qurantrans@es@dccxlviii{No se prohibían mutuamente las acciones reprobables que cometían. ¡Qué mal hacían!\qt@no{79}}
\qt@newcmd\qurantrans@es@dccxlix{Ves a muchos de ellos que traban amistad con los que no creen. Lo que han hecho antes está tan mal que Alá está irritado con ellos y tendrán un castigo eterno.\qt@no{80}}
\qt@newcmd\qurantrans@es@dccl{Si hubieran creído en Alá, en el r Profeta y en la Revelación que éste recibió, no les habrían tomado como amigos. pero muchos de ellos son perversos.\qt@no{81}}
\qt@newcmd\qurantrans@es@dccli{Verás que los más hostiles a los creyentes son los judíos y los asociadores, y que los más amigos de los creyentes son los que dicen: «Somos cristianos». Es que hay entre ellos sacerdotes y monjes y no son altivos.\qt@no{82}}
\qt@newcmd\qurantrans@es@dcclii{Cuando oyen lo que se ha revelado al Enviado, ves que sus ojos se inundan de lágrimas de reconocimiento de la Verdad. Dicen: «¡Señor! ¡Creemos! ¡Apúntanos, pues. como testigos!\qt@no{83}}
\qt@newcmd\qurantrans@es@dccliii{¿Cómo no vamos a creer en Alá y en la Verdad venida a nosotros si anhelamos que nuestro Señor nos introduzca con los justos?»\qt@no{84}}
\qt@newcmd\qurantrans@es@dccliv{Alá les recompensará por lo que han dicho con jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente. Ésa es la retribución de quienes hacen el bien.\qt@no{85}}
\qt@newcmd\qurantrans@es@dcclv{Pero quienes no crean y desmientan Nuestros signos morarán en el fuego de la gehena.\qt@no{86}}
\qt@newcmd\qurantrans@es@dcclvi{¡Creyentes! ¡No prohibáis las cosas buenas que Alá os ha permitido! ¡Y no violéis la ley, que Alá no ama a los que la violan !\qt@no{87}}
\qt@newcmd\qurantrans@es@dcclvii{¡Comed de lo lícito y bueno de que Alá os ha proveído! ¡Y temed a Alá, en Quien creéis!\qt@no{88}}
\qt@newcmd\qurantrans@es@dcclviii{Alá no os tendrá en cuenta la vanidad de vuestros juramentos, pero sí el que hayáis jurado deliberadamente. Como expiación, alimentaréis a diez pobres como soléis alimentar a vuestra familia, o les vestiréis, o manumitiréis a un esclavo. Quien no pueda, que ayune tres días. Cuando juréis, ésa será la expiación por vuestros juramentos. ¡Sed fieles a lo que juráis! Así os explica Alá Sus aleyas. Quizás, así, seáis agradecidos.\qt@no{89}}
\qt@newcmd\qurantrans@es@dcclix{¡Creyentes! El vino, el maysir, las piedras erectas y las flechas no son sino abominación y obra del Demonio. ¡Evitadlo, pues! Quizás, así, prosperéis.\qt@no{90}}
\qt@newcmd\qurantrans@es@dcclx{El Demonio quiere sólo crear hostilidad y odio entre vosotros valiéndose del vino y del maysir, e impediros que recordéis a Alá y hagáis la azalá. ¿Os abstendréis, pues?\qt@no{91}}
\qt@newcmd\qurantrans@es@dcclxi{¡Obedeced a Alá, obedeced al Enviado y guardaos! Pero, si volvéis la espalda, sabed que a Nuestro Enviado le incumbe sólo la transmisión clara.\qt@no{92}}
\qt@newcmd\qurantrans@es@dcclxii{Quienes creen y obran bien, no pecan en su comida si temen a Alá, creen y obran bien, luego temen a Alá y creen, luego temen a Alá y hacen el bien. Alá ama a quienes hacen el bien.\qt@no{93}}
\qt@newcmd\qurantrans@es@dcclxiii{¡Creyentes! Alá ha de probaros con alguna caza obtenida con vuestras manos o con vuestras lanzas, para saber quién Le teme en secreto. Quien, después de esto, viole la ley, tendrá un castigo doloroso.\qt@no{94}}
\qt@newcmd\qurantrans@es@dcclxiv{¡Creyentes! No matéis la caza mientras estéis sacralizados. Si uno de vosotros la mata deliberadamente, ofrecerá como víctima a la Caaba, en compensación, una res de su rebaño, equivalente a la caza que mató -a juicio de dos personas justas de entre vosotros-, o bien expiará dando de comer a los pobres o ayunando algo equivalente, para que guste la gravedad de su conducta. Alá perdona lo pasado, pero Alá se vengará del reincidente. Alá es poderoso, vengador.\qt@no{95}}
\qt@newcmd\qurantrans@es@dcclxv{Os es lícita la pesca y alimentaros de ella para disfrute vuestro y de los viajeros, pero os está prohibida la caza mientras dure vuestra sacralización. Y temed a Alá hacia Quien seréis congregados.\qt@no{96}}
\qt@newcmd\qurantrans@es@dcclxvi{Alá ha hecho de la Caaba, la Casa Sagrada, estación para los hombres, y ha instituido el mes sagrado, la víctima y las guirnaldas para que sepáis que Alá conoce lo que está en los cielos y en la tierra y que Alá es omnisciente.\qt@no{97}}
\qt@newcmd\qurantrans@es@dcclxvii{Sabed que Alá es severo en castigar, pero también que Alá es indulgente, misericordioso.\qt@no{98}}
\qt@newcmd\qurantrans@es@dcclxviii{Al Enviado no le incumbe sino la transmisión. Alá sabe lo que manifestáis y lo que ocultáis.\qt@no{99}}
\qt@newcmd\qurantrans@es@dcclxix{Di: «No es lo mismo el mal que el bien, aunque te plazca lo mucho malo que hay. ¡Temed, pues, a Alá, hombres de intelecto! Quizás, así, prosperéis».\qt@no{100}}
\qt@newcmd\qurantrans@es@dcclxx{¡Creyentes! No preguntéis por cosas que, si se os dieran a conocer, os dañarían. Si, con todo, preguntáis por ellas cuando se revela el Corán, se os darán a conocer y Alá os perdonará por ello. Alá es indulgente, benigno.\qt@no{101}}
\qt@newcmd\qurantrans@es@dcclxxi{Gente que os precedió hizo esas mismas preguntas y, por ellas, se hizo infiel.\qt@no{102}}
\qt@newcmd\qurantrans@es@dcclxxii{Alá no ha instituido ni bahira, ni saibas ni wasila, ni hami. Son los infieles quienes han inventado la mentira contra Alá. Y la mayoría no razonan.\qt@no{103}}
\qt@newcmd\qurantrans@es@dcclxxiii{Y cuando se les dice: «Venid a la Revelación de Alá y al Enviado», dicen: «Nos basta aquello en que encontramos a nuestros padres». ¡Cómo! ¿Y si sus padres no sabían nada, ni estaban bien dirigidos?\qt@no{104}}
\qt@newcmd\qurantrans@es@dcclxxiv{¡Creyentes! ¡Preocupaos de vosotros mismos! Quien se extravía no puede dañaros, si estáis en la buena dirección. Todos volveréis a Alá. Ya os informará Él de lo que hacíais.\qt@no{105}}
\qt@newcmd\qurantrans@es@dcclxxv{¡Creyentes! Cuando, a punto de morir, hagáis testamento, llamad como testigos a dos personas justas de los vuestros o bien a dos de fuera si estáis de viaje y os sobreviene la muerte. Retenedlas después de la azalá. Si dudáis de ellas, que juren por Alá: «¡No nos venderemos, aunque se trate de un pariente, ni ocultaremos el testimonio de Alá! Si no, seríamos de los pecadores».\qt@no{106}}
\qt@newcmd\qurantrans@es@dcclxxvi{Si se descubre que son reos de pecado, otros dos, los más próximos, les sustituirán, elegidos entre los perjudicados por el perjurio y jurarán por Alá: «Nuestro testimonio es más auténtico que el de los otros dos. Y no hemos violado la ley. Si no, seríamos de los impíos».\qt@no{107}}
\qt@newcmd\qurantrans@es@dcclxxvii{Así, será más fácil conseguir que presten testimonio como es debido, o que teman ver rechazados sus juramentos después de prestados. ¡Temed a Alá y escuchad! Alá no dirige al pueblo perverso.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcclxxviii{El día que Alá congregue a los enviados y diga: «¿Qué se os ha respondido?», dirán: «No sabemos. Tú eres Quien conoce a fondo las cosas ocultas».\qt@no{109}}
\qt@newcmd\qurantrans@es@dcclxxix{Cuando dijo Alá: «¡Jesús, hijo de María!; Recuerda Mi gracia, que os dispensé a ti y a tu madre cuando te fortalecí con el Espíritu Santo y hablaste a la gente en la cuna y de adulto, y cuando le enseñé la Escritura, la Sabiduría, la Tora y el Evangelio. Y cuando creaste de arcilla a modo de pájaros con Mi permiso, soplaste en ellos y se convirtieron en pájaros con Mi permiso. Y curaste al ciego de nacimiento y al leproso con Mi permiso. Y cuando resucitaste a los muertos con Mi permiso. Y cuando alejé de ti a los Hijos de Israel cuando viniste a ellos con las pruebas claras y los que de ellos no creían dijeron: 'Esto no es sino manifiesta magia'.\qt@no{110}}
\qt@newcmd\qurantrans@es@dcclxxx{Y cuando inspiré a los apóstoles: '¡Creed en Mí y en Mi enviado!' Dijeron: «¡Creemos! ¡Sé testigo de nuestra sumisión!'».\qt@no{111}}
\qt@newcmd\qurantrans@es@dcclxxxi{Cuando dijeron los apóstoles: «¡Jesús, hijo de María! ¿Puede tu Señor hacer que nos baje del cielo una mesa servida?». Dijo: «¡Temed a Alá, si sois creyentes!».\qt@no{112}}
\qt@newcmd\qurantrans@es@dcclxxxii{Dijeron: «Queremos comer de ella. Así, nuestros corazones se tranquilizarán, sabremos que nos has hablado verdad y podremos ser testigos de ella».\qt@no{113}}
\qt@newcmd\qurantrans@es@dcclxxxiii{Dijo Jesús, hijo de María: «¡Alá, Señor nuestro! Haz que nos baje del cielo una mesa servida, que sea para nosotros, el primero como el último, motivo de regocijo y signo venido de Ti. ¡Provéenos del sustento necesario, Tú, Que eres el Mejor de los proveedores!».\qt@no{114}}
\qt@newcmd\qurantrans@es@dcclxxxiv{Dijo Alá: «Sí, voy a hacer que os baje. Pero, si uno de vosotros, después de eso, no cree, le castigaré como no he castigado a nadie en el mundo».\qt@no{115}}
\qt@newcmd\qurantrans@es@dcclxxxv{Y cuando dijo Alá: «¡Jesús, hijo de María! ¡Eres tú quien ha dicho a los hombres: '¡Tomadnos a mí y a mi madre como a dioses, además de tomar a Alá!'?». Dijo: «¡Gloria a Ti! ¿Cómo voy a decir algo que no tengo por verdad? Si lo hubiera dicho, Tú lo habrías sabido. Tú sabes lo que hay en mí, pero yo no sé lo que hay en Ti. Tú eres Quien conoce a fondo las cosas ocultas.\qt@no{116}}
\qt@newcmd\qurantrans@es@dcclxxxvi{No les he dicho más que lo que Tú me has ordenado: '¡Servid a Alá, mi Señor y Señor vuestro!' Fui testigo de ellos mientras estuve entre ellos, pero, después de llamarme a Ti, fuiste Tú Quien les vigiló. Tú eres testigo de todo.\qt@no{117}}
\qt@newcmd\qurantrans@es@dcclxxxvii{Si les castigas, son Tus siervos, Si les perdonas, Tú eres el Poderoso, el Sabio».\qt@no{118}}
\qt@newcmd\qurantrans@es@dcclxxxviii{Alá dice: «Este es un día en que su sinceridad aprovechará a los sinceros. Tendrán jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, para siempre». Alá está satisfecho de ellos y ellos lo están de Él. ¡Ése es el éxito grandioso!\qt@no{119}}
\qt@newcmd\qurantrans@es@dcclxxxix{De Alá es el dominio de los cielos y de la tierra y de lo que en ellos está. Es omnipotente.\qt@no{120}}
\qt@newcmd\qurantrans@es@dccxc{\basmalahes ¡Alabado sea Alá, Que creó los cielos y la tierra e instituyó las tinieblas y la luz! Aun así, los que no creen equiparan a otros a su Señor.\qt@no{1}}
\qt@newcmd\qurantrans@es@dccxci{Él es Quien os creó de arcilla y decretó a cada uno un plazo. Ha sido fijado un plazo junto a Él. Y aún dudáis...\qt@no{2}}
\qt@newcmd\qurantrans@es@dccxcii{Él es Alá en los cielos y en la tierra. Sabe lo que ocultáis y lo que manifestáis. Sabe lo que merecéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@dccxciii{Siempre que viene a ellos uno de los signos de su Señor, se apartan de él.\qt@no{4}}
\qt@newcmd\qurantrans@es@dccxciv{Han desmentido la Verdad cuando ha venido a ellos, pero recibirán noticias de aquello de que se burlaban.\qt@no{5}}
\qt@newcmd\qurantrans@es@dccxcv{¿Es que no ven a cuántas generaciones precedentes hemos hecho perecer? Les habíamos dado poderío en la tierra como no os hemos dado a vosotros. Les enviamos del cielo una lluvia abundante. Hicimos que fluyeran arroyos a sus pies. Con todo, les destruimos por sus pecados y suscitamos otras generaciones después de ellos.\qt@no{6}}
\qt@newcmd\qurantrans@es@dccxcvi{Si hubiéramos hecho bajar sobre ti una Escritura escrita en pergamino y la hubieran palpado con sus manos, aun así, los que no creen habrían dicho: «Esto no es sino manifiesta magia».\qt@no{7}}
\qt@newcmd\qurantrans@es@dccxcvii{Dicen: «¿Por qué no se ha hecho descender a un ángel sobre él?» Si hubiéramos hecho descender a un ángel, ya se habría decidido la cosa y no les habría sido dado esperar.\qt@no{8}}
\qt@newcmd\qurantrans@es@dccxcviii{Si hubiéramos hecho de él un ángel, le habríamos dado apariencia humana y, con ello, habríamos contribuido a su confusión.\qt@no{9}}
\qt@newcmd\qurantrans@es@dccxcix{Se burlaron de enviados que te precedieron, pero los que se burlaban se vieron cercados por aquello de que se burlaban.\qt@no{10}}
\qt@newcmd\qurantrans@es@dccc{Di: «¡Id por la tierra y mirad cómo terminaron los desmentidores!».\qt@no{11}}
\qt@newcmd\qurantrans@es@dccci{Di: «¿A quién pertenece lo que está en los cielos y en la tierra?» Di: «¡A Alá!», Él mismo Se ha prescrito la misericordia. Él os reunirá, ciertamente, para el día indubitable de la Resurrección. Quienes se hayan perdido, no creerán.\qt@no{12}}
\qt@newcmd\qurantrans@es@dcccii{A Él pertenece lo que sucede de noche y de día. Él es Quien todo lo oye, todo lo sabe.\qt@no{13}}
\qt@newcmd\qurantrans@es@dccciii{Di: «¿Tomaré como amigo a otro distinto de Alá, creador de los cielos y de la tierra, Que alimenta sin ser alimentado?» Di: «He recibido la orden de ser el primero en someterse a Alá y no ser de los asociadores».\qt@no{14}}
\qt@newcmd\qurantrans@es@dccciv{Di: «Temo, si desobedezco a mi Señor, el castigo de un día terrible».\qt@no{15}}
\qt@newcmd\qurantrans@es@dcccv{Él se habrá apiadado de aquél a quien ese día se le haya alejado. Ése es el éxito manifiesto.\qt@no{16}}
\qt@newcmd\qurantrans@es@dcccvi{Si Alá te aflige con una desgracia, nadie más que Él podrá retirarla. Si te favorece con un bien... Él es omnipotente.\qt@no{17}}
\qt@newcmd\qurantrans@es@dcccvii{Él es Quien domina a Sus siervos. Él es el Sabio, el Bien Informado.\qt@no{18}}
\qt@newcmd\qurantrans@es@dcccviii{Di: «¿Cuál es el testimonio de más peso?» Di: «Alá es testigo entre yo y vosotros. Este Corán me ha sido revelado para que, por él. os advierta a vosotros y a aquéllos a quienes alcance. ¿Atestiguaríais, de verdad, que hay otros dioses junto con Alá?» Di: «No, no lo haría». Di: «Él es sólo un Dios Uno y soy inocente de lo que vosotros Le asociáis».\qt@no{19}}
\qt@newcmd\qurantrans@es@dcccix{Aquéllos a quienes hemos dado la Escritura la conocen como conocen a sus propios hijos varones. Quienes se hayan perdido, no creerán.\qt@no{20}}
\qt@newcmd\qurantrans@es@dcccx{¿Hay alguien que sea más impío que quien inventa una mentira contra Alá o desmiente Sus signos? Los impíos no prosperarán.\qt@no{21}}
\qt@newcmd\qurantrans@es@dcccxi{El día que les congreguemos a todos, diremos a los que hayan asociado: «¿Dónde están vuestros pretendidos asociados?»\qt@no{22}}
\qt@newcmd\qurantrans@es@dcccxii{En su confusión, no sabrán decir más que: «¡Por Alá, Señor nuestro, que no éramos asociadores!»\qt@no{23}}
\qt@newcmd\qurantrans@es@dcccxiii{¡Mira cómo mienten contra sí mismos y cómo se han esfumado sus invenciones!\qt@no{24}}
\qt@newcmd\qurantrans@es@dcccxiv{Hay entre ellos quienes te escuchan, pero hemos velado sus corazones y endurecido sus oídos para que no lo entiendan. Aunque vieran toda clase de signos, no creerían en ellos. Hasta el punto de que, cuando vienen a disputar contigo, dicen los que no creen: «Éstas no son sino patrañas de los antiguos».\qt@no{25}}
\qt@newcmd\qurantrans@es@dcccxv{Se lo impiden a otros y ellos mismos se mantienen a distancia. Pero sólo se arruinan a sí mismos, sin darse cuenta.\qt@no{26}}
\qt@newcmd\qurantrans@es@dcccxvi{Si pudieras ver cuando, puestos de pie ante el Fuego, digan: «¡Ojalá se nos devolviera! No desmentiríamos los signos de nuestro Señor, sino que seríamos de los creyentes».\qt@no{27}}
\qt@newcmd\qurantrans@es@dcccxvii{Pero ¡no! Se les mostrará claramente lo que antes ocultaban. Si se les devolviera, volverían a lo que se les prohibió. ¡Mienten, ciertamente!\qt@no{28}}
\qt@newcmd\qurantrans@es@dcccxviii{Dicen: «No hay más vida que la de acá y no seremos resucitados».\qt@no{29}}
\qt@newcmd\qurantrans@es@dcccxix{Si pudieras ver cuando, puestos de pie ante su Señor... Dirá: «¿No es esto la Verdad?» Dirán: «¡Claro qué sí, por nuestro Señor!» Dirá: «¡Gustad, pues, el castigo por no haber creído!»\qt@no{30}}
\qt@newcmd\qurantrans@es@dcccxx{Perderán quienes hayan desmentido el encuentro de Alá. Cuando, al fin, de repente, les venga la Hora, dirán: «¡Ay de nosotros, que nos descuidamos!» Y llevarán su carga a la espalda. ¿No es carga mala la que llevan?\qt@no{31}}
\qt@newcmd\qurantrans@es@dcccxxi{La vida de acá no es sino juego y distracción. Sí, la Morada Postrera es mejor para quienes temen a Alá. ¿Es que no razonáis...?\qt@no{32}}
\qt@newcmd\qurantrans@es@dcccxxii{Ya sabemos que lo que dicen te entristece. No es a ti a quien desmienten, sino que, más bien, lo que los impíos rechazan son los signos de Alá.\qt@no{33}}
\qt@newcmd\qurantrans@es@dcccxxiii{También fueron desmentidos antes de ti otros enviados, pero sufrieron con paciencia ese mentís y vejación hasta que les llegó Nuestro auxilio. No hay quien pueda cambiar las palabras de Alá. Tú mismo has oído algo acerca de los enviados.\qt@no{34}}
\qt@newcmd\qurantrans@es@dcccxxiv{Y si te resulta duro que se alejen, auque pudieras encontrar un agujero en la tierra o una escala en el cielo para traerles un signo,... Alá, si hubiera querido, les habría congregado a todos para dirigirles. ¡No seas, pues, de los ignorantes!\qt@no{35}}
\qt@newcmd\qurantrans@es@dcccxxv{Sólo escuchan quienes oyen. En cuanto a los muertos, Alá les resucitará y serán devueltos a Él.\qt@no{36}}
\qt@newcmd\qurantrans@es@dcccxxvi{Dicen: «¿Por qué no se le ha revelado un signo que procede de su Señor?» Di: «Alá es capaz de revelar un signo». Pero la mayoría no saben.\qt@no{37}}
\qt@newcmd\qurantrans@es@dcccxxvii{No hay animal en la tierra, ni ave que vuele con sus alas, que no constituyan comunidades como vosotros. No hemos descuidado nada en la Escritura. Luego, serán congregados hacia su Señor.\qt@no{38}}
\qt@newcmd\qurantrans@es@dcccxxviii{Quienes desmienten Nuestros signos son sordos, mudos, vagan entre tinieblas. Alá extravía a quien Él quiere, y a quien Él quiere le pone en una vía recta.\qt@no{39}}
\qt@newcmd\qurantrans@es@dcccxxix{Di: «¿Qué crees que iba a ser de vosotros si os viniera el castigo de Alá u os viniera la Hora? ¿Invocaríais a otros diferentes de Alá? Sinceramente...»\qt@no{40}}
\qt@newcmd\qurantrans@es@dcccxxx{¡No!, antes bien, le invocaríais a Él y quitaría, si Él quisiera, el objeto de vuestra invocación. Y olvidaríais lo que ahora Le asociáis.\qt@no{41}}
\qt@newcmd\qurantrans@es@dcccxxxi{Antes de ti, hemos mandado enviados a comunidades y hemos causado a éstas miseria y desgracia. Quizás, así, se humillaran.\qt@no{42}}
\qt@newcmd\qurantrans@es@dcccxxxii{Si se hubieran humillado cuando Nuestro rigor les alcanzó... Pero sus corazones se endurecieron y el Demonio engalanó lo que hacían.\qt@no{43}}
\qt@newcmd\qurantrans@es@dcccxxxiii{Y cuando hubieron olvidado lo que se les había recordado, les abrimos las puertas de todo. Cuando hubieron disfrutado de lo que se les había concedido, Nos apoderamos de ellos de repente y fueron presa de la desesperación.\qt@no{44}}
\qt@newcmd\qurantrans@es@dcccxxxiv{Así fue extirpado el pueblo que obró impíamente. ¡Alabado sea Alá, Señor del universo!\qt@no{45}}
\qt@newcmd\qurantrans@es@dcccxxxv{Di: «¿Qué os parece? Si Alá os privara del oído y de la vista y sellara vuestros corazones, qué dios otro que Alá podría devolvéroslos?» ¡Mira cómo exponemos las aleyas! Aun así, ellos se apartan.\qt@no{46}}
\qt@newcmd\qurantrans@es@dcccxxxvi{Di: «¿Qué crees que iba a ser de vosotros si os sorprendiera el castigo de Alá repentina o visiblemente? ¿Quién iba a ser destruido sino el pueblo impío?»\qt@no{47}}
\qt@newcmd\qurantrans@es@dcccxxxvii{No mandamos a los enviados sino como nuncios de buenas nuevas y para advertir. Quienes crean y se enmienden, no tienen que temer y no estarán tristes.\qt@no{48}}
\qt@newcmd\qurantrans@es@dcccxxxviii{A quienes desmientan Nuestros signos les alcanzará el castigo por haber sido perversos.\qt@no{49}}
\qt@newcmd\qurantrans@es@dcccxxxix{Di: «Yo no pretendo poseer los tesoros de Alá, ni conozco lo oculto, ni pretendo ser un ángel. No hago sino seguir lo que se me ha revelado». Di: «¿Son iguales el ciego y el vidente? ¿Es que no reflexionáis?»\qt@no{50}}
\qt@newcmd\qurantrans@es@dcccxl{Advierte por su medio a quienes teman ser congregados hacia su Señor que no tendrán, fuera de Él, amigo ni intercesor. Quizás. así, teman a Alá.\qt@no{51}}
\qt@newcmd\qurantrans@es@dcccxli{No rechaces a quienes invocan a su Señor mañana y tarde por deseo de agradarle. No tienes tú que pedirles cuentas de nada, ni ellos a ti. Y, si les rechazas, serás de los impíos.\qt@no{52}}
\qt@newcmd\qurantrans@es@dcccxlii{Así hemos probado a unos por otros para que digan: «¿Es a éstos a quienes Alá ha agraciado de entre nosotros?» ¿No conoce Alá mejor que nadie a los agradecidos?\qt@no{53}}
\qt@newcmd\qurantrans@es@dcccxliii{Cuando vengan a ti los que creen en Nuestros signos, di: «¡Paz sobre vosotros!» Vuestro Señor Se ha prescrito la misericordia, de modo que si uno de vosotros obra mal por ignorancia, pero luego se arrepiente y enmienda... Él es indulgente, misericordioso.\qt@no{54}}
\qt@newcmd\qurantrans@es@dcccxliv{Así es como exponemos los signos, para que aparezca claro el camino de los pecadores.\qt@no{55}}
\qt@newcmd\qurantrans@es@dcccxlv{Di: «Se me ha prohibido servir a aquéllos que invocáis en lugar de invocar a Alá». Di: «No seguiré vuestras pasiones; si no, me extraviaría y no sería de los bien dirigidos».\qt@no{56}}
\qt@newcmd\qurantrans@es@dcccxlvi{Di: «Me baso en una prueba clara venida de mi Señor y vosotros lo desmentís. Yo no tengo lo que pedís con tanto apremio. La decisión pertenece sólo a Alá: Él cuenta la verdad y Él es el Mejor en fallar».\qt@no{57}}
\qt@newcmd\qurantrans@es@dcccxlvii{Di: «Si yo tuviera lo que pedís con tanto apremio, ya se habría decidido la cosa entre yo y vosotros». Alá conoce mejor que nadie a los impíos.\qt@no{58}}
\qt@newcmd\qurantrans@es@dcccxlviii{Él posee las llaves de lo oculto, sólo Él las conoce. Él sabe lo que hay en la tierra y en el mar. No cae ni una hoja sin que Él lo sepa, no hay grano en las tinieblas de la tierra, no hay nada verde, nada seco, que no esté en una Escritura clara.\qt@no{59}}
\qt@newcmd\qurantrans@es@dcccxlix{Él es quien os llama de noche y sabe lo que habéis hecho durante el día. Luego, os despierta en él. Esto es así para que se cumpla un plazo fijo. Luego, volveréis a Él y os informará de lo que hacíais.\qt@no{60}}
\qt@newcmd\qurantrans@es@dcccl{Él es Quien domina a Sus siervos. Envía sobre vosotros a custodios. Cuando, al fin, viene la muerte a uno de vosotros, Nuestros enviados le llaman, no se descuidan.\qt@no{61}}
\qt@newcmd\qurantrans@es@dcccli{Luego, son devueltos a Alá, su verdadero Dueño. ¿No es a Él a quien toca decidir? Él es el más rápido en ajustar cuentas.\qt@no{62}}
\qt@newcmd\qurantrans@es@dccclii{Di: «¿Quién os librará de las tinieblas de la tierra y del mar?» Le invocáis humildemente y en secreto: «Si nos libra de ésta, seremos, ciertamente, de los agradecidos».\qt@no{63}}
\qt@newcmd\qurantrans@es@dcccliii{Di: «Alá os libra de ésta y de todo apuro, pero vosotros de nuevo Le asociáis».\qt@no{64}}
\qt@newcmd\qurantrans@es@dcccliv{Di: «Él es el Capaz de enviaros un castigo de arriba o de abajo, o de desconcertaros con partidos diferentes y haceros gustar vuestra mutua violencia». ¡Mira cómo exponemos las aleyas! Quizás, así comprendan mejor.\qt@no{65}}
\qt@newcmd\qurantrans@es@dccclv{Pero tu pueblo lo ha desmentido, que es la Verdad. Di: «Yo no soy vuestro protector.\qt@no{66}}
\qt@newcmd\qurantrans@es@dccclvi{Todo anuncio tiene su tiempo oportuno y pronto lo sabréis».\qt@no{67}}
\qt@newcmd\qurantrans@es@dccclvii{Cuando veas a los que parlotean de Nuestros signos, déjales hasta que cambien de conversación. Y, si el Demonio hace que te olvides, entonces, después de la amonestación, no sigas con los impíos.\qt@no{68}}
\qt@newcmd\qurantrans@es@dccclviii{Quienes temen a Alá no deben pedirles cuentas de nada, sino tan sólo amonestarles. Quizás, así, teman a Alá.\qt@no{69}}
\qt@newcmd\qurantrans@es@dccclix{¡Deja a quienes toman su religión a juego y distracción y a quienes ha engañado la vida de acá! ¡Amonéstales por su medio, no sea que alguien se pierda por razón de sus obras! No tendrá, fuera de Alá, amigo ni intercesor y, aunque ofrezca toda clase de compensaciones, no se le aceptarán. Ésos son los que se han perdido por razón de sus obras. Se les dará a beber agua muy caliente y tendrán un castigo doloroso por no haber creído.\qt@no{70}}
\qt@newcmd\qurantrans@es@dccclx{Di: «¿Invocaremos, en lugar de invocar a Alá, lo que no puede aprovecharnos ni dañarnos? ¿Volveremos sobre nuestros pasos después de habernos dirigido Alá?» Como aquél a quien los demonios han seducido y va desorientado por la tierra... Sus compañeros le llaman, invitándole a la Dirección: «¡Ven a nosotros!» Di: «La dirección de Alá es la Dirección. Hemos recibido la orden de someternos al Señor del universo.\qt@no{71}}
\qt@newcmd\qurantrans@es@dccclxi{¡Haced la azalá! ¡Temedle! Es Él hacia Quien seréis congregados».\qt@no{72}}
\qt@newcmd\qurantrans@es@dccclxii{Es Él Quien ha creado con un fin los cielos y la tierra. El día que dice: «¡Sé!», es. Su palabra es la Verdad. Suyo será el dominio el día que se toque la trompeta. El Conocedor de lo oculto y de lo patente. Él es el Sabio, el Bien Informado.\qt@no{73}}
\qt@newcmd\qurantrans@es@dccclxiii{Y cuando Abraham dijo a su padre Azar: «¿Tomas a los ídolos como dioses? Sí, veo que tú y tu pueblo estáis evidentemente extraviados».\qt@no{74}}
\qt@newcmd\qurantrans@es@dccclxiv{Y así mostramos a Abraham el reino de los cielos y de la tierra, para que fuera de los convencidos.\qt@no{75}}
\qt@newcmd\qurantrans@es@dccclxv{Cuando cerró la noche sobre él, vio una estrella y dijo: «¡Éste es mi Señor!». Pero, cuando se puso, dijo: «No amo a los que se ponen».\qt@no{76}}
\qt@newcmd\qurantrans@es@dccclxvi{Cuando vio la luna que salía, dijo: «Éste es mi Señor». Pero, cuando se puso, dijo: «Si no me dirige mi Señor, voy a ser, ciertamente, de los extraviados».\qt@no{77}}
\qt@newcmd\qurantrans@es@dccclxvii{Cuando vio el sol que salía, dijo: «Éste es mi Señor! ¡Éste es mayor!». Pero, cuando se puso, dijo: «¡Pueblo! Soy inocente de lo que Le asociáis.\qt@no{78}}
\qt@newcmd\qurantrans@es@dccclxviii{Vuelvo mi rostro, como hanif, hacia Quien ha creado los cielos y la tierra. Y no soy asociador».\qt@no{79}}
\qt@newcmd\qurantrans@es@dccclxix{Su pueblo disputó con él. Dijo: «¿Disputáis conmigo sobre Alá, a pesar de haberme Él dirigido? No temo lo que Le asociáis, a menos que mi Señor quiera algo. Mi Señor lo abarca todo en Su ciencia. ¿Es que no os dejaréis amonestar?\qt@no{80}}
\qt@newcmd\qurantrans@es@dccclxx{¿Cómo voy a temer lo que Le habéis asociado si vosotros no teméis asociar a Alá algo para lo que Él no os ha conferido autoridad? ¿Cuál, pues, de las dos partes tiene más derecho a seguridad? Si es que lo sabéis...».\qt@no{81}}
\qt@newcmd\qurantrans@es@dccclxxi{Quienes creen y no revisten su fe de impiedad, ésos son los que están en seguridad, los que están dirigidos.\qt@no{82}}
\qt@newcmd\qurantrans@es@dccclxxii{Ése es el argumento Nuestro que dimos a Abraham contra su pueblo. Ascendemos la categoría de quien queremos. Tu Señor es sabio, omnisciente.\qt@no{83}}
\qt@newcmd\qurantrans@es@dccclxxiii{Le regalamos a Isaac y a Jacob. Dirigimos a los dos. A Noé ya le habíamos dirigido antes y, de sus descendientes, a David, a Salomón, a Job, a José, a Moisés y a Aarón. Así retribuimos a quienes hacen el bien.\qt@no{84}}
\qt@newcmd\qurantrans@es@dccclxxiv{Y a Zacarías, a Juan, a Jesús y a Elías, todos ellos de los justos.\qt@no{85}}
\qt@newcmd\qurantrans@es@dccclxxv{Y a Ismael, a Eliseo, a Jonás y a Lot. A cada uno de ellos le distinguimos entre todos los hombres,\qt@no{86}}
\qt@newcmd\qurantrans@es@dccclxxvi{así como a algunos de sus antepasados, descendientes y hermanos. Les elegimos y dirigimos a una vía recta.\qt@no{87}}
\qt@newcmd\qurantrans@es@dccclxxvii{Ésta es la dirección de Alá, por la que dirige a quien Él quiere de Sus siervos. Si hubieran sido asociadores, todas sus obras habrían sido vanas.\qt@no{88}}
\qt@newcmd\qurantrans@es@dccclxxviii{Fue a éstos a quienes dimos la Escritura, el juicio y el profetismo. Y, si éstos no creen en ello, lo hemos confiado a otro pueblo, que sí que cree.\qt@no{89}}
\qt@newcmd\qurantrans@es@dccclxxix{A éstos ha dirigido Alá. ¡Sigue, pues, su Dirección! Di: «No os pido salario a cambio. No es más que una Amonestación dirigida a todo el mundo».\qt@no{90}}
\qt@newcmd\qurantrans@es@dccclxxx{No han valorado a Alá debidamente cuando han dicho: «Alá no ha revelado nada a un mortal». Di: «Y ¿quién ha revelado la Eiscrituro que Moisés trajo, luz y dirección para los hombres? la ponéis en pergaminos, que enseñáis, pero ocultáis una gran parte. Se os enseñó lo que no sabíais, ni vosotros ni vuestros padres». Di: «¡Fue Alá!». Y déjales que pasen el rato en su parloteo.\qt@no{91}}
\qt@newcmd\qurantrans@es@dccclxxxi{Es ésta una Escritura bendita que hemos revelado, que confirma la revelación anterior, para que adviertas a la metrópoli y a los que viven en sus alrededores. Quienes creen en la otra vida, creen también en ella y observan su azalá.\qt@no{92}}
\qt@newcmd\qurantrans@es@dccclxxxii{¿Hay alguien que sea más impío que quien inventa una mentira contra Alá, o quien dice: «He recibido una revelación», siendo así que no se le ha revelado nada, o quien dice: «Yo puedo revelar otro tanto de lo que Alá ha revelado»? Si pudieras ver cuando estén los impíos en su agonía y los ángeles extiendan las manos: «¡Entregad vuestras almas! Hoy se os va a retribuir con un castigo degradante, por haber dicho falsedades contra Alá y por haberos desviado altivamente de Sus signos».\qt@no{93}}
\qt@newcmd\qurantrans@es@dccclxxxiii{«Habéis venido uno a uno a Nosotros, como os creamos por vez primera, y habéis dejado a vuestras espaldas lo que os habíamos otorgado. No vemos que os acompañen vuestros intercesores, que pretendíais eran vuestros asociados. Se han roto ya los lazos que con ellos os unían, se han esfumado vuestras pretensiones».\qt@no{94}}
\qt@newcmd\qurantrans@es@dccclxxxiv{Alá hace que germinen el grano y el hueso del dátil, saca al vivo del muerto y al muerto del vivo. ¡Ése es Alá! ¡Cómo podéis, pues, ser tan desviados!\qt@no{95}}
\qt@newcmd\qurantrans@es@dccclxxxv{Quien hace que el alba apunte, Quien hizo de la noche descanso y del sol y de la luna cómputo. Esto es lo que ha decretado el Poderoso, el Omnisciente.\qt@no{96}}
\qt@newcmd\qurantrans@es@dccclxxxvi{Y Él es Quien ha hecho, para vosotros, las estrellas, con objeto de que podáis dirigiros por ellas entre las tinieblas de la tierra y del mar. Hemos expuesto así los signos a gente que sabe.\qt@no{97}}
\qt@newcmd\qurantrans@es@dccclxxxvii{Y Él es Quien os ha creado de una sola persona. Receptáculo y depósito. Hemos expuesto así los signos a gente que entiende.\qt@no{98}}
\qt@newcmd\qurantrans@es@dccclxxxviii{Y Él es Quien ha hecho bajar agua del cielo. Mediante ella hemos sacado toda clase de plantas y follaje, del que sacamos granos arracimados. Y de las vainas de la palmera, racimos de dátiles al alcance. Y huertos plantados de vides, y los olivos y los granados, parecidos y diferentes. Cuando fructifican, ¡mirad el fruto que dan y cómo madura! Ciertamente, hay en ello signos para gente que cree.\qt@no{99}}
\qt@newcmd\qurantrans@es@dccclxxxix{Han hecho de los genios asociados de Alá, siendo así que Él es Quien los ha creado. Y Le han atribuido, sin conocimiento, hijos e hijas. ¡Gloria a Él! ¡Está por encima de lo que Le atribuyen!\qt@no{100}}
\qt@newcmd\qurantrans@es@dcccxc{Creador de los cielos y de la tierra. ¿Cómo iba a tener un hijo si no tiene compañera, si lo ha creado todo y lo sabe todo?\qt@no{101}}
\qt@newcmd\qurantrans@es@dcccxci{Ése es Alá, vuestro Señor. No hay más dios que Él. Creador de todo. ¡Servidle, pues! Él vela por todo.\qt@no{102}}
\qt@newcmd\qurantrans@es@dcccxcii{La vista no Le alcanza, pero Él sí que alcanza la vista. Es el Sutil, el Bien Informado.\qt@no{103}}
\qt@newcmd\qurantrans@es@dcccxciii{«Habéis recibido intuiciones de vuestro Señor. Quien ve claro, ve en beneficio propio. Quien está ciego, lo está en detrimento propio. Yo no soy vuestro custodio.»\qt@no{104}}
\qt@newcmd\qurantrans@es@dcccxciv{Así exponemos las aleyas para que digan: «Tú has estudiado» y para explicarlo Nosotros a gente que sabe.\qt@no{105}}
\qt@newcmd\qurantrans@es@dcccxcv{Sigue lo que se te ha revelado, procedente de tu Señor. No hay más dios que Él. Y apártate de los asociadores.\qt@no{106}}
\qt@newcmd\qurantrans@es@dcccxcvi{Si Alá hubiera querido, no habrían sido asociadores. No te hemos nombrado custodio de ellos, ni eres su protector.\qt@no{107}}
\qt@newcmd\qurantrans@es@dcccxcvii{No insultéis a los que ellos invocan en lugar de invocar a Alá, no sea que, por hostilidad, insulten a Alá sin conocimiento. Así, hemos engalanado las obras de cada comunidad. Luego, volverán a su Señor y ya les informará Él de lo que hacían.\qt@no{108}}
\qt@newcmd\qurantrans@es@dcccxcviii{Han jurado solemnemente por Alá que si les viene un signo creerán, ciertamente, en él. Di: «Sólo Alá dispone de los signos». Y ¿qué es lo que os hace prever que, si ocurre, vayan a creer?\qt@no{109}}
\qt@newcmd\qurantrans@es@dcccxcix{Desviaremos sus corazones y sus ojos, como cuando no creyeron por primera vez, y les dejaremos que yerren ciegos en su rebeldía.\qt@no{110}}
\qt@newcmd\qurantrans@es@cm{Aunque hubiéramos hecho que los ángeles descendieran a ellos, aunque les hubieran hablado los muertos, aunque hubiéramos juntado ante ellos todas las cosas, no habrían creído, a menos que Alá hubiera querido. Pero la mayoría son ignorantes.\qt@no{111}}
\qt@newcmd\qurantrans@es@cmi{Así hemos asignado a cada profeta un enemigo: hombres endemoniados o genios endemoniados, que se inspiran mutuamente pomposas palabras para engañarse. Si tu Señor hubiera querido, no lo habrían hecho. ¡Déjales con sus invenciones!\qt@no{112}}
\qt@newcmd\qurantrans@es@cmii{¡Que los corazones de los que no creen en la otra vida se vean atraídos a ello! ¡Que les plazca! ¡Que lleven su merecido!\qt@no{113}}
\qt@newcmd\qurantrans@es@cmiii{«¿Buscaré, pues, a otro diferente de Alá como juez, siendo Él Quien os ha revelado la Escritura explicada detalladamente?» Aquéllos a quienes Nosotros hemos dado la Escritura saben bien que ha sido revelada por tu Señor con la Verdad. ¡No seáis, pues, de los que dudan!\qt@no{114}}
\qt@newcmd\qurantrans@es@cmiv{La Palabra de tu Señor se ha cumplido en verdad y en justicia. Nadie puede cambiar Sus palabras. Él es Quien todo lo oye, todo lo sabe.\qt@no{115}}
\qt@newcmd\qurantrans@es@cmv{Si obedecieras a la mayoría de los que están en la tierra, te extraviarían del camino de Alá. No siguen sino conjeturas, no formulan sino hipótesis.\qt@no{116}}
\qt@newcmd\qurantrans@es@cmvi{Ciertamente, tu Señor conoce mejor que nadie quién se extravía de Su camino y quiénes son los bien dirigidos.\qt@no{117}}
\qt@newcmd\qurantrans@es@cmvii{Comed, pues, de aquello sobre lo que se ha mencionado el nombre de Alá si creéis en Sus signos.\qt@no{118}}
\qt@newcmd\qurantrans@es@cmviii{¿Qué razón tenéis para no comer de aquello sobre lo que se ha mencionado el nombre de Alá, habiéndoos Él detallado lo ilícito -salvo en caso de extrema necesidad-? Muchos sin conocimiento extravían a otros con sus pasiones. Tu Señor conoce mejor que nadie a quienes violan la ley.\qt@no{119}}
\qt@newcmd\qurantrans@es@cmix{Evitad el pecado, público o privado. Los que cometan pecado serán retribuidos conforme a su merecido.\qt@no{120}}
\qt@newcmd\qurantrans@es@cmx{No comáis de aquello sobre lo que no hayáis mencionado el nombre de Alá, pues seria una perversidad. Sí, los demonios inspiran a sus amigos que discutan con vosotros. Si les obedecéis, sois asociadores.\qt@no{121}}
\qt@newcmd\qurantrans@es@cmxi{El que estaba muerto y que luego hemos resucitado dándole una luz con la cual anda entre la gente, ¿es igual que el que está entre tinieblas sin poder salir? De este modo han sido engalanadas las obras de los infieles...\qt@no{122}}
\qt@newcmd\qurantrans@es@cmxii{Así, hemos puesto en cada ciudad a los más pecadores de ella para que intriguen. Pero, al intrigar, no lo hacen sino contra sí mismos, sin darse cuenta.\qt@no{123}}
\qt@newcmd\qurantrans@es@cmxiii{Cuando les viene un signo dicen: «No creeremos hasta que se nos dé tanto cuanto se ha dado a los enviados de Alá». Pero Alá sabe bien a quién confiar Su mensaje. La humillación ante Alá y un castigo severo alcanzarán a los pecadores por haber intrigado.\qt@no{124}}
\qt@newcmd\qurantrans@es@cmxiv{Alá abre al islam el pecho de aquél a quien Él quiere dirigir. Y estrecha y oprime el pecho de aquél a quien Él quiere extraviar, como si se elevara en el aire. Así muestra Alá la indignación contra quienes no creen.\qt@no{125}}
\qt@newcmd\qurantrans@es@cmxv{Ésta es la vía de tu Señor, recta. Hemos expuesto las aleyas a gente que se deja amonestar.\qt@no{126}}
\qt@newcmd\qurantrans@es@cmxvi{La Morada de la Paz junto a su Señor es para ellos -Él es su amigo-, como premio a sus obras.\qt@no{127}}
\qt@newcmd\qurantrans@es@cmxvii{El día que Él les congregue a todos: «¡Asamblea de genios! ¡Habéis abusado de los hombres!» y los hombres que fueron amigos de los genios dirán: «¡Señor! Unos hemos sacado provecho de otros y hemos llegado ya al término que Tú nos habías señalado». Dirá: «Tendréis el Fuego por morada, en el que estaréis eternamente, a menos que Alá disponga otra cosa». Tu Señor es sabio, omnisciente.\qt@no{128}}
\qt@newcmd\qurantrans@es@cmxviii{Así conferimos a algunos impíos autoridad sobre otros por lo que han cometido.\qt@no{129}}
\qt@newcmd\qurantrans@es@cmxix{«¡Asamblea de genios y de hombres! ¿No vinieron a vosotros enviados, salidos de vosotros, para contaros Mis signos y preveniros contra el encuentro de este vuestro día?» Dirán: «Atestiguamos contra nosotros mismos». Pero la vida de acá les engañó y atestiguarán contra sí mismos su incredulidad.\qt@no{130}}
\qt@newcmd\qurantrans@es@cmxx{Porque tu Señor no va a destruir injustamente ciudades sin haber antes apercibido a sus habitantes.\qt@no{131}}
\qt@newcmd\qurantrans@es@cmxxi{Para todos habrá categorías según sus obras. Tu Señor está atento a lo que hacen.\qt@no{132}}
\qt@newcmd\qurantrans@es@cmxxii{Tu Señor es Quien Se basta a Sí mismo, el Dueño de la misericordia. Si quisiera, os retiraría y os sustituiría por quien Él quisiera, igual que os ha suscitado a vosotros de la descendencia de otra gente.\qt@no{133}}
\qt@newcmd\qurantrans@es@cmxxiii{¡Ciertamente, aquello con que se os ha amenazado vendrá! Y no podréis escapar.\qt@no{134}}
\qt@newcmd\qurantrans@es@cmxxiv{Di: «¡Pueblo! ¡Obrad según vuestra situación! Yo también obraré... Pronto sabréis para quién será la Morada Postrera. Los impíos no prosperarán».\qt@no{135}}
\qt@newcmd\qurantrans@es@cmxxv{Reservan a Alá una parte de la cosecha y de los rebaños que Él ha hecho crecer. Y dicen: «Esto es para Alá» -eso pretenden- «y esto para nuestros asociados». Pero lo que es para quienes ellos asocian no llega a Alá y lo que es para Alá llega a quienes ellos asocian. ¡Qué mal juzgan!\qt@no{136}}
\qt@newcmd\qurantrans@es@cmxxvi{Así, los que ellos asocian han hecho creer a muchos asociadores que estaba bien que mataran a sus hijos. Esto era para perderles a ellos mismos y oscurecerles su religión. Si Alá hubiera querido, no lo habrían, hecho. Déjales, pues, con sus invenciones.\qt@no{137}}
\qt@newcmd\qurantrans@es@cmxxvii{Y dicen: «He aquí unos rebaños y una cosecha que están consagrados. Nadie se alimentará de ellos sino en la medida que nosotros queramos». Eso pretenden. Hay bestias de dorso prohibido y bestias sobre las que no mencionan el nombre de Alá. Todo eso es una invención contra Él. Él les retribuirá por sus invenciones.\qt@no{138}}
\qt@newcmd\qurantrans@es@cmxxviii{Y dicen: «Lo que hay en el vientre de estas bestias está reservado para nuestros, varones y vedado a nuestras esposas». Pero, si estuviera muerta, participarían de ella. Él les retribuirá por lo que cuentan. Él es sabio, omnisciente.\qt@no{139}}
\qt@newcmd\qurantrans@es@cmxxix{Saldrán perdiendo quienes, sin conocimiento, maten a sus hijos tontamente y que, inventando contra Alá, prohíban aquello de que Alá les ha proveído. Están extraviados, no están bien dirigidos.\qt@no{140}}
\qt@newcmd\qurantrans@es@cmxxx{Él es Quien ha creado huertos, unos con emparrados y otros sin ellos, las palmeras, los cereales de alimento vario, los olivos, los granados, parecidos y diferentes. ¡Comed de su fruto, si lo tienen, pero dad lo debido el día de la cosecha! ¡Y no cometáis excesos, que Alá no ama a los inmoderados!.\qt@no{141}}
\qt@newcmd\qurantrans@es@cmxxxi{De las bestias, unas sirven de carga y otras con fines textiles. ¡Comed de lo que Alá os ha proveído y no sigáis los pasos del Demonio! Es para vosotros un enemigo declarado.\qt@no{142}}
\qt@newcmd\qurantrans@es@cmxxxii{Cuatro parejas de reses: una de ganado ovino y otra de ganado caprino -di: «¿Ha prohido los dos machos, o las dos hembras, o lo que encierran los úteros de las dos hembras? ¡Informadme con conocimiento, si sois sinceros!»-,\qt@no{143}}
\qt@newcmd\qurantrans@es@cmxxxiii{una de ganado camélido y otra de ganado bovino -di: «¿Ha prohibido los dos machos o las dos hembras o lo que encierran los úteros de las dos hembras? ¿Fuisteis, acaso, testigos cuando Alá os ordenó esto? ¿Hay alguien más impío que aquél que inventa una mentira contra Alá para, sin conocimiento, extraviar a los hombres?»-. Ciertamente, Alá no dirige al pueblo impío.\qt@no{144}}
\qt@newcmd\qurantrans@es@cmxxxiv{Di: «En lo que se me ha revelado no encuentro nada que se prohíba comer, excepto carne mortecina, sangre derramada o carne de cerdo -que es una suciedad-, o aquello sobre lo que, por pervesidad, se haya invocado un nombre diferente del de Alá. Pero, si alguien se ve compelido por la necesidad -no por deseo ni por afán de contravenir-... Tu Señor es indulgente, misericordioso».\qt@no{145}}
\qt@newcmd\qurantrans@es@cmxxxv{A los judíos les prohibimos toda bestia ungulada y la grasa de ganado bovino y de ganado menor, excepto la que tengan en los lomos o en las entrañas o la mezclada con los huesos. Así les retribuimos por su rebeldía. Decimos, sí, la verdad.\qt@no{146}}
\qt@newcmd\qurantrans@es@cmxxxvi{Si te desmienten, di: «Vuestro Señor es el Dueño de una inmensa misericordia, pero no se alejará Su rigor del pueblo pecador».\qt@no{147}}
\qt@newcmd\qurantrans@es@cmxxxvii{Los asociadores dirán: «Si Alá hubiera querido, no habríamos sido asociadores, ni tampoco nuestros padres, ni habríamos declarado nada ilícito». Así desmintieron sus antecesores, hasta que gustaron Nuestro rigor. Di: «¿Tenéis alguna ciencia que podáis mostrarnos?» No seguís sino conjeturas, no formuláis sino hipótesis.\qt@no{148}}
\qt@newcmd\qurantrans@es@cmxxxviii{Di: «Es Alá quien posee el argumento definitivo y, si hubiera querido, os habría dirigido a todos».\qt@no{149}}
\qt@newcmd\qurantrans@es@cmxxxix{Di: «¡Traed a vuestros testigos y que atestiguen que Alá ha prohibido esto!» Si atestiguan, no atestiguéis con ellos. No sigas las pasiones de quienes han desmentido Nuestros signos, de quienes no creen en la otra vida y equiparan a otros a su Señor.\qt@no{150}}
\qt@newcmd\qurantrans@es@cmxl{Di: «¡Venid, que os recitaré lo que vuestro Señor os ha prohibido: que Le asociéis nada! ¡Sed buenos con vuestros padres, no matéis a vuestros hijos por miedo de empobreceros -ya os proveeremos Nosotros, y a ellos,- alejaos de las deshonestidades, públicas o secretas, no matéis a nadie que Alá haya prohibido, sino con justo motivo ¡Esto os ha ordenado Él. Quizás, así, razonéis».\qt@no{151}}
\qt@newcmd\qurantrans@es@cmxli{«¡No toquéis la hacienda del huérfano, sino de manera conveniente, hasta que alcance la madurez! ¡Dad con equidad la medida y el peso justos! No pedimos a nadie sino según sus posibilidades. Sed justos cuando declaréis, aun si se trata de un pariente! ¡Sed fieles a la alianza con Alá! Esto os ha ordenado Él. Quizás, así os dejéis amonestar».\qt@no{152}}
\qt@newcmd\qurantrans@es@cmxlii{Y: «Ésta es Mi vía, recta. Seguidla, pues, y no sigáis otros caminos, que os desviarían de Su camino. Esto os ha ordenado Él. Quizás, así temáis a Alá».\qt@no{153}}
\qt@newcmd\qurantrans@es@cmxliii{Dimos, además, la Escritura a Moisés como complemento, por el bien que había hecho, como explicación detallada de todo, como dirección y misericordia. Quizás, así, crean en el encuentro de su Señor.\qt@no{154}}
\qt@newcmd\qurantrans@es@cmxliv{Es ésta una Escritura bendita que hemos revelado. ¡Seguidla, pues, y temed a Alá! Quizás, así se os tenga piedad.\qt@no{155}}
\qt@newcmd\qurantrans@es@cmxlv{No sea que dijerais: «Sólo se ha revelado la Escritura a dos comunidades antes que a nosotros y no nos preocupábamos de lo que ellos estudiaban».\qt@no{156}}
\qt@newcmd\qurantrans@es@cmxlvi{O que dijerais: «Si se nos hubiera revelado la Escritura, habríamos sido mejor dirigidos que ellos». Pues ya ha venido a vosotros de vuestro Señor una prueba clara, dirección y misericordia. Y ¿hay alguien más impío que quien desmiente los signos de Alá y se aparta de ellos? Retribuiremos con un mal castigo a quienes se aparten de nuestros mensajes, por haberse apartado.\qt@no{157}}
\qt@newcmd\qurantrans@es@cmxlvii{¿Qué esperan sino que vengan a ellos los ángeles, o que venga tu Señor, o que vengan algunos de los signos de tu Señor? El día que vengan algunos de los signos de tu Señor, no aprovechará su fe a nadie que antes no haya creído o que, en su fe, no haya hecho bien. Di: «¡Esperad! ¡Nosotros esperamos!»\qt@no{158}}
\qt@newcmd\qurantrans@es@cmxlviii{En cuanto a los que han escindido su religión en sectas, es asunto que no te incumbe. Su suerte está sólo en manos de Alá. Luego, ya les informará Él de lo que hacían.\qt@no{159}}
\qt@newcmd\qurantrans@es@cmxlix{Quien presente una buena obra, recibirá diez veces más. Y quien presente una mala obra, será retribuido con sólo una pena semejante. No serán tratados injustamente.\qt@no{160}}
\qt@newcmd\qurantrans@es@cml{Di: «A mí, mi Señor me ha dirigido a una vía recta, una fe verdadera, la religión de Abraham, que fue hanif y no asociador»\qt@no{161}}
\qt@newcmd\qurantrans@es@cmli{Di: «Mi azalá, mis prácticas de piedad, mi vida y mi muerte pertenecen a Alá, Señor del universo.\qt@no{162}}
\qt@newcmd\qurantrans@es@cmlii{No tiene asociado. Se me ha ordenado esto y soy el primero en someterse a Él»\qt@no{163}}
\qt@newcmd\qurantrans@es@cmliii{Di: «¿Buscaré a otro diferente de Alá como Señor. Él que es el Señor de todo?» Nadie comete mal sino en detrimento propio. Nadie cargará con la carga ajena. Luego, volveréis a vuestro Señor y ya os informará Él de aquello en que discrepabais.\qt@no{164}}
\qt@newcmd\qurantrans@es@cmliv{Él es Quien os ha hecho sucesores en la tierra y Quien os ha distinguido en categoría a unos sobre otros, para probaros en lo que os ha dado. Tu Señor es rápido en castigar, pero también es indulgente, misericordioso.\qt@no{165}}
\qt@newcmd\qurantrans@es@cmlv{\basmalahes 'lms.\qt@no{1}}
\qt@newcmd\qurantrans@es@cmlvi{Ésta es una Escritura que se te ha revelado -¡no te apures por ella!-, para que adviertas por ella, y como amonestación para los creyentes.\qt@no{2}}
\qt@newcmd\qurantrans@es@cmlvii{¡Seguid lo que vuestro Señor os ha revelado y no sigáis a otros amigos en lugar de seguirle a Él! ¡Qué poco os dejáis amonestar!\qt@no{3}}
\qt@newcmd\qurantrans@es@cmlviii{¡Cuántas ciudades hemos destruido! Les alcanzó Nuestro rigor de noche o durante la siesta.\qt@no{4}}
\qt@newcmd\qurantrans@es@cmlix{Cuando les alcanzó Nuestro rigor, no gritaron más que: «¡Fuimos impíos!».\qt@no{5}}
\qt@newcmd\qurantrans@es@cmlx{Pediremos, ciertamente, responsabilidades a aquéllos a quienes mandamos enviados, como también a los enviados.\qt@no{6}}
\qt@newcmd\qurantrans@es@cmlxi{Les contaremos, ciertamente, con conocimiento. No estábamos ausentes.\qt@no{7}}
\qt@newcmd\qurantrans@es@cmlxii{La pesa ese día será la Verdad. Aquéllos cuyas obras pesen mucho serán los que prosperen,\qt@no{8}}
\qt@newcmd\qurantrans@es@cmlxiii{mientras que aquéllos cuyas obras pesen poco perderán, porque obraron impíamente con Nuestros signos.\qt@no{9}}
\qt@newcmd\qurantrans@es@cmlxiv{Os hemos dado poderío en la tierra y os hemos puesto en ella medios de subsistencia. ¡Qué poco agradecidos sois!\qt@no{10}}
\qt@newcmd\qurantrans@es@cmlxv{Y os creamos. Luego, os formamos. Luego dijimos a los ángeles: «¡Prosternaos ante Adán!» Se prosternaron, excepto Iblis. No fue de los que se prosternaron.\qt@no{11}}
\qt@newcmd\qurantrans@es@cmlxvi{Dijo: «¿Qué es lo que te ha impedido prosternarte cuando Yo te lo he ordenado?» Dijo: «Es que soy mejor que él. A mí me creaste de fuego, mientras que a él le creaste de arcilla».\qt@no{12}}
\qt@newcmd\qurantrans@es@cmlxvii{Dijo: «Desciende, pues, de aquí! ¡No vas a echártelas de soberbio en este lugar...! ¡Sal, pues, eres de los despreciables!»\qt@no{13}}
\qt@newcmd\qurantrans@es@cmlxviii{Dijo: «¡Déjame esperar hasta el día de la Resurreción!»\qt@no{14}}
\qt@newcmd\qurantrans@es@cmlxix{Dijo: «¡Cuéntate entre aquellos a quienes es dado esperar!»\qt@no{15}}
\qt@newcmd\qurantrans@es@cmlxx{Dijo: «Como me has descarriado, he de acecharles en Tu vía recta.\qt@no{16}}
\qt@newcmd\qurantrans@es@cmlxxi{He de atacarles por delante y por detrás, por la derecha y por la izquierda. Y verás que la mayoría no son agradecidos».\qt@no{17}}
\qt@newcmd\qurantrans@es@cmlxxii{Dijo: «¡Sal de aquí, detestable, vil! ¡He de llenar la gehena de tus secuaces ¡De todos vosotros!»\qt@no{18}}
\qt@newcmd\qurantrans@es@cmlxxiii{«¡Adán! ¡Habita con tu esposa en el Jardín y comed de lo que queráis, pero no os acerquéis a este árbol! Si no, seréis de los impíos».\qt@no{19}}
\qt@newcmd\qurantrans@es@cmlxxiv{Pero el Demonio les insinuó el mal, mostrándoles su escondida desnudez, y dijo: «Vuestro Señor no os ha prohibido acercaros a este árbol sino por temor de que os convirtáis en ángeles u os hagáis inmortales».\qt@no{20}}
\qt@newcmd\qurantrans@es@cmlxxv{Y les juró: «¡De veras, os aconsejo bien!»\qt@no{21}}
\qt@newcmd\qurantrans@es@cmlxxvi{Les hizo, pues, caer dolosamente. Y cuando hubieron gustado ambos del árbol, se les reveló su desnudez y comenzaron a cubrirse con hojas del Jardín. Su Señor les llamó: «¿No os había prohibido ese árbol y dicho que el Demonio era para vosotros un enemigo declarado?»\qt@no{22}}
\qt@newcmd\qurantrans@es@cmlxxvii{Dijeron: «¡Señor! Hemos sido injustos con nosostros mismos. Si no nos perdonas y Te apiadas de nosotros, seremos, ciertamente, de los que pierden».\qt@no{23}}
\qt@newcmd\qurantrans@es@cmlxxviii{Dijo: «¡Descended! Seréis enemigos unos de otros. La tierra será por algún tiempo vuestra morada y lugar de disfrute»\qt@no{24}}
\qt@newcmd\qurantrans@es@cmlxxix{Dijo: «En ella viviréis, en ella moriréis y de ella se os sacará».\qt@no{25}}
\qt@newcmd\qurantrans@es@cmlxxx{¡Hijos de Adán! Hemos hecho bajar para vosotros una vestidura para cubrir vuestra desnudez y para ornato. Pero la vestidura del temor de Alá, ésa es mejor. Ése es uno de los signos de Alá. Quizás, así, se dejen amonestar.\qt@no{26}}
\qt@newcmd\qurantrans@es@cmlxxxi{¡Hijos de Adán! Que el Demonio no os tiente, como cuando sacó a vuestros padres del Jardín, despojándoles de su vestidura para mostrarles su desnudez. Él y su hueste os ven desde donde vosotros no les veis. A los que no creen les hemos dado los demonios como amigos.\qt@no{27}}
\qt@newcmd\qurantrans@es@cmlxxxii{Cuando cometen una deshonestidad, dicen: «Encontramos a nuestros padres haciendo lo mismo y Alá nos lo ha ordenado». Di: «Ciertamente, Alá no ordena la deshonestidad. ¿Decís contra Alá lo que no sabéis?»\qt@no{28}}
\qt@newcmd\qurantrans@es@cmlxxxiii{Di: «Mi Señor ordena la equidad. Dirigíos a Él siempre que oréis e invocadle rindiéndole culto sincero. Así como os ha creado, volveréis».\qt@no{29}}
\qt@newcmd\qurantrans@es@cmlxxxiv{Ha dirigido a unos, pero otros han merecido extraviarse. Éstos han tomado como amigos a los demonios, en lugar de tomar a Alá, y creen ser bien dirigidos.\qt@no{30}}
\qt@newcmd\qurantrans@es@cmlxxxv{¡Hijos de Adán! ¡Atended a vuestro atavío siempre que oréis! ¡Comed y bebed, pero no cometáis excesos, que Él no ama a los inmoderados!\qt@no{31}}
\qt@newcmd\qurantrans@es@cmlxxxvi{Di: «,Quién ha prohibido los adornos que Alá ha producido para Sus siervos y las cosas buenas de que os ha proveído?» Di: «Esto es para los creyentes mientras vivan la vida de acá, pero, en particular, para el día de la Resurrección». Así es como explicamos con detalle las aleyas a gente que sabe.\qt@no{32}}
\qt@newcmd\qurantrans@es@cmlxxxvii{Di: «Mi Señor prohíbe sólo las deshonestidades, tanto las públicas como las ocultas, el pecado, la opresión injusta, que asociéis a Alá algo a lo que Él no ha conferido autoridad y que digáis contra Alá lo que no sabéis».\qt@no{33}}
\qt@newcmd\qurantrans@es@cmlxxxviii{Cada comunidad tiene un plazo. Y cuando vence su plazo, no pueden retrasarlo ni adelantarlo una hora.\qt@no{34}}
\qt@newcmd\qurantrans@es@cmlxxxix{¡Hijos de Adán! Si vienen a vosotros enviados salidos de vosotros contándoos Mis signos, quienes temen a Alá y se enmiendan no tienen que temer y no estarán tristes.\qt@no{35}}
\qt@newcmd\qurantrans@es@cmxc{Pero quienes hayan desmentido Nuestros signos y se hayan apartado altivamente de ellos, ésos morarán en el Fuego eternamente.\qt@no{36}}
\qt@newcmd\qurantrans@es@cmxci{¿Hay alguien que sea más impío que quien inventa una mentira contra Alá o niega Sus signos? Ésos tendrán la suerte a que han sido destinados. Cuando, al fin, Nuestros enviados vengan a ellos para llamarles, dirán: «¿Dónde está lo que invocabais en lugar de invocar a Alá?» Ellos dirán: «¡Nos han abandonado!» Entonces, atestiguarán contra sí mismos su incredulidad.\qt@no{37}}
\qt@newcmd\qurantrans@es@cmxcii{Dirá «¡Entrad en el Fuego a reuniros con las comunidades de genios y hombres que os han precedido!» Siempre que una comunidad entra, maldice a su hermana. Cuando, al fin, se encuentren allí todas, la última en llegar dirá de la primera: «¡Señor! Éstos son quienes nos extraviaron. Dóblales, pues, el castigo del Fuego». Dirá: «Todos reciben el doble. Pero vosotros no sabéis».\qt@no{38}}
\qt@newcmd\qurantrans@es@cmxciii{La primera de ellas dirá a la última: «No gozáis de ningún privilegio sobre nosotros. Gustad, pues, el castigo que habéis merecido».\qt@no{39}}
\qt@newcmd\qurantrans@es@cmxciv{A quienes hayan desmentido Nuestros signos y se hayan apartado altivamente de ellos, no se les abrirán las puertas del cielo ni entrarán en el Jardín hasta que entre un camello en el ojo de una aguja. Así retribuiremos a los pecadores.\qt@no{40}}
\qt@newcmd\qurantrans@es@cmxcv{Tendrán la gehena por lecho y, por encima, cobertores. Así retribuiremos a los impíos.\qt@no{41}}
\qt@newcmd\qurantrans@es@cmxcvi{Quienes creyeron y obraron bien- a nadie pedimos sino según sus posibilidades-. ésos morarán en el Jardín eternamente.\qt@no{42}}
\qt@newcmd\qurantrans@es@cmxcvii{Extirparemos el rencor que quede en sus pechos. Fluirán arroyos a sus pies. Dirán: «¡Alabado sea Alá, Que nos ha dirigido acá! No habríamos sido bien dirigidos si no nos hubiera dirigido Alá. Los enviados de nuestro Señor bien que trajeron la Verdad». Y se les llamará: «Éste es el Jardín. Lo habéis heredado en premio a vuestras obras».\qt@no{43}}
\qt@newcmd\qurantrans@es@cmxcviii{Los moradores del Jardín llamarán a los moradores del Fuego: «Hemos encontrado que era verdad lo que nuestro Señor nos había prometido. Y vosotros, ¿ habéis encontrado si era verdad lo que vuestro Señor os había prometido?» «¡Si!», dirán. Entonces, un voceador pregonará entre ellos: «¡Que la maldición de Alá caiga sobre los impíos.\qt@no{44}}
\qt@newcmd\qurantrans@es@cmxcix{que desvían a otros del camino de Alá, deseando que sea tortuoso, y no creen en la otra vida!»\qt@no{45}}
\qt@newcmd\qurantrans@es@m{Hay entre los dos un velo. En los lugares elevados habrá hombres que reconocerán a todos por sus rasgos distintivos y que llamarán a los moradores del Jardín: «¡Paz sobre vosotros!» No entrarán en él, por mucho que lo deseen.\qt@no{46}}
\qt@newcmd\qurantrans@es@mi{Cuando sus miradas se vuelvan hacia los moradores del Fuego, dirán: «¡Señor! ¡No nos pongas con el pueblo impío»\qt@no{47}}
\qt@newcmd\qurantrans@es@mii{Y los moradores de los lugares elevados llamarán a hombres que reconozcan por sus rasgos distintivos. Dirán: «Lo que habéis acumulado y vuestra altivez no os han servido de nada.\qt@no{48}}
\qt@newcmd\qurantrans@es@miii{¿Son éstos aquéllos de quienes jurabais que Alá no iba a apiadarse de ellos?» «¡Entrad en el Jardín! No tenéis que temer y no estaréis tristes».\qt@no{49}}
\qt@newcmd\qurantrans@es@miv{Los moradores del Fuego gritarán a los moradores del Jardín: «¡Derramad sobre nosotros algo de agua o algo de lo que Alá os ha proveído!» Dirán: «Alá ha prohibido ambas cosas a los infieles,\qt@no{50}}
\qt@newcmd\qurantrans@es@mv{que tomaron su religión a distracción y juego, a quienes la vida de acá engañó». Hoy les olvidaremos, como ellos olvidaron que les llegaría este día y negaron Nuestros signos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mvi{Les trajimos una Escritura, que explicamos detalladamente, con pleno conocimiento, como dirección y misericordia para gente que cree.\qt@no{52}}
\qt@newcmd\qurantrans@es@mvii{¿Esperan otra cosa que su cumplimiento? El día que se cumpla, los que antes la olvidaron dirán: «Los enviados de nuestro Señor bien que trajeron la Verdad ¿Tenemos ahora intercesores que intercedan por nosotros o se nos podría devolver y obraríamos de modo diferente al que obramos?» Se han perdido a sí mismos y se han esfumado sus invenciones.\qt@no{53}}
\qt@newcmd\qurantrans@es@mviii{Vuestro Señor es Alá, Que ha creado los cielos y la tierra en seis días. Luego, se ha instalado en el Trono. Cubre el día con la noche, que le sigue rápidamente. Y el sol, la luna y las estrellas, sujetos por Su orden. ¿No son Suyas la creación y la orden? ¡Bendito sea Alá, Señor del universo!\qt@no{54}}
\qt@newcmd\qurantrans@es@mix{¡Invocad a vuestro Señor humilde y secretamente! Él no ama a quienes violan la ley.\qt@no{55}}
\qt@newcmd\qurantrans@es@mx{¡No corrompáis en la tierra después de reformada! ¡Invocadle con temor y anhelo! La misericordia de Alá está cerca de quienes hacen el bien.\qt@no{56}}
\qt@newcmd\qurantrans@es@mxi{Es Él quien envía los vientos como nuncios que preceden a Su misericordia. Cuando están cargados de nubes pesadas, las empujamos a un país muerto y hacemos que llueva en él y que salgan, gracias al agua, frutos de todas clases. Así haremos salir a los muertos. Quizás así, os dejéis amonestar.\qt@no{57}}
\qt@newcmd\qurantrans@es@mxii{La vegetación de un país bueno sale con la ayuda de su Señor, mientras que de un país malo sale pero escasa. Así explicamos los signos a gente que agradece.\qt@no{58}}
\qt@newcmd\qurantrans@es@mxiii{Enviamos Noé a su pueblo. Dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. Temo por vosotros el castigo de un día terrible».\qt@no{59}}
\qt@newcmd\qurantrans@es@mxiv{Los dignatarios de su pueblo dijeron: «Sí, vemos que estás evidentemente extraviado».\qt@no{60}}
\qt@newcmd\qurantrans@es@mxv{Dijo: «¡Puebla! No estoy extraviado, antes bien he sido enviado por el Señor del universo.\qt@no{61}}
\qt@newcmd\qurantrans@es@mxvi{Os comunico los mensajes de mi Señor y os aconsejo bien. Y sé por Alá lo que vosotros no sabéis.\qt@no{62}}
\qt@newcmd\qurantrans@es@mxvii{¿Os maravilláis de que os haya llegado una amonestación de vuestro Señor, por medio de un hombre salido de vosotros, para advertiros y para que temáis a Alá y, quizás, así, se os tenga piedad?»\qt@no{63}}
\qt@newcmd\qurantrans@es@mxviii{Pero le desmintieron. Así, pues, les salvamos, a él y a quienes estaban con él en la nave, y anegamos a quienes habían desmentido Nuestros signos. Eran, en verdad, un pueblo ciego.\qt@no{64}}
\qt@newcmd\qurantrans@es@mxix{Y a los aditas su hermano Hud. Dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. ¿No vais a temerle?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mxx{Los dignatarios de su pueblo, que no creían, dijeron: «Vemos que estás tonto y, sí, creemos que eres de los que mienten».\qt@no{66}}
\qt@newcmd\qurantrans@es@mxxi{Dijo: «¡Pueblo! No estoy tonto. Antes bien, he sido enviado por el Señor del universo.\qt@no{67}}
\qt@newcmd\qurantrans@es@mxxii{Os comunico los mensajes de mi Señor y os aconsejo fielmente.\qt@no{68}}
\qt@newcmd\qurantrans@es@mxxiii{¿Os maravilláis de que os haya llegado una amonestación de vuestro Señor por medio de un hombre salido de vosotros para advertiros? Y recordad cuando os hizo sucesores después del pueblo de Noé y os hizo corpulentos. ¡Recordad, pues, los beneficios de Alá! Quizás, así, prosperéis».\qt@no{69}}
\qt@newcmd\qurantrans@es@mxxiv{Dijeron: «¿Has venido a nosotros para que sirvamos a Alá Solo y renunciemos a aquéllos que nuestros padres servían? Tráenos, pues, aquello con que nos amenazas, si es verdad lo que dices».\qt@no{70}}
\qt@newcmd\qurantrans@es@mxxv{Dijo: «¡Que la indignación y la ira de vuestro Señor caigan sobre vosotros! ¿Disputaréis conmigo sobre los nombres que habéis puesto, vosotros y vuestros padres? Alá no les ha conferido ninguna autoridad. ¡Y esperad! Yo también soy de los que esperan».\qt@no{71}}
\qt@newcmd\qurantrans@es@mxxvi{Así, pues, salvamos a él y a los que con él estaban por una misericordia venida de Nosotros. Y extirpamos a quienes habían desmentido Nuestros signos y no eran creyentes.\qt@no{72}}
\qt@newcmd\qurantrans@es@mxxvii{Y a los tamudeos su hermano Salih. Dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. Os ha venido de vuestro Señor una prueba: es la camella de Alá, que será signo para vosotros, ¡Dejadla que pazca en la tierra de Alá y no le hagáis mal! Si no, os alcanzará un castigo doloroso.\qt@no{73}}
\qt@newcmd\qurantrans@es@mxxviii{Recordad cuando os hizo sucesores, después de los aditas y os estableció en la tierra. Edificasteis palacios en las llanuras y excavasteis casas en las montañas. Recordad los beneficios de Alá y no obréis mal en la tierra corrompiendo».\qt@no{74}}
\qt@newcmd\qurantrans@es@mxxix{Los dignatarios de su pueblo, altivos, dijeron a los débiles que habían creído: «¿Sabéis si Salih ha sido enviado por su Señor?». Dijeron: «Creemos en el mensaje que se le ha confiado».\qt@no{75}}
\qt@newcmd\qurantrans@es@mxxx{Los altivos dijeron: «Pues nosotros no creemos en lo que vosotros creéis».\qt@no{76}}
\qt@newcmd\qurantrans@es@mxxxi{Y desjarretaron la camella e infringieron la orden de su Señor, diciendo: «¡Salih! ¡Tráenos aquello con que nos amenazas, si de verdad eres de los enviados!»\qt@no{77}}
\qt@newcmd\qurantrans@es@mxxxii{Les sorprendió el Temblor y amanecieron muertos en sus casas.\qt@no{78}}
\qt@newcmd\qurantrans@es@mxxxiii{Se alejó de ellos, diciendo: «Pueblo! Os he comunicado el mensaje de mi Señor y os he aconsejado bien, pero no amáis a los buenos consejeros».\qt@no{79}}
\qt@newcmd\qurantrans@es@mxxxiv{Y a Lot. Cuando dijo a su pueblo: «¿Cometéis una deshonestidad que ninguna criatura ha cometido antes?\qt@no{80}}
\qt@newcmd\qurantrans@es@mxxxv{Ciertamente, por concupiscencia, os llegáis a los hombres en lugar de llegaros a las mujeres. ¡Sí, sois un pueblo inmoderado!»\qt@no{81}}
\qt@newcmd\qurantrans@es@mxxxvi{Lo único que respondió su pueblo fue: «¡Expulsadles de la ciudad! ¡Son gente que se las da de puros!»\qt@no{82}}
\qt@newcmd\qurantrans@es@mxxxvii{Y les salvamos, a él y a su familia, salvo a su mujer, que fue de los que se rezagaron.\qt@no{83}}
\qt@newcmd\qurantrans@es@mxxxviii{E hicimos llover sobre ellos una lluvia: ¡Y mira cómo terminaron los pecadores!\qt@no{84}}
\qt@newcmd\qurantrans@es@mxxxix{Y a los madianitas su hermano Suayb. Dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. Os ha venido, de vuestro Señor, una prueba. ¡Dad la medida y el peso justos, no defraudéis a los hombres en sus bienes! ¡No corrompáis en la tierra después de reformada! Eso es mejor para vosotros, si es que sois creyentes.\qt@no{85}}
\qt@newcmd\qurantrans@es@mxl{No acechéis en cada vía a quienes creen en Él, amenazándoles y desviándoles del camino de Alá, deseando que sea tortuoso. Y recordad, cuando erais pocos y Él os multiplicó. ¡Y mirad cómo terminaron los corruptores!\qt@no{86}}
\qt@newcmd\qurantrans@es@mxli{Y si algunos de vosotros creen en el mensaje que se me ha confiado y otros no, tened paciencia hasta que Alá decida entre nosotros. Él es el Mejor en decidir».\qt@no{87}}
\qt@newcmd\qurantrans@es@mxlii{Los dignatarios del pueblo, altivos, dijeron: «Hemos de expulsarte de nuestra ciudad, Suayb, y a los que contigo han creído, a menos que volváis a nuestra religión». Suayb dijo: «¿Aun si no nos gusta?\qt@no{88}}
\qt@newcmd\qurantrans@es@mxliii{Inventaríamos una mentira contra Alá si volviéramos a vuestra religión después de habernos salvado Alá de ella. No podemos volver a ella, a menos que Alá nuestro Señor lo quiera. Nuestro Señor lo abarca todo en Su ciencia. ¡Confiamos en Alá! ¡Señor, falla según Justicia entre nosotros y nuestro pueblo! Tú eres Quien mejor falla».\qt@no{89}}
\qt@newcmd\qurantrans@es@mxliv{Los dignatarios de su pueblo, que no creían, dijeron: «Si seguís a Suayb, estáis perdidos...»\qt@no{90}}
\qt@newcmd\qurantrans@es@mxlv{Les sorprendió el Temblor y amanecieron muertos en sus casas.\qt@no{91}}
\qt@newcmd\qurantrans@es@mxlvi{Fue como si los que habían desmentido a Suayb no hubieran habitado en ellas. Los que habían desmentido a Suayb fueron los que perdieron.\qt@no{92}}
\qt@newcmd\qurantrans@es@mxlvii{Se alejó de ellos, diciendo: «¡Pueblo! Os he comunicado los mensajes de mi Señor y os he aconsejado bien. ¿Cómo voy a sentirlo ahora por gente infiel?»\qt@no{93}}
\qt@newcmd\qurantrans@es@mxlviii{No enviamos a ningún profeta a ciudad que no infligiéramos a su población miseria y desgracia -quizás, así se humillaran-,\qt@no{94}}
\qt@newcmd\qurantrans@es@mxlix{y que no cambiáramos, a continuación, el mal por el bien hasta que olvidaran lo ocurrido y dijeran: «La desgracia y la dicha alcanzaron también a nuestros padres». Entonces, nos apoderábamos de ellos por sorpresa sin que se apercibieran.\qt@no{95}}
\qt@newcmd\qurantrans@es@ml{Si los habitantes de las ciudades hubieran creído y temido a Alá, habríamos derramado sobre ellos bendiciones del cielo y de la tierra, pero desmintieron y nos apoderamos de ellos por lo que habían cometido.\qt@no{96}}
\qt@newcmd\qurantrans@es@mli{¿Es que los habitantes de las ciudades están a salvo de que Nuestro rigor les alcance de noche, mientras duermen?\qt@no{97}}
\qt@newcmd\qurantrans@es@mlii{¿O están a salvo los habitantes de las ciudades de que Nuestro rigor les alcance de día, mientras juegan?\qt@no{98}}
\qt@newcmd\qurantrans@es@mliii{¿Es que están a salvo de la intriga de Alá? Nadie está a salvo de la intriga de Alá, sino los que pierden.\qt@no{99}}
\qt@newcmd\qurantrans@es@mliv{¿No hemos indicado a los que han heredado la tierra después de sus anteriores ocupantes que, si Nosotros quisiéramos. les afligiríamos por sus pecados, sellando sus corazones de modo que no pudieran oír?\qt@no{100}}
\qt@newcmd\qurantrans@es@mlv{Ésas son las ciudades de las que te hemos contado algunas cosas. Vinieron a ellas sus enviados con las pruebas claras, pero no estaban para creer en lo que antes habían desmentido. Así sella Alá los corazones de los infieles.\qt@no{101}}
\qt@newcmd\qurantrans@es@mlvi{No hemos encontrado en la mayoría de ellos fidelidad a una alianza, pero si hemos encontrado que la mayoría son unos perversos.\qt@no{102}}
\qt@newcmd\qurantrans@es@mlvii{Luego, después de ellos, enviamos a Moisés con Nuestros signos a Faraón y a sus dignatarios, pero fueron injustos con ellos. ¡Y mira cómo terminaron los corruptores!\qt@no{103}}
\qt@newcmd\qurantrans@es@mlviii{Moisés dijo: «Faraón! He sido enviado por el Señor del universo.\qt@no{104}}
\qt@newcmd\qurantrans@es@mlix{No debo decir nada contra Alá, sino la verdad. Os he traído una prueba clara de vuestro Señor. Deja marchar conmigo a los Hijos de Israel».\qt@no{105}}
\qt@newcmd\qurantrans@es@mlx{Dijo: «Si has traído un signo, muéstralo, si es verdad lo que dices».\qt@no{106}}
\qt@newcmd\qurantrans@es@mlxi{Tiró su vara y se convirtió en auténtica serpiente.\qt@no{107}}
\qt@newcmd\qurantrans@es@mlxii{Sacó su mano y he aquí que apareció blanca a los ojos de los presentes.\qt@no{108}}
\qt@newcmd\qurantrans@es@mlxiii{Los dignatarios del pueblo de Faraón dijeron: «Sí, éste es un mago entendido.\qt@no{109}}
\qt@newcmd\qurantrans@es@mlxiv{Quiere expulsaros de vuestra tierra ¿Qué ordenáis?»\qt@no{110}}
\qt@newcmd\qurantrans@es@mlxv{Dijeron: «¡Dales largas, a él y a su hermano, y envía a las ciudades a agentes que convoquen,\qt@no{111}}
\qt@newcmd\qurantrans@es@mlxvi{que te traigan a todo mago entendido!»\qt@no{112}}
\qt@newcmd\qurantrans@es@mlxvii{Los magos vinieron a Faraón y dijeron: «Tiene que haber una recompensa para nosotros si vencemos».\qt@no{113}}
\qt@newcmd\qurantrans@es@mlxviii{Dijo: «Sí, y seréis, ciertamente, de mis allegados».\qt@no{114}}
\qt@newcmd\qurantrans@es@mlxix{Dijeron: «¡Moisés! ,Tiras tú o tiramos nosotros?»\qt@no{115}}
\qt@newcmd\qurantrans@es@mlxx{Dijo: «¡Tirad vosotros!» Y, cuando tiraron fascinaron los ojos de la gente y les aterrorizaron. Vinieron con un encantamiento poderoso.\qt@no{116}}
\qt@newcmd\qurantrans@es@mlxxi{E inspiramos a Moisés: «¡Tira tu vara!» Y he aquí que ésta engulló sus mentiras.\qt@no{117}}
\qt@newcmd\qurantrans@es@mlxxii{Y se cumplió la Verdad y resultó inútil lo que habían hecho.\qt@no{118}}
\qt@newcmd\qurantrans@es@mlxxiii{Fueron, así, vencidos y se retiraron humillados.\qt@no{119}}
\qt@newcmd\qurantrans@es@mlxxiv{Los magos cayeron prosternados\qt@no{120}}
\qt@newcmd\qurantrans@es@mlxxv{Dijeron: «Creemos en el Señor del universo,\qt@no{121}}
\qt@newcmd\qurantrans@es@mlxxvi{el Señor de Moisés y de Aarón».\qt@no{122}}
\qt@newcmd\qurantrans@es@mlxxvii{Faraón dijo: «¡Habéis creído en él antes de que yo os autorizara! Ésta es, ciertamente, una intriga que habéis urdido en la ciudad para sacar de ella a su población, pero vais a ver...\qt@no{123}}
\qt@newcmd\qurantrans@es@mlxxviii{He de haceros amputar las manos y los pies opuestos. Luego he de haceros crucificar a todos».\qt@no{124}}
\qt@newcmd\qurantrans@es@mlxxix{Dijeron: «Ciertamente, volveremos a nuestro Señor.\qt@no{125}}
\qt@newcmd\qurantrans@es@mlxxx{Te vengas de nosotros sólo porque hemos creído en los signos de nuestro Señor cuando han venido a nosotros. ¡Señor! Infunde en nosotros paciencia y haz que cuando muramos lo hagamos sometidos a Ti».\qt@no{126}}
\qt@newcmd\qurantrans@es@mlxxxi{Los dignatarios del pueblo de Faraón dijeron: «¿Dejaréis que Moisés y su pueblo corrompan en el país y os abandonen, a ti a y a tus dioses?» Dijo: «Mataremos sin piedad a sus hijos varones y dejaremos con vida a sus mujeres. Les podemos».\qt@no{127}}
\qt@newcmd\qurantrans@es@mlxxxii{Moisés dijo a su pueblo: «¡Implorad la ayuda de Alá y tened paciencia! La tierra es de Alá y se la da en herencia a quien Él quiere de Sus siervos. El fin es para los que temen a Alá».\qt@no{128}}
\qt@newcmd\qurantrans@es@mlxxxiii{Dijeron: «Hemos sufrido antes de que tú vinieras a nosotros y luego de haber venido». Dijo: «Puede que vuestro Señor destruya a vuestro enemigo y os haga sucederles en la tierra para ver cómo actuáis».\qt@no{129}}
\qt@newcmd\qurantrans@es@mlxxxiv{Infligimos al pueblo de Faraón años y escasez de frutos. Quizás así, se dejaran amonestar.\qt@no{130}}
\qt@newcmd\qurantrans@es@mlxxxv{Cuando les sonreía la fortuna, decían: «¡Esto es nuestro!». Pero, cuando les sucedía un mal, lo achacaban al mal agüero de Moisés y de quienes con él estaban. ¿Es que su suerte no dependía sólo de Alá? Pero la mayoría no sabían.\qt@no{131}}
\qt@newcmd\qurantrans@es@mlxxxvi{Dijeron: «Sea cual sea el signo que nos traigas para hechizarnos con él, no te creeremos».\qt@no{132}}
\qt@newcmd\qurantrans@es@mlxxxvii{Enviamos contra ellos la inundación, las langostas, los piojos, las ranas y la sangre, signos inteligibles. Pero fueron altivos, eran gente pecadora.\qt@no{133}}
\qt@newcmd\qurantrans@es@mlxxxviii{Y, cuando cayó el castigo sobre ellos, dijeron: «¡Moisés! Ruega a tu Señor por nosotros en virtud de la alianza que ha concertado contigo. Si apartas el castigo de nosotros, creeremos, ciertamente, en ti y dejaremos que los Hijos de Israel partan contigo».\qt@no{134}}
\qt@newcmd\qurantrans@es@mlxxxix{Pero, cuando retiramos el castigo hasta que se cumpliera el plazo que debían observar, he aquí que quebrantaron su promesa.\qt@no{135}}
\qt@newcmd\qurantrans@es@mxc{Nos vengamos de ellos anegándoles en el mar por haber desmentido Nuestros signos y por no haber hecho caso de ellos.\qt@no{136}}
\qt@newcmd\qurantrans@es@mxci{Y dimos en herencia al pueblo que había sido humillado las tierras orientales y las occidentales, que Nosotros hemos bendecido. Y se cumplió la bella promesa de tu Señor a los Hijos de Israel, por haber tenido paciencia. Y destruimos lo que Faraón y su pueblo habían hecho y lo que habían construido.\qt@no{137}}
\qt@newcmd\qurantrans@es@mxcii{E hicimos que los Hijos de Israel atravesaran el mar y llegaron a una gente entregada al culto de sus ídolos. Dijeron: «¡Moisés! ¡Haznos un dios, como ellos tienen dioses!» «¡Sois un pueblo ignorante!», dijo.\qt@no{138}}
\qt@newcmd\qurantrans@es@mxciii{«Aquello en que estas gentes están va a ser destruido y sus obras serán vanas».\qt@no{139}}
\qt@newcmd\qurantrans@es@mxciv{Dijo: «¿Voy a buscaros un dios diferente de Alá, siendo así que Él os ha distinguido entre todos los pueblos?»\qt@no{140}}
\qt@newcmd\qurantrans@es@mxcv{Y cuando os salvamos de las gentes de Faraón, que os sometían a duro castigo, matando sin piedad a vuestros hijos varones y dejando con vida a vuestras mujeres. Con esto os probó vuestro Señor duramente.\qt@no{141}}
\qt@newcmd\qurantrans@es@mxcvi{Y nos dimos cita con Moisés durante treinta días, que completamos con otros diez. Así, la duración con su Señor fue de cuarenta días. Moisés dijo a su hermano Aarón: «Haz mis veces en mi pueblo, obra bien y no imites a los corruptores».\qt@no{142}}
\qt@newcmd\qurantrans@es@mxcvii{Cuando Moisés acudió a Nuestro encuentro y su Señor le hubo hablado, dijo: «¡Señor! ¡Muéstrate a mí, que pueda mirarte!» Dijo: «¡No Me verás! ¡Mira, en cambio, la montaña! Si continúa firme en su sitio, entonces Me verás». Pero, cuando su Señor se manifestó a la montaña, la pulverizó y Moisés cayó al suelo fulminando. Cuando volvió en si dijo: «¡Gloria a Ti! Me arrepiento y soy el primero de los que creen».\qt@no{143}}
\qt@newcmd\qurantrans@es@mxcviii{Dijo: «¡Moisés! Con Mis mensajes y con haberte hablado, te he escogido entre todos los hombres. ¡Coge, pues, lo que te doy y sé de los agradecidos!»\qt@no{144}}
\qt@newcmd\qurantrans@es@mxcix{Y le escribimos en las Tablas una exhortación sobre todo y una explicación detallada de todo. «Cógelas, pues, con fuerza y ordena a tu pueblo que coja lo mejor de ellas». Yo os haré ver la morada de los perversos.\qt@no{145}}
\qt@newcmd\qurantrans@es@mc{Apartaré de Mis signos a quienes se ensoberbezcan sin razón en la tierra. Sea cual sea el signo que ven, no creen en él. Si ven el camino de la buena dirección, no lo toman como camino, pero si ven el camino del descarrío, sí que lo toman como camino. Y esto es así porque han desmentido Nuestros signos y no han hecho caso de ellos.\qt@no{146}}
\qt@newcmd\qurantrans@es@mci{Vanas serán las obras de quienes desmintieron Nuestros signos y la existencia de la otra vida. ¿Podrán ser retribuidos por otra cosa que por lo que hicieron?\qt@no{147}}
\qt@newcmd\qurantrans@es@mcii{Y el pueblo de Moisés, ido éste, hizo un ternero de sus aderezos, un cuerpo que mugía. ¿Es que no vieron que no les hablaba ni les dirigía? Lo cogieron y obraron impíamente.\qt@no{148}}
\qt@newcmd\qurantrans@es@mciii{Y, cuando se arrepintieron y vieron que se habían extraviado, dijeron: «Si nuestro Señor no se apiada de nosotros y nos perdona, seremos, ciertamente, de los que pierden».\qt@no{149}}
\qt@newcmd\qurantrans@es@mciv{Y, cuando Moisés regresó a su pueblo, airado y dolido, dijo: «¡Qué mal os habéis portado, luego de irme y dejaros! ¿Es que queréis adelantar el juicio de vuestro Señor?» Y arrojó las Tablas y, cogiendo de la cabeza a su hermano, lo arrastró hacia sí. Dijo: «¡Hijo de mi madre! La gente me ha humillado y casi me mata. ¡No hagas, pues, que los enemigos se alegren de mi desgracia! ¡No me pongas con el pueblo impío!»\qt@no{150}}
\qt@newcmd\qurantrans@es@mcv{Dijo: «¡Señor! ¡Perdónanos a mí y a mi hermano, e introdúcenos en Tu misericordia! Tú eres la Suma Misericordia».\qt@no{151}}
\qt@newcmd\qurantrans@es@mcvi{A quienes cogieron el ternero les alcanzará la ira de su Señor y la humillación en la vida de acá. Así retribuiremos a los que inventan.\qt@no{152}}
\qt@newcmd\qurantrans@es@mcvii{Con quienes, habiendo obrado mal, luego se arrepientan y crean, tu Señor será, sí, indulgente, misericordioso.\qt@no{153}}
\qt@newcmd\qurantrans@es@mcviii{Cuando se calmó la ira de Moisés cogió las Tablas. Su texto contiene dirección y misericordia para quienes temen a su Señor.\qt@no{154}}
\qt@newcmd\qurantrans@es@mcix{Moisés eligió de su pueblo a setenta hombres para asistir a Nuestro encuentro. Cuando les sorprendió el Temblor dijo: «¡Señor! Si hubieras querido, les habrías hecho perecer antes y a mí también. ¿Vas a hacernos perecer por lo que han hecho los tontos de nuestro pueblo? Esto no es más que una prueba Tuya, que Te sirve para extraviar o dirigir a quien quieres. ¡Tú eres nuestro Amigo! Perdónanos, pues, y apiádate de nosotros! Nadie perdona tan bien como Tú.\qt@no{155}}
\qt@newcmd\qurantrans@es@mcx{Destínanos bien en la vida de acá y en la otra. Nos hemos vuelto a Ti». Dijo: «Inflijo Mi castigo a quien quiero, pero Mi misericordia es omnímoda». Destinaré a ella a quienes teman a Alá y den el azaque y a quienes crean en Nuestros signos.\qt@no{156}}
\qt@newcmd\qurantrans@es@mcxi{a quienes sigan al Enviado, el Profeta de los gentiles, a quien ven mencionado en sus textos: en la Tora y en el Evangelio, que les ordena lo que está bien y les prohíbe lo que está mal, les declara lícitas las cosas buenas e ilícitas las impuras, y les libera de sus cargas y de las cadenas que sobre ellos pesaban. Los que crean en él, le sostengan y auxilien, los que sigan la Luz enviada abajo con él, ésos prosperarán.\qt@no{157}}
\qt@newcmd\qurantrans@es@mcxii{Di: «¡Hombres Yo soy el Enviado de Alá a todos vosotros, de Aquél a Quien pertenece el dominio de los cielos y de la tierra. No hay más dios que Él. Él da la vida y da la muerte. ¡Creed, pues, en Alá y en su Enviado, el Profeta de los gentiles, que cree en Alá y en Sus palabras! ¡Y seguidle! Quizás, así, seáis bien dirigidos».\qt@no{158}}
\qt@newcmd\qurantrans@es@mcxiii{En el pueblo de Moisés había una comunidad que se dirigía según la Verdad, y que, gracias a ella, observaba la justicia.\qt@no{159}}
\qt@newcmd\qurantrans@es@mcxiv{Los dividimos en doce tribus, como comunidades. Cuando el pueblo pidió agua a Moisés, inspiramos a éste «¡Golpea la roca con tu vara!». Y brotaron de ella doce manantiales. Todos sabían de cuál debían beber. Hicimos que se les nublara y les enviamos de lo alto el maná y las codornices: «¡Comed de las cosas buenas de que os hemos proveído.» Y no fueron injustos con Nosotros, sino que lo fueron consigo mismos.\qt@no{160}}
\qt@newcmd\qurantrans@es@mcxv{Y cuando se les dijo: «Habitad en esta ciudad y comed cuanto queráis de lo que en ella haya. Decid '¡Perdón!' ¡Entrad por la puerta prosternándoos! Os perdonaremos vuestros pecados y daremos más a los que hagan el bien».\qt@no{161}}
\qt@newcmd\qurantrans@es@mcxvi{Pero los impíos de ellos cambiaron por otras las palabras ¡que se les habían dicho y les enviamos un castigo del cielo por haber obrado impíamente.\qt@no{162}}
\qt@newcmd\qurantrans@es@mcxvii{Y pregúntales por aquella ciudad, a orillas del mar, cuyos habitantes violaban el sábado. Los sábados venían a ellos los peces a flor de agua y los otros días no venían a ellos. Les probamos así por haber obrado perversamente.\qt@no{163}}
\qt@newcmd\qurantrans@es@mcxviii{Y cuando unos dijeron: «¿Por qué exhortáis a un pueblo que Alá va a hacer perecer o a castigar severamente?» Dijeron: «Para que vuestro Señor nos disculpe. Quizás, así teman a Alá».\qt@no{164}}
\qt@newcmd\qurantrans@es@mcxix{Y, cuando hubieron olvidado lo que se les había recordado, salvamos a quienes habían prohibido el mal e infligimos un mal castigo a los impíos, por haber obrado perversamente.\qt@no{165}}
\qt@newcmd\qurantrans@es@mcxx{Y, cuando desatendieron las prohibiciones, les dijimos: «¡Convertíos en monos repugnantes!»\qt@no{166}}
\qt@newcmd\qurantrans@es@mcxxi{Y cuando tu Señor anunció que enviaría, ciertamente, contra ellos hasta el día de la Resurrección a gente que les impusiera un duro castigo. Ciertamente, tu Señor es rápido en castigar, pero también es indulgente, misericordioso.\qt@no{167}}
\qt@newcmd\qurantrans@es@mcxxii{Los dividimos en la tierra en comunidades. De ellos, había unos que eran justos y otros que no. Les probamos con bendiciones e infortunios. Quizás, así, se convirtieran.\qt@no{168}}
\qt@newcmd\qurantrans@es@mcxxiii{Sus sucesores, habiendo heredado la Escritura, se apoderan de los bienes de este mundo, diciendo: «Ya se nos perdonará». Y si se les ofrecen otros bienes, semejantes a los primeros, se apoderan también de ellos. ¿No se concertó con ellos el pacto de la Escritura , según el cual no dirían nada contra Alá sino la verdad? Y eso que han estudiado cuanto en ella hay... Pero la Morada Postrera es mejor para quienes temen a Alá - ¿es que no razonáis?-,\qt@no{169}}
\qt@newcmd\qurantrans@es@mcxxiv{para los que se aferran a la Escritura y hacen la azalá. No dejaremos de remunerar a quienes obren bien.\qt@no{170}}
\qt@newcmd\qurantrans@es@mcxxv{Y cuando sacudimos la montaña sobre ellos como si hubiera sido un pabellón y creyeron que se les venía encima: «¡Coged con fuerza lo que os hemos dado y recordad bien su contenido! Quizás, así, temáis a Alá».\qt@no{171}}
\qt@newcmd\qurantrans@es@mcxxvi{Y cuando tu Señor sacó de los riñones de los hijos de Adán a su descendencia y les hizo atestiguar contra sí mismos: «¿No soy yo vuestro Señor?» Dijeron: «¡Claro que sí, damos fe!» No sea que dijerais el día de la Resurrección: «No habíamos reparado en ello».\qt@no{172}}
\qt@newcmd\qurantrans@es@mcxxvii{O que dijerais: «Nuestros padres eran ya asociadores y nosostros no somos más que sus descendientes. ¿Vas a hacernos perecer por lo que los falsarios han hecho?»\qt@no{173}}
\qt@newcmd\qurantrans@es@mcxxviii{Así explicamos las aleyas. Quizás así se conviertan.\qt@no{174}}
\qt@newcmd\qurantrans@es@mcxxix{Cuéntales lo que pasó con aquél a quien dimos Nuestros signos y se deshizo de ellos. El Demonio le persiguió y fue de los descarriados.\qt@no{175}}
\qt@newcmd\qurantrans@es@mcxxx{Si hubiéramos querido, le habríamos levantado con ellos. Pero se apegó a la tierra y siguió su pasión. Pasó con él como pasa con el perro: jadea lo mismo si le atacas que si le dejas en paz. Así es la gente que desmiente Nuestros signos. Cuéntales estas cosas. Quizás, así, reflexionen.\qt@no{176}}
\qt@newcmd\qurantrans@es@mcxxxi{¡Qué mal ejemplo da la gente que desmiente Nuestros signos y es injusta consigo misma!\qt@no{177}}
\qt@newcmd\qurantrans@es@mcxxxii{Aquél a quien Alá dirige está en el buen camino. Aquéllos, en cambio, a quienes Él extravía, son los que pierden.\qt@no{178}}
\qt@newcmd\qurantrans@es@mcxxxiii{Hemos creado para la gehena a muchos de los genios y de los hombres. Tienen corazones con los que no comprenden, ojos con los que no ven, oídos con los que no oyen. Son como rebaños. No, aún más extraviados. Esos tales son los que no se preocupan.\qt@no{179}}
\qt@newcmd\qurantrans@es@mcxxxiv{Alá posee los nombres más bellos. Empléalos, pues, para invocarle y apártate de quienes los profanen, que serán retribuidos con arreglo a sus obras.\qt@no{180}}
\qt@newcmd\qurantrans@es@mcxxxv{Entre nuestras criaturas hay una comunidad que se dirige según la Verdad y que, gracias a ella, observa la justicia.\qt@no{181}}
\qt@newcmd\qurantrans@es@mcxxxvi{A quienes desmientan Nuestos signos les conduciremos paso a paso, sin que sepan como.\qt@no{182}}
\qt@newcmd\qurantrans@es@mcxxxvii{Y les concedo una prórroga. Mi estratagema es segura.\qt@no{183}}
\qt@newcmd\qurantrans@es@mcxxxviii{¿No reflexionan? Su paisano no es un poseso. Es sólo un monitor que habla claro.\qt@no{184}}
\qt@newcmd\qurantrans@es@mcxxxix{¿No han considerado el reino de los cielos y de la tierra y todo lo que Alá ha creado? ¿Y que tal vez se acerque su fin? ¿En qué anuncio, después de éste, van a creer?\qt@no{185}}
\qt@newcmd\qurantrans@es@mcxl{Aquél a quien Alá extravía, no podrá encontrar quien le dirija. Él les dejará que yerren ciegos en su rebeldía.\qt@no{186}}
\qt@newcmd\qurantrans@es@mcxli{Te preguntan por la Hora: «¿Cuándo llegará?» Di: «Sólo mi Señor tiene conocimiento de ella. Nadie sino Él la manifestará a su tiempo. Abruma en los cielos y en la tierra. No vendrá a vosotros sino de repente»,. Te preguntan a ti como si estuvieras bien enterado. Di: «Sólo Alá tiene conocimiento de ella». Pero la mayoría de los hombres no saben.\qt@no{187}}
\qt@newcmd\qurantrans@es@mcxlii{Di: «Yo no dispongo de nada que pueda aprovecharme o dañarme sino tanto cuanto Alá quiera. Si yo conociera lo oculto, abundaría en bienes y no me alcazaría el mal. Pero no soy sino un monitor, un nuncio de buenas nuevas para gente que cree».\qt@no{188}}
\qt@newcmd\qurantrans@es@mcxliii{Él es Quien os ha creado de una sola persona, de la que ha sacado a su cónyuge para que encuentre quietud en ella. Cuando yació con ella, ésta llevó una carga ligera, con la que iba de acá para allá; pero cuando se sintió pesada, invocaron ambos a Alá, su Señor. «Si nos das un hijo bueno, seremos, ciertamente, de los agradecidos.\qt@no{189}}
\qt@newcmd\qurantrans@es@mcxliv{Pero, cuando les dio uno bueno, pusieron a Alá asociados en lo que Él les había dado. ¡Y Alá está por encima de lo que Le asocian!\qt@no{190}}
\qt@newcmd\qurantrans@es@mcxlv{¿Le asocian dioses que no crean nada -antes bien, ellos mismos han sido creados-\qt@no{191}}
\qt@newcmd\qurantrans@es@mcxlvi{y que no pueden ni auxiliarles a ellos ni auxiliarse a sí mismos?\qt@no{192}}
\qt@newcmd\qurantrans@es@mcxlvii{Si les llamáis a la Dirección, no os siguen. Les da lo mismo que les llaméis o no.\qt@no{193}}
\qt@newcmd\qurantrans@es@mcxlviii{Aquéllos a quienes invocáis, en lugar de invocar a Alá, son siervos como vosotros. ¡Invocadles, pues, y que os escuchen, si es verdad lo que decís...!\qt@no{194}}
\qt@newcmd\qurantrans@es@mcxlix{¿Tienen pies para andar, manos para asir, ojos para ver, oídos para oír? Di: «¡Invocad a vuestros asociados y urdid algo contra mí! ¡No me hagáis esperar!\qt@no{195}}
\qt@newcmd\qurantrans@es@mcl{Mi amigo es Alá, Que ha revelado la Escritura y Que elige a los justos como amigos.\qt@no{196}}
\qt@newcmd\qurantrans@es@mcli{Y los que vosotros invocáis, en lugar de invocarle a Él, no pueden auxiliaros a vosotros ni auxiliarse a sí mismos».\qt@no{197}}
\qt@newcmd\qurantrans@es@mclii{¡Si les llamáis a la Dirección, no oyen. Les ves que te miran sin verte.\qt@no{198}}
\qt@newcmd\qurantrans@es@mcliii{¡Sé indulgente, prescribe el bien y apártate de los ignorantes!\qt@no{199}}
\qt@newcmd\qurantrans@es@mcliv{Si el Demonio te incita al mal, busca refugio en Alá. Él todo lo oye, todo lo sabe.\qt@no{200}}
\qt@newcmd\qurantrans@es@mclv{Cuando los que temen a Alá sufren una aparición del Demonio, se dejan amonestar y ven claro.\qt@no{201}}
\qt@newcmd\qurantrans@es@mclvi{A sus hermanos, en cambio, persisten en mantenerles descarriados.\qt@no{202}}
\qt@newcmd\qurantrans@es@mclvii{Y si no les traes un signo, dicen: «¡Cómo! ¿Por qué no te has escogido uno?» Di: «Yo no hago más que seguir lo que mi Señor me revela». Ésas son pruebas visibles de vuestro Señor, dirección y misericordia para gente que cree.\qt@no{203}}
\qt@newcmd\qurantrans@es@mclviii{Y, cuando se recite el Corán, ¡escuchadlo en silencio! Quizás así se os tenga piedad.\qt@no{204}}
\qt@newcmd\qurantrans@es@mclix{Invoca a tu Señor en tu interior, humilde y temerosamente, a media voz, mañana y tarde, y no seas de los despreocupados.\qt@no{205}}
\qt@newcmd\qurantrans@es@mclx{Los que están junto a tu Señor no tienen a menos servirle. Le glorifican y se prosternan ante Él.\qt@no{206}}
\qt@newcmd\qurantrans@es@mclxi{\basmalahes Te preguntan por el botín. Di: «El botín pertenece a Alá y al Enviado». ¡Temed, pues, a Alá! ¡Manteneos en paz! ¡Obedeced a Alá y a Su Enviado si sois creyentes!\qt@no{1}}
\qt@newcmd\qurantrans@es@mclxii{Son creyentes sólo aquéllos cuyos corazones tiemblan a la mención de Alá, que, cuando se les recitan Sus aleyas, éstas aumentan su fe, que confían en su Señor,\qt@no{2}}
\qt@newcmd\qurantrans@es@mclxiii{que hacen la azalá y dan limosna de lo que les hemos proveído.\qt@no{3}}
\qt@newcmd\qurantrans@es@mclxiv{Éstos son los creyentes de verdad. Gozarán de elevada categoría junto a su Señor, de perdón y generoso sustento.\qt@no{4}}
\qt@newcmd\qurantrans@es@mclxv{Igual que algunos creyentes se oponían cuando tu Señor te sacaba con razón de tu casa,\qt@no{5}}
\qt@newcmd\qurantrans@es@mclxvi{así ahora disputan contigo sobre la Verdad, luego de haberse ésta mostrado claramente, como si fueran arrastrados a la muerte, conscientes de ello.\qt@no{6}}
\qt@newcmd\qurantrans@es@mclxvii{Y cuando Alá os prometió que uno de los dos grupos caería en vuestro poder y deseasteis que fuera el inerme, cuando lo que Alá quería era hacer triunfar la Verdad con Sus palabras y extirpar a los infieles,\qt@no{7}}
\qt@newcmd\qurantrans@es@mclxviii{para hacer triunfar la Verdad y aniquilar lo falso, a despecho de los pecadores.\qt@no{8}}
\qt@newcmd\qurantrans@es@mclxix{Cuando pedisteis auxilio a vuestro Señor y Él os escuchó: «Os reforzaré con mil ángeles uno tras otro».\qt@no{9}}
\qt@newcmd\qurantrans@es@mclxx{Alá no lo hizo sino como buena nueva y para que se tranquilizaran vuestros corazones con ello. La victoria no viene sino de Alá. Alá es poderoso, sabio.\qt@no{10}}
\qt@newcmd\qurantrans@es@mclxxi{Cuando hizo que os entrara sueño, para daros sensación de seguridad venida de Él, e hizo que bajara del cielo agua para purificaros con ella y alejar la mancha del Demonio, para reanimaros y afirmar así vuestros pasos.\qt@no{11}}
\qt@newcmd\qurantrans@es@mclxxii{Cuando vuestro Señor inspiró a los ángeles: «Yo estoy con vosotros. ¡Confirmad, pues, a los que creen! Infundiré el terror en los corazones de quiens no crean. ¡Cortadles del cuello, pegadles en todos los dedos!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mclxxiii{Es que se habían separado de Alá y de Su Enviado... Y quien se separa de Alá y de Su Enviado... Alá castiga severamente.\qt@no{13}}
\qt@newcmd\qurantrans@es@mclxxiv{¡Ahí tenéis! ¡Gustadlo! Y que los infieles tendrán el castigo del Fuego.\qt@no{14}}
\qt@newcmd\qurantrans@es@mclxxv{¡Creyentes! Cuando os encontréis con los infieles marchando, ¡no les volváis la espalda!\qt@no{15}}
\qt@newcmd\qurantrans@es@mclxxvi{Quien ese día les vuelva la espalda -a menos que sea que se destaque para acudir a otro combate o para incorporarse a otra tropa- incurrirá en la ira de Alá y tendrá la gehena por morada. ¡Qué mal fin...!\qt@no{16}}
\qt@newcmd\qurantrans@es@mclxxvii{No erais vosotros quienes les mataban, era Alá Quien les mataba. Cuando tirabas, no eras tú quien tiraba, era Alá Quien tiraba, para hacer experimentar a los creyentes un favor venido de Él. Alá todo lo oye, todo lo sabe.\qt@no{17}}
\qt@newcmd\qurantrans@es@mclxxviii{¡Ahí tenéis! Y que Alá hará fracasar la artimaña de los infieles.\qt@no{18}}
\qt@newcmd\qurantrans@es@mclxxix{«Si buscáis un fallo, ahí lo tenéis. Más os valdría renunciar a vuestra hostilidad. Y, si reanudáis la lucha, Nosotros también la reanudaremos y vuestras huestes no os servirán de nada, por numerosas que sean. ¡Alá está con los creyentes!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mclxxx{«¡Creyentes! ¡Obedeced a Alá y a Su Enviado! ¡No le volváis la espalda mientras oís...!»\qt@no{20}}
\qt@newcmd\qurantrans@es@mclxxxi{No hagáis como los que dicen: «¡Ya hemos oído!», sin haber oído.\qt@no{21}}
\qt@newcmd\qurantrans@es@mclxxxii{Los seres peores, para Alá, son los sordomudos, que no razonan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mclxxxiii{Si Alá hubiera reconocido en ellos bien, les habría concedido la facultad de oír. Pero, aun así, habrían vuelto la espalda y se habrían apartado.\qt@no{23}}
\qt@newcmd\qurantrans@es@mclxxxiv{¡Creyentes! ¡Escuchad a Alá y al Enviado cuando éste os llama a algo que os da la vida! ¡Sabed que Alá se interpone entre el hombre y su corazón y que seréis congregados hacia Él!\qt@no{24}}
\qt@newcmd\qurantrans@es@mclxxxv{¡Guardaos de una tentación que no alcanzará exclusivamente a aquéllos de vosotros que sean impíos! ¡Sabed que Alá castiga severamente!\qt@no{25}}
\qt@newcmd\qurantrans@es@mclxxxvi{¡Y recordad cuando erais pocos, oprimidos en el país, temerosos de que la gente os capturara! Entonces, os procuró refugio, os fortaleció con Su auxilio y os proveyó de cosas buenas. Quizás, así, fuerais agradecidos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mclxxxvii{¡Creyentes! ¡No traicionéis a Alá y a Enviado! ¡No traicionéis, a sabiendas, la confianza puesta en vosotros!\qt@no{27}}
\qt@newcmd\qurantrans@es@mclxxxviii{Sabed que vuestra hacienda y vuestros hijos constituyen una tentación, pero también que Alá tiene junto a Sí una magnífica recompensa.\qt@no{28}}
\qt@newcmd\qurantrans@es@mclxxxix{¡Creyentes! Si teméis a Alá, Él os concederá un Criterio, borrará vuestras malas obras y os perdonará. Alá es el Dueño del favor inmenso.\qt@no{29}}
\qt@newcmd\qurantrans@es@mcxc{Y cuando los infieles intrigaban contra ti para capturarte, matarte o expulsarte. Intrigaban ellos e intrigaba Alá, pero Alá es el Mejor de los que intrigan.\qt@no{30}}
\qt@newcmd\qurantrans@es@mcxci{Y cuando se les recitaban Nuestras aleyas, decían: «¡Ya hemos oído! Si quisiéramos, diríamos algo parecido. Éstas no son sino patrañas de los antiguos».\qt@no{31}}
\qt@newcmd\qurantrans@es@mcxcii{Y cuando decían: «¡Alá! Si es esto la Verdad que de Ti procede, haz que nos lluevan piedras del cielo o inflígenos un castigo doloroso».\qt@no{32}}
\qt@newcmd\qurantrans@es@mcxciii{Pero Alá no les iba a castigar estando tú en medio de ellos. Alá no les iba a castigar mientras ellos pedían perdón.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcxciv{Y ¿por qué no va Alá a castigarles, si apartan de la Mezquita Sagrada? Ni tampoco son amigos de Él. Sólo son amigos Suyos los que Le temen, pero la mayoría no saben.\qt@no{34}}
\qt@newcmd\qurantrans@es@mcxcv{Su azalá en la Casa no consiste más que en silbidos y palmas. «¡Gustad, pues, el castigo merecido por no haber creído!»\qt@no{35}}
\qt@newcmd\qurantrans@es@mcxcvi{Los infieles gastan su hacienda en desviar a otros del camino de Alá. La gastarán y, después, se lamentarán. Luego, serán vencidos. Y los infieles serán congregados hacia la gehena.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcxcvii{para que Alá distinga al malo del bueno, coloque a los malos unos encima de otros, los amontone a todos y los eche a la gehena. Ésos serán los que pierdan.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcxcviii{Di a los infieles que, si cesan, se les perdonará lo pasado; pero que, si reinciden, seguirán la suerte de los antiguos.\qt@no{38}}
\qt@newcmd\qurantrans@es@mcxcix{Combatid contra ellos hasta que dejen de induciros a apostatar y se rinda todo el culto a Alá. Si cesan, Alá ve bien lo que hacen.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcc{Y, si vuelven la espalda, sabed que Alá es vuestro Protector. ¡Es un protector excelente, un auxiliar excelente!\qt@no{40}}
\qt@newcmd\qurantrans@es@mcci{Sabed que, si obtenéis algún botín un quinto corresponde a Alá, al Enviado y a sus parientes, a los huérfanos, a los pobres y al viajero, si creéis en Alá y en lo que hemos revelado a Nuestro siervo el día del Criterio, el día que se encontraron los dos ejércitos. Alá es omnipotente.\qt@no{41}}
\qt@newcmd\qurantrans@es@mccii{Cuando estabais en la ladera más próxima y ellos en la más lejana, mientras que la caravana estaba más baja que vosotros. Si hubierais intentado daros cita, no os habríais puesto de acuerdo sobre ella, pero para que Alá decidiera algo que debía hacerse. Para que, ante una prueba clara, pereciera quien debía perecer y, ante una prueba clara, sobreviviera quien debía sobrevivir. Alá todo lo oye, todo lo sabe.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcciii{Cuando, en tu sueño, Alá te los mostró poco numerosos; que, si te los hubiera mostrado numerosos, os habríais desanimado y habríais discutido sobre el particular, pero Alá os preservó. Él sabe bien lo que encierran los pechos.\qt@no{43}}
\qt@newcmd\qurantrans@es@mcciv{Y cuando Alá, al iniciarse el encuentro, os los mostró poco numerosos a vuestros ojos, igual que os empequeñeció a sus ojos, para que Alá decidiera algo que debía hacerse. Y todo será devuelto a Alá.\qt@no{44}}
\qt@newcmd\qurantrans@es@mccv{¡Creyentes! Cuando encontréis a una tropa ¡manteneos firmes y recordad mucho a Alá! ¡Quizás, así, consigáis la victoria!\qt@no{45}}
\qt@newcmd\qurantrans@es@mccvi{¡Y obedeced a Alá y a Su Enviado! ¡No discutáis! Si no, os desanimaréis y se enfriará vuestro ardor. ¡Tened paciencia, que Alá está con los pacientes!\qt@no{46}}
\qt@newcmd\qurantrans@es@mccvii{No seáis como los que salieron de sus casas con pompa y ostentación, desviando a otros del camino de Alá. Alá abarca lo que hacen.\qt@no{47}}
\qt@newcmd\qurantrans@es@mccviii{Y cuando el Demonio engalanó sus obras y dijo: «¡Nadie podrá venceros hoy, yo os protejo!» Pero, cuando las dos tropas se divisaron, dio media vuelta y dijo: «Yo no soy responsable de vosotros. Veo lo que vosotros no veis. Temo a Alá. Alá castiga severamente».\qt@no{48}}
\qt@newcmd\qurantrans@es@mccix{Cuando los hipócritas y los enfermos de corazón dijeron: «A éstos les ha engañado su religión». Pero quien confía en Alá... Alá es poderoso, sabio.\qt@no{49}}
\qt@newcmd\qurantrans@es@mccx{Si pudieras ver cuando los ángeles llamen a los que no han creído, golpeándoles en el rostro y en la espalda. Y: «¡Gustad el castigo del fuego de la gehena\qt@no{50}}
\qt@newcmd\qurantrans@es@mccxi{por las obras que habéis cometido, que Alá no es injusto con Sus siervos!»\qt@no{51}}
\qt@newcmd\qurantrans@es@mccxii{Como ocurrió a la gente de Faraón y a los que les precedieron: no creyeron en los signos de Alá y Alá les castigó por sus pecados. Alá es fuerte, castiga severamente.\qt@no{52}}
\qt@newcmd\qurantrans@es@mccxiii{Esto es así porque Alá no modifica la gracia que dispensa a un pueblo mientras éste no cambie lo que en sí tiene. Alá todo lo oye, todo lo sabe.\qt@no{53}}
\qt@newcmd\qurantrans@es@mccxiv{Como ocurrió a la gente de Faraón y a los que les precedieron: desmintieron los signos de su Señor y les hicimos perecer por sus pecados. Anegamos a la gente de Faraón: todos eran impíos.\qt@no{54}}
\qt@newcmd\qurantrans@es@mccxv{Los seres peores, para Alá, son los que, habiendo sido infieles en el pasado, se obstinan en su incredulidad,\qt@no{55}}
\qt@newcmd\qurantrans@es@mccxvi{que, habiendo tú concertado una alianza con ellos, la violan a cada momento sin temer a Alá.\qt@no{56}}
\qt@newcmd\qurantrans@es@mccxvii{Si, pues, das con ellos en la guerra, que sirva de escarmiento a los que les siguen. Quizás, así, se dejen amonestar.\qt@no{57}}
\qt@newcmd\qurantrans@es@mccxviii{Si temes una traición por parte de una gente, denuncia, con equidad, la alianza con ella. Alá no ama a los traidores.\qt@no{58}}
\qt@newcmd\qurantrans@es@mccxix{¡Que no crean los infieles que van a escapar! ¡No podrán!\qt@no{59}}
\qt@newcmd\qurantrans@es@mccxx{¡Preparad contra ellos toda la fuerza, toda la caballería que podáis para amedrentar al enemigo de Alá y vuestro y a otros fuera de ellos, que no conocéis pero que Alá conoce! Cualquier cosa que gastéis por la causa de Alá os será devuelta, sin que seáis tratados injustamente.\qt@no{60}}
\qt@newcmd\qurantrans@es@mccxxi{Si, al contrario, se inclinan hacia la paz, ¡inclínate tú también hacia ella! ¡Y confía en Alá! Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{61}}
\qt@newcmd\qurantrans@es@mccxxii{Si quieren engañarte, debe Alá bastarte. Él es Quien te ha fortalecido con Su auxilio y con los creyentes.\qt@no{62}}
\qt@newcmd\qurantrans@es@mccxxiii{cuyos corazones Él ha reconciliado. Tú, aunque hubieras gastado todo cuanto hay en la tierra, no habrías sido capaz de reconciliar sus corazones. Alá, en cambio, los ha reconciliado. Es poderoso, sabio.\qt@no{63}}
\qt@newcmd\qurantrans@es@mccxxiv{¡Profeta! ¡Que Alá te baste! ¡Y a los creyentes que te han seguido!\qt@no{64}}
\qt@newcmd\qurantrans@es@mccxxv{¡Profeta! ¡Anima a los creyentes al combate! Si hay entre vosotros veinte hombres tenaces, vencerán a doscientos. Y si cien, vencerán a mil infieles, pues éstos son gente que no comprende.\qt@no{65}}
\qt@newcmd\qurantrans@es@mccxxvi{Ahora, Alá os ha aliviado. Sabe que sois débiles. Si hay entre vosotros cien hombres tenaces, vencerán a docientos. Y si mil, vencerán a dos mil, con permiso de Alá. Alá está con los tenaces.\qt@no{66}}
\qt@newcmd\qurantrans@es@mccxxvii{No está bien que un profeta tenga cautivos mientras no someta en la tierra. Vosotros queréis lo que la vida de acá ofrece, en tanto que Alá quiere la otra vida. Alá es poderoso, sabio.\qt@no{67}}
\qt@newcmd\qurantrans@es@mccxxviii{Si no llega a ser por una prescripción previa de Alá, habríais sufrido un castigo terrible por haberos apoderado de aquello.\qt@no{68}}
\qt@newcmd\qurantrans@es@mccxxix{¡Tomad del botín hecho lo lícito, lo bueno! ¡Y temed a Alá! Alá es indulgente, misericordioso.\qt@no{69}}
\qt@newcmd\qurantrans@es@mccxxx{¡Profeta! Di a los cautivos que tengáis en vuestro poder: «Si Alá encuentra bien en vuestros corazones, os dará algo mejor de lo que se os ha quitado y os perdonará. Alá es indulgente, misericordioso».\qt@no{70}}
\qt@newcmd\qurantrans@es@mccxxxi{Y si quieren traicionarte, ya antes traicionaron a Alá. Y Él ha dado poder sobre ellos. Alá es omnisciente, sabio.\qt@no{71}}
\qt@newcmd\qurantrans@es@mccxxxii{Los creyentes que emigraron y combatieron con su hacienda y sus personas por la causa de Alá y los que les dieron refugio y auxilio, ésos son amigos unos de otros. Los creyentes que no emigraron no serán nada amigos hasta tanto que emigren. Si os piden que les auxiliéis en nombre de la religión, debéis auxiliarles, a menos que se trate de ir contra gente con la que os una un pacto. Alá ve bien lo que hacéis.\qt@no{72}}
\qt@newcmd\qurantrans@es@mccxxxiii{Los infieles son amigos unos de otros. Si no obráis así, habrá en la tierra desorden y gran corrupción.\qt@no{73}}
\qt@newcmd\qurantrans@es@mccxxxiv{Los creyentes que emigraron y lucharon por Alá, y quienes les dieron refugio y auxilio, ésos son los creyentes de verdad. Tendrán perdón y generoso sustento.\qt@no{74}}
\qt@newcmd\qurantrans@es@mccxxxv{Quienes, después, creyeron, emigraron y combatieron con vosotros, ésos son de los vuestros. Con todo, y según la Escritura de Alá, los unidos por lazos de consanguinidad están más cerca unos de otros. Alá es omnisciente.\qt@no{75}}
\qt@newcmd\qurantrans@es@mccxxxvi{\basmalahes Denuncia por Alá y Su Enviado de la alianza que habéis concertado con los asociadores:\qt@no{1}}
\qt@newcmd\qurantrans@es@mccxxxvii{«Circulad por la tierra durante cuatro meses. Pero sabed que no podréis escapar de Alá y que Alá llenará de vergüenza a los infieles».\qt@no{2}}
\qt@newcmd\qurantrans@es@mccxxxviii{Proclama de Alá y Su Enviado, dirigida a los hombres el día de la peregrinación mayor. «Alá no es responsable de los asociadores, y Su Enviado tampoco. Si os arrepentís será mejor para vosotros. Pero, si volvéis la espalda, sabed que no escaparéis de Alá». ¡Anuncia a los infieles un castigo doloroso!\qt@no{3}}
\qt@newcmd\qurantrans@es@mccxxxix{Se exceptúan los asociadores con quienes habéis concertado una alianza y no os han fallado en nada ni han ayudado a nadie contra vosotros. Respetad vuestra alianza con ellos durante el plazo convenido. Alá ama a quienes Le temen.\qt@no{4}}
\qt@newcmd\qurantrans@es@mccxl{Cuando hayan transcurrido los meses sagrados, matad a los asociadores dondequiera que les encontréis. ¡Capturadles! ¡Sitiadles! ¡Tendedles emboscadas por todas partes! Pero si se arrepienten, hacen la azalá y dan el azaque, entonces ¡dejadles en paz! Alá es indulgente, misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mccxli{Si uno de los asociadores te pide protección concédesela, para que oiga la Palabra de Alá. Luego, facilítale la llegada a un lugar en que esté seguro. Es que son gente que no sabe.\qt@no{6}}
\qt@newcmd\qurantrans@es@mccxlii{¿Cómo podrán los asociadores concertar una alianza con Alá y con Su Enviado, a no ser aquéllos con quienes concertasteis una alianza junto a la Mezquita Sagrada? Mientras cumplan con vosotros, cumplid con ellos. Alá ama a quienes Le temen.\qt@no{7}}
\qt@newcmd\qurantrans@es@mccxliii{¿Cómo si, cuando os vencen, no respetan alianza ni compromiso con vosotros? Os satisfacen con la boca, pero sus corazones se oponen y la mayoría son unos perversos.\qt@no{8}}
\qt@newcmd\qurantrans@es@mccxliv{Han malvendido los signos de Alá y han desviado a otros de Su camino. ¡Qué detestable es lo que han hecho!\qt@no{9}}
\qt@newcmd\qurantrans@es@mccxlv{No respetan alianza ni compromiso con el creyente. ¡ ésos son los que violan la ley!\qt@no{10}}
\qt@newcmd\qurantrans@es@mccxlvi{Pero si se arrepienten, hacen la azalá y dan el azaque, entonces serán vuestros hermanos en religión. Exponemos claramente las aleyas a gente que sabe.\qt@no{11}}
\qt@newcmd\qurantrans@es@mccxlvii{Pero, si violan sus juramentos después de haber concluido una alianza y atacan vuestra religión, combatid contra los jefes de la incredulidad. No respetan ningún juramento. Quizás, así, desistan.\qt@no{12}}
\qt@newcmd\qurantrans@es@mccxlviii{¿Cómo no vais a combatir contra gente que ha violado su juramento, que hubiera preferido expulsar al Enviado y os atacó primero? ¿Les tenéis miedo, siendo así que Alá tiene más derecho a que Le tengáis miedo? Si es que sois creyentes...\qt@no{13}}
\qt@newcmd\qurantrans@es@mccxlix{¡Combatid contra ellos! Alá le castigará a manos vuestras y les llenará de vergüenza, mientras que a vosotros os auxiliará contra ellos, curando así los pechos de gente creyente\qt@no{14}}
\qt@newcmd\qurantrans@es@mccl{y desvaneciendo la ira de sus corazones. Alá se vuelve hacia quien Él quiere. Alá es omnisciente, sabio.\qt@no{15}}
\qt@newcmd\qurantrans@es@mccli{¿O es que habéis creído que se os iba a dejar en paz y que Alá aún no conoce a quienes de vosotros han combatido sin trabar amistad con nadie, fuera de Alá, de Su Enviado y de los creyentes? Alá está bien informado de lo que hacéis.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcclii{Los asociadores no deben cuidar del mantenimiento de las mezquitas de Alá, siendo testigos contra sí mismos de su incredulidad. Ésos, ¡qué vanas son sus obras! ¡Estarán en el Fuego eternamente!\qt@no{17}}
\qt@newcmd\qurantrans@es@mccliii{.Que sólo cuide del mantenimiento de las mezquitas de Alá quien crea en Alá y en el último Día, haga la azalá, dé el azaque y no tenga miedo sino de Alá. Quizás ésos sean de los bien dirigidos...\qt@no{18}}
\qt@newcmd\qurantrans@es@mccliv{¿Vais a comparar al que da de beber a los peregrinos y cuida del mantenimiento de la Mezquita Sagrada con el que cree en Alá y en el último Día y lucha por Alá? No son iguales para Alá. Alá no dirige al pueblo impío.\qt@no{19}}
\qt@newcmd\qurantrans@es@mcclv{Quienes crean, emigren y luchen por Alá con su hacienda y sus personas tendrán una categoría más elevada junto a Alá. Ésos serán los que triunfen.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcclvi{Su Señor les anuncia Su misericordia y satisfacción, así, como jardines en los que gozarán de delicia sin fin,\qt@no{21}}
\qt@newcmd\qurantrans@es@mcclvii{en los que estarán eternamente, para siempre. Alá tiene junto a Sí una magnífica recompensa.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcclviii{¡Creyentes! No toméis como amigos a vuestros padres y a vuestros hermanos si prefieren la incredulidad a la fe. Quienes de vosotros les consideran amigos, ésos son los impíos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcclix{Di: «Si preferís vuestros padres, vuestros hijos varones, vuestros hermanos, vuestras esposas, vuestra tribu, la hacienda que habéis adquirido, un negocio por cuyo resultado teméis y casas que os placen, a Alá y a Su Enviado y a la lucha por Su causa, esperad a que venga Alá con Su orden...» Alá no dirige al pueblo perverso.\qt@no{24}}
\qt@newcmd\qurantrans@es@mcclx{Alá os ha ayudado a vencer en muchos sitios. Y el día de Hunayn, cuando, complacidos por vuestro gran número, éste no os sirvió de nada; cuando la tierra, a pesar de su vastedad, os resultó angosta y volvisteis la espalda para huir.\qt@no{25}}
\qt@newcmd\qurantrans@es@mcclxi{Alá, entonces, envió de los alto Su sakina sobre Su Enviado y sobre los creyentes. Hizo también descender legiones invisibles a vuestros ojos y castigó a los que no creían. Ésa es la retribución de los infieles.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcclxii{Pero, después de eso, Alá se volverá hacia quien Él quiera. Alá es indulgente, misericordioso.\qt@no{27}}
\qt@newcmd\qurantrans@es@mcclxiii{¡Creyentes! Los asociadores son mera impureza. ¡Que no se acerquen, pues, a la Mezquita Sagrada después de este su año! Si teméis escasez, Alá os enriquecerá por favor Suyo, si quiere. Alá es omnisciente, sabio.\qt@no{28}}
\qt@newcmd\qurantrans@es@mcclxiv{¡Combatid conta quienes, habiendo recibido la Escritura, no creen en Alá ni en el último Día, ni prohíben lo que Alá y Su Enviado han prohibido, ni practican la religión verdadera, hasta que, humillados, paguen el tributo directamente!\qt@no{29}}
\qt@newcmd\qurantrans@es@mcclxv{Los judíos dicen: «Uzayr es el hijo de Alá». Y los cristianos dicen: «El Ungido es el hijo de Alá». Eso es lo que dicen de palabra. Remedan lo que ya antes habían dicho los infieles. ¡Que Alá les maldiga! ¡Cómo pueden ser tan desviados!\qt@no{30}}
\qt@newcmd\qurantrans@es@mcclxvi{Han tomado a sus doctores y a sus monjes, así como al Ungido, hijo de María, como señores, en lugar de tomar a Alá cuando las órdenes que habían recibido no eran sino de servir a un Dios Uno. ¡No hay más dios que Él! ¡Gloria a Él! ¡Está por encima de lo que Le asocian!\qt@no{31}}
\qt@newcmd\qurantrans@es@mcclxvii{Quisieran apagar de un soplo la Luz de Alá pero Alá no desea sino que resplandezca, a despecho de los infieles.\qt@no{32}}
\qt@newcmd\qurantrans@es@mcclxviii{Él es Quien ha mandado a Su Enviado con la Dirección y con la religión verdadera para que, a despecho de los asociadores, prevalezca sobre toda otra religión.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcclxix{¡Creyentes! Muchos doctores y monjes devoran, sí, la hacienda ajena injustamente, desviando a otros del camino de Alá. A quienes atesoran oro y plata y no lo gastan por la causa de Alá, anúnciales un castigo doloroso,\qt@no{34}}
\qt@newcmd\qurantrans@es@mcclxx{el día que esos metales se pongan candentes en el fuego de la gehena y sus frentes, costados y espaldas sean marcados con ellos: «Esto es lo que atesorabais para vosotros. ¡Gustad, pues, lo que atesorabais!»\qt@no{35}}
\qt@newcmd\qurantrans@es@mcclxxi{El número de meses, para Alá, es de doce. Fueron inscritos en la Escritura de Alá el día que creó los cielos y la tierra. De ellos, cuatro son sagrados: ésa es la religión verdadera. ¡No seáis injustos con vosotros mismos no respetándolos! ¡Y combatid todos contra los asociadores como ellos también combaten todos contra vosotros! Y sabed que Alá está con los que Le temen.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcclxxii{El mes intercalar no significa más que un incremento en la incredulidad, con la que se extravían los infieles. Lo declaran profano un año y sagrado otro año, para estar de acuerdo con el número de lo que Alá ha declarado sagrado, declarando así profano lo que Alá ha declarado sagrado. La malicia de sus obras ha sido engalanada, pero Alá no dirige al pueblo infiel.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcclxxiii{¡Creyentes! ¿Qué os pasa? ¿Por qué, cuando se os dice: «¡Id a la guerra por la causa de Alá!» permanecéis clavados en tierra? ¿Preferís la vida de acá a la otra? Y ¿qué es el breve disfrute de la vidad de acá comparado con la otra, sino bien poco...?\qt@no{38}}
\qt@newcmd\qurantrans@es@mcclxxiv{Si no vais a la guerra, os infligirá un doloroso castigo. Hará que otro pueblo os sustituya, sin que podáis causarle ningún daño. Alá es omnipotente.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcclxxv{Si le negáis auxilio, Alá sí que le auxilió cuando, expulsado por los infieles, con un solo compañero, le decía a éste estando los dos en la cueva: «¡No estés triste! ¡Alá está con nosotros!» Alá hizo descender sobre él Su sakina y le reforzó con legiones invisibles a vuestros ojos. Alá puso Su Palabra por encima de la palabra de los infieles.. Alá es poderoso, sabio.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcclxxvi{¡Id a la guerra, tanto si os es fácil como si os es difícil! ¡Luchad por Alá con vuestra hacienda y vuestras personas! Es mejor para vosotros. Si supierais...\qt@no{41}}
\qt@newcmd\qurantrans@es@mcclxxvii{Si se hubiera tratado de una ventaja inmediata o de un viaje corto, te habrían seguido, pero el objetivo les ha parecido distante. Jurarán por Alá: «Si hubiéramos podido, os habríamos acompañado a la guerra». Se pierden a sí mismos. Alá sabe que mienten.\qt@no{42}}
\qt@newcmd\qurantrans@es@mcclxxviii{¡Que Alá te perdone! ¿Por qué les has dispensado antes de haber distinguido a los sinceros de los que mienten?\qt@no{43}}
\qt@newcmd\qurantrans@es@mcclxxix{Quienes creen en Alá y en el último Día no te piden dispensa cuando de luchar con su hacienda y sus personas se trata. Alá conoce bien a quienes Le temen.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcclxxx{Sólo te piden dispensa quienes no creen en Alá y en el último Día, aquéllos cuyos corazones están llenos de dudas y que, por dudar, vacilan.\qt@no{45}}
\qt@newcmd\qurantrans@es@mcclxxxi{Si hubieran querido ir a la guerra, se habrían preparado para ello, pero Alá no ha aprobado su marcha. Les ha infundido pereza y se les ha dicho: «¡Quedaos con los que se quedan!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mcclxxxii{Si os hubieran acompañado a la guerra, no habrían hecho más que aumentar la confusión y habrían sembrado la desconfianza entre vosotros, buscando soliviantaros. Hay entre vosotros quienes dan oídos a lo que dicen, pero Alá conoce bien a los impíos.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcclxxxiii{Ya buscaron antes soliviantar y enredaron bien tus asuntos hasta que vino la Verdad y apareció la orden de Alá, a despecho de ellos.\qt@no{48}}
\qt@newcmd\qurantrans@es@mcclxxxiv{Hay entre ellos quien dice: «Dispénsame y no me tientes!» Pero ¿es que no han caído ya en la tentación? La gehena, ciertamente, cercará a los infieles.\qt@no{49}}
\qt@newcmd\qurantrans@es@mcclxxxv{Si te sucede algo bueno, les duele, y, si te aflige una desgracia, dicen: «¡Ya hemos tomado nuestras precauciones!» Y se van tan contentos...\qt@no{50}}
\qt@newcmd\qurantrans@es@mcclxxxvi{Di: «Sólo podrá ocurrirnos lo que Alá nos haya predestinado. Él es nuestro Dueño. ¡Que los creyentes, pues, confíen en Alá!»\qt@no{51}}
\qt@newcmd\qurantrans@es@mcclxxxvii{Di: «Qué podéis esperar para nosotros sino una de las dos contingencias más bellas?» Nosotros, en cambio, esperamos que Alá os aflija con un castigo venido de Él o a manos nuestras. ¡Esperad, pues! Nosotros también esperamos con vosotros.\qt@no{52}}
\qt@newcmd\qurantrans@es@mcclxxxviii{Di: «Da lo mismo que deis limosna a gusto o a disgusto, pues no se os ha de aceptar, ya que sois gente perversa».\qt@no{53}}
\qt@newcmd\qurantrans@es@mcclxxxix{Lo único que ha impedido que su limosna sea aceptada es que no creen en Alá ni en Su Enviado, no acuden a la azalá sino perezosamente y no dan limosna sino a disgusto.\qt@no{54}}
\qt@newcmd\qurantrans@es@mccxc{¡No te maravilles de su hacienda ni de sus hijos! Alá sólo quiere con ello castigarles en la vida de acá y que exhalen su último suspiro siendo infieles.\qt@no{55}}
\qt@newcmd\qurantrans@es@mccxci{Juran por Alá que son, sí, de los vuestros, pero no lo son, sino que son gente que tiene miedo.\qt@no{56}}
\qt@newcmd\qurantrans@es@mccxcii{Si encontraran un refugio o cuevas o algún sitio donde poder esconderse irían allá a toda prisa.\qt@no{57}}
\qt@newcmd\qurantrans@es@mccxciii{Algunos de ellos te critican a propósito de las limosnas. Si se les da de ellas, están contentos; si no se les da de ellas, se enfadan.\qt@no{58}}
\qt@newcmd\qurantrans@es@mccxciv{Si quedaran satisfechos de lo que Alá y Su Enviado les han dado y dijeran: «¡Alá nos basta! Alá nos dará de Su favor y Su Enviado también. ¡Deseamos ardientemente a Alá!»...\qt@no{59}}
\qt@newcmd\qurantrans@es@mccxcv{Las limosnas son sólo para los necesitados, los pobres, los limosneros, aquéllos cuya voluntad hay que captar, los cautivos, los insolventes, la causa de Alá y el viajero. Es un deber impuesto por Alá. Alá es omnisciente, sabio.\qt@no{60}}
\qt@newcmd\qurantrans@es@mccxcvi{Hay entre ellos quienes molestan al Profeta y dicen: «¡Es todo oídos!» Di: «Por vuestro bien es todo oídos. Cree en Alá y tiene fe en los creyentes. Es misericordioso para aquéllos de vosotros que creen». Quienes molesten al Enviado de Alá, tendrán un castigo doloroso.\qt@no{61}}
\qt@newcmd\qurantrans@es@mccxcvii{Os juran por Alá por satisfaceros, pero Alá tiene más derecho, y Su Enviado también, a que Le satisfagan. Si es que son creyentes...\qt@no{62}}
\qt@newcmd\qurantrans@es@mccxcviii{¿No saben que quien se opone a Alá y a Su Enviado tendrá eternamente el Fuego de la gehena? ¡Qué enorme deshonra..!\qt@no{63}}
\qt@newcmd\qurantrans@es@mccxcix{Los hipócritas temen la revelación de una sura que les informe del contenido de sus corazones. Di: «¡Burlaos, que ya sacará Alá lo que teméis!»\qt@no{64}}
\qt@newcmd\qurantrans@es@mccc{Si les preguntas, dicen: «No hacíamos más que parlotear y bromear». Di: «¡Os burlabais de Alá, de Sus signos y de Su Enviado?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mccci{¡No os disculpéis! Habéis dejado de creer después de haber creído y, si perdonamos a alguno de vosotros, castigaremos a otros por haber sido pecadores.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcccii{Los hipócritas y las hipócritas son todos uno. Ordenan lo que está mal y prohíben lo que está bien. Cierran sus manos. Han olvidado a Alá y Él les ha olvidado. Los hipócritas son los perversos.\qt@no{67}}
\qt@newcmd\qurantrans@es@mccciii{Alá ha amenazado a los hipócritas, a las hipócritas y a los infieles con el fuego de la gehena, en el que estarán eternamente. Les bastará. ¡Qué Alá les maldiga! Tendrán un castigo permanente.\qt@no{68}}
\qt@newcmd\qurantrans@es@mccciv{Lo mismo les pasó a los que os precedieron. Eran más fuertes que vosotros, más ricos y tenían más hijos. Disfrutaron de su parte. Disfrutad vosotros también de vuestra parte, como vuestros antecesores disfrutaron de la suya. Habéis parloteado igual que ellos. Vanas fueron sus obras en la vida de acá y vanas lo serán en la otra. Ésos son los que pierden.\qt@no{69}}
\qt@newcmd\qurantrans@es@mcccv{¿No se han enterado de lo que pasó a quienes les precedieron: el pueblo de Noé, los aditas, los tamudeos, el pueblo de Abraham, los madianitas y los de las vueltas de arriba abajo? Sus enviados vinieron a ellos con las pruebas claras. No fue Alá quien fue injusto con ellos, sino que ellos lo fueron consigo mismos.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcccvi{Pero los creyentes y las creyentes son amigos unos de otros. Ordenan lo que está bien y prohíben lo que está mal. Hacen la azalá, dan el azaque y obedecen a Alá y a Su Enviado. De ésos se apiadará Alá. Alá es poderoso, sabio.\qt@no{71}}
\qt@newcmd\qurantrans@es@mcccvii{Alá ha prometido a los creyentes y a las creyentes jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, y viviendas agradables en los jardines del edén. Pero la satisfacción de Alá será mejor aún. ¡Ése el éxito grandioso!\qt@no{72}}
\qt@newcmd\qurantrans@es@mcccviii{¡Profeta! ¡Combate contra los infieles y los hipócritas, sé duro con ellos! Su refugio será la gehena. ¡Qué mal fin...!\qt@no{73}}
\qt@newcmd\qurantrans@es@mcccix{Juran por Alá que no han profesado la incredulidad, cuando la verdad es que sí. Han apostado después de haber abrazado el islam. Aspiraban a algo que no han conseguido y han quedado resentidos sólo por no haber obtenido más que aquello con que Alá y Su Enviado les han enriquecido, por favor Suyo. Sería mejor para ellos que se arrepintieran. Si vuelven la espalda, Alá les infligirá un castigo doloroso en la vida de acá y en la otra. No encontrarán en la tierra amigo ni auxiliar.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcccx{Algunos de ellos han concertado una alianza con Alá: «Si nos da algo de Su favor, sí que daremos limosna, sí que seremos de los justos».\qt@no{75}}
\qt@newcmd\qurantrans@es@mcccxi{Pero, cuando les da algo de Su favor, se muestran avaros de ello, vuelven la espalda y se van.\qt@no{76}}
\qt@newcmd\qurantrans@es@mcccxii{Así, ha infundido en su ánimo la hipocresía hasta el día que Le encuentren, por haber faltado a lo que habían prometido a Alá y por haber mentido.\qt@no{77}}
\qt@newcmd\qurantrans@es@mcccxiii{¿No saben que Alá conoce sus secretos y sus conciliábulos, y que Alá conoce a fondo las cosas ocultas?\qt@no{78}}
\qt@newcmd\qurantrans@es@mcccxiv{Son ellos los que critican, tanto a los creyentes que, espontáneamente, dan limosna, como a quienes sólo con un gran esfuerzo consiguen darla. Se burlan de ellos. También Alá se burlará de ellos y tendrán un castigo doloroso.\qt@no{79}}
\qt@newcmd\qurantrans@es@mcccxv{Da lo mismo que pidas o no que se les perdone. Aunque lo pidieras setenta veces, Alá no les perdonaría, porque no han creído en Alá y en Su Enviado. Alá no dirige al pueblo perverso.\qt@no{80}}
\qt@newcmd\qurantrans@es@mcccxvi{Los dejados atrás se alegraron de poder quedarse en casa en contra del Enviado de Alá. Les repugnaba luchar por Alá con su hacienda y sus personas y decían: «No vayáis a la guerra con este calor». Di: «El fuego de la gehena es aún más caliente». Si entendieran...\qt@no{81}}
\qt@newcmd\qurantrans@es@mcccxvii{¡Que rían, pues, un poco! Ya llorarán, y mucho, como retribución de lo que han cometido.\qt@no{82}}
\qt@newcmd\qurantrans@es@mcccxviii{Si Alá vuelve a llevarte a un grupo de ellos y te piden permiso para ir a la guerra, di: «¡No iréis nunca conmigo! ¡No combatiréis conmigo contra ningún enenmigo! Preferisteis una vez quedaros en casa. ¡Quedaos, pues, con los que se quedan detrás!»\qt@no{83}}
\qt@newcmd\qurantrans@es@mcccxix{¡No ores nunca por ninguno de ellos cuando muera, ni te detengas ante su tumba! No han creído en Alá y en Su Enviado y han muerto en su perversidad.\qt@no{84}}
\qt@newcmd\qurantrans@es@mcccxx{¡ No te maravilles de su hacienda y de sus hijos! Alá sólo quiere con ello castigarles en la vida de acá y que exhalen su último suspiro siendo infieles.\qt@no{85}}
\qt@newcmd\qurantrans@es@mcccxxi{Cuando se revela una sura: «¡Creed en Alá y combatid junto a Su Enviado», los más ricos de ellos te piden permiso y dicen: «¡Deja que nos quedemos con los que se quedan!»\qt@no{86}}
\qt@newcmd\qurantrans@es@mcccxxii{Prefieren quedarse con las mujeres dejadas detrás. Han sido sellados sus corazones, así que no entienden.\qt@no{87}}
\qt@newcmd\qurantrans@es@mcccxxiii{Pero el Enviado y los que con él creen combaten con su hacienda y sus personas. Suyas serán las cosas buenas. Ésos son los que prosperarán.\qt@no{88}}
\qt@newcmd\qurantrans@es@mcccxxiv{Alá les ha preparado jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente ¡Ése es el éxito grandioso.\qt@no{89}}
\qt@newcmd\qurantrans@es@mcccxxv{Los beduinos que se excusan vienen a que se les dé permiso. Los que mienten a Alá y a Su Enviado se quedan en casa. Un castigo doloroso alcanzará a los que de ellos no crean.\qt@no{90}}
\qt@newcmd\qurantrans@es@mcccxxvi{Si son sinceros para con Alá y con Su Enviado, no habrá nada que reprochar a los débiles, a los enfermos, a los que no encuentran los medios. No hay motivo contra los que obran con honradez. Alá es indulgente, misericordioso.\qt@no{91}}
\qt@newcmd\qurantrans@es@mcccxxvii{Tampoco contra aquéllos a quienes, viniendo a ti para que les facilites montura, dices: «No os encuentro montura» y se vuelven con los ojos arrasados de lágrimas de tristeza porque no encuentran los medios.\qt@no{92}}
\qt@newcmd\qurantrans@es@mcccxxviii{Sólo hay motivo contra los que, siendo ricos, te piden permiso. Prefieren quedarse con las mujeres dejadas detrás. Alá ha sellado sus corazones, así que no saben.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcccxxix{Se excusarán ante vosotros cuando volváis a ellos. Di: «¡No os excuséis! ¡No vamos a creeros! Alá ya nos ha informado acerca de vosotros. Alá y Su Enviado verán vuestras obras. Luego, se os devolverá al Conocedor de lo oculto y de lo patente y ya os informará Él de lo que hacíais».\qt@no{94}}
\qt@newcmd\qurantrans@es@mcccxxx{Cuando regreséis a ellos os pedirán, jurando por Alá, que les dejéis. Dejadles, pues, son una abominación. Su morada será la gehena como retribución de lo que han cometido.\qt@no{95}}
\qt@newcmd\qurantrans@es@mcccxxxi{Os conjuran que aceptéis sus excusas. Pero, si vosotros las aceptáis, Alá no las aceptará del pueblo perverso.\qt@no{96}}
\qt@newcmd\qurantrans@es@mcccxxxii{Los beduinos son los más infieles, los más hipócritas y los más propensos a ignorar las leyes contenidas en la revelación de Alá a Su Enviado. Alá es omnisciente, sabio.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcccxxxiii{Algunos beduinos consideran como onerosa obligación pecuniaria lo que gastan, y acechan vuestras vicisitudes. ¡Que sean ellos los que sufran un revés! Alá todo lo oye, todo lo sabe.\qt@no{98}}
\qt@newcmd\qurantrans@es@mcccxxxiv{Pero hay otros beduinos que creen en Alá y en el último Día y consideran lo que gastan y las oraciones del Enviado como medios de acercarse a Alá. ¿No es esto para ellos un medio de acercarse? Alá les introducirá en Su misericordia. Alá es indulgente, misericordioso.\qt@no{99}}
\qt@newcmd\qurantrans@es@mcccxxxv{Alá está satisfecho de los más distinguidos -los primeros de los emigrados y de los auxiliares-, y de quienes les siguieron en sus buenas obras. Ellos también estarán satisfechos de Él, Que les ha preparado jardines por cuyos bajos fluyen arroyos en los que estarán eternamente, para siempre. ¡Ése es el éxito grandioso!\qt@no{100}}
\qt@newcmd\qurantrans@es@mcccxxxvi{Entre los beduinos que os rodean y entre los medineses hay hipócritas que se obstinan en su hipocresía. Tú no les conoces, Nosotros les conocemos. Les castigaremos dos veces. Luego, serán enviados a un castigo terrible.\qt@no{101}}
\qt@newcmd\qurantrans@es@mcccxxxvii{Otros en cambio, reconocen sus pecados. Han mezclado obras buenas con otras malas. Tal vez Alá se vuelva a ellos. Alá es indulgente, misericordioso.\qt@no{102}}
\qt@newcmd\qurantrans@es@mcccxxxviii{¡Deduce de sus bienes una limosna para limpiarles y purificarles con ella! ¡Y ora por ellos! Tu oración les sosiega. Alá todo lo oye, todo lo sabe.\qt@no{103}}
\qt@newcmd\qurantrans@es@mcccxxxix{¿No saben que Alá es Quien acepta el arrepentimiento de Sus siervos y recibe las limosnas y que Alá es el Indulgente, el Misericordioso?\qt@no{104}}
\qt@newcmd\qurantrans@es@mcccxl{Di: «¡Allá vosotros! Alá verá vuestras obras, así como Su Enviado y los creyentes. Se os devolverá al Conocedor de lo oculto y de lo patente y ya os informará Él de lo que hacíais».\qt@no{105}}
\qt@newcmd\qurantrans@es@mcccxli{A otros se les hace esperar la decisión de Alá: castigo o misericordia. Alá es omnisciente, sabio.\qt@no{106}}
\qt@newcmd\qurantrans@es@mcccxlii{Quienes edificaron una mezquita con ánimo de dañar para ayuda de la incredulidad, para dividir a los creyentes y como refugio para quien había hecho antes la guerra a Alá y a Su Enviado, juran solemnemente: «¡No quisimos sino lo mejor!» Pero Alá es testigo de que mienten.\qt@no{107}}
\qt@newcmd\qurantrans@es@mcccxliii{¡No ores nunca en esa mezquita! Una mezquita fundada desde el primer día en el temor de Alá tiene más derecho a que ores en ella. La frecuentan hombres que gustan de purificarse y Alá ama a los que se purifican.\qt@no{108}}
\qt@newcmd\qurantrans@es@mcccxliv{¿Quién es mejor: quien ha cimentado su edificio en el temor de Alá y en Su satisfacción o quien lo ha cimentado al borde de una escarpa desgastada por la acción del agua y desmoronadiza, que se derrumba arrastrándole al fuego de la gehena? Alá no dirige al pueblo impío.\qt@no{109}}
\qt@newcmd\qurantrans@es@mcccxlv{El edificio que se han construido no dejará de ser motivo de duda en sus corazones, a menos que éstos se hagan pedazos. Alá es omnisciente, sabio.\qt@no{110}}
\qt@newcmd\qurantrans@es@mcccxlvi{Alá ha comprado a los creyentes sus personas y su hacienda, ofreciédoles, a cambio, el Jardín. Combaten por Alá: matan o les matan. Es una promesa que Le obliga, verdad, contenida en la Tora. en el Evangelio y en el Corán. Y ¿quién respeta mejor su alianza que Alá? ¡Regocijaos por el trato que habéis cerrado con É! ¡Ése es el éxito grandioso!\qt@no{111}}
\qt@newcmd\qurantrans@es@mcccxlvii{Quienes se arrepienten sirven a Alá, Le alaban, ayunan, se inclinan, se prosternan, ordenan lo que está bien y prohíben lo que está mal, observan las leyes de Alá... ¡Y anuncia la buena nueva a los creyentes!\qt@no{112}}
\qt@newcmd\qurantrans@es@mcccxlviii{El Profeta y los creyentes no deben pedir el perdón de los asociadores, aunque sean parientes suyos, después de haber visto claramente que morarán en el fuego de la gehena.\qt@no{113}}
\qt@newcmd\qurantrans@es@mcccxlix{El perdón que Abraham pidió para su padre no fue sino en virtud de una promesa que le había hecho; pero, cuando vio claramente que era enemigo de Alá, se desentendió de él. Abraham era, ciertamente, tierno, benigno.\qt@no{114}}
\qt@newcmd\qurantrans@es@mcccl{Alá, después de haber dirigido a un pueblo, no va a extraviarle sin antes haberle enseñado lo que debe temer. Alá es omnisciente.\qt@no{115}}
\qt@newcmd\qurantrans@es@mcccli{De Alá es el dominio de los cielos y de la tierra. Él da la vida y da la muerte. No tenéis, fuera de Alá, amigo ni auxiliar.\qt@no{116}}
\qt@newcmd\qurantrans@es@mccclii{Alá se ha vuelto al Profeta, a los emigrados y a los auxiliares, que le siguieron en una hora de apuro, luego de haberse casi desviado los corazones de algunos de ellos. Se ha vuelto, depués, a ellos. Alá es con ellos manso, misericordioso.\qt@no{117}}
\qt@newcmd\qurantrans@es@mcccliii{Y a los tres que fueron dejados atrás hasta que la tierra, a pesar de su vastedad, les resultó angosta, y sus espíritus se angustiaron también, y creyeron que no había más refugio contra Alá que Él mismo. Luego, se volvió a ellos para que se arrepintieran. Alá es el Indulgente, el Misericordioso.\qt@no{118}}
\qt@newcmd\qurantrans@es@mcccliv{¡Creyentes! Temed a Alá y estad con los sinceros.\qt@no{119}}
\qt@newcmd\qurantrans@es@mccclv{Los medineses y los beduinos que acampan a su alrededor no deben quedarse a la zaga del Enviado de Alá ni preferir el bienestar propio al de él. Si lo hacen así, no padecerán sed, ni fatiga, ni hambre por Alá. Todo suelo que pisen, para irritación de los infieles, y toda ventaja que obtengan sobre el enemigo, serán inscritos como obra buena. Alá no deja de remunerar a quienes hacen el bien.\qt@no{120}}
\qt@newcmd\qurantrans@es@mccclvi{No gastarán nada, ni poco ni mucho, no atravesarán valle alguno, que no quede todo inscrito en su favor, para que Alá les retribuya sólo por sus mejores obras.\qt@no{121}}
\qt@newcmd\qurantrans@es@mccclvii{No tienen por qué acudir todos los creyentes. Que de cada agrupación de ellos sólo algunos acudan a instruirse en la Religión, a fin de advertir a los suyos cuando regresen a ellos. Quizás, así tengan cuidado.\qt@no{122}}
\qt@newcmd\qurantrans@es@mccclviii{¡Creyentes! ¡Combatid contra los infieles que tengáis cerca! ¡Que os encuentren duros! ¡Sabed que Alá está con los que Le temen!\qt@no{123}}
\qt@newcmd\qurantrans@es@mccclix{Cuando se revela una sura, hay algunos de ellos que dicen: «Ésta ¿a quién de vosotros le ha aumentado la fe?» Se la aumenta a los que creen, y de ello se regocijan,\qt@no{124}}
\qt@newcmd\qurantrans@es@mccclx{mientras que a los enfermos de corazón les aumenta la mancha que ya tenían y mueren siendo infieles.\qt@no{125}}
\qt@newcmd\qurantrans@es@mccclxi{¿Es que no ven que se les prueba una o dos veces al año? Pero ni se arrepienten ni se dejan amonestar.\qt@no{126}}
\qt@newcmd\qurantrans@es@mccclxii{Y cuando se revela una sura, se miran unos a otros: «¿Os ve alguien?» Luego, se van. Alá ha desviado sus corazones, porque son gente que no entiende.\qt@no{127}}
\qt@newcmd\qurantrans@es@mccclxiii{Os ha venido un Enviado salido de vosotros. Le duele que sufráis, anhela vuestro bien. Con los creyentes es manso, misericordioso.\qt@no{128}}
\qt@newcmd\qurantrans@es@mccclxiv{Si te vuelven la espalda, di: «¡Alá me basta! ¡No hay más dios que Él! ¡En Él confío! ¡Él es el Señor del Trono augusto!»\qt@no{129}}
\qt@newcmd\qurantrans@es@mccclxv{\basmalahes 'lr. Éstas son las aleyas de la Escritura sabia.\qt@no{1}}
\qt@newcmd\qurantrans@es@mccclxvi{¿Se sorprenden los hombres de que hayamos revelado a uno de ellos: «Advierte a los hombres y anuncia a los creyentes la buena nueva de que, cuando se presenten a su Señor, tendrán una buena posición»? Los infieles dicen: «Éste es, sí, un mago manifiesto».\qt@no{2}}
\qt@newcmd\qurantrans@es@mccclxvii{Vuestro Señor es Alá, Que ha creado los cielos y la tierra en seis días. Luego, se ha instalado en el trono para disponerlo todo. Nadie puede interceder sin Su permiso. ¡Ése es Alá, vuestro Señor! ¡Servidle, pues! ¿Es que no os dejaréis amonestar?\qt@no{3}}
\qt@newcmd\qurantrans@es@mccclxviii{Todos volveréis a Él. ¡Promesa de Alá, verdad! Él inicia la creación y luego la repite, para remunerar con equidad a quienes han creído y obrado bien. En cuanto a quienes hayan sido infieles, se les dará a beber agua muy caliente y sufrirán un castigo doloroso por no haber creído.\qt@no{4}}
\qt@newcmd\qurantrans@es@mccclxix{Él es Quien ha hecho del sol claridad y de la luna luz, Quien ha determinado las fases de ésta para que sepáis el número de años y el cómputo. Alá no ha creado esto sino con un fin. Él explica los signos a gente que sabe.\qt@no{5}}
\qt@newcmd\qurantrans@es@mccclxx{En la sucesión de la noche y el día y en todo lo que Alá ha creado en los cielos y en la tierra hay, ciertamente, signos para gente que Le teme.\qt@no{6}}
\qt@newcmd\qurantrans@es@mccclxxi{Quienes no cuentan con encontrarnos y prefieren la vida de acá, hallando en ella quietud, así como quienes se despreocupan de Nuestros signos,\qt@no{7}}
\qt@newcmd\qurantrans@es@mccclxxii{tendrán el Fuego como morada por lo que han cometido.\qt@no{8}}
\qt@newcmd\qurantrans@es@mccclxxiii{A quienes hayan creído y obrado bien, su Señor les dirigirá por medio de su fe. A sus pies fluirán arroyos en los jardines de la Delicia.\qt@no{9}}
\qt@newcmd\qurantrans@es@mccclxxiv{Su invocación allí será: «¡Gloria a Ti, Alá!» Su saludo allí será: «¡Paz!» y terminarán con esta invocación: «¡Alabado sea Alá, Señor del universo!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mccclxxv{Si Alá precipitara el mal sobre los hombres con la misma premura con que éstos buscan su bienestar, habría ya llegado su fin. Dejamos, pues, a quienes no cuentan con encontrarnos que yerren ciegos en su rebeldía.\qt@no{11}}
\qt@newcmd\qurantrans@es@mccclxxvi{Cuando el hombre sufre una desgracia, Nos invoca, lo mismo si está echado que si está sentado o de pie. Pero, en cuanto le libramos de su desgracia, continúa su camino como si no Nos hubiera invocado por la desgracia que sufría. Así es como son engalanadas las obras de los inmoderados.\qt@no{12}}
\qt@newcmd\qurantrans@es@mccclxxvii{Antes de vosotros habíamos ya hecho perecer a generaciones que habían sido impías. Sus enviados les trajeron las pruebas claras, pero no estaban para creer. Así retribuimos al pueblo pecador.\qt@no{13}}
\qt@newcmd\qurantrans@es@mccclxxviii{Luego, os constituimos sucesores en la tierra, después de ellos, para ver cómo os portabais.\qt@no{14}}
\qt@newcmd\qurantrans@es@mccclxxix{Cuando se les recitan Nuestras aleyas como pruebas claras, quienes no cuentan con encontrarnos dicen: «¡Tráenos otro Corán o modifica éste!» Di: «No me toca a mí modificarlo por iniciativa propia. Lo único que hago es seguir lo que se me ha revelado. Temo, si desobedezco a mi Señor, el castigo de un día terrible».\qt@no{15}}
\qt@newcmd\qurantrans@es@mccclxxx{Di: «Si Alá hubiera querido, yo no os lo habría recitado y Él no os lo habría dado a conocer. Antes de él, he permanecido una vida con vosotros. ¿Es que no razonáis?»\qt@no{16}}
\qt@newcmd\qurantrans@es@mccclxxxi{¿Hay alguien que sea más impío que quien inventa una mentira contra Alá o desmiente Sus signos? Los pecadores no prosperarán.\qt@no{17}}
\qt@newcmd\qurantrans@es@mccclxxxii{En lugar de servir a Alá, sirven lo que no puede ni dañarles ni aprovecharles, y dicen: «¡Éstos son nuestros intercesores ante Alá!» Di: «¿Es que pretendéis informar a Alá de algo, en los cielos o en la tierra, que Él no sepa?» ¡Gloria a Él! ¡Está por encima de lo que Le asocian!\qt@no{18}}
\qt@newcmd\qurantrans@es@mccclxxxiii{La Humanidad no constituía sino una sola comunidad. Luego, discreparon entre sí y, si no llega a ser por una palabra previa de tu Señor, ya se habría decidido entre ellos sobre aquello en que discrepaban.\qt@no{19}}
\qt@newcmd\qurantrans@es@mccclxxxiv{Dicen: «¡Por qué no se le ha revelado un signo procedente de su Señor?» Di, pues: «Lo oculto pertenece sólo a Alá. ¡Esperad, pues! Yo también soy de los que esperan».\qt@no{20}}
\qt@newcmd\qurantrans@es@mccclxxxv{Apenas hacemos gustar a los hombres una misericordia, después de haber sufrido una desgracia, al punto intrigan contra Nuestros signos. Di: «¡Alá es más rápido en intrigar!» Nuestros enviados toman nota de vuestra intriga.\qt@no{21}}
\qt@newcmd\qurantrans@es@mccclxxxvi{Él es Quien os hace viajar por tierra o por mar. Cuando, navegando con viento favorable, contentos con él, se levanta un viento tempestuoso, azotan las olas por todas partes y creen llegada la hora de la muerte, invocan a Alá rindiéndole culto sincero. «Si nos salvas de ésta, seremos, ciertamente, de los agradecidos».\qt@no{22}}
\qt@newcmd\qurantrans@es@mccclxxxvii{Y apenas les salva, ya en tierra, al punto se insolentan injustamente. «¡Hombres! ¡Vuestra insolencia se volverá contra vosotros! Tendréis breve disfrute de la vida de acá. Luego, volveréis a Nosotros y ya os informaremos de lo que hacíais».\qt@no{23}}
\qt@newcmd\qurantrans@es@mccclxxxviii{La vida de acá es como agua que hacemos bajar del cielo. Las plantas de la tierra se empapan de ella y alimentan a los hombres y a los rebaños, hasta que, cuando la tierra se ha adornado y engalanado, y creen los hombres que ya la dominan, llega a ella Nuestra orden, de noche o de día, y la dejamos cual rastrojo, como si, la víspera, no hubiera estado floreciente. Así explicamos los signos a gente que reflexiona.\qt@no{24}}
\qt@newcmd\qurantrans@es@mccclxxxix{Alá invita a la Morada de la Paz y dirige a quien Él quiere a una vía recta.\qt@no{25}}
\qt@newcmd\qurantrans@es@mcccxc{Para quienes obren bien, lo mejor y más. Ni el polvo ni la humillación cubrirán sus rostros. Ésos morarán en el Jardín eternamente.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcccxci{A quienes obren mal, se les retribuirá con otro tanto. Les cubrirá la humillación -no tendrán quien les proteja de Alá-, como si jirones de tinieblas nocturnas cubrieran sus rostros. Ésos morarán en el Fuego eternamente.\qt@no{27}}
\qt@newcmd\qurantrans@es@mcccxcii{El día que les congreguemos a todos, diremos a los asociadores: «¡Quedaos donde estáis, vosotros y vuestros asociados!» Les separaremos a unos de otros y sus asocidos dirán: «¡No era a nosotros a quienes servíais!\qt@no{28}}
\qt@newcmd\qurantrans@es@mcccxciii{Alá basta como testigo entre nosotros y vosotros de que no hacíamos caso de vuestro servicio».\qt@no{29}}
\qt@newcmd\qurantrans@es@mcccxciv{Allí, cada uno experimentará de nuevo lo que hizo en vida. Serán devueltos a Alá, su verdadero Dueño, y se esfumarán sus invenciones.\qt@no{30}}
\qt@newcmd\qurantrans@es@mcccxcv{Di: «¿Quién os procura el sustento del cielo y de la tierra? ¿Quién dispone del oído y de la vista? ¿Quién saca al vivo del muerto y al muerto del vivo? ¿Quién lo dispone todo? Dirán: «¡Alá!» Di, pues: «¿Y no vais a temerle?»\qt@no{31}}
\qt@newcmd\qurantrans@es@mcccxcvi{Ése es Alá, vuestro verdadero Señor. Y ¿qué hay más allá de la Verdad, sino el extravío? ¡Cómo podéis, pues, ser tan desviados!\qt@no{32}}
\qt@newcmd\qurantrans@es@mcccxcvii{Así se ha cumplido la sentencia de tu Señor contra los perversos: no creerán.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcccxcviii{Di: «¿Hay alguno de vuestros asociados que inicie la creación y luego la repita?» Di: «Alá inicia la creación y luego la repite. ¡Cómo podéis, pues, ser tan desviados!»\qt@no{34}}
\qt@newcmd\qurantrans@es@mcccxcix{Di: «¿Hay algunos de vuestros asociados que dirija a la Verdad?» Di: «Alá dirige a la Verdad. ¿Quién tiene más derecho a ser seguido: quien dirige a la Verdad o quien no da con la buena dirección, a menos de ser dirigido? Pero ¿qué os pasa?, ¿qué manera de juzgar es ésa?»\qt@no{35}}
\qt@newcmd\qurantrans@es@mcd{Pero la mayoría no siguen sino conjeturas, y, ante la Verdad, las conjeturas no sirven de nada. Alá sabe bien lo que y hacen.\qt@no{36}}
\qt@newcmd\qurantrans@es@mcdi{Este Corán no puede haberlo inventado nadie fuera de Alá. No sólo eso, sino que viene a confirmar los mensajes anteriores y a explicar detalladamente la Escritura , exenta de dudas, que procede del Señor del universo.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcdii{O dicen: «Él lo ha inventado». Di: «Si es verdad lo que decís, ¡traed una sura semejante y llamad a quien podáis, en lugar de llamar a Alá!»\qt@no{38}}
\qt@newcmd\qurantrans@es@mcdiii{Al contrario, han desmentido lo que no abarcan en su ciencia y aquello cuya interpretación aún no han recibido. Así desmintieron sus antecesores. ¡Y mira cómo terminaron los impíos!\qt@no{39}}
\qt@newcmd\qurantrans@es@mcdiv{De ellos hay quien cree en él y quien no, pero tu Señor conoce mejor que nadie a los corruptores.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcdv{Si te desmienten, di: «Yo respondo de mis actos y vosotros de los vuestros. Vosotros no sois responsables de lo que yo haga y yo no soy responsable de lo que vosotros hagáis».\qt@no{41}}
\qt@newcmd\qurantrans@es@mcdvi{De ellos hay quienes te escuchan. Pero ¿puedes tú hacer que los sordos oigan, aun cuando no comprendan...?\qt@no{42}}
\qt@newcmd\qurantrans@es@mcdvii{De ellos hay quien te mira. Pero ¿puedes tú dirigir a los ciegos, aun cuando no vean...?\qt@no{43}}
\qt@newcmd\qurantrans@es@mcdviii{Alá no es nada injusto con los hombres, sino que son los hombres los injustos consigo mismos.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcdix{Y el día que les congregue, será como si no hubieran permanecido más de una hora del día. Se reconocerán. Perderán quienes hayan desmentido el encuentro de Alá. No fueron bien dirigidos.\qt@no{45}}
\qt@newcmd\qurantrans@es@mcdx{Lo mismo si te mostramos algo de aquello con que les amenazamos que si te llamamos, volverán a Nosotros. Luego, Alá será testigo de lo que hacían.\qt@no{46}}
\qt@newcmd\qurantrans@es@mcdxi{Cada comunidad tiene un enviado. Cuando venga su enviado, se decidirá entre ellos con equidad y no serán tratados injustamente.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcdxii{Dicen: «¿Cuándo se cumplirá esta amenaza, si es verdad lo que decís...?»\qt@no{48}}
\qt@newcmd\qurantrans@es@mcdxiii{Di: «Yo no tengo poder para dañarme ni para aprovecharme sino tanto cuanto Alá quiera. Cada comunidad tiene un plazo. Cuando vence su plazo, no pueden retrasarlo ni adelantarlo una hora».\qt@no{49}}
\qt@newcmd\qurantrans@es@mcdxiv{Di: «¿Qué os parece? Si os sorprendiera Su castigo de noche o de día, ¿querrían los pecadores aún adelantarlo?\qt@no{50}}
\qt@newcmd\qurantrans@es@mcdxv{¿Dejáis el creer en él para cuando ocurra? Creed ahora, cuando pedís adelantarlo».\qt@no{51}}
\qt@newcmd\qurantrans@es@mcdxvi{Se dirá a los impíos: «¡Gustad el castigo enterno! ¿Se os retribuye por otra cosa que por lo que habéis merecido?»\qt@no{52}}
\qt@newcmd\qurantrans@es@mcdxvii{Te pedirán información: «Entonces, eso ¿es verdad?» Di: «¡Sí, por mi Señor!, que es verdad y no podréis escapar».\qt@no{53}}
\qt@newcmd\qurantrans@es@mcdxviii{Todo impío que poseyera cuanto hay en la tierra, lo ofrecería como rescate. Disimularán su pena cuando vean el castigo. Se decidirá entre ellos con equidad y no serán tratados injustamente.\qt@no{54}}
\qt@newcmd\qurantrans@es@mcdxix{¿No es de Alá lo que está en los cielos y en la tierra? ¡Lo que Alá promete es verdad! Pero la mayoría no saben.\qt@no{55}}
\qt@newcmd\qurantrans@es@mcdxx{Él da la vida y da la muerte. Y seréis devueltos a Él.\qt@no{56}}
\qt@newcmd\qurantrans@es@mcdxxi{¡Hombres! Habéis recibido una exhortación procedente de vuestro Señor, remedio para los males de vuestros corazones, dirección y misericordia para los creyentes.\qt@no{57}}
\qt@newcmd\qurantrans@es@mcdxxii{Di: «¡Que se alegren del favor de Alá y de Su misericordia. Eso es mejor que lo que ellos amasan».\qt@no{58}}
\qt@newcmd\qurantrans@es@mcdxxiii{Di: «¿Habéis visto el sustento que Alá ha hecho bajar para vosotros? ¿Y habéis declarado esto lícito y aquello ilícito? ¿Es que Alá os lo ha permitido o lo habéis inventado contra Alá?»\qt@no{59}}
\qt@newcmd\qurantrans@es@mcdxxiv{El día de la Resurreción ¿qué pensarán los que inventaron la mentira contra Alá? Sí, Alá dispensa Su favor a los hombres, pero la mayoría no agradecen.\qt@no{60}}
\qt@newcmd\qurantrans@es@mcdxxv{En cualquier situación en que te encuentres, cualquiera que sea el pasaje que recites del Corán, cualquier cosa que hagáis, Nosotros somos testigos de vosotros desde su principio. A tu Señor no se Le pasa desapercibido el peso de un átomo en la tierra ni en el cielo. No hay nada, menor o mayor que eso, que no esté en una Escritura clara.\qt@no{61}}
\qt@newcmd\qurantrans@es@mcdxxvi{Ciertamente, los amigos de Alá no tienen que temer y no estarán tristes.\qt@no{62}}
\qt@newcmd\qurantrans@es@mcdxxvii{Creyeron y temieron a Alá.\qt@no{63}}
\qt@newcmd\qurantrans@es@mcdxxviii{Recibirán la buena nueva en la vida de acá y en la otra. No cabe alteración en las palabras de Alá. ¡Ése es el éxito grandioso!\qt@no{64}}
\qt@newcmd\qurantrans@es@mcdxxix{¡Que no te entristezca lo que digan! El poder pertenece, en su totalidad, a Alá. Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{65}}
\qt@newcmd\qurantrans@es@mcdxxx{¿No es, acaso, de Alá lo que está en los cielos y en la tierra? ¿Qué siguen, pues, quienes invocan a otros asociados, en lugar de invocar a Alá? No siguen sino conjeturas, no formulan sino hipótesis.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcdxxxi{Él es Quien ha dispuesto para vosotros la noche para que descanséis en ella, y el día para que podáis ver claro. Ciertamente, hay en ello signos para gente que oye.\qt@no{67}}
\qt@newcmd\qurantrans@es@mcdxxxii{Dicen: «Alá ha adoptado un hijo». ¡Gloria a Él! Él es Quien Se basta a Sí mismo. Suyo es lo que está en los cielos y en la tierra. ¡No tenéis ninguna autoridad para hablar así! ¿Decís contra Alá lo que no sabéis?\qt@no{68}}
\qt@newcmd\qurantrans@es@mcdxxxiii{Di: «Quienes inventen la mentira contra Alá no prosperarán».\qt@no{69}}
\qt@newcmd\qurantrans@es@mcdxxxiv{Tendrán breve disfrute en la vida de acá y, luego, volverán a Nosotros. Luego, les haremos gustar el castigo severo por no haber creído.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcdxxxv{Cuéntales la historia de Noé, cuando dijo a los suyos: «¡Pueblo! Si os molesta que esté entre vosotros y que os amoneste con los signos de Alá, yo confío en Alá. Aunaos, pues, con vuestros asociados y no os preocupéis más. ¡Decidid, luego, respecto a mí y no me hagáis esperar!»\qt@no{71}}
\qt@newcmd\qurantrans@es@mcdxxxvi{Pero, si dais media... Yo no os he pedido un salario. Mi salario incumbe sólo a Alá. He recibido la orden de ser de los que se someten a Alá.\qt@no{72}}
\qt@newcmd\qurantrans@es@mcdxxxvii{Le desmintieron, pero les salvamos a él y a quienes estaban con él en la nave, y les hicimos sucesores. Y anegamos a quienes desmintieron Nuestros signos. ¡Y mira cómo terminaron los que habían sido advertidos!\qt@no{73}}
\qt@newcmd\qurantrans@es@mcdxxxviii{Después de él, mandamos a otros enviados a sus pueblos, que les trajeron las pruebas claras, pero no estaban para creer en lo que antes habían desmentido. Así es como sellamos los corazones de los que violan la ley.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcdxxxix{Luego, después de ellos, enviamos a Moisés y a Aarón con Nuestros signos a Faraón y a sus dignatarios. Pero fueron altivos. Eran gente pecadora.\qt@no{75}}
\qt@newcmd\qurantrans@es@mcdxl{Cuando recibieron la Verdad, venida de Nosotros, dijeron: «¡Esto es, ciertamente, manifiesta magia!»\qt@no{76}}
\qt@newcmd\qurantrans@es@mcdxli{Moisés dijo: «¿Os atrevéis a tachar de magia la Verdad que habéis recibido?» Los magos no prosperarán.\qt@no{77}}
\qt@newcmd\qurantrans@es@mcdxlii{Dijeron: «¿Has venido a nosotros con objeto de apartarnos de lo que nuestros padres seguían, para que la dominación de la tierra pase a vosotros dos? ¡No tenemos fe en vosotros!»\qt@no{78}}
\qt@newcmd\qurantrans@es@mcdxliii{Faraón dijo: «¡Traedme acá a todo mago entendido!»\qt@no{79}}
\qt@newcmd\qurantrans@es@mcdxliv{Y cuando llegaron los magos, Moisés les dijo: «¡Tirad lo que vayáis a tirar!»\qt@no{80}}
\qt@newcmd\qurantrans@es@mcdxlv{Y cuando tiraron, dijo Moisés: «Lo que habéis traído es magia. Alá va a destruirlo. Alá no permite que prospere la obra de los corruptores.\qt@no{81}}
\qt@newcmd\qurantrans@es@mcdxlvi{Y Alá hace triunfar la Verdad con Sus palabras, a despecho de los pecadores».\qt@no{82}}
\qt@newcmd\qurantrans@es@mcdxlvii{Sólo una minoría de su pueblo creyó en Moisés, porque tenían miedo de que Faraón y sus dignatarios les pusieran a prueba. Ciertamente, Faraón se conducía altivamente en el país y era de los inmoderados.\qt@no{83}}
\qt@newcmd\qurantrans@es@mcdxlviii{Moisés dijo: «¡Pueblo! Si creéis en Alá, ¡confiad en Él! Si es que estáis sometidos a Él...»\qt@no{84}}
\qt@newcmd\qurantrans@es@mcdxlix{Dijeron: «¡Confiamos en Alá! ¡Señor! ¡No hagas de nosotros instrumentos de tentación para el pueblo impío!\qt@no{85}}
\qt@newcmd\qurantrans@es@mcdl{¡Sálvanos por Tu misericordia del pueblo infiel!»\qt@no{86}}
\qt@newcmd\qurantrans@es@mcdli{E inspiramos a Moisés y a su hermano: «¡Estableced casas para vuestro pueblo en Egipto y haced de vuestras casas lugares de culto! ¡Y haced la azalá!» ¡Y anuncia la buena nueva a los creyentes!\qt@no{87}}
\qt@newcmd\qurantrans@es@mcdlii{Moisés dijo: «¡Señor! Tú has dado a Faraón y a sus dignatarios lujo y bienes en la vida de acá para terminar, ¡Señor!. extraviando a otros de Tu camino. ¡Señor! ¡Borra sus bienes y endurece sus corazones a fin de que no crean hasta que vean el castigo doloroso!»\qt@no{88}}
\qt@newcmd\qurantrans@es@mcdliii{Dijo: «Vuestra plegaria ha sido escuchada. ¡Id los dos por la vía recta y no sigáis el camino de los que no saben!»\qt@no{89}}
\qt@newcmd\qurantrans@es@mcdliv{Hicimos que los Hijos de Israel atravesaran el mar. Faraón y sus tropas les persiguieron con espíritu de rebeldía y hostilidad hasta que, a punto de ahogarse, dijo: «¡Sí, creo que no hay más dios que Aquél en Quien los Hijos de Israel creen! Y soy de los que se someten a Él».\qt@no{90}}
\qt@newcmd\qurantrans@es@mcdlv{«¿Ahora? ¿Después de haber desobedecido y de haber sido de los corruptores?\qt@no{91}}
\qt@newcmd\qurantrans@es@mcdlvi{Esto no obstante, hoy te salvaremos en cuanto al cuerpo a fin de que seas signo para los que te sucedan». Son muchos, en verdad, los hombres que no se preocupan de Nuestros signos...\qt@no{92}}
\qt@newcmd\qurantrans@es@mcdlvii{Hemos instalado a los Hijos de Israel en un lugar bueno y les hemos proveído de cosas buenas. Y no discreparon sino después de haber recibido la Ciencia. Tu Señor decidirá entre ellos el día de la Resurrección sobre aquello en que discrepaban.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcdlviii{Si tienes alguna duda acerca de lo que te hemos revelado, pregunta a quienes, antes de ti, ya leían la Escritura. Te ha venido, de tu Señor, la Verdad. ¡No seas, pues, de los que dudan!\qt@no{94}}
\qt@newcmd\qurantrans@es@mcdlix{Y ¡guárdate de ser de los que desmienten los signos de Alá; si no, serás de los que pierden!\qt@no{95}}
\qt@newcmd\qurantrans@es@mcdlx{Aquéllos contra quienes se ha cumplido la sentencia de tu Señor no creerán,\qt@no{96}}
\qt@newcmd\qurantrans@es@mcdlxi{aunque reciban todos los signos, hasta que vean el castigo doloroso.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcdlxii{¿Por qué no ha habido ninguna ciudad que haya creído y a la que su fe haya aprovechado, fuera del pueblo de Jonás...? Cuando creyeron, les evitamos el castigo, vergonzoso en la vida de acá y les permitimos gozar aún por algún tiempo.\qt@no{98}}
\qt@newcmd\qurantrans@es@mcdlxiii{Si tu Señor hubiera querido, todos los habitantes de la tierra, absolutamente todos, habrían creído. Y ¿vas tú a forzar a los hombres a que sean creyentes,\qt@no{99}}
\qt@newcmd\qurantrans@es@mcdlxiv{siendo así que nadie está para creer si Alá no lo permite? Y Se irrita contra quienes no razonan.\qt@no{100}}
\qt@newcmd\qurantrans@es@mcdlxv{Di: «¡Mirad lo que está en los cielos y en la tierra!» Pero ni los signos ni las advertencias sirven de nada a gente que no cree.\qt@no{101}}
\qt@newcmd\qurantrans@es@mcdlxvi{¿Qué esperan, pues, sino días como los de quienes pasaron antes de ellos? Di: «¡Esperad! Yo también soy de los que esperan».\qt@no{102}}
\qt@newcmd\qurantrans@es@mcdlxvii{Luego, salvaremos a Nuestros enviados y a los que hayan creído. Salvar a los creyentes es deber Nuestro.\qt@no{103}}
\qt@newcmd\qurantrans@es@mcdlxviii{Di: «¡Hombres! Si dudáis de mi religión, yo no sirvo a quienes vosotros servís en lugar de servir a Alá, sino que sirvo a Alá, Que os llamará! ¡He recibido la orden de ser de los creyentes».\qt@no{104}}
\qt@newcmd\qurantrans@es@mcdlxix{Y: «¡Profesa la Religión como hanif y no seas asociador!»\qt@no{105}}
\qt@newcmd\qurantrans@es@mcdlxx{No invoques, en lugar de invocar a Alá, lo que no puede aprovecharte ni dañarte. Si lo hicieras, entonces, serías de los impíos.\qt@no{106}}
\qt@newcmd\qurantrans@es@mcdlxxi{Si Alá te aflige con una desgracia, nadie sino Él podrá librarte de ella. Si Él te desea un bien, nadie podrá oponerse a Su favor. Se lo concede a quien Él quiere de Sus siervos. Él es el Indulgente, el Misericordioso.\qt@no{107}}
\qt@newcmd\qurantrans@es@mcdlxxii{Di: «¡Hombres! Os ha venido, de vuestro Señor, la Verdad. Quien sigue la vía recta, la sigue, en realidad, en provecho propio. Y quien se extravía, se extravía, en realidad, en detrimento propio. Yo no soy vuestro protector».\qt@no{108}}
\qt@newcmd\qurantrans@es@mcdlxxiii{¡Sigue lo que se te ha revelado y ten paciencia hasta que Alá decida! ¡Él es el Mejor en decidir!\qt@no{109}}
\qt@newcmd\qurantrans@es@mcdlxxiv{\basmalahes 'lr. He aquí una Escritura cuyas aleyas han sido hechas unívocas y, luego, explica das detalladamente, y que procede de Uno Que es sabio, Que está bien informado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mcdlxxv{¡Que no sirváis sino a Alá! Yo soy para vosotros, de parte Suya, un monitor y nuncio de buenas nuevas.\qt@no{2}}
\qt@newcmd\qurantrans@es@mcdlxxvi{Y ¡que pidáis perdón a vuestro Señor y, luego, os volváis a Él! Os permitirá, entonces, disfrutar bien por un tiempo determinado y concederá Su favor a todo favorecido. Pero, si volvéis la espalda, temo por vosotros el castigo de un día terrible.\qt@no{3}}
\qt@newcmd\qurantrans@es@mcdlxxvii{Volveréis a Alá. Es omnipotente.\qt@no{4}}
\qt@newcmd\qurantrans@es@mcdlxxviii{Se repliegan en sí mismos para sustraerse a Él. Aunque se cubran con la ropa, Él sabe lo que ocultan y lo que manifiestan: sabe bien lo que encierran los pechos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mcdlxxix{No hay bestia sobre la tierra a cuyo sustento no provea Alá, Que conoce su madriguera y su depósito: todo está en una Escritura clara.\qt@no{6}}
\qt@newcmd\qurantrans@es@mcdlxxx{Él es Quien ha creado los cielos y la tierra en seis días, teniendo Su Trono en el agua, para probaros, para ver quién de vosotros es el que mejor se comporta. Si dices: «Seréis resucitados después de muertos», seguro que los infieles dicen: «Esto no es más que manifiesta magia».\qt@no{7}}
\qt@newcmd\qurantrans@es@mcdlxxxi{Si retrasamos su castigo hasta un momento dado, seguro que dicen: «¿Qué es lo que lo impide ?» El día que les llegue no se les alejará de él y se verán cercados por aquello de que se burlaban.\qt@no{8}}
\qt@newcmd\qurantrans@es@mcdlxxxii{Si hacemos gustar al hombre una misericordia venida de Nosotros y luego le privamos de ella, está completamente desesperado, desagradecido.\qt@no{9}}
\qt@newcmd\qurantrans@es@mcdlxxxiii{Si le hacemos gustar una dicha., luego de haber sufrido una desdicha, seguro que dice: «¡Se han alejado de mí los males!» Sí, se regocija, se ufana.\qt@no{10}}
\qt@newcmd\qurantrans@es@mcdlxxxiv{En cambio, quienes sean pacientes y obren bien, obtendrán perdón y una gran recompensa.\qt@no{11}}
\qt@newcmd\qurantrans@es@mcdlxxxv{Tú, quizás, omitirías parte de lo que se te ha revelado -y te angustias por ello- porque dicen: «¿Por qué no se le ha enviado abajo un tesoro o le ha acompañado un ángel?» Pero tú no eres más que un monitor. Y Alá vela por todo...\qt@no{12}}
\qt@newcmd\qurantrans@es@mcdlxxxvi{O dicen: «Él lo ha inventado». Di: «Si es verdad lo que decís, ¡traed diez suras como él, inventadas, y llamad a quien podáis, en lugar de llamar a Alá!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mcdlxxxvii{Y si no os escuchan, sabed que ha sido revelado con la ciencia de Alá y que no hay más dios que Él. ¿Os someteréis, pues, a Él?\qt@no{14}}
\qt@newcmd\qurantrans@es@mcdlxxxviii{A quienes hayan deseado la vida de acá y su ornato, les remuneraremos en ella con arreglo a sus obras y no serán defraudados en ella.\qt@no{15}}
\qt@newcmd\qurantrans@es@mcdlxxxix{Ésos son los que no tendrán en la otra vida más que el Fuego. Sus obras no fructificarán y será vano lo que hayan hecho.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcdxc{¿Es que quien se basa en una prueba clara venida de su Señor, recitada por un testigo de Éste...? Antes de él, laEscritura de Moisés servía de guía y de misericordia. Ésos creen en ella. Quien de los grupos no cree en ella tiene el Fuego como lugar de cita. Tú no dudes de ella. Es la Verdad venida de tu Señor. Pero la mayoría de los hombres no creen.\qt@no{17}}
\qt@newcmd\qurantrans@es@mcdxci{¿Hay alguien más impío que quien inventa una mentira contra Alá? Esos tales serán conducidos ante su Señor y los testigos dirán: «Éstos son los que mintieron contra su Señor». ¡Sí! ¡Que la maldición de Dios caiga sobre los impíos,\qt@no{18}}
\qt@newcmd\qurantrans@es@mcdxcii{que desvían a otros del camino de Alá, deseando que sea tortuoso, y no creen en la otra vida!\qt@no{19}}
\qt@newcmd\qurantrans@es@mcdxciii{No pudieron escapar en la tierra ni tuvieron, fuera de Alá, amigos. Se les doblará el castigo. No podían oír y no veían.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcdxciv{Ésos son los que se han perdido a sí mismos. Se han esfumado sus invenciones...\qt@no{21}}
\qt@newcmd\qurantrans@es@mcdxcv{¡En verdad, en la otra vida serán los que más pierdan!\qt@no{22}}
\qt@newcmd\qurantrans@es@mcdxcvi{Pero quienes crean, obren bien y se muestren humildes para con su Señor, ésos morarán en el Jardín eternamente.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcdxcvii{Estas dos clases de personas son como uno ciego y sordo y otro que ve y oye. ¿Son similares? ¿Es que no os dejaréis amonestar?\qt@no{24}}
\qt@newcmd\qurantrans@es@mcdxcviii{Y ya enviamos Noé a su pueblo: «Soy para vosotros un monitor que habla claro:\qt@no{25}}
\qt@newcmd\qurantrans@es@mcdxcix{¡No sirváis sino a Alá! Temo por vosotros el castigo de un día doloroso».\qt@no{26}}
\qt@newcmd\qurantrans@es@md{Los dignatarios de su pueblo, que no creían, dijeron: «No vemos en ti más que un mortal como nosotros y no vemos que nadie te siga sino la hez de nuestro pueblo, que lo hace irreflexivamente. Ni vemos que gocéis de ningún privilegio sobre nosotros. Antes bien, creemos que mentís».\qt@no{27}}
\qt@newcmd\qurantrans@es@mdi{Dijo: «¡Pueblo! ¿Qué os parece? Si yo me baso en una prueba clara venida de mi Señor -que me ha hecho objeto de una misericordia venida de Él-, y que vosotros, en vuestra ceguera, no percibís, ¿deberemos imponérosla a despecho vuestro?\qt@no{28}}
\qt@newcmd\qurantrans@es@mdii{¡Pueblo! No os pido hacienda a cambio -mi salario incumbe sólo a Alá- y no voy a rechazar a quienes creen. Sí, encontrarán a su Señor. Pero veo que sois un pueblo ignorante.\qt@no{29}}
\qt@newcmd\qurantrans@es@mdiii{¡Pueblo! Si les rechazo, ¿quién me auxiliará contra Alá? ¿Es que no os dejaréis amonestar?\qt@no{30}}
\qt@newcmd\qurantrans@es@mdiv{Yo no pretendo poseer los tesoros de Alá, ni conozco lo oculto, ni pretendo ser un ángel. Yo no digo a los que vosotros despreciáis que Alá no les reserva ningún bien. Alá conoce bien sus pensamientos. Si tal dijera, sería de los impíos».\qt@no{31}}
\qt@newcmd\qurantrans@es@mdv{Dijeron: «¡Noé! No paras de discutir con nosotros. ¡Tráenos, pues, aquello con que nos amenazas, si es verdad lo que dices!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mdvi{Dijo: «Sólo Alá hará que se cumpla, si Él quiere, y no podréis escapar».\qt@no{33}}
\qt@newcmd\qurantrans@es@mdvii{«Si yo quisiera aconsejaros, mi consejo no os serviría de nada si Alá quisiera descarriaros. Él es vuestro Señor y seréis devueltos a Él».\qt@no{34}}
\qt@newcmd\qurantrans@es@mdviii{O dicen: «Él lo ha inventado». Di:«Si yo lo he inventado, ¡caiga sobre mí mi pecado! Pero soy inocente de lo que me imputáis».\qt@no{35}}
\qt@newcmd\qurantrans@es@mdix{Y se reveló a Noé: «De tu pueblo sólo creerán los que ya creían. ¡No te aflijas, pues, por lo que hicieren!\qt@no{36}}
\qt@newcmd\qurantrans@es@mdx{¡Construye la nave bajo Nuestra mirada y según Nuestra inspiración y no me hables de los que han obrado impíamente! ¡Van a ser anegados!»\qt@no{37}}
\qt@newcmd\qurantrans@es@mdxi{Y, mientras construía la nave, siempre que pasaban por allí dignatarios de su pueblo se burlaban de él. Decía: «Si os burláis de nosotros, ya nos burlaremos de vosotros como os burláis.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdxii{Veréis quién recibirá un castigo humillante y sobre quién se abatirá un castigo permanente»\qt@no{39}}
\qt@newcmd\qurantrans@es@mdxiii{Hasta que, cuando vino Nuestra orden y el horno hirvió, dijimos: «Carga en ella a una pareja de cada especie, a tu familia -salvo a aquél cuya suerte ha sido ya echada- y a los creyentes»,. Pero no eran sino pocos los que con él creían.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdxiv{Dijo: «¡Subid a ella! ¡Que navegue y llegue a buen puerto en el nombre de Alá! Mi Señor es, ciertamente, indulgente, misericordioso».\qt@no{41}}
\qt@newcmd\qurantrans@es@mdxv{Y navegó con ellos entre olas como montañas. Noé llamó a su hijo, que se había quedado aparte: «¡Hijito! ¡Sube con nosotros, no te quedes con los infieles!»\qt@no{42}}
\qt@newcmd\qurantrans@es@mdxvi{Dijo: «Me refugiaré en una montaña que me proteja del agua». Dijo: «Hoy nadie encontrará protección contra la orden de Alá, salvo aquél de quien Él se apiade». Se interpusieron entre ambos las olas y fue de los que se ahogaron.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdxvii{Y se dijo: «¡Traga, tierra, tu agua! ¡Escampa, cielo!», Y el agua fue absorbida, se cumplió la orden y se posó en el Chudi. Y se dijo: «¡Atrás el pueblo impío!»\qt@no{44}}
\qt@newcmd\qurantrans@es@mdxviii{Noé invocó a su Señor y dijo: «¡Señor! Mi hijo es de mi familia. Lo que Tú prometes es verdad. Tú eres Quien mejor decide».\qt@no{45}}
\qt@newcmd\qurantrans@es@mdxix{Dijo: «¡Noé! ¡Él no es de tu familia! ¡Es un acto incorrecto! ¡No me pidas algo de lo que no tienes conocimiento! Te prevengo: ¡no seas de los ignorantes!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mdxx{Dijo: «¡Señor, líbrame de pedirte algo de lo que no tengo conocimiento! Si Tú no me perdonas y Te apiadas de mí, seré de los que están perdidos...»\qt@no{47}}
\qt@newcmd\qurantrans@es@mdxxi{Se dijo: «¡Noé! ¡Desembarca con paz venida de Nosotros y con bendiciones sobre ti y las comunidades que desciendan de quienes te acompañan. Hay comunidades a las que dejaremos que gocen por breve tiempo. Luego, les castigaremos severamente».\qt@no{48}}
\qt@newcmd\qurantrans@es@mdxxii{Esto forma parte de las historias referentes a lo oculto que Nosotros te revelamos. No las conocías antes tú, ni tampoco tu pueblo. ¡Ten paciencia, pues! ¡El fin es para los que temen a Alá!\qt@no{49}}
\qt@newcmd\qurantrans@es@mdxxiii{Y a los aditas su hermano Hud. Dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. No hacéis más que inventar.\qt@no{50}}
\qt@newcmd\qurantrans@es@mdxxiv{¡ Pueblo! No os pido salario a cambio. Mi salario incumbe sólo a Aquél Que me ha creado. ¿Es que no razonáis?\qt@no{51}}
\qt@newcmd\qurantrans@es@mdxxv{Y, ¡pueblo!, ¡pedid perdón a vuestro Señor y, luego, volveos a Él! Enviará sobre vosotros del cielo una lluvia abundante y os fortalecerá. ¡No volváis la espalda como pecadores!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mdxxvi{Dijeron: «¡Hud! ¡No nos has traído ninguna prueba clara! ¡No vamos a dejar a nuestros dioses porque tú lo digas! ¡No tenemos fe en ti!\qt@no{53}}
\qt@newcmd\qurantrans@es@mdxxvii{Lo único que decimos es que uno de nuestros dioses te ha causado mal». Dijo: «¡Pongo a Alá por testigo y sed vosotros también testigos de que soy inocente de lo que vosotros asociáis\qt@no{54}}
\qt@newcmd\qurantrans@es@mdxxviii{en lugar de Él! ¡Urdid algo todos contra mí y no me hagáis esperar!»\qt@no{55}}
\qt@newcmd\qurantrans@es@mdxxix{Yo confío en Alá, mi Señor y Señor vuestro. ¡No hay ser que no dependa de Él! Mi Señor está en una vía recta.\qt@no{56}}
\qt@newcmd\qurantrans@es@mdxxx{Si volvéis la espalda... yo ya os he comunicado aquello con que he sido enviado a vosotros. Mi Señor hará que os suceda otro pueblo y no podréis hacerle ningún daño. ¡Mi Señor todo lo vigila!\qt@no{57}}
\qt@newcmd\qurantrans@es@mdxxxi{Cuando vino Nuestra orden, salvamos por una misericordia venida de Nosotros a Hud y a los que con él creyeron y les libramos de un duro castigo.\qt@no{58}}
\qt@newcmd\qurantrans@es@mdxxxii{Así eran los aditas. Negaron los signos de su Señor y desobedecieron a Sus enviados, siguiendo, en cambio, las órdenes de todo tirano desviado.\qt@no{59}}
\qt@newcmd\qurantrans@es@mdxxxiii{En la vida de acá fueron perseguidos por una maldición y también lo serán el día de la Resurreción. ¡No! ¡Los aditas no creyeron en su Señor! ¡Sí! ¡Atrás los aditas, pueblo de Hud!\qt@no{60}}
\qt@newcmd\qurantrans@es@mdxxxiv{Y a los tamudeos su hermano Salih. Dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. Él os ha creado de la tierra y os ha establecido en ella. ¡Pedidle perdón! Luego, ¡volveos a Él! Mi Señor está cerca, escucha».\qt@no{61}}
\qt@newcmd\qurantrans@es@mdxxxv{Dijeron: «¡Salih! habíamos puesto en ti hasta ahora nuestra esperanza. ¿Nos prohíbes que sirvamos lo que servían nuestros padres? Dudamos seriamente de aquello a que nos llamas».\qt@no{62}}
\qt@newcmd\qurantrans@es@mdxxxvi{Dijo: «¡Pueblo! ¿Qué os parece? Si yo me baso en una prueba clara venida de mi Señor, Que me ha hecho objeto de una misericordia venida de Él, ¿quién me auxiliará contra Alá si Le desobedezco? No haríais sino aumentar mi perdición.\qt@no{63}}
\qt@newcmd\qurantrans@es@mdxxxvii{Y, ¡pueblo!, ésa es la camella de Alá, que seá signo para vosotros. ¡Dejadla que pazca en la tierra de Alá y no le hagáis mal! Si no, os alcanzará pronto un castigo».\qt@no{64}}
\qt@newcmd\qurantrans@es@mdxxxviii{Pero la desjarretaron y dijo: «¡Gozad aún de vuestros bienes durante tres días! Es una amenaza que no dejará de cumplirse».\qt@no{65}}
\qt@newcmd\qurantrans@es@mdxxxix{Y, cuando vino Nuestra orden, preservamos por una misericordia venida de Nosotros a Salih y a los que con él creyeron del oprobio de aquel día. Tu Señor es el Fuerte, el Poderoso.\qt@no{66}}
\qt@newcmd\qurantrans@es@mdxl{El Grito sorprendió a los que habían sido impíos y amanecieron muertos en sus casas,\qt@no{67}}
\qt@newcmd\qurantrans@es@mdxli{como si no hubieran habitado en ellas. ¡No! ¡Los tamudeos no creyeron en su Señor! ¡Sí! ¡Atrás los tamudeos!\qt@no{68}}
\qt@newcmd\qurantrans@es@mdxlii{Y ya trajeron nuestros enviados la buena nueva a Abraham. Dijeron: «¡Paz!» Dijo: «¡Paz!» Y no tardó en traer un ternero asado.\qt@no{69}}
\qt@newcmd\qurantrans@es@mdxliii{Y cuando vio que sus manos no lo tocaban, sospechó de ellos y sintió temor de ellos. Dijeron: «¡No temas! Se nos ha enviado al pueblo de Lot».\qt@no{70}}
\qt@newcmd\qurantrans@es@mdxliv{Su mujer estaba presente y se rió. Y le anunciamos la buena nueva de Isaac y, después de la de Isaac, la de Jacob.\qt@no{71}}
\qt@newcmd\qurantrans@es@mdxlv{Dijo ella: «¡Ay de mí! ¿Voy a dar a luz ahora que soy tan vieja y este mi marido» tan viejo? ¡Ciertamente, esto es algo asombroso!»\qt@no{72}}
\qt@newcmd\qurantrans@es@mdxlvi{«¿Te asombras de la orden de Alá?» dijeron. «¡Que la misericordia de Alá y Sus bendiciones sean sobre vosotros, gente de la casa! ¡Es digno de ser alabado, glorificado!»\qt@no{73}}
\qt@newcmd\qurantrans@es@mdxlvii{Y cuando el temor de Abraham se hubo desvanecido y recibió la buena noticia, se puso a discutir con Nosotros sobre el pueblo de Lot.\qt@no{74}}
\qt@newcmd\qurantrans@es@mdxlviii{Abraham era, ciertamente, benigno, tierno, estaba arrepentido.\qt@no{75}}
\qt@newcmd\qurantrans@es@mdxlix{«¡Abraham! ¡Deja de defenderles! ¡Ha llegado la orden de tu Señor y recibirán un castigo ineludible!»\qt@no{76}}
\qt@newcmd\qurantrans@es@mdl{Y cuando Nuestros enviados vinieron a Lot, éste se afligió por ellos y se sintió impotente para protegerles. Dijo: «¡Este es un día terrible!»\qt@no{77}}
\qt@newcmd\qurantrans@es@mdli{Su pueblo, que solía antes cometer el mal, corrió a Lot, que dijo: «¡Pueblo! ¡Aquí tenéis a mis hijas. Son más puras para vosotros. ¡Temed a Alá y no me avergoncéis en mis huéspedes! ¿No hay entre vosotros un hombre honrado?\qt@no{78}}
\qt@newcmd\qurantrans@es@mdlii{Dijeron: «Ya sabes que no tenemos ningún derecho a tus hijas. Tú ya sabes lo que queremos...»\qt@no{79}}
\qt@newcmd\qurantrans@es@mdliii{Dijo: «¡Ah! Si os pudiera... o si pudiera recurrir a un apoyo fuerte...»\qt@no{80}}
\qt@newcmd\qurantrans@es@mdliv{Dijeron: «¡Lot! ¡Somos los enviados de tu Señor! ¡No se llegarán a ti! ¡Ponte en camino con tu familia durante la noche y que ninguno de vosotros se vuelva! Tu mujer, sí que se volverá y le alcanzará el mismo castigo que a ellos. Esto les ocurrirá al alba. ¿No está cercana el alba?»\qt@no{81}}
\qt@newcmd\qurantrans@es@mdlv{Y cuando vino Nuestra orden, la volvimos de arriba abajo e hicimos llover sobre ella piedras de arcilla a montones,\qt@no{82}}
\qt@newcmd\qurantrans@es@mdlvi{marcadas junto a tu Señor. Y no está lejos de los impíos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mdlvii{Y a los madianitas su hermano Suayb. Dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. ¡No defraudéis en la medida ni en el peso! Os veo en el bienestar, pero temo por vosotros el castigo de un día de alcance universal.\qt@no{84}}
\qt@newcmd\qurantrans@es@mdlviii{Y, ¡pueblo!, ¡dad la medida y el peso equitativos! ¡No defraudéis a los demás en sus bienes! ¡No obréis mal en la tierra corrompiendo!\qt@no{85}}
\qt@newcmd\qurantrans@es@mdlix{Lo que Alá os deja es mejor para‚ vosotros, si es que sois creyentes. Y yo no soy vuestro custodio»\qt@no{86}}
\qt@newcmd\qurantrans@es@mdlx{Dijeron: «¡Suayb! ¿Acaso te ordena tu religión que dejemos lo que nuestros padres servían o que dejemos de utilizar libremente nuestra hacienda? Tú eres, ciertamente, el benigno, el honrado».\qt@no{87}}
\qt@newcmd\qurantrans@es@mdlxi{Dijo: «¡Pueblo! ¿Qué os parece? Si yo me baso en una prueba clara venida de mi Señor y Él me provee de un bello sustento venido de Él... Yo no pretendo contrariaros cuando os prohíbo algo. No pretendo sino reformaros en la medida de mis posibles. Mi éxito no depende sino de Alá. En Él confío y a Él me vuelvo arrepentido.\qt@no{88}}
\qt@newcmd\qurantrans@es@mdlxii{Y ¡pueblo!, ¡que la oposición a mí no os cause los mismos males que alcanzaron al pueblo de Noé o al pueblo de Hud o al pueblo de Salih! Y el pueblo de Lot no está lejos de vosotros.\qt@no{89}}
\qt@newcmd\qurantrans@es@mdlxiii{¡Pedid perdón a vuestro Señor! Luego, ¡volveos a Él Mi Señor es misericordioso. lleno de amor».\qt@no{90}}
\qt@newcmd\qurantrans@es@mdlxiv{Dijeron: «¡Suayb! No entendemos mucho de lo que dices. Entre nosotros se te tiene por débil. Si no hubiera sido por tu clan, te habríamos lapidado. No nos impresionas».\qt@no{91}}
\qt@newcmd\qurantrans@es@mdlxv{Dijo: «¡Pueblo! ¡Os impresiona mi clan más que Alá, a Quien habéis pospuesto con desprecio? Mi Señor abarca todo lo que hacéis.\qt@no{92}}
\qt@newcmd\qurantrans@es@mdlxvi{¡Pueblo! ¡Obrad según vuestra situación! Yo también obraré... Veréis quién va a recibir un castigo humillante y quién es el que miente... ¡Vigilad! Yo también vigilaré con vosotros».\qt@no{93}}
\qt@newcmd\qurantrans@es@mdlxvii{Cuando vino Nuestra orden, salvamos por una misericordia venida de Nosotros a Suayb y a los que con él creían. El Grito sorprendió a los que habían sido impíos y amanecieron muertos en sus casas,\qt@no{94}}
\qt@newcmd\qurantrans@es@mdlxviii{como si no hubieran habitado en ellas. ¡Sí! Atrás los madianitas! como también se había dicho a los tamudeos.\qt@no{95}}
\qt@newcmd\qurantrans@es@mdlxix{Y ya enviamos a Moisés con Nuestros signos y con una autoridad manifiesta\qt@no{96}}
\qt@newcmd\qurantrans@es@mdlxx{a Faraón y a sus dignatarios. Pero éstos siguieron la orden de Faraón. Y la orden de Faraón no era sensata.\qt@no{97}}
\qt@newcmd\qurantrans@es@mdlxxi{El día de la Resurreción, precederá a su pueblo y le conducirá a beber al Fuego. ¡Qué mal abrevadero...!\qt@no{98}}
\qt@newcmd\qurantrans@es@mdlxxii{En esta vida fueron perseguidos por una maldición y lo serán también el día de la Resurrección. ¡Qué mal regalo...!\qt@no{99}}
\qt@newcmd\qurantrans@es@mdlxxiii{Te contamos estas cosas de las ciudades: algunas de ellas están aún en pie, otras son rastrojo.\qt@no{100}}
\qt@newcmd\qurantrans@es@mdlxxiv{No hemos sido Nosotros quienes han sido injustos con sus habitantes, sino que ellos lo han sido consigo mismos. Sus dioses, a los que invocaban, en lugar de invocar a Alá, no les sirvieron de nada cuando vino la orden de tu Señor. No hicieron sino aumentar su perdición.\qt@no{101}}
\qt@newcmd\qurantrans@es@mdlxxv{Así castiga tu Señor cuando castiga las ciudades que son impías. Su castigo es doloroso, severo.\qt@no{102}}
\qt@newcmd\qurantrans@es@mdlxxvi{Ciertamente, hay en ello un signo para quien teme el castigo de la otra vida. Ése es un día en que todos los hombres serán congregados, un día que todos presenciarán.\qt@no{103}}
\qt@newcmd\qurantrans@es@mdlxxvii{No lo retrasaremos sino hasta el plazo fijado.\qt@no{104}}
\qt@newcmd\qurantrans@es@mdlxxviii{El día que esto ocurra nadie hablará sino con Su permiso. De los hombres, unos serán desgraciados, otros felices.\qt@no{105}}
\qt@newcmd\qurantrans@es@mdlxxix{Los desgraciados estarán en el Fuego, gimiendo y bramando,\qt@no{106}}
\qt@newcmd\qurantrans@es@mdlxxx{eternamente, mientras duren los cielos y la tierra, a menos que tu Señor disponga otra cosa. Tu Señor hace siempre lo que quiere.\qt@no{107}}
\qt@newcmd\qurantrans@es@mdlxxxi{Los felices, en cambio, estarán en el Jardín, eternamente, mientras duren los cielos y la tierra, a menos que tu Señor disponga otra cosa. Será un don ininterrumpido.\qt@no{108}}
\qt@newcmd\qurantrans@es@mdlxxxii{No vivas con dudas respecto a lo que sirven esas gentes. No sirven sino como servían antes sus padres. Vamos a darles, sin mengua, la parte que les corresponde.\qt@no{109}}
\qt@newcmd\qurantrans@es@mdlxxxiii{Y ya dimos a Moisés la Escritura, pero discreparon acerca de ella y, si no llega a ser por una palabra previa de tu Señor, ya se habría decidido entre ellos. Y ellos dudan seriamente de ella.\qt@no{110}}
\qt@newcmd\qurantrans@es@mdlxxxiv{Ciertamente, tu Señor remunerará a todos sus obras sin falta. Está bien informado de lo que hacen.\qt@no{111}}
\qt@newcmd\qurantrans@es@mdlxxxv{Sé recto como se te ha ordenado y lo mismo los que, contigo, se arrepientan. ¡No seáis rebeldes! Él ve bien lo que hacéis.\qt@no{112}}
\qt@newcmd\qurantrans@es@mdlxxxvi{¡Y no os arriméis a los impíos, no sea que el fuego os alcance! No tenéis, fuera de Alá amigos. Luego, no seréis auxiliados.\qt@no{113}}
\qt@newcmd\qurantrans@es@mdlxxxvii{Haz la azalá en las dos horas extremas del día y en las primeras de la noche. Las buenas obras disipan las malas. Ésta es una amonestación para los que recuerdan.\qt@no{114}}
\qt@newcmd\qurantrans@es@mdlxxxviii{¡Y ten paciencia! Alá no deja de remunerar a quienes hacen el bien.\qt@no{115}}
\qt@newcmd\qurantrans@es@mdlxxxix{Entre las generaciones que os precedieron, ¿por qué no hubo gentes virtuosas que se opusieran a la corrupción en la a tierra, salvo unos pocos que Nosotros salvamos, mientras que los impíos persistían en el lujo en que vivían y se hacían culpables?\qt@no{116}}
\qt@newcmd\qurantrans@es@mdxc{No iba tu Señor a destruir las ciudades injustamente mientras sus poblaciones se portaban correctamente.\qt@no{117}}
\qt@newcmd\qurantrans@es@mdxci{Tu Señor, si hubiera querido, habría hecho de los hombres una sola comunidad. Pero no cesan en sus discrepancias,\qt@no{118}}
\qt@newcmd\qurantrans@es@mdxcii{salvo aquéllos que han sido objeto de la misericordia de tu Señor, y por eso los ha creado. Se ha cumplido la palabra de tu Señor: «¡He de llenar la gehena de genios y de hombres, de todos ellos!»\qt@no{119}}
\qt@newcmd\qurantrans@es@mdxciii{Te contamos todo esto, sacado de las historias de los enviados, para confirmar tu corazón. Así te llegan, con ellas, la Verdad, una exhortación y una amonestación para los creyentes.\qt@no{120}}
\qt@newcmd\qurantrans@es@mdxciv{Y di a los que no creen: «¡Obrad según vuestra situación! Nosotros también obraremos....\qt@no{121}}
\qt@newcmd\qurantrans@es@mdxcv{¡Y esperad! ¡Nosotros esperamos!»\qt@no{122}}
\qt@newcmd\qurantrans@es@mdxcvi{A Alá pertenece lo oculto de los cielos y de la tierra. Él es el fin de todo. ¡Sírvele! ¡Confía en Él! Tu Señor está atento a lo que hacéis.\qt@no{123}}
\qt@newcmd\qurantrans@es@mdxcvii{\basmalahes 'lr. Ésas son las aleyas de la Escritura clara.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdxcviii{La hemos revelado como Corán árabe. Quizás, así razonéis.\qt@no{2}}
\qt@newcmd\qurantrans@es@mdxcix{Con la revelación que te hacemos de este Corán vamos a contarte Nosotros el más bello de los relatos, aunque hayas sido antes de los despreocupados.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdc{Cuando José dijo a su padre: «¡Padre! He visto once estrellas, el sol y la luna. Los he visto prosternarse ante mí».\qt@no{4}}
\qt@newcmd\qurantrans@es@mdci{Dijo: «¡Hijito! !No cuentes tu sueño a tus hermanos; si no, emplearán una artimaña contra tí El Demonio es para el hombre un enemigo declarado.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcii{Así te elegirá tu Señor y te enseñará a interpretar sueños. Completará Su gracia en ti y en la familia de Jacob, como antes la completó en tus dos antepasados Abraham e Isaac. Tu Señor es omnisciente, sabio».\qt@no{6}}
\qt@newcmd\qurantrans@es@mdciii{Ciertamente, en José y sus hermanos hay signos para los que inquieren.\qt@no{7}}
\qt@newcmd\qurantrans@es@mdciv{Cuando dijeron: «Sí, nuestro padre quiere más a José y a su hermano que a nosotros, aun siendo nosotros más numerosos. Nuestro padre está evidentemente extraviado.\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcv{¡Matemos a José o expulsémosle a cualquier país, para que nuestro padre no nos mire más que a nosotros! Desaparecido José, seremos gente honrada».\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcvi{Pero uno de ellos dijo: «¡No matéis a José ¡Echadlo, más bien, al fondo del aljibe, si es que os lo habéis propuesto...! Algún viajero lo recogerá...»\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcvii{Dijeron: «¡Padre! ¡,Por qué no te fías de nosotros respecto a José? Tenemos buenas intenciones para con él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcviii{¡Envíale mañana con nosotros! Se divertirá y jugará. Cuidaremos, ciertamente, de él».\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcix{«Me entristece que os lo llevéis», dijo. «Temo que, en un descuido vuestro, se lo coma el lobo».\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcx{Dijeron: «Si el lobo se lo comiera, siendo nosotros tantos, sí que tendríamos mala suerte».\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcxi{Cuando se lo llevaron y se pusieron de acuerdo para echarlo al fondo del aljibe... Y le inspiramos: «¡Ya les recordarás más tarde, sin que te reconozcan, lo que ahora han hecho!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcxii{Al anochecer regresaron a su padre, llorando.\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcxiii{Dijeron: «Padre! Fuimos a hacer carreras y dejamos a José junto a nuestras cosas. Entonces, se lo comió el lobo. No nos creerás, pero decimos la verdad».\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcxiv{Y presentaron su camisa manchada de sangre falsa. Dijo: «¡No! Vuestra imaginación os ha sugerido esto. ¡Hay que tener digna paciencia! Alá es Aquél Cuya ayuda se implora contra lo que contáis».\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcxv{Llegaron unos viajeros y enviaron a su aguador, que bajó el cubo. Dijo: «¡Buena noticia! ¡Hay aquí un muchacho!» Y lo ocultaron con ánimo de venderlo. Pero Alá sabía bien lo que hacían.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcxvi{Y lo malvendieron por contados dirhemes, subestimándolo.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcxvii{El que lo había comprado, que era de Egipto, dijo a su mujer: «¡Acógele bien! Quizá nos sea útil o lo adoptemos como hijo». Así dimos poderío a José en el país, y hasta le enseñamos a interpretar sueños. Alá prevalece en lo que ordena, pero la mayoría de los hombres no saben.\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcxviii{Cuando alcanzó la madurez, le dimos juicio y ciencia. Así retribuimos a quienes hacen el bien.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcxix{La señora de la casa en que estaba José le solicitó. Cerró bien las puertas y dijo: «¡Ven acá!» Dijo él: «¡Alá me libre! Él es mi señor y me ha procurado una buena acogida. Los impíos no prosperarán».\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcxx{Ella lo deseaba y él la deseó. De no haber sido iluminado por su Señor... Fue así para que apartáramos de él el mal y la vergüenza. Era uno de Nuestros siervos escogidos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcxxi{Se precipitaron los dos hacia la puerta y ella desgarró por detrás su camisa. Y encontraron a la puerta a su marido. Dijo ella: «¡Cuál es la retribución de quien ha querido mal a tu familia, sino la cárcel o un castigo doloroso?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcxxii{Dijo: «Ella me ha solicitado». Y un miembro de la familia de ella atestiguó que si su camisa había sido desgarrada por delante, entonces, ella decía la verdad y él mentía,\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcxxiii{mientras que si había sido desgarrada por detrás, entonces, ella mentía, y él decía la verdad.\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcxxiv{Y cuando vio que su camisa había sido desgarrada por detrás dijo: «Es una astucia propia de vosotras. Es enorme vuestra astucia...\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcxxv{¡José! ¡No pienses más en eso! ¡Y tú, pide perdón por tu pecado! ¡Has pecado!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcxxvi{Unas mujeres decían en la ciudad: «La mujer del Poderoso solicita a su mozo. Se ha vuelto loca de amor por él. Sí, vemos que está evidentemente extraviada».\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcxxvii{Cuando ella oyó sus murmuraciones, envió a por ellas y les preparó un banquete, dando a cada una de ellas un cuchillo. Y dijo que saliera adonde ellas estaban. Cuando las mujeres le vieron, le encontraron tan bien parecido que se hicieron cortes en las manos y dijeron: «¡Santo Alá! ¡Éste no es un mortal, éste no es sino un ángel maravilloso!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcxxviii{Dijo ella: «Ahí tenéis a aquél por quien me habéis censurado y a quien yo he solicitado, pero él ha permanecido firme. Ahora bien, si no hace lo que yo le ordeno, ha de ser encarcelado y será, ciertamente, de los despreciables».\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcxxix{Dijo él: «¡Señor! Prefiero la cárcel a acceder a lo que ellas me piden. Pero, si no apartas de mí su astucia, cederé a ellas y seré de los ignorantes».\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcxxx{Su Señor le escuchó y apartó de él su astucia. Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcxxxi{Más tarde, a pesar de haber visto los a signos, les pareció que debían encarcelarle por algún tiempo.\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcxxxii{Con él. entraron en la cárcel dos esclavos. Uno de ellos dijo: «Me he visto prensando uva». Y el otro dijo: «Yo me he visto llevando sobre la cabeza pan, del que comían los pájaros. ¡Danos a conocer su interpretación! Vemos que eres de quienes hacen el bien.\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcxxxiii{Dijo: «No recibiréis la comida que os corresponde antes de que yo os haya, previamente, dado a conocer su interpretación. Esto forma parte de lo que mi Señor me ha enseñado. He abandonado la religión de gente que no creía en Alá ni en la otra vida.\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcxxxiv{y he seguido la religión de mis antepasados Abraham, Isaac y Jacob. No debemos asociar nada a Alá. Este es un favor que Alá nos hace, a nosotros y a los hombres. Pero la mayoría de los hombres no agradecen.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcxxxv{¡Compañeros de cárcel! ¿Son preferibles señores separados a Alá, el Uno, el Invicto?\qt@no{39}}
\qt@newcmd\qurantrans@es@mdcxxxvi{Lo que servís, en lugar de servirle a Él, no son sino nombres que habéis puesto, vosotros y vuestros padres, nombres a los que Alá no ha conferido ninguna autoridad. La decisión pertenece sólo a Alá. Él ha ordenado que no sirváis a nadie sino a Él. Ésa es la religión verdadera. Pero la mayoría de los hombres no saben.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdcxxxvii{¡Compañeros de cárcel! Uno de vosotros dos escanciará vino a su señor. El otro será crucificado y los pájaros comerán de su cabeza. Se ha decidido ya lo que me consultabais».\qt@no{41}}
\qt@newcmd\qurantrans@es@mdcxxxviii{Y dijo a aquél de los dos de quien creía que iba a salvarse: «¡Recuérdame ante tu señor!», pues el Demonio había hecho que se olvidara del recuerdo de su Señor. Y continuó en la cárcel varios años más.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdcxxxix{El rey dijo: «He visto siete vacas gordas a las que comían siete flacas, y siete espigas verdes y otras tantas secas. ¡Dignatarios! ¡Aclaradme mi sueño, si es que sois capaces de interpretar sueños!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mdcxl{Dijeron: «¡Amasijo de sueños! Nosotros no sabemos de interpretación de sueños.\qt@no{44}}
\qt@newcmd\qurantrans@es@mdcxli{Aquél de los dos que se había salvado recordó al cabo de un tiempo y dijo: «¡Yo os daré a conocer su interpretación! ¡Dejadme ir!»\qt@no{45}}
\qt@newcmd\qurantrans@es@mdcxlii{«¡José, veraz! ¡Acláranos qué significan siete vacas gordas a las que comen siete flacas y siete espigas verdes y otras tantas secas! Quizá vuelva yo a los hombres. Quizás, así, se enteren».\qt@no{46}}
\qt@newcmd\qurantrans@es@mdcxliii{Dijo: «Sembráis durante siete años, como de costumbre, y, al segar, dejad la espiga, salvo una porción pequeña de que comeréis.\qt@no{47}}
\qt@newcmd\qurantrans@es@mdcxliv{Sucederán siete años de carestía que agotarán lo que hayáis almacenado previsoramente, salvo un poco que reserváis.\qt@no{48}}
\qt@newcmd\qurantrans@es@mdcxlv{Seguirá un año en el que la gente será favorecida y podrá prensar».\qt@no{49}}
\qt@newcmd\qurantrans@es@mdcxlvi{El rey dijo: «¡Traédmelo!» Cuando el enviado vino a él, dijo: «¡Vuelve a tu señor y pregúntale qué intención animaba a las mujeres que se hicieron cortes en las manos! Mi Señor está bien enterado de su astucia».\qt@no{50}}
\qt@newcmd\qurantrans@es@mdcxlvii{.Dijo: «¿Cuál era vuestra intención cuando solicitasteis a José?» Dijeron ellas: «¡Santo Alá! No sabemos de él que haya hecho nada malo». La mujer del Poderoso dijo: «Ahora brilla la verdad. ¡Yo soy la que le solicitó! Él es de los que dicen la verdad».\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcxlviii{«Esto es así para que sepa que no le he traicionado a escondidas y que Alá no dirige la astucia de los traidores.\qt@no{52}}
\qt@newcmd\qurantrans@es@mdcxlix{Yo no pretendo ser inocente. El alma exige el mal, a menos que mi Señor use de Su misericordia. Mi Señor es indulgente, misericordioso».\qt@no{53}}
\qt@newcmd\qurantrans@es@mdcl{El rey dijo: «¡Traédmelo! Le destino a mi servicio». Cuando hubo hablado con él, dijo: «Hoy has encontrado entre nosotros un puesto de autoridad, de confianza».\qt@no{54}}
\qt@newcmd\qurantrans@es@mdcli{Dijo: «¡Ponme al frente de los almacenes del país! ¡Yo sé bien cómo guardarlos!»\qt@no{55}}
\qt@newcmd\qurantrans@es@mdclii{Y así dimos poderío a José en el país, en el que podía establecerse donde quería. Nosotros hacemos objeto de Nuestra misericordia a quien queremos y no dejamos de remunerar a quienes hacen el bien.\qt@no{56}}
\qt@newcmd\qurantrans@es@mdcliii{Con todo, la recompensa de la otra vida es mejor para quienes creen y temen a Alá.\qt@no{57}}
\qt@newcmd\qurantrans@es@mdcliv{Los hermanos de José vinieron y entraron a verle. Éste les reconoció, pero ellos a él no.\qt@no{58}}
\qt@newcmd\qurantrans@es@mdclv{Cuando les hubo suministrado sus provisiones dijo: «Traedme a un hermano vuestro de padre. ¿No veis que doy la medida justa y que soy el mejor de los hospederos?\qt@no{59}}
\qt@newcmd\qurantrans@es@mdclvi{Si no me lo traéis, no obtendréis más grano de mí ni os acercaréis más a mí»\qt@no{60}}
\qt@newcmd\qurantrans@es@mdclvii{Dijeron: «Se lo pediremos a su padre, ¡sí que lo haremos!»\qt@no{61}}
\qt@newcmd\qurantrans@es@mdclviii{Y dijo a sus esclavos: «¡Poned su mercancía en sus alforjas. Quizá la reconozcan cuando regresen a los suyos. Quizás, así, regresen...»\qt@no{62}}
\qt@newcmd\qurantrans@es@mdclix{De vuelta a su padre, dijeron: «¡Padre! Se nos ha negado el grano. Envía, pues, con nosotros a nuestro hermano y así recibiremos grano. Cuidaremos, ciertamente, de él».\qt@no{63}}
\qt@newcmd\qurantrans@es@mdclx{Dijo: «Las seguridades que ahora me ofrecéis respecto a él ¿son diferentes de las que antes me ofrecisteis repecto a su hermano? Pero Alá es Quien cuida mejor y es la Suma Misericordia».\qt@no{64}}
\qt@newcmd\qurantrans@es@mdclxi{Y, cuando abrieron su equipaje, hallaron que se les había devuelto su mercancía. Dijeron: «¡Padre! ¿Qué más podríamos desear? He aquí que se nos ha devuelto nuestra mercancía. Aprovisionaremos a nuestra familia, cuidaremos de nuestro hermano y añadiremos una carga de camello: será una carga ligera».\qt@no{65}}
\qt@newcmd\qurantrans@es@mdclxii{Dijo: «No lo enviaré con vosotros mientras no os comprometáis ante Alá a traérmelo, salvo en caso de fuerza mayor». Cuando se hubieron comprometido, dijo: «Alá responde de nuestras palabras».\qt@no{66}}
\qt@newcmd\qurantrans@es@mdclxiii{Y dijo: «¡Hijos míos! No entréis por una sola puerta, sino por puertas diferentes. Yo no os serviría de nada frente a Alá. La decisión pertenece sólo a Alá. ¡En Él confío! ¡Que los que confían confíen en Él!\qt@no{67}}
\qt@newcmd\qurantrans@es@mdclxiv{Cuando entraron como les había ordenado su padre, esto no les valió de nada frente a Alá. Era sólo una necesidad del alma de Jacob, que él satisfizo. Poseía ciencia porque Nosostros se la habíamos enseñado. Pero la mayoría de los hombres no saben.\qt@no{68}}
\qt@newcmd\qurantrans@es@mdclxv{Cuando estuvieron ante José, éste arrimó a sí a su hermano y dijo: «¡Soy tu hermano! ¡No te aflijas, pues, por lo que hicieron!»\qt@no{69}}
\qt@newcmd\qurantrans@es@mdclxvi{Habiéndoles aprovisionado, puso la copa en la alforja de su hermano. Luego, un voceador pregonó: «¡Caravaneros! ¡Sois, ciertamente, unos ladrones!»\qt@no{70}}
\qt@newcmd\qurantrans@es@mdclxvii{Dijeron, dirigiéndose a ellos: «Qué echáis de menos?»\qt@no{71}}
\qt@newcmd\qurantrans@es@mdclxviii{Dijeron: «Echamos de menos la copa del rey. Una carga de camello para quien la traiga. Yo lo garantizo».\qt@no{72}}
\qt@newcmd\qurantrans@es@mdclxix{«¡Por Alá!» dijeron. «Bien sabéis que o no hemos venido a corromper en el país y que no somos ladrones».\qt@no{73}}
\qt@newcmd\qurantrans@es@mdclxx{Dijeron: «Y, si mentís, ¿Cuál será su retribución?»\qt@no{74}}
\qt@newcmd\qurantrans@es@mdclxxi{Dijeron: «La retribución de aquél en cuya alforja se encuentre será que se quede aquí detenido. Así retribuimos a los impíos».\qt@no{75}}
\qt@newcmd\qurantrans@es@mdclxxii{Comenzó por sus sacos antes que por el de su hermano. Luego, la sacó del saco de su hermano. Nosotros sugerimos esta artimaña a José, pues no podía prender a su hermano según la ley del rey, a menos que Alá quisiera. Elevamos la categoría de quien Nosotros queremos. Por encima de todo el que posee ciencia hay Uno Que todo lo sabe.\qt@no{76}}
\qt@newcmd\qurantrans@es@mdclxxiii{Dijeron: «Si él ha robado, ya un hermano suyo ha robado antes». Pero José lo mantuvo secreto y no se lo reveló. Pensó: «Os encontráis en la situación peor y Alá sabe bien lo que contáis».\qt@no{77}}
\qt@newcmd\qurantrans@es@mdclxxiv{Dijeron: «¡Poderoso! Tiene un padre muy anciano. Retén a uno de nosotros en su lugar. Vemos que eres de quienes hacen el bien».\qt@no{78}}
\qt@newcmd\qurantrans@es@mdclxxv{Dijo: «¡Alá nos libre de retener a otro distinto de aquél en cuyo poder hemos encontrado nuestra propiedad! Seríamos, si no, injustos».\qt@no{79}}
\qt@newcmd\qurantrans@es@mdclxxvi{Desesperado de hacerle cambiar, celebraron una consulta. El mayor dijo: «¿Habéis olvidado que vuestro padre os ha exigido comprometeros ante Alá y cómo faltasteis antes a José? Yo no saldré de este país hasta que mi padre me lo permita o hasta que Alá decida en mi favor, que Él es el Mejor en decidir.\qt@no{80}}
\qt@newcmd\qurantrans@es@mdclxxvii{Regresad a vuestro padre y decid: '¡Padre! Tu hijo ha robado. No atestiguamos sino lo que sabemos. No podíamos vigilar lo oculto.\qt@no{81}}
\qt@newcmd\qurantrans@es@mdclxxviii{Interroga a la ciudad en que nos hallábamos y a la caravana con la cual hemos venido. ¡Sí, decimos la verdad!'»\qt@no{82}}
\qt@newcmd\qurantrans@es@mdclxxix{Dijo: «¡No! Vuestra imaginación os ha sugerido esto. ¡Hay que tener digna paciencia! Tal vez Alá me los devuelva a todos. Él es el Omnisciente, el Sabio».\qt@no{83}}
\qt@newcmd\qurantrans@es@mdclxxx{Y se alejó de ellos y dijo: «¡Qué triste estoy por José!» Y, de tristeza, sus ojos perdieron la vista. Sufría en silencio...\qt@no{84}}
\qt@newcmd\qurantrans@es@mdclxxxi{Dijeron: «¡Por Alá, que no vas a dejar de recordar a José hasta ponerte enfermo o morir!»\qt@no{85}}
\qt@newcmd\qurantrans@es@mdclxxxii{Dijo: «Sólo me quejo a Alá de mi pesadumbre y de mi tristeza. Pero sé por Alá lo que vosotros no sabéis...\qt@no{86}}
\qt@newcmd\qurantrans@es@mdclxxxiii{¡Hijos míos! ¡Id e indagad acerca de José y de su hermano y no desesperéis de la misericordia de Alá, porque sólo el pueblo infiel desespera de la misericordia de Alá!»\qt@no{87}}
\qt@newcmd\qurantrans@es@mdclxxxiv{Cuando estuvieron ante él, dijeron: «¡Poderoso! Hemos sufrido una desgracia, nosotros y nuestra familia, y traemos una mercancía de poco valor. ¡Danos, pues, la medida justa y haznos caridad! Alá retribuye a los que hacen la caridad».\qt@no{88}}
\qt@newcmd\qurantrans@es@mdclxxxv{Dijo: «¿Sabéis lo que, en vuestra ignorancia, hicisteis a José y a su hermano?»\qt@no{89}}
\qt@newcmd\qurantrans@es@mdclxxxvi{Dijeron: «¿De veras eres tú José?» Dijo: «¡Yo soy José y éste es mi hermano! Alá nos ha agraciado. Quien teme a Alá y es paciente...Alá no deja de remunerar a quienes hacen el bien».\qt@no{90}}
\qt@newcmd\qurantrans@es@mdclxxxvii{Dijeron: «¡Por Alá! Ciertamente, Alá te ha preferido a nosotros. ¡Hemos pecado!»\qt@no{91}}
\qt@newcmd\qurantrans@es@mdclxxxviii{Dijo: «¡Hoy no os reprochéis nada! ¡Alá os perdonará Él es la Suma Misericordia.\qt@no{92}}
\qt@newcmd\qurantrans@es@mdclxxxix{¡Llevaos esta camisa mía y aplicadla al rostro de mi padre: recuperará la vista! ¡Traedme luego a vuestra familia, a todos!»\qt@no{93}}
\qt@newcmd\qurantrans@es@mdcxc{Al tiempo que la caravana emprendía el regreso, dijo su padre: «Noto el olor de José, a menos que creáis que chocheo».\qt@no{94}}
\qt@newcmd\qurantrans@es@mdcxci{Dijeron: «¡Por Alá, ya estás en tu antiguo error!»\qt@no{95}}
\qt@newcmd\qurantrans@es@mdcxcii{Cuando el portador de la buena nueva llegó, la aplicó a su rostro y recuperó la vista. Dijo: «¿No os decía yo que sé por Alá lo que vosotros no sabéis?»\qt@no{96}}
\qt@newcmd\qurantrans@es@mdcxciii{Dijeron: «¡Padre! ¡Pide a Alá que nos perdone nuestros pecados! ¡Hemos pecado!»\qt@no{97}}
\qt@newcmd\qurantrans@es@mdcxciv{Dijo: «¡Pediré a mi Señor que os perdone! Él es el Indulgentes el Misericordioso».\qt@no{98}}
\qt@newcmd\qurantrans@es@mdcxcv{Cuando estuvieron ante José, éste arrimó a sí a sus padres y dijo: «¡Entrad seguros en Egipto, si Alá quiere!»\qt@no{99}}
\qt@newcmd\qurantrans@es@mdcxcvi{Hizo subir a sus padres al trono. Y cayeron prosternados ante él. Y dijo: «¡Padre! He aquí la interpretación de mi sueño de antes. Mi Señor ha hecho de él una realidad. Fue bueno conmigo, sacándome de la cárcel y trayéndoos del desierto, luego de haber sembrado el Demonio la discordia entre yo y mis hermanos. Mi Señor es bondadoso para quien Él quiere. Él es el Omnisciente, el Sabio.\qt@no{100}}
\qt@newcmd\qurantrans@es@mdcxcvii{¡Señor! Tú me has dado del dominio y me has enseñado a interpretar sueños. ¡Creador de los cielos y de la tierra! ¡Tú eres mi Amigo en la vida de acá y en la otra! ¡Haz que cuando muera lo haga sometido a Ti y me reúna con los justos!»\qt@no{101}}
\qt@newcmd\qurantrans@es@mdcxcviii{Esto forma parte de las historias referentes a lo oculto, que Nosotros te revelamos. Tú no estabas con ellos cuando se pusieron de acuerdo e intrigaron.\qt@no{102}}
\qt@newcmd\qurantrans@es@mdcxcix{La mayoría de los hombres, a pesar de tu celo, no creen.\qt@no{103}}
\qt@newcmd\qurantrans@es@mdcc{Y tú no les pides un salario a cambio. No es sino una amonestación dirigida a todo el mundo.\qt@no{104}}
\qt@newcmd\qurantrans@es@mdcci{¡Qué designios hay en los cielos y en la tierra, junto a los cuales pasan indiferentes!\qt@no{105}}
\qt@newcmd\qurantrans@es@mdccii{La mayoría no creen en Alá sino como asociadores.\qt@no{106}}
\qt@newcmd\qurantrans@es@mdcciii{¿Es que están, pues, a salvo de que les venga, cubriéndolos, el castigo de Alá, o de que les venga la Hora de repente, sin presentirla?\qt@no{107}}
\qt@newcmd\qurantrans@es@mdcciv{Di: «Éste es mi camino. Basado en una prueba visible, llamo a Alá, y los que me siguen también. ¡Gloria a Alá! Yo no soy de los asociadores».\qt@no{108}}
\qt@newcmd\qurantrans@es@mdccv{Antes de ti. no enviamos más que a hombres de las ciudades, a los que hicimos revelaciones. ¿No han ido por la tierra y mirado cómo terminaron sus antecesores? Sí, la Morada de la otra vida es mejor para los que temen a Alá ¿Es que no razonáis...?\qt@no{109}}
\qt@newcmd\qurantrans@es@mdccvi{Cuando ya los enviados desesperaban y pensaban que se les había mentido, les llegó Nuestro auxilio y fue salvado el que quisimos. Pero Nuestro rigor no respetará al pueblo pecador.\qt@no{110}}
\qt@newcmd\qurantrans@es@mdccvii{Hay en sus historias motivo de reflexión para los dotados de intelecto... No es un relato inventado, sino confirmación de los mensajes anteriores, explicación detallada de todo, dirección y misericordia para gente que cree.\qt@no{111}}
\qt@newcmd\qurantrans@es@mdccviii{\basmalahes 'lmr. Ésas son las aleyas de la Escritura. Lo que se te ha revelado, de parte de tu Señor, es la verdad, pero la mayoría de los hombres no creen.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdccix{Alá es quien elevó los cielos sin pilares visibles. Luego, se instaló en el Trono y sujetó el sol y la luna, prosiguiendo los dos su curso hacia un término fijo. Él lo dispone todo. Explica detalladamente los signos. Quizás, así, estéis convencidos del encuentro de vuestro Señor.\qt@no{2}}
\qt@newcmd\qurantrans@es@mdccx{Él es quien ha extendido la tierra y puesto en ella montañas firmes, ríos y una pareja en cada fruto. Cubre el día con la noche. Ciertamente, hay en ello signos para gente que reflexiona.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdccxi{En la tierra hay parcelas de terreno colindantes, viñedos, cereales, palmeras de tronco simple o múltiple. Todo lo riega una misma agua, pero hacemos que unos frutos sean mejores que otros. Ciertamente, hay en ello signos para gente que razona.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdccxii{Si de algo te asombras, asómbrate de su palabra: «Cuando seamos tierra, ¿es verdad que se nos creará de nuevo?» Ésos son los que niegan a su Señor, ésos los que llevarán argollas al cuello, ésos los moradores del Fuego, eternamente.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdccxiii{Te piden que precipites el mal antes que el bien, aun habiendo precedido castigos ejemplares. Tu Señor es el que perdona a los hombres, a pesar de su impiedad. Pero también tu Señor es severo en castigar.\qt@no{6}}
\qt@newcmd\qurantrans@es@mdccxiv{Los infieles dicen: «¿Por qué no se le ha revelado un signo procedente de su Señor?» Tú eres sólo uno que advierte y cada pueblo tiene quien le dirija.\qt@no{7}}
\qt@newcmd\qurantrans@es@mdccxv{Alá sabe lo que cada hembra lleva y cuándo se contrae el útero, cuándo se dilata. Todo lo tiene medido.\qt@no{8}}
\qt@newcmd\qurantrans@es@mdccxvi{El Conocedor de lo oculto y de lo patente, el Grande, el Sublime.\qt@no{9}}
\qt@newcmd\qurantrans@es@mdccxvii{Da lo mismo que uno de vosotros diga algo en secreto o lo divulgue, se esconda de noche o se muestre de día.\qt@no{10}}
\qt@newcmd\qurantrans@es@mdccxviii{Tiene, por delante y por detrás, pegados a él, que le custodian por orden de Alá. Alá no cambiará la condición de un pueblo mientras éste no cambie lo que en sí tiene. Pero, si Alá quiere mal a un pueblo, no hay manera de evitarlo: fuera de Él, no tienen amigo.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdccxix{Él es quien os hace ver el relámpago, motivo de temor y de anhelo, Él quien forma los nubarrones.\qt@no{12}}
\qt@newcmd\qurantrans@es@mdccxx{Por temor a Él, el trueno celebra Sus alabanzas, y los ángeles también. Él envía los rayos y hiere con ellos a quien Él quiere, mientras discuten sobre Alá, pues es fuerte en poderío.\qt@no{13}}
\qt@newcmd\qurantrans@es@mdccxxi{La verdadera invocación es la que se dirige a Él. Los que invocan a otros, en lugar de invocarle a Él, no serán escuchados nada. Les pasará, más bien, como a quien, deseando alcanzar el agua con la boca, se contenta con extender hacia ella las manos y no lo consigue. La invocación de los infieles es inútil.\qt@no{14}}
\qt@newcmd\qurantrans@es@mdccxxii{Ante Alá se prosternan mañana y tarde los que están en los cielos y en la tierra, de grado o por fuerza, así como sus sombras.\qt@no{15}}
\qt@newcmd\qurantrans@es@mdccxxiii{Di: «¿Quién es el Señor de los cielos y de la tierra?» Di: «¡Alá!» Di: «¿Y tomaréis, en lugar de tomarle a Él, a amigos que no disponen para sí mismos de lo que puede aprovechar o dañar?» Di: «¿Son iguales el ciego y el vidente? ¿Son iguales las tinieblas y la luz? ¿Han dado a Alá asociados que hayan creado algo como lo que Él ha creado, al punto de llegar a confundir lo creado?» Di: «Alá es el Creador de todo. Él es el Uno, el Invicto».\qt@no{16}}
\qt@newcmd\qurantrans@es@mdccxxiv{Ha hecho bajar del cielo agua, que se desliza por los valles, según la capacidad de éstos. El torrente arrastra una espuma flotante, semejante a la escoria que se produce en la fundición para fabricar joyas o utensilios. Así habla Alá en símil de la Verdad y de lo falso: la espuma se pierde; en cambio, queda en la tierra lo útil a los hombres. Así propone Alá los símiles.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdccxxv{Los que escuchen a su Señor tendrán , lo mejor. A los que no Le escuchen, aunque posean todo lo que hay en la tierra y otro tanto y lo ofrezcan como rescate, les irá mal al ajustar las cuentas. Su morada será la gehena. ¡Qué mal lecho...!\qt@no{18}}
\qt@newcmd\qurantrans@es@mdccxxvi{Quien sepa que lo que tu Señor te ha ir; revelado es la Verdad, ¿será como el ciego? Sólo se dejan amonestar los dotados de intelecto.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdccxxvii{Quienes observan fielmente la alianza con Alá y no violan lo pactado,\qt@no{20}}
\qt@newcmd\qurantrans@es@mdccxxviii{quienes mantienen los lazos que Alá ha ordenado mantener y tienen miedo de su Señor y de que les vaya mal al ajustar las cuentas,\qt@no{21}}
\qt@newcmd\qurantrans@es@mdccxxix{quienes tienen paciencia por deseo de agradar a su Señor, hacen la azalá, dan limosna, en secreto o en público, de lo que les hemos proveído y repelen el mal con el bien, ésos tendrán la Morada Postrera,\qt@no{22}}
\qt@newcmd\qurantrans@es@mdccxxx{los jardines del edén, en que entrarán, junto con aquéllos de sus padres, esposas y descendientes que fueron buenos. Los ángeles entrarán en donde ellos estén, por todas partes:\qt@no{23}}
\qt@newcmd\qurantrans@es@mdccxxxi{«¡Paz sobre vosotros, por haber tenido paciencia!» ¡Qué agradable será la Morada Postrera!\qt@no{24}}
\qt@newcmd\qurantrans@es@mdccxxxii{Pero quienes violan la alianza con Alá después de haberla contraído, cortan los lazos que Alá ha ordenado mantener y corrompen en la tierra, ésos serán malditos y tendrán una Morada detestable.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdccxxxiii{Alá dispensa el sustento a quien Él quiere: a unos con largueza, a otros con mesura. Se han regocijado en la vida de acá y la vida de acá no es, comparada con la otra, sino breve disfrute...\qt@no{26}}
\qt@newcmd\qurantrans@es@mdccxxxiv{Los infieles dicen: «¿Por qué no se le ha revelado un signo que procede de su Señor?» Di: «Alá extravía a quien Él quiere y dirige a Él a quien se arrepiente».\qt@no{27}}
\qt@newcmd\qurantrans@es@mdccxxxv{Quienes crean, aquéllos cuyos corazones se tranquilicen con el recuerdo de Alá -¿cómo no van a tranquilizarse los corazones con el recuerdo de Alá?-,\qt@no{28}}
\qt@newcmd\qurantrans@es@mdccxxxvi{quienes crean y obren bien, serán bienaventurados y tendrán un bello lugar de retorno.\qt@no{29}}
\qt@newcmd\qurantrans@es@mdccxxxvii{Así te hemos enviado a una comunidad que fue precedida de otras, para que les recites lo que te hemos revelado, pero niegan al Compasivo. Di: «¡Es mi Señor! No hay más dios que Él. En Él confío y a Él me vuelvo arrepentido».\qt@no{30}}
\qt@newcmd\qurantrans@es@mdccxxxviii{Si hubiera un Corán en virtud del cual pudieran ponerse en marcha las montañas, agrietarse la tierra, hablar los muertos... Pero todo está en manos de Alá. Los que creen ¿no saben que si Alá hubiera querido habría puesto a todos los hombres en la buena dirección? No dejará de alcanzar una calamidad a los infieles en premio a sus obras o bien tendrá lugar cerca de sus casas hasta que se cumpla la promesa de Alá. Alá no falta a Su promesa.\qt@no{31}}
\qt@newcmd\qurantrans@es@mdccxxxix{Ya han sido objeto de burla otros enviados antes de ti. Concedí una prórroga a los infieles; luego, les sorprendí. Y ¡cuál no fue Mi castigo...!\qt@no{32}}
\qt@newcmd\qurantrans@es@mdccxl{¡,Acaso Quien vigila lo que cada uno hace...? Con todo, han dado a Alá asociados. Di: «¡Ponedles nombre! ¿O es que vais a informarle de algo en la tierra que Él ignore? ¿O es sólo una manera de hablar?» Al contrario, a los infieles les es engalanada su intriga y son apartados del Camino. Y aquél a quien Alá extravía no podrá encontrar quien le dirija.\qt@no{33}}
\qt@newcmd\qurantrans@es@mdccxli{Tendrán un castigo en la vida de acá, pero en la otra tendrán un castigo más penoso. No tendrán quien les proteja contra Alá.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdccxlii{Imagen del Jardín prometido a quienes temen a Alá: fluyen arroyos por sus bajos, tiene frutos y sombra perpetuos. Ése será el fin de los que temieron a Alá. El fin de los infieles, empero, será el Fuego.\qt@no{35}}
\qt@newcmd\qurantrans@es@mdccxliii{Aquéllos a quienes dimos la Escritura, se alegran de lo que se te ha revelado. En los grupos, en cambio, hay quienes rechazan una parte. Di: «He recibido sólo la orden de servir a Alá y de no asociarle. Llamo a Él y a Él vuelvo».\qt@no{36}}
\qt@newcmd\qurantrans@es@mdccxliv{Así lo hemos revelado como juicio en lengua árabe. Si tú sigues sus pasiones, después de haber sabido tú lo que has sabido, no tendrás amigo ni protector frente a Alá.\qt@no{37}}
\qt@newcmd\qurantrans@es@mdccxlv{Mandamos a otros enviados antes de ti, y les dimos esposas y descendientes. Ningún enviado, empero, puede traer un signo si no es con permiso de Alá. Cada época tiene su Escritura»\qt@no{38}}
\qt@newcmd\qurantrans@es@mdccxlvi{Alá abroga o confirma lo que quiere. Él tiene la Escritura Matriz.\qt@no{39}}
\qt@newcmd\qurantrans@es@mdccxlvii{Lo mismo si te mostramos algo de lo que les reservamos, que si te llamamos, a ti te incumbe sólo la transmisión y a Nosotros el ajuste de cuentas.\qt@no{40}}
\qt@newcmd\qurantrans@es@mdccxlviii{¿Es que no ven Nuestra intervención cuando reducimos la superficie de la tierra? ¡Alá decide! Nadie puede oponerse a Su decisión y es rápido en ajustar cuentas...\qt@no{41}}
\qt@newcmd\qurantrans@es@mdccxlix{Sus antecesores intrigaron, pero el éxito de toda intriga depende de Alá. Sabe lo que cada uno merece y los infieles verán para quién es la Morada Postrera.\qt@no{42}}
\qt@newcmd\qurantrans@es@mdccl{Los infieles dicen: «¡Tú no has sido enviado!» Di: «Alá basta como testigo entre yo y vosotros, y quienes tienen la ciencia de la Escritura».\qt@no{43}}
\qt@newcmd\qurantrans@es@mdccli{\basmalahes 'lr. Ésta es una Escritura que te hemos revelado para que, con permiso de su Señor, saques a los hombres de las tinieblas a la luz, a la vía del Poderoso, del Digno de Alabanza,\qt@no{1}}
\qt@newcmd\qurantrans@es@mdcclii{de Alá, a Quien pertenece lo que está en los cielos y lo que está en la tierra. ¡Ay de los infieles, por un castigo severo...!\qt@no{2}}
\qt@newcmd\qurantrans@es@mdccliii{Quienes prefieren la vida de acá a la otra y desvían a otros del camino de Alá, deseando que sea tortuoso, están profundamente extraviados.\qt@no{3}}
\qt@newcmd\qurantrans@es@mdccliv{No mandamos a ningún enviado que no hablara en la lengua de su pueblo, para que les explicara con claridad. Alá extravía a quien Él quiere y dirige a quien Él quiere. él es el Poderoso, el Sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdcclv{Ya hemos enviado a Moisés con Nuestros signos: «¡Saca a tu pueblo de las tinieblas a la luz y recuérdales los Días de Alá!» Ciertamente, hay en ello signos para todo aquél que tenga mucha paciencia, mucha gratitud.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcclvi{Y cuando Moisés dijo a su pueblo: «Recordad la gracia que Alá os dispensó cuando os salvó de las gentes de Faraón, que os sometían a duro castigo, degollando a vuestros hijos varones y dejando con vida a vuestras mujeres. Con esto os probó vuestro Señor duramente».\qt@no{6}}
\qt@newcmd\qurantrans@es@mdcclvii{Y cuando vuestro Señor anunció: «Si sois agradecidos, os daré más. Pero, si sois desagradecidos,... Ciertamente, Mi castigo es severo».\qt@no{7}}
\qt@newcmd\qurantrans@es@mdcclviii{Moisés dijo: «Si sois desagradecidos, vosotros y todos los que están en la tierra... Alá Se basta a Sí mismo, es digno de alabanza».\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcclix{¿No os habéis enterado de lo que pasó a quienes os precedieron: el pueblo de Noé, los aditas, los tamudeos, y los que les sucedieron, que sólo Alá conoce? Vinieron a ellos sus enviados con las pruebas claras, pero llevaron las manos a sus bocas y dijeron: «No creemos en vuestro mensaje y dudamos seriamente de aquello a que nos invitáis».\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcclx{Sus enviados dijeron: «¿Es posible dudar de Alá, creador de los cielos y de la tierra? Él os llama para perdonaros vuestros pecados y remitiros a un plazo fijo». Dijeron: «No sois más que unos mortales como nosotros. Queréis apartarnos de los dioses a los que nuestros antepasados servían. ¡Aportadnos, pues, una autoridad evidente!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcclxi{Sus enviados les dijeron: «No somos más que unos mortales como vosotros, pero Alá agracia a quien Él quiere de Sus siervos. Y nosotros no podemos aportaros una autoridad sino con permiso de Alá. ¡Que los creyentes confíen en Alá!»\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcclxii{¿Cómo no vamos a poner nosotros nuestra confianza en Alá, si nos ha dirigido en nuestros caminos? Tendremos, ciertamente, paciencia, a pesar de lo mucho que nos molestáis. ¡Que los que confían confíen en Alá!\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcclxiii{Los infieles dijeron a su enviados: «¡Hemos de expulsaros de nuestro territorio, a menos que volváis a nuestra religión!» Su Señor les inspiró: «¡Hemos de hacer perecer a los impíos\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcclxiv{y hemos de instalaros, después de ellos, en la tierra! Esto es para quien tema Mi condición y tema Mi amenaza».\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcclxv{Pidieron un fallo y todo tirano desviado sufrió una decepción.\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcclxvi{Le espera la gehena y se le dará a beber una mezcla de pus y sangre,\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcclxvii{a tragos, que apenas podrá pasar. La muerte vendrá a él por todas partes, sin que llegue a morir. Le espera un duro castigo.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcclxviii{Las obras de quienes no creen en su Señor son como cenizas azotadas por el viento en un día de tormenta. No pueden esperar nada por lo que han merecido. Ése es el profundo extravío.\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcclxix{¿No has visto que Alá ha creado con un fin los cielos y la tierra? Si Él quisiera, os haría desaparecer y os sustituiría por criaturas nuevas.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcclxx{Y eso no sería difícil para Alá.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcclxxi{Todos comparecerán ante Alá. Los débiles dirán entonces a los altivos: «Nosotros os seguíamos. ¿No podríais ahora servirnos de algo contra el castigo de Alá?» Dirán: «Si Alá nos hubiera dirigido, os habríamos dirigido. Da igual que nos impacientemos o que tengamos paciencia: no tenemos escape...»\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcclxxii{El Demonio dirá cuando se decida la cosa: «Alá os hizo una promesa de verdad, pero yo os hice una que no he cumplido. No tenía más poder sobre vosotros que para llamaros y me escuchasteis. ¡No me censuréis, pues, a mí, sino censuraos a vosotros mismos! Ni yo puedo socorreros, ni vosotros podéis socorrerme. Niego que me hayáis asociado antes a Alá». Los impíos tendrán un castigo doloroso,\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcclxxiii{mientras que a quienes hayan creído y obrado el bien se les introducirá en jardines por cuyos bajos fluyen arroyos y en los que estarán, con permiso de su Señor, eternamente. Como saludo oirán: «¡Paz!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcclxxiv{¿No has visto cómo ha propuesto Alá como símil una buena palabra, semejante a un árbol bueno, de raíz firme y copa que se eleva en el aire,\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcclxxv{que da fruto en toda estación, con permiso de su Señor? Alá propone símiles a los hombres. Quizás, así. se dejen amonestar.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcclxxvi{Una mala palabra es, al contrario, semejante a un árbol malo arrancado del suelo: le falta firmeza.\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcclxxvii{Alá confirma con palabra firme a quienes creen, en la vida de acá y en la , otra. Pero Alá extravía a los ímpios. Alá hace lo que quiere.\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcclxxviii{¿No has visto a quienes cambian la gracia de Alá por la incredulidad y alojan a su pueblo en la morada de perdición?\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcclxxix{En la gehena, en la que arderán. ¡Qué mala morada...!\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcclxxx{Atribuyeron iguales a Alá para extraviar a otros de Su camino. Di: «¡Gozad brevemente! ¡Estáis destinados al Fuego!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcclxxxi{Di a mis servidores creyentes que hagan la azalá y que den limosna, en secreto o en público, de lo que les hemos proveído, antes de que venga día en que ya no haya comercio ni amistad.\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcclxxxii{Alá es Quien ha creado los cielos y la tierra y ha hecho bajar agua del cielo, mediante la cual ha sacado frutos para sustentaros. Ha sujetado a vuestro servicio las naves para que, por Su orden, surquen el mar. Ha sujetado a vuestro servicio los ríos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcclxxxiii{Ha sujetado a vuestro servicio el sol y la luna, que siguen su curso. Ha sujetado a vuestro servicio la noche y el día.\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcclxxxiv{Os ha dado de todo lo que Le habéis pedido. Si os pusierais a contar las gracias de Alá, no podríais enumerarlas. El hombre es, ciertamente, muy impío, muy desagradecido.\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcclxxxv{Y cuando Abraham dijo: «¡Señor! ¡Que esté segura esta ciudad! ¡Y evita que yo y mis hijos sirvamos a los ídolos!\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcclxxxvi{¡Señor! ¡Han extraviado a muchos hombres! Quien me siga será de los míos. Pero quien me desobedezca... Tú eres indulgente, misericordioso.\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcclxxxvii{¡Señor! He establecido a parte de mi descendencia en un valle sin cultivar, junto a tu Casa Sagrada, ¡Señor!, para que hagan la azalá. ¡Haz que los corazones de algunos hombres sean afectuosos con ellos! ¡Provéeles de frutos! Quizás, así, sean agradecidos.\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcclxxxviii{¡Señor! Tú sabes bien lo que ocultamos y lo que manifestamos. No hay nada, en la tierra como en el cielo, que se esconda a Alá.\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcclxxxix{¡Alabado sea Alá, Que, a pesar de mi vejez, me ha regalado a Ismael e Isaac! Mi Señor oye, ciertamente, a quien Le invoca.\qt@no{39}}
\qt@newcmd\qurantrans@es@mdccxc{¡Señor! ¡Haz que haga la azalá, y también mi descendencia, Señor, y acepta mi invocación!\qt@no{40}}
\qt@newcmd\qurantrans@es@mdccxci{¡Señor! Perdónanos, a mí, a mis padres y a los creyentes el día que se ajusten cuentas».\qt@no{41}}
\qt@newcmd\qurantrans@es@mdccxcii{No creas que Alá se despreocupa de lo que hacen los impíos. Les remite solamente a un día en que mirarán con los ojos desorbitados,\qt@no{42}}
\qt@newcmd\qurantrans@es@mdccxciii{corriendo con el cuello extendido, erguida la cabeza, clavada la mirada, el corazón vacío.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdccxciv{¡Prevén a los hombres contra el día en que tendrá lugar el Castigo! Entonces, dirán los impíos: «¡Señor! ¡Remítenos a un plazo próximo para que respondamos a Tu llamada y sigamos a los enviados!» «¿No jurasteis en otra ocasión que no conoceríais el ocaso?\qt@no{44}}
\qt@newcmd\qurantrans@es@mdccxcv{Habitasteis las mismas viviendas que habitaron quienes fueron injustos consigo mismos y se os mostró claramente cómo hicimos con ellos. Os dimos ejemplos...»\qt@no{45}}
\qt@newcmd\qurantrans@es@mdccxcvi{Urdieron intrigas, pero Alá las conocía, y eso que eran intrigas como para trasladar montañas.\qt@no{46}}
\qt@newcmd\qurantrans@es@mdccxcvii{No creas que Alá vaya a faltar a la promesa hecha a Sus enviados - ¡Alá es poderoso, vengador!-,\qt@no{47}}
\qt@newcmd\qurantrans@es@mdccxcviii{el día que la tierra sea sustituida por otra tierra y los cielos por otros cielos, que comparezcan ante Alá, el Uno, el Invicto.\qt@no{48}}
\qt@newcmd\qurantrans@es@mdccxcix{Ese día verás a los culpables encadenados juntos,\qt@no{49}}
\qt@newcmd\qurantrans@es@mdccc{sus indumentos hechos de alquitrán, cubiertos de fuego sus rostros.\qt@no{50}}
\qt@newcmd\qurantrans@es@mdccci{Alá retribuirá así a cada uno según sus méritos. ¡Alá es rápido en ajustar cuentas!\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcccii{Éste es un comunicado dirigido a los hombres para que, por él, sean advertidos, para que sepan que Él es un Dios Uno y para que los dotados de intelecto se dejen amonestar.\qt@no{52}}
\qt@newcmd\qurantrans@es@mdccciii{\basmalahes 'lr. Éstas son las aleyas de la Escritura y de un Corán claro.\qt@no{1}}
\qt@newcmd\qurantrans@es@mdccciv{Puede que los infieles deseen haber sido musulmanes...\qt@no{2}}
\qt@newcmd\qurantrans@es@mdcccv{¡Déjales que coman y que gocen por breve tiempo! ¡Que se distraigan con la esperanza! ¡Van a ver...!\qt@no{3}}
\qt@newcmd\qurantrans@es@mdcccvi{Nunca destruimos ciudad cuya suerte no estuviera decidida.\qt@no{4}}
\qt@newcmd\qurantrans@es@mdcccvii{Ninguna comunidad puede adelantar ni retrasar su plazo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mdcccviii{Dicen: «¡Eh, tú, a quien se ha hecho bajar la Amonestación! ¡Eres, ciertamente, un poseso!\qt@no{6}}
\qt@newcmd\qurantrans@es@mdcccix{Si es verdad lo que dices, ¿por qué no nos traes a los ángeles?»\qt@no{7}}
\qt@newcmd\qurantrans@es@mdcccx{Haremos descender a los ángeles de veras y, entonces, ya no les será dado esperar.\qt@no{8}}
\qt@newcmd\qurantrans@es@mdcccxi{Somos Nosotros Quienes hemos revelado la Amonestación y somos Nosotros sus custodios.\qt@no{9}}
\qt@newcmd\qurantrans@es@mdcccxii{Antes de ti, mandamos a otros enviados a los pueblos antiguos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mdcccxiii{No vino a ellos enviado que no se burlaran de él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mdcccxiv{Así se lo insinuamos ahora a los pecadores,\qt@no{12}}
\qt@newcmd\qurantrans@es@mdcccxv{pero no creen en él, a pesar del ejemplo que han dejado los antiguos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mdcccxvi{Aun si les abriéramos una puerta del cielo y pudieran ascender a él,\qt@no{14}}
\qt@newcmd\qurantrans@es@mdcccxvii{dirían: «Nuestra vista ha sido enturbiada nada más, o, más bien, somos gente a quienes se ha hechizado».\qt@no{15}}
\qt@newcmd\qurantrans@es@mdcccxviii{Sí, hemos puesto constelaciones en el cielo, las hemos engalanado a las miradas,\qt@no{16}}
\qt@newcmd\qurantrans@es@mdcccxix{y las hemos protegido contra todo demonio maldito.\qt@no{17}}
\qt@newcmd\qurantrans@es@mdcccxx{Pero, si uno de ellos escucha a hurtadillas, entonces, le persigue una llama brillante.\qt@no{18}}
\qt@newcmd\qurantrans@es@mdcccxxi{Hemos extendido la tierra, colocado en ella firmes montañas y hecho crecer en ella de todo en la debida proporción.\qt@no{19}}
\qt@newcmd\qurantrans@es@mdcccxxii{Y hemos puesto en ella subsistencias para vosotros y para quien no depende de vuestro sustento.\qt@no{20}}
\qt@newcmd\qurantrans@es@mdcccxxiii{No hay nada de que no dispongamos Nosotros tesoros. Pero no lo hacemos bajar sino con arreglo a una medida determinada.\qt@no{21}}
\qt@newcmd\qurantrans@es@mdcccxxiv{Hemos enviado los vientos, que fecundan, y hacemos bajar del cielo agua, de la que os damos a beber y que no sabéis conservar.\qt@no{22}}
\qt@newcmd\qurantrans@es@mdcccxxv{Somos Nosotros, sí, Quienes damos la vida y la muerte, Nosotros los Herederos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mdcccxxvi{Ciertamente, conocemos a los que de vosotros se adelantan y, ciertamente, conocemos a los que se retrasan.\qt@no{24}}
\qt@newcmd\qurantrans@es@mdcccxxvii{Tu Señor es Quien les congregará. Él es sabio, omnisciente.\qt@no{25}}
\qt@newcmd\qurantrans@es@mdcccxxviii{Hemos creado al hombre de barro arcilloso, maleable,\qt@no{26}}
\qt@newcmd\qurantrans@es@mdcccxxix{mientras que a los genios los habíamos creado antes de fuego de viento abrasador.\qt@no{27}}
\qt@newcmd\qurantrans@es@mdcccxxx{Y cuando tu Señor dijo a los ángeles: «Voy a crear a un mortal de barro arcilloso, maleable,\qt@no{28}}
\qt@newcmd\qurantrans@es@mdcccxxxi{y, cuando lo haya formado armoniosamente e infundido en él de Mi Espíritu, caed prosternados ante él».\qt@no{29}}
\qt@newcmd\qurantrans@es@mdcccxxxii{Todo los ángeles, juntos, se prosternaron,\qt@no{30}}
\qt@newcmd\qurantrans@es@mdcccxxxiii{excepto Iblis, que rehusó unirse a los que se prosternaban.\qt@no{31}}
\qt@newcmd\qurantrans@es@mdcccxxxiv{Dijo: «¡Iblis! ¿Qué tienes, que no te unes a los que se prosternan?»\qt@no{32}}
\qt@newcmd\qurantrans@es@mdcccxxxv{Dijo: «Yo no voy a prosternarme ante un mortal que Tú has creado de barro arcilloso, maleable».\qt@no{33}}
\qt@newcmd\qurantrans@es@mdcccxxxvi{Dijo: «¡Sal de aquí! ¡Eres un maldito!\qt@no{34}}
\qt@newcmd\qurantrans@es@mdcccxxxvii{¡La maldición te perseguirá hasta el día del Juicio!»\qt@no{35}}
\qt@newcmd\qurantrans@es@mdcccxxxviii{Dijo, «¡Señor, déjame esperar hasta el día de la Resurreción!»\qt@no{36}}
\qt@newcmd\qurantrans@es@mdcccxxxix{Dijo: «¡Entonces, serás de aquéllos a quienes se ha concedido de prórroga\qt@no{37}}
\qt@newcmd\qurantrans@es@mdcccxl{hasta el día señalado!»\qt@no{38}}
\qt@newcmd\qurantrans@es@mdcccxli{Dijo: «¡Señor! Por haberme Tú descarriado, he de engalanarles en la tierra y he de descarriarles a todos,\qt@no{39}}
\qt@newcmd\qurantrans@es@mdcccxlii{salvo a aquéllos que sean siervos Tuyos escogidos».\qt@no{40}}
\qt@newcmd\qurantrans@es@mdcccxliii{Dijo: «Esto es, para Mí, una vía recta.\qt@no{41}}
\qt@newcmd\qurantrans@es@mdcccxliv{Tú no tienes poder alguno sobre Mis siervos, salvo sobre los descarriados que te sigan».\qt@no{42}}
\qt@newcmd\qurantrans@es@mdcccxlv{La gehena es el lugar de cita de todos ellos.\qt@no{43}}
\qt@newcmd\qurantrans@es@mdcccxlvi{Tiene siete puertas y cada una tendrá un grupo definido de ellos.\qt@no{44}}
\qt@newcmd\qurantrans@es@mdcccxlvii{Los temerosos de Alá estarán entre jardines y fuentes.\qt@no{45}}
\qt@newcmd\qurantrans@es@mdcccxlviii{«¡Entrad en ellos, en paz, seguros!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mdcccxlix{Extirparemos el rencor que quede en sus pechos. Serán como hermanos, en lechos, unos enfrente de otros.\qt@no{47}}
\qt@newcmd\qurantrans@es@mdcccl{Allí no sufrirán pena, ni serán expulsados.\qt@no{48}}
\qt@newcmd\qurantrans@es@mdcccli{Informa a Mis siervos de que Yo soy el Indulgente, el Misericordioso,\qt@no{49}}
\qt@newcmd\qurantrans@es@mdccclii{pero que Mi castigo es el castigo doloroso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mdcccliii{Infórmales de lo que pasó con los huéspedes de Abraham,\qt@no{51}}
\qt@newcmd\qurantrans@es@mdcccliv{cuando, entrados en donde él estaba, dijeron: «¡Paz!» Dijo: «¡Nos dais miedo!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mdccclv{«¡No tengas miedo!», dijeron. «Te anunciamos la buena noticia de un muchacho lleno de ciencia».\qt@no{53}}
\qt@newcmd\qurantrans@es@mdccclvi{Dijo: «¿Me anunciáis buenas noticias, a pesar de mi avanzada edad? Y ¿qué es lo que me anunciáis?»\qt@no{54}}
\qt@newcmd\qurantrans@es@mdccclvii{Dijeron: «Te anunciamos la buena noticia de la Verdad. ¡No te desesperes!»\qt@no{55}}
\qt@newcmd\qurantrans@es@mdccclviii{Dijo: «Y quién podría desesperar de la misericordia de su Señor, sino los extraviados!?»\qt@no{56}}
\qt@newcmd\qurantrans@es@mdccclix{Dijo: «¿Qué es lo que os trae, ¡enviados!?»\qt@no{57}}
\qt@newcmd\qurantrans@es@mdccclx{Dijeron: «Se nos ha enviado a un pueblo pecador.\qt@no{58}}
\qt@newcmd\qurantrans@es@mdccclxi{No incluimos a la familia de Lot, a los que salvaremos, a todos.\qt@no{59}}
\qt@newcmd\qurantrans@es@mdccclxii{salvo a su mujer». Determinamos: sería de los que se rezagaran.\qt@no{60}}
\qt@newcmd\qurantrans@es@mdccclxiii{Cuando los enviados llegaron a la familia de Lot,\qt@no{61}}
\qt@newcmd\qurantrans@es@mdccclxiv{dijo: «Sois gente desconocida».\qt@no{62}}
\qt@newcmd\qurantrans@es@mdccclxv{Dijeron: «¡No, sino que te traemos aquello de que han dudado!\qt@no{63}}
\qt@newcmd\qurantrans@es@mdccclxvi{Te traemos la Verdad. ¡Sí, es como decimos!\qt@no{64}}
\qt@newcmd\qurantrans@es@mdccclxvii{¡Ponte en camino con tu familia, durante la noche! ¡Ve el último y que ninguno de vosotros se vuelva! ¡Id a donde se os ordena!»\qt@no{65}}
\qt@newcmd\qurantrans@es@mdccclxviii{Y decidimos respecto a él este asunto: iban a amanecer todos ellos, hasta el último, despedazados.\qt@no{66}}
\qt@newcmd\qurantrans@es@mdccclxix{La población de la ciudad vino, llena de alegría.\qt@no{67}}
\qt@newcmd\qurantrans@es@mdccclxx{Dijo: «¡Éstos son huéspedes míos! ¡No me deshonréis!\qt@no{68}}
\qt@newcmd\qurantrans@es@mdccclxxi{¡Temed a Alá y no me llenéis de vergüenza!»\qt@no{69}}
\qt@newcmd\qurantrans@es@mdccclxxii{Dijeron: «¿No te habíamos prohibido que trajeras a nadie?»\qt@no{70}}
\qt@newcmd\qurantrans@es@mdccclxxiii{Dijo: «¡Aquí tenéis a mis hijas, si es que os lo habéis propuesto...!»\qt@no{71}}
\qt@newcmd\qurantrans@es@mdccclxxiv{¡Por tu vida!, que erraban en su ofuscación.\qt@no{72}}
\qt@newcmd\qurantrans@es@mdccclxxv{Y les sorprendió el Grito a la salida del sol.\qt@no{73}}
\qt@newcmd\qurantrans@es@mdccclxxvi{La volvimos de arriba abajo e hicimos llover sobre ellos piedras de arcilla.\qt@no{74}}
\qt@newcmd\qurantrans@es@mdccclxxvii{Ciertamente, hay en ello signos para los que prestan atención.\qt@no{75}}
\qt@newcmd\qurantrans@es@mdccclxxviii{Está situada, ciertamente, en un camino que aún existe.\qt@no{76}}
\qt@newcmd\qurantrans@es@mdccclxxix{Ciertamente, hay en ello un signo para los creyentes.\qt@no{77}}
\qt@newcmd\qurantrans@es@mdccclxxx{Los habitantes de la Espesura fueron, sí impíos.\qt@no{78}}
\qt@newcmd\qurantrans@es@mdccclxxxi{y nos vengamos de ellos. Los dos casos son típicos y claros.\qt@no{79}}
\qt@newcmd\qurantrans@es@mdccclxxxii{Los habitantes de al-Hichr desmintieron a los enviados.\qt@no{80}}
\qt@newcmd\qurantrans@es@mdccclxxxiii{Les trajimos Nuestros signos y se apartaron de ellos.\qt@no{81}}
\qt@newcmd\qurantrans@es@mdccclxxxiv{Excavaban, tranquilos, casas en las montañas.\qt@no{82}}
\qt@newcmd\qurantrans@es@mdccclxxxv{Les sorprendió el Grito por la mañana\qt@no{83}}
\qt@newcmd\qurantrans@es@mdccclxxxvi{y sus posesiones no les sirvieron de nada.\qt@no{84}}
\qt@newcmd\qurantrans@es@mdccclxxxvii{No hemos creado sino con un fin los cielos, la tierra y lo que entre ellos hay. ¡Sí, la Hora llega! ¡Perdona, pues, generosamente!\qt@no{85}}
\qt@newcmd\qurantrans@es@mdccclxxxviii{Tu Señor es el Creador de todo, el Omnisciente.\qt@no{86}}
\qt@newcmd\qurantrans@es@mdccclxxxix{Te hemos dado siete de las mazani y el sublime Corán.\qt@no{87}}
\qt@newcmd\qurantrans@es@mdcccxc{¡No codicies los goces efímeros que hemos concedido a algunos de ellos y no estés triste por ellos! Y ¡sé benévolo con los creyentes!\qt@no{88}}
\qt@newcmd\qurantrans@es@mdcccxci{Di: «¡Soy el monitor que habla claro!»\qt@no{89}}
\qt@newcmd\qurantrans@es@mdcccxcii{como hemos infligido un castigo a los conjurados,\qt@no{90}}
\qt@newcmd\qurantrans@es@mdcccxciii{que han hecho pedazos el Corán.\qt@no{91}}
\qt@newcmd\qurantrans@es@mdcccxciv{¡Por tu Señor, que hemos de pedir cuentas a todos ellos\qt@no{92}}
\qt@newcmd\qurantrans@es@mdcccxcv{de sus actos!\qt@no{93}}
\qt@newcmd\qurantrans@es@mdcccxcvi{¡Anuncia lo que se te ordena y apártate de los asociadores!\qt@no{94}}
\qt@newcmd\qurantrans@es@mdcccxcvii{Nosotros te bastamos contra los que se burlan,\qt@no{95}}
\qt@newcmd\qurantrans@es@mdcccxcviii{que ponen, junto con Alá, a otro dios. ¡Van a ver...!\qt@no{96}}
\qt@newcmd\qurantrans@es@mdcccxcix{Bien sabemos que te angustias por lo que dicen.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcm{Pero tú ¡celebra las alabanzas de tu Señor y sé de los que se prosternan!\qt@no{98}}
\qt@newcmd\qurantrans@es@mcmi{¡Y sirve a tu Señor hasta que venga a ti la cierta!\qt@no{99}}
\qt@newcmd\qurantrans@es@mcmii{\basmalahes ¡La orden de Alá viene! ¡No queráis adelantarla! ¡Gloria a Él! Está por encima de lo que Le asocian.\qt@no{1}}
\qt@newcmd\qurantrans@es@mcmiii{Hace descender a los ángeles con el Espíritu que procede de Su orden sobre quien Él quiere de Sus siervos: «¡Advertid que no hay otro dios que Yo! ¡Temedme, pues!»\qt@no{2}}
\qt@newcmd\qurantrans@es@mcmiv{Ha creado los cielos y la tierra con un fin. Está por encima de lo que Le asocian.\qt@no{3}}
\qt@newcmd\qurantrans@es@mcmv{Ha creado al hombre de una gota y ¡ahí le tienes, porfiador declarado!\qt@no{4}}
\qt@newcmd\qurantrans@es@mcmvi{Y los rebaños los ha creado para vosotros. Hay en ellos abrigo y otras ventajas y os alimentáis de ellos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mcmvii{Disfrutáis viéndolos cuando los volvéis por la tarde o cuando los sacáis a pastar por la mañana.\qt@no{6}}
\qt@newcmd\qurantrans@es@mcmviii{Llevan vuestras cargas a países que no alcanzaríais sino con mucha pena. Vuestro Señor es, en verdad, manso, misericordioso.\qt@no{7}}
\qt@newcmd\qurantrans@es@mcmix{Y los caballos, los mulos, los asnos, para que os sirvan de montura y de ornato. Y crea otras cosas que no sabéis.\qt@no{8}}
\qt@newcmd\qurantrans@es@mcmx{A Alá le incumbe indicar el Camino, del que algunos se desvían. Si hubiera querido, os habría dirigido a todos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mcmxi{Él es Quien ha hecho bajar para vosotros agua del cielo. De ella bebéis y de ella viven las matas con que apacentáis.\qt@no{10}}
\qt@newcmd\qurantrans@es@mcmxii{Gracias a ella, hace crecer para vosotros los cereales, los olivos, las palmeras, las vides y toda clase de frutos. Ciertamente, hay en ello un signo para gente que reflexiona.\qt@no{11}}
\qt@newcmd\qurantrans@es@mcmxiii{Y ha sujetado a vuestro servicio la noche y el día, el sol y la luna. Las estrellas están sujetas por Su orden. Ciertamente, hay en ello signos para gente que razona.\qt@no{12}}
\qt@newcmd\qurantrans@es@mcmxiv{Las criaturas que Él ha puesto en la tierra para vosotros son de clases diversas. Ciertamente, hay en ello un signo para gente que se deja amonesta\qt@no{13}}
\qt@newcmd\qurantrans@es@mcmxv{Él es Quien ha sujetado el mar para que comáis de él carne fresca y obtengáis de él adornos que poneros. Y ves que las naves lo surcan. Para que busquéis Su favor. Quizás, así, seáis agradecidos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mcmxvi{Y ha fijado en la tierra las montañas para que ella y vosotros no vaciléis, ríos, caminos -quizás, así, seáis bien dirigidos-\qt@no{15}}
\qt@newcmd\qurantrans@es@mcmxvii{y mojones. Y se guían por los astros.\qt@no{16}}
\qt@newcmd\qurantrans@es@mcmxviii{¿Acaso Quien crea es como quien no crea? ¿Es que no os dejaréis amonestar?\qt@no{17}}
\qt@newcmd\qurantrans@es@mcmxix{Si os pusierais a contar las gracias de Alá, no podríais enumerarlas. Alá es, en verdad, indulgente, misericordioso.\qt@no{18}}
\qt@newcmd\qurantrans@es@mcmxx{Alá sabe lo que ocultáis y lo que manifestáis.\qt@no{19}}
\qt@newcmd\qurantrans@es@mcmxxi{Aquéllos que ellos invocan en lugar de invocar a Alá, no crean nada, sino que ellos son creados.\qt@no{20}}
\qt@newcmd\qurantrans@es@mcmxxii{Están muertos, no vivos. Y no saben cuándo serán resucitados.\qt@no{21}}
\qt@newcmd\qurantrans@es@mcmxxiii{Vuestro Dios es un Dios Uno. Los corazones de quienes, altivos, no creen en la otra vida Le niegan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mcmxxiv{¡En verdad, Alá sabe lo que ocultan y lo que manifiestan! No ama a los altivos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mcmxxv{Si se les dice: «¿Qué ha revelado vuestro Señor?», dicen: «Patrañas de los antiguos».\qt@no{24}}
\qt@newcmd\qurantrans@es@mcmxxvi{¡Que lleven su carga completa el día de la Resurrección y algo de la carga de los que, sin conocimiento, extraviaron! ¡Qué carga más detestable!\qt@no{25}}
\qt@newcmd\qurantrans@es@mcmxxvii{Sus antecesores intrigaron. Alá vino contra los cimientos de su edificio y el techo se desplomó sobre ellos. Les vino el castigo de donde no lo presentían.\qt@no{26}}
\qt@newcmd\qurantrans@es@mcmxxviii{Luego, el día de la Resurrección, Él les avergonzará y dirá: «¿Dónde están Mis asociados, sobre los que discutíais?» Quienes hayan recibido la Ciencia dirán: «Hoy la vergüenza y la desgracia caen sobre los infieles,\qt@no{27}}
\qt@newcmd\qurantrans@es@mcmxxix{a quienes, injustos consigo mismos, los ángeles llaman». Ofrecerán someterse: «No hacíamos ningún mal». «¡Claro que sí! ¡Alá sabe bien lo que hacíais!\qt@no{28}}
\qt@newcmd\qurantrans@es@mcmxxx{¡Entrad por las puertas de la gehena, por toda la eternidad!» ¡Qué mala es la morada de los soberbios!\qt@no{29}}
\qt@newcmd\qurantrans@es@mcmxxxi{A los que temieron a Alá se les dirá: «¿Qué ha revelado vuestro Señor?» Dirán: «Un bien». Quienes obren bien tendrán en la vida de acá una bella recompensa, pero la Morada de la otra vida será mejor aún. ¡Qué agradable será la Morada de los que hayan temido a Alá!\qt@no{30}}
\qt@newcmd\qurantrans@es@mcmxxxii{Entrarán en los jardines del edén, por cuyos bajos fluyen arroyos. Tendrán en ellos lo que deseen. Así retribuye Alá a quienes Le temen,\qt@no{31}}
\qt@newcmd\qurantrans@es@mcmxxxiii{a quienes, buenos, llaman los ángeles diciendo: «¡Paz sobre vosotros! ¡Entrad en el Jardín, como premio a vuestras obras!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mcmxxxiv{¿Qué esperan sino que vengan los ángeles o que venga la orden de tu Señor? Así hicieron sus antecesores. No fue Alá quien fue injusto con ellos, sino que ellos lo fueron consigo mismos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mcmxxxv{Les alcanzará la misma maldad de sus acciones y les cercará aquello de que se burlaban.\qt@no{34}}
\qt@newcmd\qurantrans@es@mcmxxxvi{Dirán los asociadores: «Si Alá hubiera querido, ni nosotros ni nuestros padres habríamos servido nada en lugar de servirle a Él. No habríamos prohibido nada que Él no hubiera prohibido». Así hicieron sus antecesores. Y ¿qué otra cosa incumbe a los enviados, sino la transmisión clara?\qt@no{35}}
\qt@newcmd\qurantrans@es@mcmxxxvii{Mandamos a cada comunidad un enviado: «Servid a Alá y evitad a los taguts». A algunos de ellos les dirigió Alá, mientras que otros merecieron extraviarse. ¡Id por la tierra y mirad cómo terminaron los desmentidores!\qt@no{36}}
\qt@newcmd\qurantrans@es@mcmxxxviii{Si anhelas dirigirles,... Alá no dirige a quienes Él extravía y no tendrán quien les auxilie.\qt@no{37}}
\qt@newcmd\qurantrans@es@mcmxxxix{Han jurado solemnemente por Alá: «¡Alá no resucitará a quien haya muerto!» ¡Claro que sí! Es una promesa que Le obliga, verdad. Pero la mayoría de los hombres no saben.\qt@no{38}}
\qt@newcmd\qurantrans@es@mcmxl{Para mostrarles aquello en que discrepaban y para que sepan los infieles que han mentido.\qt@no{39}}
\qt@newcmd\qurantrans@es@mcmxli{Cuando queremos algo, Nos basta decirle: «¡Sé!», y es.\qt@no{40}}
\qt@newcmd\qurantrans@es@mcmxlii{A quienes han emigrado por Alá, después de haber sido tratados injustamente, hemos de procurarles una buena situación en la vida de acá, pero la recompensa de la otra será mayor aún. Si supieran...\qt@no{41}}
\qt@newcmd\qurantrans@es@mcmxliii{Que tienen paciencia y confían en Alá...\qt@no{42}}
\qt@newcmd\qurantrans@es@mcmxliv{Antes de ti, no enviamos sino a hombres a los que hicimos revelaciones -si no lo sabéis, preguntad a la gente de la Amonestación-,\qt@no{43}}
\qt@newcmd\qurantrans@es@mcmxlv{con las pruebas claras y con las Escrituras. A ti también te hemos revelado la Amonestación para que expliques a los hombres lo que se les ha revelado. Quizás,, así, reflexionen.\qt@no{44}}
\qt@newcmd\qurantrans@es@mcmxlvi{Quienes han tramado males ¿están, pues, a salvo de que Alá haga que la tierra los trague, o de que el castigo les venga de donde no lo presientan,\qt@no{45}}
\qt@newcmd\qurantrans@es@mcmxlvii{o de que les sorprenda en plena actividad sin que puedan escapar,\qt@no{46}}
\qt@newcmd\qurantrans@es@mcmxlviii{o de que les sorprenda atemorizados? Vuestro Señor es, ciertamente, manso, misericordioso.\qt@no{47}}
\qt@newcmd\qurantrans@es@mcmxlix{¿No han visto que la sombra de todo lo que Alá ha creado se mueve hacia la derecha y hacia la izquierda, en humilde prosternación ante Alá?\qt@no{48}}
\qt@newcmd\qurantrans@es@mcml{Lo que está en los cielos y en la tierra se prosterna ante Alá: todo animal y los ángeles. Y éstos sin altivez.\qt@no{49}}
\qt@newcmd\qurantrans@es@mcmli{Temen a su Señor, que está por encima de ellos, y hacen lo que se les ordena.\qt@no{50}}
\qt@newcmd\qurantrans@es@mcmlii{Alá ha dicho: «¡No toméis a dos dioses! ¡Él es sólo un Dios Uno! ¡Temedme, pues, a Mí, y sólo a Mí»\qt@no{51}}
\qt@newcmd\qurantrans@es@mcmliii{Suyo es lo que está en los cielos y en la tierra. Se le debe un culto permanente. ¿Vais a temer a otro diferente de Alá?\qt@no{52}}
\qt@newcmd\qurantrans@es@mcmliv{No tenéis gracia que no proceda de Alá. Cuando sufrís una desgracia, acudís a Él.\qt@no{53}}
\qt@newcmd\qurantrans@es@mcmlv{Pero, luego, cuando aparta de vosotros la desgracia, he aquí que algunos de vosotros asocian a su Señor,\qt@no{54}}
\qt@newcmd\qurantrans@es@mcmlvi{para terminar negando lo que les hemos dado. ¡Gozad, pues, brevemente! ¡Vais a ver...!\qt@no{55}}
\qt@newcmd\qurantrans@es@mcmlvii{Atribuyen a lo que no conocen algunos de los bienes de que les hemos proveído. ¡Por Alá, que habréis de responder de lo que inventabais!\qt@no{56}}
\qt@newcmd\qurantrans@es@mcmlviii{Atribuyen hijas a Alá -¡gloria a Él!- y a sí mismos se atribuyen lo que desean.\qt@no{57}}
\qt@newcmd\qurantrans@es@mcmlix{Cuando se le anuncia a uno de ellos una niña, se queda hosco y se angustia.\qt@no{58}}
\qt@newcmd\qurantrans@es@mcmlx{Esquiva a la gente por vergüenza de lo que se le ha anunciado, preguntándose si lo conservará, para deshonra suya, o lo esconderá bajo tierra... ¡Qué mal juzgan!\qt@no{59}}
\qt@newcmd\qurantrans@es@mcmlxi{Quienes no creen en la otra vida representan el mal, mientras que Alá, representa el ideal supremo. Él es el Poderoso, el Sabio.\qt@no{60}}
\qt@newcmd\qurantrans@es@mcmlxii{Si Alá tuviera en cuenta la impiedad humana, no dejaría ningún ser vivo sobre ella. Pero los retrasa por un plazo determinado y, cuando vence su plazo, no pueden retrasarlo ni adelantarlo una hora.\qt@no{61}}
\qt@newcmd\qurantrans@es@mcmlxiii{Atribuyen a Alá lo que detestan y sus lenguas inventan la mentira cuando pretenden que les espera lo mejor. ¡En verdad, tendrán el Fuego, e irán los primeros!\qt@no{62}}
\qt@newcmd\qurantrans@es@mcmlxiv{¡Por Alá!, que antes de ti hemos mandado enviados a comunidades. Pero el Demonio engalanó las obras de éstas y hoy es él su amigo. Tendrán un castigo doloroso.\qt@no{63}}
\qt@newcmd\qurantrans@es@mcmlxv{No te hemos revelado la Escritura sino para que les expliques en qué discrepaban y como dirección y misericordia para gente que cree.\qt@no{64}}
\qt@newcmd\qurantrans@es@mcmlxvi{Alá ha hecho bajar agua del cielo, vivificando con ella la tierra después de muerta. Ciertamente, hay en ello un signo para gente que oye.\qt@no{65}}
\qt@newcmd\qurantrans@es@mcmlxvii{Y en los rebaños tenéis motivo de reflexión. Os damos a beber del contenido de sus vientres, entre heces y sangre: una leche pura, grata a los bebedores.\qt@no{66}}
\qt@newcmd\qurantrans@es@mcmlxviii{De los frutos de las palmeras y de la vides obtenéis una bebida embriagadora y un bello sustento. Ciertamente, hay en ello un signo para gente que razona.\qt@no{67}}
\qt@newcmd\qurantrans@es@mcmlxix{Tu Señor ha inspirado a las abejas: «Estableced habitación en las montañas, en los árboles y en las construcciones humanas.\qt@no{68}}
\qt@newcmd\qurantrans@es@mcmlxx{Comed de todos los frutos y caminad dócilmente por los caminos de vuestro Señor». De su abdomen sale un líquido de diferentes clases, que contiene un remedio para los hombres. Ciertamente, hay en ello un signo para gente que reflexiona.\qt@no{69}}
\qt@newcmd\qurantrans@es@mcmlxxi{Alá os ha creado y luego os llamará. A algunos de vosotros se les deja que alcancen una edad decrépita, para que, después de haber sabido, terminen no sabiendo nada. Alá es omnisciente, poderoso.\qt@no{70}}
\qt@newcmd\qurantrans@es@mcmlxxii{Alá os ha favorecido a unos con más sustento que a otros; pero aquéllos que han sido favorecidos no ceden tanto de su sustento a sus esclavos que lleguen a igualarse con ellos. ¿Y rehusarán la gracia de Alá?\qt@no{71}}
\qt@newcmd\qurantrans@es@mcmlxxiii{Alá os ha dado esposas nacidas de vosotros. Y, de vuestras esposas, hijos varones y nietos. Os ha proveído también de cosas buenas. ¿Creen, pues, en lo falso y no creerán en la gracia de Alá?\qt@no{72}}
\qt@newcmd\qurantrans@es@mcmlxxiv{En lugar de servir a Alá, sirven a lo que no puede procurarles sustento de los cielos ni de la tierra, lo que no posee ningún poder.\qt@no{73}}
\qt@newcmd\qurantrans@es@mcmlxxv{¡No pongáis a Alá como objeto de vuestras comparaciones! Alá sabe, mientras que vosotros no sabéis.\qt@no{74}}
\qt@newcmd\qurantrans@es@mcmlxxvi{Alá propone un símil: un esclavo, propiedad de otro, incapaz de nada, y un hombre a quien Nosotros hemos proveído de bello sustento, del que da limosna, en í secreto o en público. ¿Son, acaso, iguales? ¡Alabado sea Alá! Pero la mayoría no saben.\qt@no{75}}
\qt@newcmd\qurantrans@es@mcmlxxvii{Alá propone un símil: dos hombres, uno de ellos mudo, incapaz de nada y carga para su dueño; le mande adonde le mande, no trae ningún bien. ¡Son iguales este hombre y el que prescribe la justicia y está en una vía recta?\qt@no{76}}
\qt@newcmd\qurantrans@es@mcmlxxviii{A Alá pertenece lo oculto de los cielos y de la tierra. La orden que anuncie la Hora no será sino como un abrir y cerrar de ojos, o más breve. Alá es omnipotente.\qt@no{77}}
\qt@newcmd\qurantrans@es@mcmlxxix{Alá os ha sacado del seno de vuestras madres, privados de todo saber. Él os ha dado el oído, la vista y el intelecto. Quizás, así, seáis agradecidos.\qt@no{78}}
\qt@newcmd\qurantrans@es@mcmlxxx{¿No han visto las aves sujetas en el aire del cielo? Sólo Alá las sostiene. Ciertamente, hay en ello signos para gente que cree.\qt@no{79}}
\qt@newcmd\qurantrans@es@mcmlxxxi{Alá os ha hecho de vuestras viviendas un lugar habitable. De la piel de los rebaños os ha hecho tiendas, que encontráis ligeras al trasladaros o al acampar. De su lana, de su pelo y de su crin, artículos domésticos para disfrute por algún tiempo.\qt@no{80}}
\qt@newcmd\qurantrans@es@mcmlxxxii{De lo que ha creado, Alá os ha procurado sombra, refugios en las montañas, indumentos que os resguardan del calor e indumentos que os protegen de los golpes. Así completa Su gracia en vosotros. Quizás, así, os sometáis a Alá.\qt@no{81}}
\qt@newcmd\qurantrans@es@mcmlxxxiii{Si vuelven la espalda... A ti te incumbe sólo la transmisión clara.\qt@no{82}}
\qt@newcmd\qurantrans@es@mcmlxxxiv{Conocen la gracia de Alá, pero la niegan. La mayoría son unos desagradecidos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mcmlxxxv{Y el día que hagamos surgir de cada comunidad a un testigo, no se permitirá a los que no hayan creído, ni se les agraciará.\qt@no{84}}
\qt@newcmd\qurantrans@es@mcmlxxxvi{Y cuando los impíos vean el castigo, éste no se les mitigará, ni les será dado esperar.\qt@no{85}}
\qt@newcmd\qurantrans@es@mcmlxxxvii{Y cuando los asociadores vean a los que ellos asociaron a Alá, dirán: «¡Señor!! ¡Éstos son los que Te habíamos asociado, a quienes invocábamos en lugar de invocarte a Tí!» Y esos asociados les rebatirán: «¡Mentís, ciertamente!»\qt@no{86}}
\qt@newcmd\qurantrans@es@mcmlxxxviii{Y, entonces, ofreceran a Alá someterse. Pero sus invenciones se esfumarán.\qt@no{87}}
\qt@newcmd\qurantrans@es@mcmlxxxix{A los que no creyeron y desviaron a otros del camino de Alá, les infligiremos castigo sobre castigo por haber corrompido.\qt@no{88}}
\qt@newcmd\qurantrans@es@mcmxc{El día que hagamos surgir de cada comunidad a un testigo de cargo, te traeremos a ti como testigo contra éstos. Te hemos revelado la Escritura como aclaración de todo, como dirección y misericordia, como buena nueva para los que se someten.\qt@no{89}}
\qt@newcmd\qurantrans@es@mcmxci{Alá prescribe la justicia, la beneficencia y la liberalidad con los parientes. Prohíbe la deshonestidad, lo reprobable y la opresión. Os exhorta. Quizás, así, os dejéis amonestar.\qt@no{90}}
\qt@newcmd\qurantrans@es@mcmxcii{Cuando concertéis una alianza con Alá, sed fieles a ella. No violéis los juramentos después de haberlos ratificado. Habéis puesto a Alá como garante contra vosotros. Alá sabe lo que hacéis.\qt@no{91}}
\qt@newcmd\qurantrans@es@mcmxciii{No hagáis como aquélla que deshacía de nuevo el hilo que había hilado fuertemente. Utilizáis vuestros juramentos para engañaros so pretexto de que una comunidad es más fuerte que otra. Alá no hace más que probaros con ello. El día de la Resurreción ha de mostraros aquello en que discrepabais.\qt@no{92}}
\qt@newcmd\qurantrans@es@mcmxciv{Alá, si hubiera querido, habría hecho de vosotros una sola comunidad. Pero extravía a quien Él quiere y dirige a quien Él quiere. Tendréis que responder de lo que hacíais.\qt@no{93}}
\qt@newcmd\qurantrans@es@mcmxcv{No utilicéis vuestros juramentos para engañaros; si no, el pie os fallará después de haberlo tenido firme. Gustaréis la desgracia por haber desviado a otros del camino de Alá y tendréis un castigo terrible.\qt@no{94}}
\qt@newcmd\qurantrans@es@mcmxcvi{No malvendáis la alianza con Alá. Lo que Alá tiene es mejor para vosotros. Si supierais...\qt@no{95}}
\qt@newcmd\qurantrans@es@mcmxcvii{Lo que vosotros tenéis se agota. En cambio, lo que Alá tiene perdura. A los que tengan paciencia les retribuiremos, sí, con arreglo a sus mejores obras.\qt@no{96}}
\qt@newcmd\qurantrans@es@mcmxcviii{Al creyente, varón o hembra, que obre bien, le haremos, ciertamente, que viva una vida buena y le retribuiremos, sí, con arreglo a sus mejores obras.\qt@no{97}}
\qt@newcmd\qurantrans@es@mcmxcix{Cuando recites el Corán, busca refugio en Alá del maldito Demonio.\qt@no{98}}
\qt@newcmd\qurantrans@es@mm{Él no puede nada contra los que creen y confían en su Señor.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmi{Sólo tiene poder contra los que traban amistad con él y asocian a Él otros dioses.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmii{Cuando sustituimos una aleya por otra -Alá sabe bien lo que revela- dicen: «¡Eres sólo un falsario!» Pero la mayoría no saben.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmiii{Di: «El Espiritu Santo lo ha revelado, de tu Señor, con la Verdad, para confirmar a los que creen y como dirección y buena nueva para los que se someten a Alá».\qt@no{102}}
\qt@newcmd\qurantrans@es@mmiv{Bien sabemos que dicen: «A este hombre le enseña sólo un simple mortal». Pero aquél en quien piensan habla una lengua no árabe, mientras que ésta es una lengua árabe clara.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmv{Alá no dirigirá a quienes no crean en los signos de Alá y tendrán un castigo doloroso.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmvi{Sólo inventan la mentira quienes no creen en los signos de Alá. Ésos son los que mienten.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmvii{Quien no crea en Alá luego de haber creído -no quien sufra coacción mientras su corazón permanece tranquilo en la fe, sino quien abra su pecho a la incredulidad-, ese tal incurrirá en la ira de Alá y tendrá un castigo terrible.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmviii{Y eso por haber preferido la vida de acá a la otra. Alá no dirige al pueblo infiel.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmix{Ésos son aquéllos cuyo corazón, oído y vista Alá ha sellado. Ésos los que no se preocupan...\qt@no{108}}
\qt@newcmd\qurantrans@es@mmx{¡En verdad, serán los que pierdan en la otra vida!\qt@no{109}}
\qt@newcmd\qurantrans@es@mmxi{Tu Señor, para quienes hayan emigrado, después de haber sufrido pruebas y de haber, luego, combatido y tenido paciencia, tu Señor será, ciertamente, después de eso, indulgente, misericordioso,\qt@no{110}}
\qt@newcmd\qurantrans@es@mmxii{el día que venga cada uno intentando justificarse, cada uno reciba conforme a sus obras y nadie sea tratado injustamente.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmxiii{Alá propone como parábola una ciudad, segura y tranquila, que recibía abundante sustento de todas partes. Y no agradeció las gracias de Alá. Alá, en castigo por su conducta, le dio a gustar la vestidura del hambre y del temor.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmxiv{Ha venido a ellos un Enviado salido de ellos, pero le han desmentido y el castigo les ha sorprendido en su impiedad.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmxv{¡Comed de lo lícito y bueno de que Alá os ha proveído! ¡Y agradeced la gracia de Alá, si es a Él solo a Quien servís!\qt@no{114}}
\qt@newcmd\qurantrans@es@mmxvi{Os ha prohibido sólo la carne mortecina, la sangre, la carne de cerdo y la de todo animal sobre el que se haya invocado un nombre diferente del de Alá. Pero, si alguien se ve compelido por la necesidad -no por deseo ni por afán de contravenir... Alá es indulgente, misericordioso.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmxvii{No digáis, entre lo que vuestras lenguas profieren, mentiras como «Esto es lícito y esto es ilícito», inventando así la mentira contra Alá. Quienes inventen la mentira contra Alá no prosperarán.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmxviii{¡Mezquino disfrute! ¡Tendrán un castigo doloroso!\qt@no{117}}
\qt@newcmd\qurantrans@es@mmxix{A los judíos les prohibimos lo que ya te contamos. No hemos sido Nosotros quienes han sido injustos con ellos, sino que ellos lo han sido consigo mismos.\qt@no{118}}
\qt@newcmd\qurantrans@es@mmxx{Sin embargo, con los que, habiendo cometido el mal por ignorancia, luego se arrepientan y enmienden, tu Señor será, ciertamente, después de eso, indulgente, misericordioso.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmxxi{Abraham fue una comunidad, devoto de Alá, hanif y no asociador,\qt@no{120}}
\qt@newcmd\qurantrans@es@mmxxii{agradecido a Sus gracias. Él le eligió y le dirigió a una vía recta.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmxxiii{En la vida de acá le dimos una buena situación y en la otra es de los justos.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmxxiv{Luego, te hemos revelado: «Sigue la religión de Abraham, que fue hanif y no asociador».\qt@no{123}}
\qt@newcmd\qurantrans@es@mmxxv{El sábado se impuso solamente a los que sobre él discrepaban. Tu Señor, ciertamente, decidirá entre ellos el día de la Resurrección sobre aquello en que discrepaban.\qt@no{124}}
\qt@newcmd\qurantrans@es@mmxxvi{Llama al camino de tu Señor con sabiduría y buena exhortación. Discute con ellos de la manera más conveniente. Tu Señor conoce mejor que nadie a quien se extravía de Su camino y conoce mejor que nadie a quien está bien dirigido.\qt@no{125}}
\qt@newcmd\qurantrans@es@mmxxvii{Si castigáis, castigad de la misma manera que se os ha castigado. Pero, si tenéis paciencia, es mejor para vosotros.\qt@no{126}}
\qt@newcmd\qurantrans@es@mmxxviii{¡Ten paciencia! No podrás tener paciencia sino con la ayuda de Alá. Y no estés triste por ellos, ni te angusties por sus intrigas.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmxxix{Alá está con quienes Le temen y quienes hacen el bien.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmxxx{\basmalahes ¡Gloria a Quien hizo viajar a Su Siervo de noche, desde la Mezquita Sagrada a la Mezquita Lejana, cuyos alrededores hemos bendecido, para mostrarle parte de Nuestros signos! Él es Quien todo lo oye, todo lo ve.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmxxxi{Dimos a Moisés la Escritura e hicimos de ella dirección para los Hijos de Israel: «¡No toméis protector fuera de Mí,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmxxxii{descendientes de los que llevamos con Noé!» Éste fue un siervo muy agradecido.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmxxxiii{Decretamos en la Escritura respecto a los Hijos de Israel: Ciertamente, corromperéis en la tierra dos veces y os conduciréis con gran altivez.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmxxxiv{Cuando, de las dos amenazas, se cumpla la primera, suscitaremos contra vosotros a siervos Nuestros, dotados de gran valor y penetrarán en el interior de las casas. Amenaza que se cumplirá».\qt@no{5}}
\qt@newcmd\qurantrans@es@mmxxxv{Más tarde, os permitimos desquitaros de ellos. Os dimos más hacienda e hijos varones e hicimos de vosotros un pueblo numeroso.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmxxxvi{El bien o mal que hagáis redundará en provecho o detrimento vuestro. «Cuando se cumpla la última amenaza, os afligirán y entrarán en el Templo como entraron una vez primera y exterminarán todo aquello de que se apoderen».\qt@no{7}}
\qt@newcmd\qurantrans@es@mmxxxvii{Quizá vuestro Señor se apiade de vosotros. Pero, si reincidís, Nosotros también reincidiremos. Hemos hecho de la gehena cárcel para los infieles.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmxxxviii{Este Corán dirige a lo que es más recto y anuncia a los creyentes que obran bien la buena nueva de una gran recompensa,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmxxxix{y que a los que no creen en la otra vida les hemos preparado un castigo doloroso.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmxl{El hombre invoca el mal con la misma facilidad con que invoca el bien: el hombre es muy precipitado...\qt@no{11}}
\qt@newcmd\qurantrans@es@mmxli{Hemos hecho de la noche y del día dos signos. Hemos apagado el signo de la noche y hecho visible el signo del día, para que busquéis favor de vuestro Señor y sepáis el número de años y el cómputo: todo lo hemos explicado detalladamente.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmxlii{Hemos asignado a cada hombre su suerte, y el día de la Resurrección le sacaremos una Escritura que encontrará desenrollada:\qt@no{13}}
\qt@newcmd\qurantrans@es@mmxliii{«¡Lee tu Escritura ! ¡Hoy bastas tú para ajustarte cuentas!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmxliv{Quien sigue la vía recta la sigue, en realidad, en provecho propio, y quien se extravía, se extravía, en realidad, en detrimento propio. Nadie cargará con la carga ajena. Nunca hemos castigado sin haber mandado antes a un enviado.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmxlv{Cuando queremos destruir una ciudad, ordenamos a sus ricos y ellos se entregan en ella a la iniquidad. Entonces, la sentencia contra ella se cumple y la aniquilamos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmxlvi{¡A cuántas generaciones hemos hecho perecer después de Noé! Tu Señor está suficientemente informado de los pecados de Sus siervos, los ve suficiente mente.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmxlvii{Si alguien desea la vida fugaz, Nosotros nos apresuraremos a darle en ella lo que queremos -y a quien queremos. Luego, le destinamos la gehena, donde arderá denigrado, desechado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmxlviii{Al creyente que desee la otra vida y se esfuerce por alcanzarla, se le reconocerá su esfuerzo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmxlix{A unos y a otros, a todos, les concederemos en abundancia de los dones de tu Señor. ¡Los dones de tu Señor no se niegan a nadie!\qt@no{20}}
\qt@newcmd\qurantrans@es@mml{¡Mira cómo hemos preferido a unos más que a otros! En la otra vida habrá, no obstante, categorías más elevadas y una mayor distinción.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmli{No pongas junto con Alá a otro dios; si no, te encontrarás denigrado, abandonado.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmlii{Tu Señor ha decretado que no debéis servir sino a Él y que debéis ser buenos con vuestros padres. Si uno de ellos o ambos envejecen en tu casa, no les digas: «¡Uf!» y trates con antipatía, sino sé cariñoso con ellos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmliii{Por piedad, muéstrate deferente con ellos y di: «¡Señor, ten misericordia de ellos como ellos la tuvieron cuando me educaron siendo niño!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmliv{Vuestro Señor conoce bien vuestros pensamientos. Si sois justos... Él es indulgente con los que se arrepienten sinceramente.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmlv{Da lo que es de derecho al pariente, así como al pobre y al viaiero, pero sin prodigarte demasiado,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmlvi{que los pródigos son hermanos de los demonios, y el Demonio es desagradecido para con su Señor.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmlvii{Si, buscando una misericordia venida de tu Señor, que esperas, tienes que apartarte de aquéllos, diles, al menos, una palabra amable.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmlviii{No lleves la mano cerrada a tu cuello, ni la extiendas demasiado; si no, te encontrarás censurado, falto de recursos.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmlix{Tu Señor dispensa el sustento a quien Él quiere: a unos con largueza, a otros con mesura. Está bien informado de Sus siervos, les ve bien.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmlx{¡No matéis a vuestros hijos por miedo a empobreceros! Somos Nosotros Quienes les proveemos, y a vosotros también. Matarles es un gran pecado.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmlxi{¡Evitad la fornicación: es una deshonestidad! ¡Mal camino...!\qt@no{32}}
\qt@newcmd\qurantrans@es@mmlxii{No matéis a nadie que Dios haya prohibido, sino con justo motivo. Si se mata a alguien sin razón, damos autoridad a su pariente próximo, pero que éste no se exceda en la venganza. Se le auxiliará.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmlxiii{No toquéis la hacienda del huérfano sino de manera conveniente hasta que alcance la madurez. ¡Cumplid todo compromiso, porque se pedirá cuenta de él!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmlxiv{Cuando midáis, dad la medida justa y pesad con una balanza exacta. Es mejor y da muy buen resultado.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmlxv{No vayas tras algo de lo que no tienes ningún conocimiento. Del oído, de la vista, del intelecto, de todo eso se pedirá cuenta.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmlxvi{No vayas por la tierra con insolencia, que no eres capaz de hender la tierra, ni de alzarte a la altura de las montañas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmlxvii{Tu Señor detesta lo malo que en ello hay.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmlxviii{Esto forma parte de la sabiduría que tu Señor te ha inspirado. No pongas junto con Alá a otro dios; si no, serás precipitado en la gehena, censurado, desechado.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmlxix{¿Es que vuestro Señor, que ha escogido daros hijos varones, iba a tomar para Sí hijas de entre los ángeles? Decís, en verdad, algo muy grave.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmlxx{Hemos expuesto en este Corán para que se dejen amonestar, pero esto no hace sino acrecentar su repulsa.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmlxxi{Di: «Si hubiera dioses además de Él, como dicen, buscarían un camino que les condujera hasta el Señor del Trono.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmlxxii{¡Gloria a Él! ¡Está por encima de lo que dicen!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmlxxiii{Le glorifican los siete cielos, la tierra y sus habitantes. No hay nada que no celebre Sus alabanzas, pero no comprendéis su glorificación. Él es benigno, indulgente.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmlxxiv{Cuando recitas el Corán, tendemos un velo opaco entre ti y los que no creen en la otra vida,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmlxxv{velamos sus corazones y endurecemos sus oídos para que no lo entiendan. Cuando invocas en el Corán a tu Señor Solo, vuelven la espalda en repulsa.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmlxxvi{Nosotros sabemos bien lo que escuchan cuando te escuchan o cuando están en conciliábulos, cuando dicen los impíos: «No seguís sino a un hombre hechizado».\qt@no{47}}
\qt@newcmd\qurantrans@es@mmlxxvii{¡Mira a qué te comparan! Se extravían y no pueden encontrar camino.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmlxxviii{Dicen: «Cuando seamos huesos y polvo, ¿es verdad que se nos resucitará a una nueva creación?»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmlxxix{Di: «Aunque seáis piedra, hierro\qt@no{50}}
\qt@newcmd\qurantrans@es@mmlxxx{o cualquier sustancia que imaginéis difícil...» Dirán: «¿Y quién nos volverá!» Di: «Quien os creó una vez primera». Y, sacudiendo la cabeza hacia ti, dirán: «¿Cuándo?» Di: «Tal vez pronto».\qt@no{51}}
\qt@newcmd\qurantrans@es@mmlxxxi{El día que os llame, responderéis alabándole y creeréis no haber permanecido sino poco tiempo.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmlxxxii{Di a Mis siervos que hablen de la mejor manera que puedan. El Demonio siembra la discordia entre ellos. El Demonio es para el hombre un enemigo declarado.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmlxxxiii{Vuestro Señor os conoce bien. Si quiere, se apiadará de vosotros y, si quiere, os castigará. No te hemos enviado para que seas su protector.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmlxxxiv{Tu Señor conoce bien a quienes están en los cielos y en la tierra. Hemos preferido a unos profetas más que a otros. Y dimos a David Salmos.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmlxxxv{Di: «¡Invocad a los que, en lugar de Él, pretendéis! ¡No pueden evitaros la desgracia ni modificarla!»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmlxxxvi{Los mismos a quienes invocan buscan el medio de acercarse a su Señor. Esperan en Su misericordia y temen Su castigo. El castigo de tu Señor es temible.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmlxxxvii{No hay ninguna ciudad que no destruyamos o que no castiguemos severamente antes del día de la Resurreción. Está anotado en la Escritura.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmlxxxviii{No Nos ha impedido obrar milagros sino que los antiguos los desmintieran. Dimos la camella a los tamudeos como milagro palpable, pero obraron impíamente con ella. No obramos los milagros sino para atemorizar.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmlxxxix{Y cuando te dijimos: «Tu Señor cerca a los hombres». No hicimos del sueño que te mostramos y del árbol maldito mencionado en el Corán sino tentación para los hombres. Cuanto más les amedrentamos, más aumenta su rebeldía.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmxc{Y cuando dijimos a los ángeles: «¡Prosternaos ante Adán!». Se prosternaron, excepto Iblis, que dijo: «¿Voy a prosternarme ante quien has creado de arcilla?»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmxci{Dijo: «¿Qué Te parece? Éste es aquél a quien has honrado más que a mí. Si me remites hasta el día de la Resurrección, dominaré a todos sus descendientes, salvo a unos pocos».\qt@no{62}}
\qt@newcmd\qurantrans@es@mmxcii{Dijo: «¡Vete! La gehena será amplia retribución para ti y para tus secuaces.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmxciii{¡Ahuyenta con tu voz a todos los que puedas! ¡Atácales con tu caballería y con tu infantería! ¡Asóciate a ellos en la hacienda y en los hijos! ¡Promételes!». Pero el Demonio no les promete sino falacia.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmxciv{«Pero no tienes ninguna autoridad sobre Mis siervos». ¡Tu Señor basta como protector!\qt@no{65}}
\qt@newcmd\qurantrans@es@mmxcv{Vuestro Señor es Quien, para vosotros, hace que surquen las naves el mar, para que busquéis Su favor. Es misericordioso con vosotros.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmxcvi{Si sufrís una desgracia en el mar, los que invocáis se esfuman, Él no. Pero, en cuanto os salva llevándoos a tierra firme, os apartáis. El hombre es muy desagradecido.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmxcvii{¿Estáis, pues, a salvo de que Alá haga que la tierra os trague o de que envíe contra vosostros una tempestad de arena? No podrías encontrar protector.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmxcviii{¿O estáis a salvo de que lo repita una segunda vez, enviando contra vosotros un viento huracanado y anegándoos por haber sido desagradecidos? No encontraríais a nadie que, en vuestro favor, Nos demandara por ello.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmxcix{Hemos honrado a los hijos de Adán. Los hemos llevado por tierra y por mar, les hemos proveído de cosas buenas y los hemos preferido marcadamente a muchas otras criaturas.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmc{El día que llamemos a todos los hombres con su Libro, aquéllos a quienes se dé su Escritura en la diestra, ésos leerán su Escritura y no serán tratados injustamente en lo más mínimo.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmci{Quien haya estado ciego en esta vida continuará ciego en la otra y aún se extraviará más del Camino.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcii{En verdad, casi han conseguido desviarte de lo que te habíamos revelado, con objeto de que inventaras contra Nosotros otra cosa. Te habrían tomado como amigo.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmciii{Si no te hubiéramos confirmado, casi te habrías arrimado algún poco hacia ellos.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmciv{Te habríamos hecho gustar el doble en la vida y el doble en la muerte. Y no habrías encontrado quien te auxiliara contra Nosotros.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcv{En verdad, casi te incitaron a huir del país con objeto de hacerte salir de él -en ese caso no se habrían quedado en él después de ti sino por poco tiempo-,\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcvi{lo mismo que ocurrió con los enviados que mandamos antes de ti, práctica Nuestra que encontrarás inmutable.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcvii{Haz la azalá al ocaso hasta la caída de la noche, y la recitación del alba, que la recitación del alba tiene testigos.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcviii{Parte de la noche, vela: será para ti una obra supererogatoria. Quizá tu Señor te resucite a un estado digno de encomio.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcix{Y di: «¡Señor! ¡Hazme entrar bien, hazme salir bien! ¡Concédeme, de Ti, una autoridad que me auxilie!»\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcx{Y di: «¡Ha venido la Verdad y se ha disipado lo falso! ¡Lo falso tiene que disiparse!»\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcxi{Hacemos descender, por medio del Corán, lo que es curación y misericordia para los creyentes, pero esto no hace sino perder más a los impíos.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcxii{Cuando agraciamos al hombre, éste se desvía y se aleja. Pero, si sufre un mal, se desespera.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcxiii{Di: «Cada uno obra a su modo, pero vuestro Señor conoce bien al que va mejor dirigido por el Camino».\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcxiv{Te preguntan por el espíritu. Di: «El espíritu procede de la orden de mi Señor». Pero no habéis recibido sino poca ciencia.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcxv{Si quisiéramos, retiraríamos lo que te hemos revelado y no encontrarías quien te protegiera en esto contra Nosotros.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcxvi{No es sino una misericordia venida de tu Señor, Que te ha favorecido grandemente.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcxvii{Di: «Si los hombres y los genios se unieran para producir un Corán como éste, no podrían conseguirlo, aunque se ayudaran mutuamente».\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcxviii{En este Corán hemos expuesto a los hombres toda clase de ejemplos. Pero la mayoría de los hombres no quieren sino ser infieles.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcxix{Y dicen: «No creeremos en ti hasta que nos hagas brotar un manantial de la tierra,\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcxx{o que tengas un jardín con palmeras y vides entre los que hagas brotar caudalosos arroyos,\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcxxi{o que, como pretendes, hagas caer sobre nosotros parte del cielo o nos traigas en tu apoyo a Alá y a los ángeles,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcxxii{o que tengas una casa suntuosa, o te eleves en el aire. Pero tampoco vamos a creer en tu elevación mientras no nos hagas bajar una Escritura que podamos leer». Di: «¡Gloria a mi Señor! ¿Y qué soy yo sino un mortal, un enviado?»\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcxxiii{No ha impedido a los hombres creer cuando les ha llegado la Dirección sino el haber dicho: «¿Ha mandado Alá a un mortal como enviado?»\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcxxiv{Di: «Si hubiera habido en la tierra ángeles andando tranquilamente, habríamos hecho que les bajara del cielo un ángel como enviado».\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcxxv{Di: «Alá basta como testigo entre yo y vosotros. Está bien informado sobre Sus siervos, les ve bien».\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcxxvi{Aquél a quien Alá dirige está bien dirigido. Pero no encontrarás amigos, fuera de Él, para aquéllos a quienes Él extravía. Les congregaremos el día de la Resurrección boca abajo, ciegos, mudos, sordos. Tendrán la gehena por morada. Siempre que el fuego vaya a apagarse, se lo atizaremos.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcxxvii{Ésa será su retribución por no haber creído en Nuestros signos y por haber dicho: «Cuando seamos huesos y polvo, ¿es verdad que se nos resucitará a una nueva creación?»\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcxxviii{¿Es que no ven que Alá, Que ha creado los cielos y la tierra, es capaz de crear semejantes a ellos? Les ha señalado un plazo indubitable, pero los impíos no quieren sino ser infieles.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmcxxix{Di: «Si poseyerais los tesoros de misericordia de mi Señor, entonces, los retendríais por miedo de gastarlos». El hombre es tacaño...\qt@no{100}}
\qt@newcmd\qurantrans@es@mmcxxx{Dimos a Moisés nueve signos claros. Pregunta a los Hijos de Israel qué pasó, cuando vino a ellos y Faraón le dijo: «¡Moisés! ¡Yo creo, sí, que estás hechizado!»\qt@no{101}}
\qt@newcmd\qurantrans@es@mmcxxxi{Dijo: «Tú sabes bien que sólo el Señor de los cielos y de la tierra ha hecho bajar éstos como pruebas evidentes. ¡Yo creo, Faraón, sí, que estás perdido!»,\qt@no{102}}
\qt@newcmd\qurantrans@es@mmcxxxii{Quiso ahuyentarles del país y le anegamos con todos los suyos.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmcxxxiii{Y, después de él, dijimos a los Hijos de Israel: «Habitad la tierra y, cuando se cumpla la promesa de la otra vida, os llevaremos en tropel».\qt@no{104}}
\qt@newcmd\qurantrans@es@mmcxxxiv{Lo hemos hecho descender con la Verdad y con la Verdad ha descendido. No te hemos enviado sino como nuncio de buenas nuevas y como monitor.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmcxxxv{Es un Corán que hemos dividido para que lo recites a la gente reposadamente. Lo hemos revelado de hecho.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmcxxxvi{Di: «Creáis en él o no, quienes han y recibido de antes la Ciencia, cuando les es recitado, caen prosternados, rostro en tierra,\qt@no{107}}
\qt@newcmd\qurantrans@es@mmcxxxvii{y dicen: '¡Gloria a nuestro Señor! ¡Se ha cumplido, sí, la promesa de nuestro Señor!'\qt@no{108}}
\qt@newcmd\qurantrans@es@mmcxxxviii{Y continúan rostro en tierra, llorando y creciendo en humildad».\qt@no{109}}
\qt@newcmd\qurantrans@es@mmcxxxix{Di: «¡Invocad a 'Alá' o invocad al 'Compasivo'! Como quiera que invoquéis, Él posee los nombres más bellos». No hagas la azalá en voz demasiado alta, ni demasiado baja, sino con voz moderada.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmcxl{Y di: «¡Alabado sea Alá, Que no ha adoptado un hijo, ni tiene asociado en el dominio, ni amigo frente a la humillación!» ¡Y ensalza Su grandeza!\qt@no{111}}
\qt@newcmd\qurantrans@es@mmcxli{\basmalahes ¡Alabado sea Alá, que ha revelado la Escritura a Su siervo y no ha puesto en ella tortuosidad,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcxlii{sino que la ha hecho recta, para prevenir contra una grave calamidad que procede de Él, anunciar a los creyentes que obran bien que tendrán una bella recompensa,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcxliii{en la que permanecerán para siempre,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcxliv{y para advertir a los que dicen que Alá ha adoptado un hijo!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcxlv{Ni ellos ni sus predecesores tienen ningún conocimiento de eso. ¡Qué monstruosa palabra la que sale de sus bocas! No dicen sino mentira.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcxlvi{Tú quizá te consumas de pena, si no creen en esta historia, por las huellas que dejan.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcxlvii{Hemos adornado la tierra con lo que en ella hay para probarles y ver quién de ellos es el que mejor se porta\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcxlviii{Y, ciertamente, haremos de su superficie un sequeral.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcxlix{¿Crees que los de la caverna y de ar-Raqim constituyen una maravilla entre Nuestros signos?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcl{Cuando los jóvenes, al refugiarse en la caverna, dijeron: «¡Señor! ¡Concédenos una misericordia de Ti y haz que nos conduzcamos correctamente!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcli{Y les hicimos dormir en la caverna por muchos años.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmclii{Luego, les despertamos para saber cuál de los dos grupos calculaba mejor cuánto tiempo habían permanecido.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcliii{Nosotros vamos a contarte su relato verdadero. Eran jóvenes que creían en su Señor y a quienes habíamos confirmado en la buena dirección.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcliv{Fortalecimos su ánimo cuando se levantaron y dijeron: «Nuestro Señor es el Señor de los cielos y de la tierra. No invocaremos a más dios que a Él. Si no, diríamos una solemne mentira.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmclv{Este pueblo nuestro ha tomado dioses en lugar de tomarle a Él. ¿Por qué no presentan alguna autoridad clara en su favor? ¿Hay alguien que sea más impío que quien inventa una mentira contra Alá?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmclvi{Cuando os hayáis alejado de ellos y de lo que, en lugar de Dios, sirven, ¡refugiaos en la caverna! Vuestro Señor extenderá, sobre vosotros algo de Su misericordia y dispondrá de la mejor manera de vuestra suerte».\qt@no{16}}
\qt@newcmd\qurantrans@es@mmclvii{Habrías visto que el sol, al salir, se desviaba de su caverna hacia la derecha y, al ponerse, los rebasaba hacia la izquierda, mientras ellos estaban en una oquedad de ella. Ése es uno de los signos de Alá. Aquél a quien Alá dirige está bien dirigido, pero para aquél a quien Él extravía no encontrarás amigo que le guíe.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmclviii{Les hubieras creído despiertos cuando, en realidad, dormían. Les dábamos vuelta a derecha e izquierda, mientras su perro estaba en el umbral con las patas delanteras extendidas. Si les hubieras visto, te habrías escapado de ellos, lleno de miedo.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmclix{Así estaban cuando les despertamos para que se preguntaran unos a otros. Uno de ellos dijo: «¿Cuánto tiempo habéis permanecido?» Dijeron: «Permanecimos un día o menos». Dijeron: «Vuestro Señor sabe bien cuánto tiempo habéis permanecido. Enviad a uno de vosotros con esta vuestra moneda a la ciudad. Que mire quién tiene el alimento más fresco y que os traiga provisión del mismo. Que se conduzca bien y que no atraiga la atención de nadie sobre vosotros,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmclx{pues, si se enteraran de vuestra existencia, os lapidarían u os harían volver a su religión y nunca más seríais felices».\qt@no{20}}
\qt@newcmd\qurantrans@es@mmclxi{Y así los descubrimos para que supieran que lo que Alá promete es verdad y que no hay duda respecto a la Hora. Cuando discutían entre sí sobre su asunto. Dijeron: «¡Edificad sobre ellos! Su Señor les conoce bien». Los que prevalecieron en su asunto dijeron: «¡Levantemos sobre ellos un santuario!»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmclxii{Unos dirán: «Eran tres, cuatro con su perro». Otros dirán: «Eran cinco, seis con su perro», conjeturando sobre lo oculto. Otros dirán: «Eran siete, ocho con su perro». Di: «Mi Señor sabe bien su número, sólo pocos les conocen». No discutas, pues, sobre ellos, sino someramente y no consultes sobre ellos a nadie.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmclxiii{Y no digas a propósito de nada: «Lo haré mañana»,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmclxiv{sin: «si Alá quiere». Y, si te olvidas de hacerlo, recuerda a tu Señor, diciendo: «Quizá mi Señor me dirija a algo que esté más cerca que eso de lo recto».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmclxv{Permanecieron en su caverna trescientos años, a los que se añaden nueve.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmclxvi{Di: «Alá sabe bien cuánto tiempo permanecieron. Suyo es lo oculto de los cielos y de la tierra. ¡Qué bien ve y qué bien oye! Fuera de Él, los hombres no tienen amigo. Y Él no asocia a nadie en Su decisión».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmclxvii{Recita lo que se te ha revelado de la Escritura de tu Señor. No hay quien pueda cambiar Sus palabras y no encontrarás asilo fuera de Él.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmclxviii{¡No rehúyas estar con los que invocan a su Señor mañana y tarde por deseo de agradarle! ¡No quites los ojos de ellos por deseo del ornato de la vida de acá! ¡No obedezcas a aquél cuyo corazón hemos hecho que se despreocupe de Nuestro recuerdo, que sigue su pasión y se conduce insolentemente!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmclxix{Y di: «La Verdad viene de vuestro Señor. ¡Que crea quien quiera, y quien no quiera que no crea!» Hemos preparado para los impíos un fuego cuyas llamas les cercarán. Si piden socorro, se les socorrerá con un líquido como de metal fundido, que les abrasará el rostro. ¡Mala bebida! Y ¡mal lugar de descanso!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmclxx{Quienes, en cambio, crean y obren bien... No dejaremos de remunerar a quienes se conduzcan bien.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmclxxi{Para ésos serán los jardines del edén, por cuyos bajos fluyen arroyos. Se les adornará allí con brazaletes de oro, se les vestirá de satén y brocado verdes, estarán allí reclinados en divanes. ¡Qué agradable recompensa y qué bello lugar de descanso!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmclxxii{Propónles la parábola de dos hombres, a uno de los cuales dimos dos viñedos, que cercamos de palmeras y separamos con sembrados.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmclxxiii{Ambos viñedos dieron su cosecha, no fallaron nada, e hicimos brotar entre ellos un arroyo.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmclxxiv{Uno tuvo frutos y dijo a su compañero, con quien dialogaba: «Soy más que tú en hacienda y más fuerte en gente».\qt@no{34}}
\qt@newcmd\qurantrans@es@mmclxxv{Y entró en su viñedo, injusto consigo mismo. Dijo: «No creo que éste perezca nunca.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmclxxvi{Ni creo que ocurra la Hora. Pero, aun si soy llevado ante mi Señor, he de encontrar, a cambio, algo mejor que él».\qt@no{36}}
\qt@newcmd\qurantrans@es@mmclxxvii{El compañero con quien dialogaba le dijo: «¿No crees en Quien te creó de tierra, luego, de una gota y, luego, te dio forma de hombre?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmclxxviii{En cuanto a mí, Él es Alá, mi Señor, y no asocio nadie a mi Señor.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmclxxix{Si, al entrar en tu viñedo, hubieras dicho: '¡Que sea lo que Alá quiera! ¡La fuerza reside sólo en Alá!' Si ves que yo tengo menos que tú en hacienda e hijos,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmclxxx{quizá me dé Alá algo mejor que tu viñedo, lance contra él rayos del cielo y se convierta en compo pelado,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmclxxxi{o se filtre su agua por la tierra y no puedas volver a encontrarla».\qt@no{41}}
\qt@newcmd\qurantrans@es@mmclxxxii{Su cosecha fue destruida y, a la mañana siguiente, se retorcía las manos pensando en lo mucho que había gastado en él: sus cepas estaban arruinadas. Y decía: «¡Ojalá no hubiera asociado nadie a mi Señor!»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmclxxxiii{No hubo grupo que, fuera de Alá, pudiera auxiliarle, ni pudo defenderse a sí mismo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmclxxxiv{En casos así sólo Alá, la Verdad, ofrece amistad. Él es el Mejor en recompensar y el Mejor como fin.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmclxxxv{Propónles la parábola de la vida de acá. Es como agua que hacemos bajar del cielo y se empapa de ella la vegetación de la tierra, pero se convierte en hierba seca, que los vientos dispersan. Alá es potísimo en todo.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmclxxxvi{La hacienda y los hijos varones son el ornato de la vida de acá. Pero las obras perdurables, las buenas obras, recibirán una mejor recompensa ante tu Señor, constituyen una esperanza mejor fundada.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmclxxxvii{El día que pongamos en marcha las montañas, veas la tierra allanada, congreguemos a todos sin excepción,\qt@no{47}}
\qt@newcmd\qurantrans@es@mmclxxxviii{y sean presentados en fila ante tu Señor. «Venís a Nosotros como os creamos por vez primera. Y ¿pretendíais que no íbamos a citaros?»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmclxxxix{Se expondrá la Escritura y oirás decir a los pecadores, temiendo por su contenido: «¡Ay de nosotros! ¿Qué clase de Escritura es ésta, que no deja de enumerar nada, ni grande ni pequeño?» Allí encontrarán ante ellos lo que han hecho. Y tu Señor no será injusto con nadie.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcxc{Y cuando dijimos a los ángeles: «¡Prosternaos ante Adán!» Se prosternaron, excepto Iblis, que era uno de los genios y desobedeció la orden de su Señor. ¿Cómo? ¿Les tomaréis, a él y a sus descendientes, como amigos, en lugar de tomarme a Mí, siendo así que son vuestros enemigos? ¡Qué mal trueque para los impíos!\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcxci{No les he puesto como testigos de la creación de los cielos y de la tierra ni de su propia creación, ni he tomado como auxiliares a los que extravían a otros.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcxcii{El día que diga: «¡Llamad a aquéllos que pretendíais que eran Mis asociados!», les invocarán, pero no les ecucharán. Pondremos un abismo entre ellos.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcxciii{Los pecadores verán el Fuego y creerán que se precipitan en él, sin encontrar modo de escapar.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcxciv{En este Corán hemos expuesto a los hombres toda clase de ejemplos, pero el hombre es, de todos los seres, el más discutidor.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcxcv{Lo único que impide a los hombres creer cuando les llega la Dirección y pedir el perdón de su Señor, es el no admitir que les alcanzará la misma suerte que a los antiguos o que deberán afrontar el castigo.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcxcvi{No mandamos a los enviados sino como nuncios de buenas nuevas y para advertir. Los que no creen discuten con argucias para derribar, así, la Verdad, y toman a burla Mis signos y las advertencias.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcxcvii{¿Hay alguien que sea más impío que quien, habiéndosele recordado los signos de su Señor, se desvía luego de ellos y olvida lo que sus manos obraron? Hemos velado sus corazones y endurecido sus oídos para que no lo entiendan. Aunque les llames hacia la Dirección, no serán nunca bien dirigidos.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcxcviii{Tu Señor es el Indulgente, el Dueño de la Misericordia. Si les diera su merecido, les adelantaría el castigo. Tienen, sin embargo, una cita a la que no podrán faltar.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcxcix{Hicimos perecer esas ciudades cuando obraron impíamente, habiendo fijado por anticipado cuándo iban a perecer.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcc{Y cuando Moisés dijo a su mozo: «No cejaré hasta que alcance la confluencia de las dos grandes masas de agua, aunque tenga que andar muchos años».\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcci{Y, cuando alcanzaron su confluencia, se olvidaron de su pez, que emprendió tranquilamente el camino hacia la gran masa de agua.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmccii{Y, cuando pasaron más allá dijo a su mozo: «¡Trae la comida, que nos hemos cansado con este viaje!»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcciii{Dijo: «¿Qué te parece? Cuando nos refugiamos en la roca, me olvidé del pez -nadie sino el Demonio hizo olvidarme de que me acordara de él- y emprendió el camino hacia la gran masa de agua. ¡Es asombroso!»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcciv{Dijo: «Eso es lo que deseábamos», y regresaron volviendo sobre sus pasos,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmccv{encontrando a uno de Nuestros, siervos a quien habíamos hecho objeto de una misericordia venida de Nosotros y enseñado una ciencia de Nosotros.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmccvi{Moisés le dijo: «¿Te sigo para que me enseñes algo de la buena dirección que se te ha enseñado?»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmccvii{Dijo: «No podrás tener paciencia conmigo.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmccviii{¿Y cómo vas a tenerla en aquello de que no tienes pleno conocimiento?»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmccix{Dijo: «Me encontrarás, si Alá quiere, paciente, y no desobedeceré tus órdenes».\qt@no{69}}
\qt@newcmd\qurantrans@es@mmccx{Dijo: «Si me sigues, pues, no me preguntes nada sin que yo te lo sugiera».\qt@no{70}}
\qt@newcmd\qurantrans@es@mmccxi{Y se fueron ambos hasta que, habiendo subido a la nave, hizo en ella un boquete. Dijo: «¿Le has hecho un boquete para que se ahoguen sus pasajeros? ¡Has hecho algo muy grave!»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmccxii{Dijo: «¿No te he dicho que no podrías tener paciencia conmigo?»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmccxiii{«No lleves a mal mi olvido», dijo, «y no me sometas a una prueba demasiado difícil».\qt@no{73}}
\qt@newcmd\qurantrans@es@mmccxiv{Y reanudaron ambos la marcha, hasta que encontraron a un muchacho y le mató. Dijo: «¿Has matado a una persona inocente que no había matado a nadie? ¡Has hecho algo horroroso!»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmccxv{Dijo: «¿No te he dicho que no podrías tener paciencia conmigo?»\qt@no{75}}
\qt@newcmd\qurantrans@es@mmccxvi{Dijo: «Si en adelante te pregunto algo, no me tengas más por compañero. Y acepta mis excusas».\qt@no{76}}
\qt@newcmd\qurantrans@es@mmccxvii{Y se pusieron de nuevo en camino hasta que llegaron a una ciudad a cuyos habitantes pidieron de comer, pero éstos les negaron la hospitalidad. Encontraron, luego, en ella un muro que amenazaba derrumbarse y lo apuntaló. Dijo: «Si hubieras querido, habrías podido recibir un salario por eso».\qt@no{77}}
\qt@newcmd\qurantrans@es@mmccxviii{Dijo: «Ha llegado el momento de separarnos. Voy a informarte del significado de aquello en que no has podido tener paciencia.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmccxix{En cuanto a la nave, pertenecía a unos pobres que trabajaban en el mar y yo quise averiarla, pues detrás de ellos venía un rey que se apoderaba por la fuerza de todas las naves.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmccxx{Y en cuanto al muchacho, sus padres eran creyentes y tuvimos miedo de que les impusiera su rebeldía e incredulidad,\qt@no{80}}
\qt@newcmd\qurantrans@es@mmccxxi{y quisimos que su Señor les diera a cambio uno más puro que aquél y más afectuoso.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmccxxii{Y en cuanto al muro, pertenecía a dos muchachos huérfanos de la ciudad. Debajo de él había un tesoro que les pertenecía. Su padre era bueno y tu Señor quiso que descubrieran su tesoro cuando alcanzaran la madurez, como muestra de misericordia venida de tu Señor. No lo hice por propia iniciativa. Éste es el significado de aquello en que no has podido tener paciencia».\qt@no{82}}
\qt@newcmd\qurantrans@es@mmccxxiii{Te preguntarán por el Bicorne. Di: «Voy a contaros una historia a propósito de él».\qt@no{83}}
\qt@newcmd\qurantrans@es@mmccxxiv{Le habíamos dado poderío en el país y le habíamos facilitado todo.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmccxxv{Siguió, pues, un camino\qt@no{85}}
\qt@newcmd\qurantrans@es@mmccxxvi{hasta que, a la puesta del sol, encontró que éste se ocultaba en una fuente pecinosa, junto a la cual encontró a gente. Dijimos:«Bicorne! Puedes castigarles o hacerles bien».\qt@no{86}}
\qt@newcmd\qurantrans@es@mmccxxvii{Dijo: «Castigaremos a quien obre impíamente y, luego, será llevado a su Señor, que le infligirá un castigo horroroso.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmccxxviii{Pero quien crea y obre bien tendrá como retribución lo mejor y le ordenaremos cosas fáciles».\qt@no{88}}
\qt@newcmd\qurantrans@es@mmccxxix{Luego, siguió otro camino\qt@no{89}}
\qt@newcmd\qurantrans@es@mmccxxx{hasta que, a la salida del sol, encontró que éste aparecía sobre otra gente a la que no habíamos dado refugio para protegerse de él.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmccxxxi{Así fue. Nosotros teníamos pleno conocimiento de lo que él tenía.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmccxxxii{Luego, siguió otro camino\qt@no{92}}
\qt@newcmd\qurantrans@es@mmccxxxiii{hasta que, llegado a un espacio entre los dos diques, encontró del lado de acá a gente que apenas comprendía palabra.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmccxxxiv{Dijeron: «¡Bicorne! Gog y Magog corrompen en la tierra. ¿Podríamos retribuirte a cambio de que colocaras un dique entre nosotros y ellos?»\qt@no{94}}
\qt@newcmd\qurantrans@es@mmccxxxv{Dijo: «El poderío que mi Señor me ha dado es mejor. ¡Ayudadme esforzadamente y levantaré una muralla entre vosotros y ellos!\qt@no{95}}
\qt@newcmd\qurantrans@es@mmccxxxvi{¡Traedme bloques de hierro!» Hasta que, habiendo rellenado el espacio vacío entre las dos laderas, dijo: «¡Soplad!» Hasta que, habiendo hecho del hierro fuego, dijo: «¡Traedme bronce fundido para derramarlo encima!»\qt@no{96}}
\qt@newcmd\qurantrans@es@mmccxxxvii{Y no pudieron escalarla, ni pudieron abrir brecha en ella.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmccxxxviii{Dijo: «Ésta es una misericordia venida de mi Señor, pero, cuando venga la promesa de mi Señor, Él la demolerá. Lo que mi Señor promete es verdad».\qt@no{98}}
\qt@newcmd\qurantrans@es@mmccxxxix{Ese día dejaremos que unos y otros se entremezclen. Se tocará la trompeta y los reuniremos a todos.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmccxl{Ese día mostraremos plenamente la gehena a los incrédulos,\qt@no{100}}
\qt@newcmd\qurantrans@es@mmccxli{cuyos ojos estaban cerrados a Mi recuerdo y que no podían oír.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmccxlii{¿Piensan, acaso, quienes no creen, que podrán tomar a Mis siervos como amigos en lugar de tomarme a Mí? Hemos preparado la gehena como alojamiento para los infieles\qt@no{102}}
\qt@newcmd\qurantrans@es@mmccxliii{Di: «¿Os daré a conocer quiénes son los que más pierden por sus obras,\qt@no{103}}
\qt@newcmd\qurantrans@es@mmccxliv{aquéllos cuyo celo se pierde en la vida de acá mientras creen obrar bien?»\qt@no{104}}
\qt@newcmd\qurantrans@es@mmccxlv{Son ellos los que no creen en los signos de su Señor, ni en que Le encontrarán. Vanas habrán sido sus obras y el día de la Resurrección no les reconoceremos peso.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmccxlvi{Su retribución será la gehena por no haber creído y por haber tomado a burla Mis signos y a Mis enviados.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmccxlvii{En cambio, los que hayan creído y obrado bien se alojarán en los jardines del paraíso,\qt@no{107}}
\qt@newcmd\qurantrans@es@mmccxlviii{eternamente, y no desearán mudarse.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmccxlix{Di: «si fuera el mar tinta para las palabras de mi Señor, se agotaría el mar antes de que se agotaran las palabras de mar Señor, aun si añadiéramos otro mar de tinta».\qt@no{109}}
\qt@newcmd\qurantrans@es@mmccl{Di: «Yo soy sólo un mortal como vosotros, a quien se ha revelado que vuestro Dios es un Dios Uno. Quien cuente con encontrar a su Señor, que haga buenas, obras y que cuando adore a su Señor, no Le asocie nadie».\qt@no{110}}
\qt@newcmd\qurantrans@es@mmccli{\basmalahes khy's.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcclii{Recuerdo de la misericordia que tu Señor tuvo con Su siervo Zacarías.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmccliii{Cuando invocó interiormente a su Señor.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmccliv{Dijo: «¡Señor! Se me han debilitado los huesos, mis cabellos han encanecido. Cuando Te he invocado, Señor, nunca me has decepcionado.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcclv{Temo la conducta de mis parientes a mi muerte, pues mi mujer es estéril. Regálame, pues, de Ti un descendiente,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcclvi{que me herede a mí y herede de la familia de Jacob, y ¡haz, Señor, que él Te sea agradable!»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcclvii{«¡Zacarías! Te anunciamos la buena nueva de un muchacho que se llamará Juan, sin homónimos en el pasado».\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcclviii{«¡Señor!» dijo «¿Cómo puedo tener un muchacho, siendo mi mujer estéril y yo un viejo decrépito?»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcclix{«Así será», dijo. «Tu Señor dice: 'Es cosa fácil para Mí. Ya te he creado antes cuando no eras nada'».\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcclx{Dijo: «¡Señor! ¡Dame un signo!» Dijo: «Tu signo será que, estando sano, no podrás hablar a la gente durante tres días».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcclxi{Entonces, salió del Templo hacia su gente y les significó que debían glorificar mañana y tarde.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcclxii{«¡Juan! ¡Coge la Escritura con mano firme!» Y le otorgamos el juicio cuando aún era niño,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcclxiii{así como ternura de Nosotros y pureza. Y fue temeroso de Alá\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcclxiv{y piadoso con sus padres; no fue violento, desobediente.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcclxv{¡Paz sobre él el día que nació, el día que muera y el día que sea resucitado a la vida!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcclxvi{Y recuerda a María en la Escritura, cuando dejó a su familia para retirarse a un lugar de Oriente.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmcclxvii{Y tendió un velo para ocultarse de ellos. Le enviamos Nuestro Espíritu y éste se le presentó como un mortal acabado.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmcclxviii{Dijo ella: «Me refugio de ti en el Compasivo. Si es que temes a Alá...»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmcclxix{Dijo él: «Yo soy sólo el enviado de tu Señor para regalarte un muchacho puro».\qt@no{19}}
\qt@newcmd\qurantrans@es@mmcclxx{Dijo ella: «¿Cómo puedo tener un muchacho si no me ha tocado mortal, ni soy una ramera?»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmcclxxi{«Así será», dijo. «Tu Señor dice: 'Es cosa fácil para Mí. Para hacer de él signo para la gente y muestra de Nuestra misericordia'. Es cosa decidida».\qt@no{21}}
\qt@newcmd\qurantrans@es@mmcclxxii{Quedó embarazada con él y se retiró con él a un lugar alejado.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmcclxxiii{Entonces los dolores de parto la empujaron hacia el tronco de la palmera. Dijo: «¡Ojalá hubiera muerto antes y se me hubiera olvidado del todo...!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmcclxxiv{Entonces, de sus pies, le llamó: «¡No estés triste! Tu Señor ha puesto a tus pies un arroyuelo.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmcclxxv{¡Sacude hacia ti el tronco de la palmera y ésta hará caer sobre ti dátiles frescos, maduros!\qt@no{25}}
\qt@newcmd\qurantrans@es@mmcclxxvi{¡Come, pues, bebe y alégrate! Y, si ves a algún mortal, di: 'He hecho voto de silencio al Compasivo. No voy a hablar, pues, hoy con nadie'»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmcclxxvii{Y vino con él a los suyos, llevándolo. Dijeron: «¡María! ¡Has hecho algo inaudito!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmcclxxviii{¡Hermana de Aarón! Tu padre no era un hombre malo, ni tu madre una ramera».\qt@no{28}}
\qt@newcmd\qurantrans@es@mmcclxxix{Entonces ella se lo indicó. Dijeron: «¿Cómo vamos a hablar a uno que aún está en la cuna, a un niño?»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmcclxxx{Dijo él: «Soy el siervo de Alá. Él me ha dado la Escritura y ha hecho de mí un profeta.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmcclxxxi{Me ha bendecido dondequiera que me encuentre y me ha ordenado la azalá y el azaque mientras viva,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmcclxxxii{y que sea piadoso con mi madre. No me ha hecho violento, desgraciado.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmcclxxxiii{La paz sobre mí el día que nací, el día que muera y el día que sea resucitado a la vida».\qt@no{33}}
\qt@newcmd\qurantrans@es@mmcclxxxiv{Tal es Jesús hijo de María, para decir la Verdad, de la que ellos dudan.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmcclxxxv{Es impropio de Alá adoptar un hijo. ¡Gloria a Él! Cuando decide algo, le dice tan sólo: «¡Sé!» y se.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmcclxxxvi{Y: «Alá es mi Señor y Señor vuestro. ¡Servidle, pues! Esto es una vía recta».\qt@no{36}}
\qt@newcmd\qurantrans@es@mmcclxxxvii{Pero los grupos discreparon unos de otros. ¡Ay de los que no hayan creído, porque presenciarán un día terrible!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmcclxxxviii{¡Qué bien oirán y verán el día que vengan a Nosotros! Pero los impíos están hoy, evidentemente, extraviados.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmcclxxxix{¡Prevénles contra el día de la Lamentación, cuando se decida la cosa! Y ellos, entre tanto, están despreocupados y no creen.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmccxc{Nosotros heredaremos la tierra y a sus habitantes. Y a Nosotros serán devueltos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmccxci{Y recuerda en la Escritura a Abraham. Fue veraz, profeta.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmccxcii{Cuando dijo a su padre: «¡Padre! ¿Por qué sirves lo que no oye, ni ve, ni te sirve de nada?\qt@no{42}}
\qt@newcmd\qurantrans@es@mmccxciii{¡Padre! He recibido una ciencia que tú no has recibido. ¡Sígueme, pues, y yo te dirigiré por una vía llana!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmccxciv{¡Padre! ¡No sirvas al Demonio! El Demonio se rebeló contra el Compasivo.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmccxcv{¡Padre! Temo que te alcance un castigo del Compasivo y que te hagas, así, amigo del Demonio».\qt@no{45}}
\qt@newcmd\qurantrans@es@mmccxcvi{Dijo: «Abraham! ¿Sientes aversión a mis dioses? Si no paras, he de lapidarte. ¡Aléjate de mí por algún tiempo!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmccxcvii{Dijo: «¡Paz sobre ti! Pediré por tu perdón a mi Señor. Ha sido benévolo conmigo.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmccxcviii{Me aparto de vosotros y de lo que invocáis en lugar de invocar a Alá, e invoco a mi Señor. Quizá tenga suerte invocando a mi Señor».\qt@no{48}}
\qt@newcmd\qurantrans@es@mmccxcix{Cuando se apartó de ellos y de lo que servían en lugar de servir a Alá, le regalamos a Isaac y a Jacob e hicimos de cada uno de éstos un profeta.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmccc{Les regalamos de Nuestra misericordia y les dimos una reputación buenísima.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmccci{Y recuerda en la Escritura a Moisés. Fue escogido. Fue enviado, profeta.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcccii{Le llamamos desde la ladera derecha del monte e hicimos que se acercara en plan confidencial.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmccciii{Por una misericordia Nuestra, le regalamos como profeta a su hermano Aarón.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmccciv{Y recuerda en la Escritura a Ismael. Fue cumplidor de su promesa. Fue enviado, profeta.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcccv{Prescribía a su gente la azalá y el azaque, y fue bien visto de su Señor.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcccvi{Y recuerda en la Escritura a Idris. Fue veraz, profeta.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcccvii{Le elevamos a un lugar eminente.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcccviii{Éstos son los que Alá ha agraciado entre los profetas descendientes de Adán, entre los que llevamos con Noé, entre los descendientes de Abraham y de Israel, entre los que dirigimos y elegimos. Cuando se les recitan las aleyas del Compasivo, caen prosternados llorando.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcccix{Sus sucesores descuidaron la azalá, siguieron lo apetecible y terminarán descarriándose.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcccx{salvo quienes se arrepientan, crean y obren bien. Ésos entrarán en el Jardín y no serán tratados injustamente en nada,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcccxi{en los jardines del edén prometidos por el Compasivo a Sus siervos en lo oculto. Su promesa se cumplirá.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcccxii{No oirán allí vaniloquio, sino «¡Paz!» y tendrán allí su sustento, mañana y tarde.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcccxiii{Ése es el Jardín que daremos en herencia a aquéllos de Nuestros siervos que hayan temido a Alá.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcccxiv{«No descendemos sino por orden de tu Señor. Suyo es el pasado, el futuro y el presente. Tu Señor no es olvidadizo.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcccxv{Es el Señor de los cielos, de la tierra y de lo que entre ellos está. ¡Sírvele, pues, persevera en Su servicio! ¿Sabes de alguien que sea Su homónimo?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcccxvi{El hombre dice: «Cuando muera, ¿se me resucitará?»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcccxvii{Pero ¿,es que no recuerda el hombre que ya antes, cuando no era nada, le creamos?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcccxviii{¡Por tu Señor, que hemos de congregarles, junto con los demonios, y, luego, hemos de hacerles comparecer, arrodillados, alrededor de la gehena!\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcccxix{Luego, hemos de arrancar de cada grupo a aquéllos que se hayan mostrado más rebeldes al Compasivo.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcccxx{Además, sabemos bien quiénes son los que más merecen abrasarse en ella.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcccxxi{Ninguno de vosotros dejará de llegarse a ella. Es una decisión irrevocable de tu Señor.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcccxxii{Luego, salvaremos a quienes temieron a Alá, y abandonaremos en ella, arrodillados, a los impíos.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcccxxiii{Cuando se les recitan Nuestras aleyas, como pruebas claras, dicen los infieles a los creyentes: «¿Cuál de los dos grupos está mejor situado y frecuenta mejor sociedad?»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcccxxiv{¡A cuántas generaciones antes de ellos, que les superaban en bienes y en apariencia, hemos hecho perecer...!\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcccxxv{Di: «¡Que el Compasivo prolongue la vida de los que están extraviados, hasta que vean lo que les amenaza: el castigo o la Hora! Entonces verán quién es el que se encuentra en la situación peor y dispone de tropas más débiles».\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcccxxvi{A los que se dejen dirigir, Alá les dirigirá aún mejor. Las obras perdurables, las obras buenas, recibirán ante tu Señor una recompensa mejor y un fin mejor.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcccxxvii{¿Y te parece que quien no cree en Nuestros signos y dice: «Recibiré, ciertamente, hacienda e hijos»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcccxxviii{conoce lo oculto o ha concertado una alianza con el Compasivo?\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcccxxix{¡No! Antes bien, tomaremos nota de lo que él dice y le prolongaremos el castigo.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcccxxx{Heredaremos de él lo que dice y vendrá, solo, a Nosotros.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcccxxxi{Han tomado dioses en lugar de tomar a Alá, para alcanzar poder.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcccxxxii{¡No! Negarán haberles servido y se convertirán en adversarios suyos.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcccxxxiii{¿No ves que hemos enviado a los demonios contra los infieles para que les instiguen al mal?\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcccxxxiv{¡No te precipites con ellos, que les contamos los días!\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcccxxxv{El día que congreguemos hacia el Compasivo a los temerosos de Alá, en grupo,\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcccxxxvi{y conduzcamos a los pecadores, en masa, a la gehena,\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcccxxxvii{no dispondrán de intercesores sino los que hayan concertado una alianza con el Compasivo.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcccxxxviii{Dicen: «El Compasivo ha adoptado un hijo».\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcccxxxix{Habéis cometido algo horrible,\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcccxl{que hace casi que los cielos se hiendan, que la tierra se abra, que las montañas caigan demolidas,\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcccxli{por haber atribuido un hijo al Compasivo,\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcccxlii{siendo así que no le está bien al Compasivo adoptar un hijo.\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcccxliii{No hay nadie en los cielos ni en la tierra que no venga al Compasivo sino como siervo.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcccxliv{Él los ha enumerado y contado bien.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcccxlv{Todos vendrán a Él, uno a uno, el día de la Resurrección.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcccxlvi{A quienes hayan creído y obrado bien, el Compasivo les dará amor.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcccxlvii{En verdad, lo hemos hecho fácil en tu lengua, para que anuncies con él la buena nueva a los que temen a Alá y para que adviertas con él a la gente pendenciera.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcccxlviii{¡A cuántas generaciones antes de ellos hemos hecho perecer! ¿Percibes a alguno de ellos u oyes de ellos un leve susurro?\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcccxlix{\basmalahes th.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcccl{No te hemos revelado el Corán para que padezcas,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcccli{sino como Recuerdo para quien tiene miedo de Alá,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmccclii{como revelación venida de Quien ha creado la tierra y los altos cielos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcccliii{El Compasivo se ha instalado en el Trono.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcccliv{Suyo es lo que está en los cielos y en la tierra, entre ellos y bajo tierra.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmccclv{No es preciso que te expreses en voz alta, pues Él conoce lo secreto y lo aún más recóndito.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmccclvi{¡Alá! ¡No hay más dios que Él! Posee los nombres más bellos.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmccclvii{¿Te has enterado de la historia de Moisés?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmccclviii{Cuando vio un fuego y dijo a su familia: «¡Quedaos aquí! Distingo un fuego. Quizá pueda yo traeros de él un tizón o encontrar la buena dirección con ayuda del fuego».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmccclix{Cuando llegó al fuego, le llamaron: «¡Moisés!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmccclx{Yo soy, ciertamente, tu Señor. Quítate las sandalias! Estás en el valle sagrado de Tuwa.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmccclxi{Y te he escogido Yo. Escucha, pues, lo que se va a revelar.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmccclxii{Yo soy, ciertamente, Alá. No hay más dios que Yo. ¡Sírveme, pues, y haz la azalá para recordarme!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmccclxiii{La Hora llega -estoy por ocultarla- para que cada uno sea retribuido según su esfuerzo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmccclxiv{¡Que no te desvíe de ella quien no cree en ella y sigue su pasión! Si no, ¡perecerás!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmccclxv{¿Qué es eso que tienes en la diestra, Moisés?»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmccclxvi{«Es mi vara», dijo. «Me apoyo en ella y con ella vareo los árboles para alimentar a mi rebaño. También la empleo para otros usos».\qt@no{18}}
\qt@newcmd\qurantrans@es@mmccclxvii{Dijo: «¡Tírala, Moisés!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmccclxviii{La tiró y he aquí que se convirtió en una serpiente que reptaba.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmccclxix{Dijo: «¡Cógela y no temas! Vamos a devolverle su condición primera.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmccclxx{¡Y llévate la mano al costado! Saldrá, blanca, sana - otro signo-.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmccclxxi{Para mostrarte parte de Nuestros tan grandes signos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmccclxxii{¡Ve a Faraón! Se muestra reacio».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmccclxxiii{Dijo: «¡Señor! ¡Infúndeme ánimo!\qt@no{25}}
\qt@newcmd\qurantrans@es@mmccclxxiv{¡Facilítame la tarea!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmccclxxv{¡Desata un nudo de mi lengua!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmccclxxvi{Así entenderán lo que yo diga.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmccclxxvii{Dame a alguien de mi familia que me ayude:\qt@no{29}}
\qt@newcmd\qurantrans@es@mmccclxxviii{a Aarón, mi hermano.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmccclxxix{¡Aumenta con él mi fuerza\qt@no{31}}
\qt@newcmd\qurantrans@es@mmccclxxx{y asóciale a mi tarea,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmccclxxxi{para que Te glorifiquemos mucho\qt@no{33}}
\qt@newcmd\qurantrans@es@mmccclxxxii{y Te recordemos mucho!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmccclxxxiii{Tú nos ves bien».\qt@no{35}}
\qt@newcmd\qurantrans@es@mmccclxxxiv{Dijo: «¡Moisés! Tu ruego ha sido escuchado.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmccclxxxv{Ya te agraciamos otra vez.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmccclxxxvi{Cuando inspiramos a tu madre lo siguiente:\qt@no{38}}
\qt@newcmd\qurantrans@es@mmccclxxxvii{'Échalo a esta arqueta y échala al río. El río lo depositará en la orilla. Un enemigo mío y suyo lo recogerá'. He lanzado sobre ti un amor venido de Mí para que seas educado bajo Mi mirada.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmccclxxxviii{Cuando tu hermana pasaba por allí y dijo: '¿Queréis que os indique a alguien que podría encargarse de él?'. Así te devolvimos a tu madre para que se alegrara y no estuviera triste. Mataste a un hombre, te salvamos de la tribulación y te sometimos a muchas pruebas. Viviste durante años con los madianitas y luego viniste acá, Moisés. cuando estaba determinado.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmccclxxxix{Te he escogido para Mí.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmcccxc{¡Ve! acompañado de tu hermano, con Mis signos, y no descuidéis el recordarme!\qt@no{42}}
\qt@newcmd\qurantrans@es@mmcccxci{¡Id a Faraón! Se muestra rebelde.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmcccxcii{¡Hablad con él amablemente! Quizás, así, se deje amonestar o tenga miedo de Alá».\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcccxciii{Dijeron: «¡Señor! Tememos que la tome con nosotros o que se muestre rebelde».\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcccxciv{Dijo: «¡No temáis! Yo estoy con vosotros, oyendo y viendo.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcccxcv{Id, pues, a él y decid: 'Somos los enviados de tu Señor. ¡Deja marchar con nosotros a los Hijos de Israel y no les atormentes! Te hemos traído un signo de tu Señor. ¡La paz sobre quien siga la Dirección !'\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcccxcvi{Se nos ha revelado que se infligirá el castigo a quien desmienta o se desvíe».\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcccxcvii{Dijo: «¿Y quién es vuestro Señor, Moisés?»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcccxcviii{Dijo: «Nuestro Señor es Quien ha dado a todo su forma y, luego, dirigido».\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcccxcix{Dijo: «¿Y qué ha sido de las genera ciones pasadas?»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcd{Dijo: «Mi Señor lo sabe y está en una Escritura. Mi Señor no yerra, ni olvida.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcdi{Quien os ha puesto la tierra como cuna y os ha trazado en ella caminos y hecho bajar agua del cielo. Mediante ella, hemos sacado toda clase de plantas.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcdii{¡Comed y apacentad vuestros rebaños! Hay, en ello, ciertamente, signos para los dotados de entendimiento.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcdiii{Os hemos creado de ella y a ella os devolveremos, para sacaros otra vez de ella».\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcdiv{Le mostramos todos Nuestros signos, pero él desmintió y rehusó creer.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcdv{Dijo: «¡Moisés! ¿Has venido a nosotros para sacarnos de nuestra tierra con tu magia?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcdvi{Hemos de responderte con otra magia igual. ¡Fija entre nosotros y tú una cita, a la que ni nosotros ni tú faltemos, en un lugar a propósito!»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcdvii{Dijo: «Vuestra cita será para el día de la Gran Fiesta. Que la gente sea convocada por la mañana».\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcdviii{Faraón se retiró, preparó sus artilugios y acudió.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcdix{Moisés les dijo: «¡Ay de vosotros! ¡No inventéis mentira contra Alá! Si no, os destruirá con un castigo. Quien invente, sufrirá una decepción».\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcdx{Los magos discutieron entre sí sobre su asunto y mantuvieron secreta la discusión.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcdxi{Dijeron: «En verdad, estos dos son unos magos que, con su magia, quieren sacaros de vuestra tierra y acabar con vuestra eminente doctrina.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcdxii{Preparad vuestros artilugios y, luego, venid uno a uno. ¡Quien gane hoy será feliz!»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcdxiii{Dijeron: «¡Moisés! ¿Quién es el primero en tirar? ¿Tú o nosotros?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcdxiv{Dijo: «¡No! ¡Tirad vosotros!» Y he aquí que le pareció que, por efecto de su magia, sus cuerdas y varas echaban a correr.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcdxv{Y Moisés temió en sus adentros.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcdxvi{Dijimos: «¡No temas, que ganarás tú!\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcdxvii{Tira lo que tienes en la diestra y devorará lo que ellos han hecho, que lo que ellos han hecho es sólo artimaña del mago. Y el mago no prosperará, venga de donde venga».\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcdxviii{Los magos cayeron prosternados. Dijeron: «¡Creemos en el Señor de Aarón y de Moisés!»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcdxix{Dijo: «Le habéis creído antes de que yo os autorizara a ello. Él es vuestro maestro, que os ha enseñado la magia. He de haceros amputar las manos y los pies opuestos y crucificar en troncos de palmera. Así sabréis, ciertamente, quién de nosotros es el que inflige un castigo más cruel y más duradero».\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcdxx{Dijeron: «No te preferiremos a ti a las pruebas claras que se nos han ofrecido ni a Quien nos ha creado. Decidas lo que decidas, tú sólo decides sobre la vida de acá.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcdxxi{Creemos en nuestro Señor, para que nos perdone nuestros pecados y la magia a que nos has obligado. Alá es mejor y más duradero».\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcdxxii{Quien viene a su Señor como culpable tendrá la gehena y en ella no podrá morir ni vivir.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcdxxiii{Quien, al contrario, venga a Él como creyente, después de haber obrado bien, tendrá la categoría más elevada:\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcdxxiv{los jardines del edén, por cuyos bajos fluyen arroyos, en los que estará eternamente. Ésa es la retribución de quien se mantiene puro.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcdxxv{Inspiramos a Moisés: «¡Sal de noche con Mis siervos y ábreles un camino seco en el mar! ¡No temas que os alcancen, no tengas miedo!»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcdxxvi{Faraón les persiguió con sus tropas y las aguas del mar les cubrieron.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmcdxxvii{Faraón había extraviado a su pueblo, no le había dirigido bien.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmcdxxviii{¡Hijos de Israel! Os hemos salvado de vuestros enemigos y nos hemos dado cita con vosotros en la ladera derecha del monte. Hemos hecho descender sobre vosotros el maná y las codornices:\qt@no{80}}
\qt@newcmd\qurantrans@es@mmcdxxix{«Comed de lo bueno de que os hemos proveído, pero sin excederos. Si no, me airaré con vosotros». Y aquél que incurre en Mi ira va a la ruina...\qt@no{81}}
\qt@newcmd\qurantrans@es@mmcdxxx{Yo soy, ciertamente, indulgente con quien se arrepiente, cree, obra bien y, luego, se deja dirigir bien.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmcdxxxi{«¡Moisés! ¿Por qué te has dado tanta prisa en alejarte de tu pueblo?»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmcdxxxii{Dijo: «Son ellos los que me persiguen. Y he corrido hacia Ti, Señor, para complacerte».\qt@no{84}}
\qt@newcmd\qurantrans@es@mmcdxxxiii{Dijo: «Hemos probado a tu pueblo después de irte, y el samaritano les ha extraviado».\qt@no{85}}
\qt@newcmd\qurantrans@es@mmcdxxxiv{Y Moisés regresó a su pueblo, airado, dolido. Dijo: «¡Pueblo! ¿No os había prometido vuestro Señor algo bello? ¿Es que la alianza os ha resultado demasiado larga o habéis querido que vuestro Señor se aíre con vosotros al faltar a lo que me habéis prometido?»\qt@no{86}}
\qt@newcmd\qurantrans@es@mmcdxxxv{Dijeron: «No hemos faltado por propio impulso a lo que te habíamos prometido, sino que se nos obligó a cargar con las joyas del pueblo y las hemos arrojado. Y lo mismo hizo el samaritano».\qt@no{87}}
\qt@newcmd\qurantrans@es@mmcdxxxvi{Éste les sacó un ternero, un cuerpo que mugía, y dijeron: «Este es vuestro dios y el dios de Moisés. Pero ha olvidado».\qt@no{88}}
\qt@newcmd\qurantrans@es@mmcdxxxvii{¿Es que no veían que no les daba ninguna contestación y no podía ni dañarles ni aprovecharles?\qt@no{89}}
\qt@newcmd\qurantrans@es@mmcdxxxviii{Ya antes les había dicho Aarón: «¡Pueblo! Sólo se os ha tentado con él. Vuestro Señor es el Compasivo. ¡Seguidme, pues, y obedeced mis órdenes!»\qt@no{90}}
\qt@newcmd\qurantrans@es@mmcdxxxix{Dijeron: «No dejaremos de entregarnos a su culto hasta que Moisés haya regresado».\qt@no{91}}
\qt@newcmd\qurantrans@es@mmcdxl{Dijo: «¡Aarón! Cuando has visto que se extraviaban, ¿qué es lo que te ha impedido\qt@no{92}}
\qt@newcmd\qurantrans@es@mmcdxli{seguirme? ¿Has desobedecido mis órdenes?»\qt@no{93}}
\qt@newcmd\qurantrans@es@mmcdxlii{Dijo: «¡Hijo de mi madre! ¡No me cojas por la barba ni por la cabeza! Tenía miedo de que dijeras: Has escindido a los Hijos de Israel y no has observado mi palabra'».\qt@no{94}}
\qt@newcmd\qurantrans@es@mmcdxliii{Dijo: «¿Qué alegas tú, samaritano?»\qt@no{95}}
\qt@newcmd\qurantrans@es@mmcdxliv{Dijo: «He visto algo que ellos no han visto. He tomado un puñado del polvo pisado por el enviado y lo he arrojado. Así me lo ha sugerido la imaginación».\qt@no{96}}
\qt@newcmd\qurantrans@es@mmcdxlv{Dijo: «¡Vete de aquí! En esta vida irás gritando: '¡No me toquéis!' Se te ha fijado una cita a la que no faltarás. ¡Y mira a tu dios, a cuyo culto tanto te has entregado! ¡Hemos de quemarlo y dispersar sus cenizas por el mar!\qt@no{97}}
\qt@newcmd\qurantrans@es@mmcdxlvi{¡Sólo Alá es vuestro dios, aparte del Cual no hay otro dios! Lo abarca todo en Su ciencia».\qt@no{98}}
\qt@newcmd\qurantrans@es@mmcdxlvii{Así te contamos historias de antaño y te hemos dado una Amonestación de Nosotros.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmcdxlviii{Quien se desvíe de ella llevará una carga el día de la Resurrección,\qt@no{100}}
\qt@newcmd\qurantrans@es@mmcdxlix{eternamente. ¡Qué carga más pesada tendrán el día de la Resurrección!\qt@no{101}}
\qt@newcmd\qurantrans@es@mmcdl{El día que se toque la trompeta y reunamos a los pecadores, ese día, ojizarcos,\qt@no{102}}
\qt@newcmd\qurantrans@es@mmcdli{diciéndose unos a otros por lo bajo: «No habéis permanecido sino diez días».\qt@no{103}}
\qt@newcmd\qurantrans@es@mmcdlii{Sabemos bien lo que dirán cuando el que más se distinga por su buena conducta diga: «No habéis permanecido sino un día».\qt@no{104}}
\qt@newcmd\qurantrans@es@mmcdliii{Te preguntarán por las montañas. Di: «Señor las reducirá a polvo y aventará.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmcdliv{Las dejará cual llano nivelado,\qt@no{106}}
\qt@newcmd\qurantrans@es@mmcdlv{en el que no se verán depresiones ni elevaciones».\qt@no{107}}
\qt@newcmd\qurantrans@es@mmcdlvi{Ese día, seguirán al Pregonero, que no se desviará. Bajarán las voces ante el Compasivo y no se oirá sino un susurro de pasos.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmcdlvii{Ese día no aprovechará más intercesión que la de aquél que cuente con la autorización del Compasivo, de aquél cuyas palabras Él acepte.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmcdlviii{Conoce su pasado y su futuro mientras que ellos no pueden abarcarlos en su ciencia.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmcdlix{Los rostros se humillarán ante el Viviente, el Subsistente. Quien se haya cargado de impiedad, sufrirá una decepción\qt@no{111}}
\qt@newcmd\qurantrans@es@mmcdlx{Quien, en cambio, obra bien, siendo creyente, no tiene por qué temer injusticia ni opresión.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmcdlxi{Así la hemos revelado como Corán árabe. Hemos expuesto en él amenazas. Quizás, así, Nos teman o les sirva de amonestación.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmcdlxii{¡Exaltado sea Alá, el Rey verdadero! ¡No te precipites en la Recitación antes de que te sea revelada por entero! Y di: «¡Señor! ¡Aumenta mi ciencia!»\qt@no{114}}
\qt@newcmd\qurantrans@es@mmcdlxiii{Habíamos concertado antes una alianza con Adán, pero olvidó y no vimos en él resolución.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmcdlxiv{Y cuando dijimos a los ángeles: «¡Prosternaos ante Adán!» Se prosternaron, excepto Iblis, que se negó.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmcdlxv{Dijimos: «¡Adán! Éste es un enemigo para ti y para tu esposa ¡Que no os expulse del Jardín; si no, serás desgraciado!\qt@no{117}}
\qt@newcmd\qurantrans@es@mmcdlxvi{En él, no debes sufrir hambre ni desnudez,\qt@no{118}}
\qt@newcmd\qurantrans@es@mmcdlxvii{ni sed, ni ardor del sol».\qt@no{119}}
\qt@newcmd\qurantrans@es@mmcdlxviii{Pero el Demonio le insinuó el mal. Dijo: «¡Adán! ¿Te indico el árbol de la inmortalidad y de un dominio imperecedero?»\qt@no{120}}
\qt@newcmd\qurantrans@es@mmcdlxix{Comieron de él, se les reveló su desnudez y comenzaron a cubrirse con hojas del Jardín. Adán desobedeció a su Señor y se descarrió.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmcdlxx{Luego, su Señor le escogió. le perdonó y le puso en la buena dirección.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmcdlxxi{Dijo: «¡Descended ambos de él! ¡Todos! ¡Seréis enemigos unos de otros. Si, pues, recibís de Mí una dirección, quien siga Mi dirección no se extraviará y no será desgraciado.\qt@no{123}}
\qt@newcmd\qurantrans@es@mmcdlxxii{Pero quien no siga Mi Amonestación llevará una existencia miserable y le resucitaremos, ciego, el día de la Resurrección».\qt@no{124}}
\qt@newcmd\qurantrans@es@mmcdlxxiii{Dirá: «¡Señor! ¿Por qué me has resucitado ciego, siendo así que antes veía?»\qt@no{125}}
\qt@newcmd\qurantrans@es@mmcdlxxiv{Dirá: «Igual que tú recibiste Nuestros signos y los olvidaste, así hoy eres olvidado».\qt@no{126}}
\qt@newcmd\qurantrans@es@mmcdlxxv{Así retribuiremos a quien haya cometido excesos y no haya creído en los signos de su Señor. Y el castigo de la otra vida será más cruel y más duradero.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmcdlxxvi{¿Es que no les dice nada que hayamos hecho perecer a tantas generaciones precedentes, cuyas viviendas huellan ellos ahora? Ciertamente, hay en ello signos para los dotados de entendimiento.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmcdlxxvii{Si no llega a ser por una palabra previa de tu Señor y no hubiera sido prefijado el plazo, habría sido ineludible.\qt@no{129}}
\qt@newcmd\qurantrans@es@mmcdlxxviii{¡Ten paciencia, pues, con lo que dicen y celebra las alabanzas de tu Señor antes de la salida del sol y antes de su puesta! ¡Glorifícale durante las horas de la noche y en las horas extremas del día! Quizás, así, quedes satisfecho.\qt@no{130}}
\qt@newcmd\qurantrans@es@mmcdlxxix{Y no codicies los goces efímeros que hemos concedido a algunos de ellos, brillo de la vida de acá, con objeto de probarles con ellos. El sustento de tu Señor es mejor y más duradero.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmcdlxxx{¡Prescribe a tu gente la azalá y persevera en ella! No te pedimos sustento. Somos Nosotros Quienes te sustentamos. El buen fin está destinado a los que temen a Alá.\qt@no{132}}
\qt@newcmd\qurantrans@es@mmcdlxxxi{Dicen: «¿Por qué no nos trae un signo de su Señor?» Pero ¿es que no han recibido prueba clara de lo que contienen las Hojas primeras?\qt@no{133}}
\qt@newcmd\qurantrans@es@mmcdlxxxii{Si les Hubiéramos hecho perecer antes con un castigo, habrían dicho: «¡Señor! ¿Por qué no nos has mandado un enviado? Habríamos seguido Tus signos antes de ser humillados y confundidos».\qt@no{134}}
\qt@newcmd\qurantrans@es@mmcdlxxxiii{Di: «Todos esperan. ¡Esperad, pues! Ya veréis quién sigue la vía llana y quién sigue la buena dirección».\qt@no{135}}
\qt@newcmd\qurantrans@es@mmcdlxxxiv{\basmalahes Se acerca el momento en que los hombres deban rendir cuentas, pero ellos, despreocupados, se desvían.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcdlxxxv{Cuando reciben una nueva amonestación de su Señor, la escuchan sin tomarla en serio,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcdlxxxvi{divertidos sus corazones. Los impíos cuchichean entre sí: «¿No es éste sino un mortal como vosotros? ¿Cederéis a la magia a sabiendas?»\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcdlxxxvii{Dice: «Mi Señor sabe lo que se dice en el cielo y en la tierra. Él es Quien todo lo oye, Quien todo lo sabe».\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcdlxxxviii{Ellos, en cambio, dicen: «¡Amasijo de sueños! ¡No! ¡Él lo ha inventado! ¡No! Es un poeta! ¡Que nos traiga un signo como los antiguos enviados!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcdlxxxix{Antes de ellos, ninguna de las ciudades que destruimos creía. Y éstos ¿van a creer?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcdxc{Antes de ti, no enviamos sino a hombres a los que hicimos revelaciones. Si no lo sabéis, ¡preguntad a la gente de la Amonestación!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcdxci{No les dimos un cuerpo que no necesitara alimentarse. Y no eran inmortales.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcdxcii{Cumplimos la promesa que les hicimos y les salvamos, igual que a otros a quienes Nosotros quisimos salvar, mientras que hicimos perecer a los inmoderados.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcdxciii{Os hemos revelado una Escritura en que se os amonesta. ¿Es que no comprendéis?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcdxciv{¡Cuántas ciudades impías hemos arruinado, suscitando después a otros pueblos!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcdxcv{Cuando sintieron Nuestro rigor, quisieron escapar de ellas rápidamente.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcdxcvi{«¡No huyáis, volved a vuestra vida regalada, a vuestras mansiones! Quizá se os pidan cuentas».\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcdxcvii{Dijeron: «¡Ay de nosotros, que hemos obrado impíamente!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcdxcviii{Y no cesaron en sus lamentaciones hasta que les segamos sin vida.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcdxcix{No creamos el cielo, la tierra y lo que entre ellos hay para pasar el rato.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmd{Si hubiéramos querido distraernos, lo habríamos conseguido por Nosotros mismos, de habérnoslo propuesto.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdi{Antes, al contrario, lanzamos la Verdad contra lo falso, lo invalida... y éste se disipa. ¡Ay de vosotros, por lo que contáis...!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdii{Suyos son quienes están en los cielos y en la tierra. Y quienes están junto a Él no se consideran demasiado altos para servirle, ni se cansan de ello.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdiii{Glorifican noche y día sin cesar.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdiv{¿Han tomado de la tierra a dioses capaces de resucitar?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdv{Si hubiera habido en ellos otros dioses distintos de Alá, se habrían corrompido. ¡Gloria a Alá, Señor del Trono, Que está por encima de lo que cuentan!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdvi{No tendrá Él que responder de lo que hace, pero ellos tendrán que responder.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdvii{Entonces, ¿han tomado a dioses en lugar de tomarle a Él? Di: «¡Aportad vuestra prueba!». Ésta es la Amonestación de mis contemporáneos y la Amonestación de mis antecesores. Pero la mayoría no conocen la Verdad y se desvían.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdviii{Antes de ti no mandamos a ningún enviado que no le reveláramos: «¡No hay más dios que Yo! ¡Servidme, pues!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdix{Y dicen: «El Compasivo ha adoptado hijos». ¡Gloria a É! Son, nada más, siervos honrados.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdx{Dejan que sea Él el primero en hablar y obran siguiendo Sus órdenes.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdxi{Él conoce su pasado y su futuro. No intercederán sino por aquéllos de quienes Él esté satisfecho. Están imbuidos del miedo que Él les inspira.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdxii{A quien de ellos diga: «Soy un dios fuera de Él» le retribuiremos con la gehena. Así retribuimos a los impíos.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdxiii{¿Es que no han visto los infieles que los cielos y la tierra formaban un todo homogéneo y los separamos? ¿Y que sacamos del agua a todo ser viviente? ¿Y no creerán?\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdxiv{Hemos colocado en la tierra montañas firmes para que ella y sus habitantes no vacilen. Hemos puesto en ella anchos pasos a modo de caminos. Quizás, así, sean bien dirigidos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdxv{Hemos hecho del cielo una techumbre protegida. Pero ellos se desvían de sus signos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdxvi{Él es Quien ha creado la noche y el día, el sol y la luna. Cada uno navega en una órbita.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdxvii{No hemos hecho eterno a ningún mortal antes de ti. Muriendo tú, ¿iban otros a ser inmortales?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdxviii{Cada uno gustará la muerte. Os probamos tentándoos con el mal y con el bien. Y a Nosotros seréis devueltos.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdxix{Cuanto te ven los infieles«no hacen sino tomarte a burla: «¿Es Éste quien habla mal de vuestros dioses?» Y no creen en la amonestación del Compasivo.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdxx{El hombre ha sido creado precipitado. Ya os haré ver Mis signos. ¡No Me deis prisa!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdxxi{que decís?» Y dicen: «¿Cuándo se cumplirá esta amenaza, si es verdad lo\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdxxii{Si supieran los infieles, cuando no puedan apartar el fuego de sus rostros ni de sus espaldas, cuando no puedan ser auxiliados...\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdxxiii{Pero ¡no! Les vendrá de repente y les dejará aturdidos. No podrán ni rechazarla ni retardarla.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdxxiv{Se burlaron de otros enviados que te precedieron, pero los que se burlaban se vieron cercados por aquello de que se burlaban.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdxxv{Di: «¿Quién os protegerá, noche y día. contra el Compasivo?» Pero no hacen caso de la amonestación de su Señor.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdxxvi{¿Tienen dioses que les defiendan en lugar de Nosotros? Éstos no pueden auxiliarse a sí mismos, ni encontrarán quien les ayude frente a Nosotros.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdxxvii{Les hemos permitido gozar de efímeros placeres, a ellos y a sus padres, hasta alcanzar una edad avanzada. ¿Es que no se dan cuenta de Nuestra intervención cuando reducimos la superficie de la tierra? ¡Serán ellos los vencedores?\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdxxviii{Di: «Os advierto, en verdad, por la Revelación, pero los sordos no oyen el llamamiento cuando se les advierte».\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdxxix{Si les alcanza un soplo del castigo de tu Señor, dicen de seguro: «¡Ay de nosotros, que hemos obrado impíamente!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdxxx{Para el día de la Resurrección dispondremos balanzas que den el peso justo y nadie será tratado injustamente en nada. Aunque se trate de algo del peso de un grano de mostaza, lo tendremos en cuenta. ¡Bastamos Nosotros para ajustar cuentas!\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdxxxi{Dimos a Moisés y a Aarón el Criterio, una claridad y una amonestación para los temerosos de Alá,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdxxxii{que tienen miedo de su Señor en secreto y se preocupan por la Hora.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdxxxiii{Esto es una amonestación bendita, que Nosotros hemos revelado ¿Y la negaréis?\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdxxxiv{Antes, dimos a Abraham, a quien conocíamos, la rectitud.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdxxxv{Cuando dijo a su padre y a su pueblo: «¿Qué son estas estatuas a cuyo culto estáis entregados?»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdxxxvi{Dijeron: «Nuestros padres ya les rendían culto».\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdxxxvii{Dijo: «Pues vosotros y vuestros padres estáis evidentemente extraviados».\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdxxxviii{Dijeron: «¿Nos hablas en serio o bromeas?»\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdxxxix{Dijo: «¡No! Vuestro Señor es el Señor de los cielos y de la tierra, que Él ha creado. Yo soy testigo de ello.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdxl{-¡Y por Alá!, que he de urdir algo contra vuestros ídolos cuando hayáis vuelto la espalda-».\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdxli{Y los hizo pedazos, excepto a uno grande que les pertenecía. Quizás, así, volvieran a él.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdxlii{Dijeron: «¿Quién ha hecho eso a nuestros dioses? Ese tal es, ciertamente, de los impíos».\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdxliii{«Hemos oído», dijeron, «a un mozo llamado Abraham que hablaba mal de ellos».\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdxliv{Dijeron: «¡Traedlo a vista de la gente! Quizás, así, sean testigos».\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdxlv{Dijeron: «¡Abraham! ¿Has hecho tú eso con nuestros dioses?»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdxlvi{«¡No!» dijo. «El mayor de ellos es quien lo ha hecho. ¡Preguntádselo, si es que son capaces de hablar!»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdxlvii{Se volvieron a sí mismos y dijeron: «Sois vosotros los impíos».\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdxlviii{Pero, en seguida, mudaron completamente de opinión: «Tú sabes bien que éstos son incapaces de hablar».\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdxlix{Dijo: «¿Es que servís, en lugar de servir a Alá, lo que no puede aprovecharos nada, ni dañaros?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdl{¡Uf, vosotros y lo que servís en lugar de servir a Alá! ¿Es que no razonáis?»\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdli{Dijeron: «¡Quemadlo y auxiliad así a vuestros dioses, si es que os lo habéis propuesto...!»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdlii{Dijimos: «¡Fuego! ¡Sé frío para Abraham y no le dañes!»\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdliii{Quisieron emplear artimañas contra él, pero hicimos que fueran ellos los que más perdieran.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdliv{Les salvamos, a él y a Lot, a la tierra que hemos bendecido para todo el mundo.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdlv{Y le regalamos, por añadidura, a Isaac y a Jacob. Y de todos hicimos justos.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdlvi{Les hicimos jefes, que dirigieran siguiendo Nuestra orden. Les inspiramos que obraran bien, hicieran la azalá y dieran el azaque. Y Nos rindieron culto.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdlvii{A Lot le dimos juicio y ciencia y le salvamos de la ciudad que se entregaba a la torpeza. Eran gente malvada, perversa.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdlviii{Le introdujimos en Nuestra misericordia. Es de los justos.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdlix{Y a Noé. Cuando, antes, invocó y le escuchamos. Y les salvamos, a él y a los suyos, de la gran calamidad.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdlx{Y le auxiliamos contra el pueblo que había desmentido Nuestros signos. Eran gente mala y los anegamos a todos.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdlxi{Y a David y Salomón. Cuando dictaron sentencia sobre el sembrado en que las ovejas de la gente se habían introducido de noche. Nosotros fuimos testigos de su sentencia.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdlxii{Hicimos comprender a Salomón de qué se trataba. Dimos a cada uno juicio y ciencia. Sujetamos, junto con David, las montañas y las aves para que glorificaran. Nosotros hicimos eso.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmdlxiii{Le enseñamos a elaborar cotas de malla para vosotros, para que os protegieran de vuestra propia violencia. ¿Ya lo agradecéis?\qt@no{80}}
\qt@newcmd\qurantrans@es@mmdlxiv{Y a Salomón el ventarrón, que sopla, a una orden suya, hacia la tierra que hemos bendecido. Lo sabemos todo...\qt@no{81}}
\qt@newcmd\qurantrans@es@mmdlxv{De los demonios, había algunos que buceaban para él y hacían otros trabajos. Nosotros les vigilábamos.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmdlxvi{Y a Job. Cuando invocó a su Señor: «¡He sufrido una desgracia, pero Tú eres la Suma Misericordia!»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmdlxvii{Y le escuchamos, alejando de él la desgracia que tenía, dándole su familia y otro tanto, como misericordia venida de Nosotros y como amonestación para Nuestros siervos.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmdlxviii{Y a Ismael, Idris y Dulkifl. Todos fueron de los pacientes.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmdlxix{Les introdujimos en Nuestra misericordia. Son de los justos.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmdlxx{Y al del pez. Cuando se fue airado y creyó que no podríamos hacer nada contra él. Y clamó en las tinieblas: «¡No hay más dios que Tú! ¡Gloria a Ti! He sido de los impíos».\qt@no{87}}
\qt@newcmd\qurantrans@es@mmdlxxi{Le escuchamos, pues, y le salvamos de la tribulación. Así es como salvamos a los creyentes.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmdlxxii{Y a Zacarías. Cuando invocó a su Señor: «¡Señor! ¡No me dejes solo! ¡Pero Tú eres el Mejor de los herederos!»\qt@no{89}}
\qt@newcmd\qurantrans@es@mmdlxxiii{Y le escuchamos y le regalamos Juan e hicimos que su esposa fuera capaz de concebir. Rivalizaban en buenas obras, Nos invocaban con amor y con temor y se conducían humildemente ante Nosotros.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmdlxxiv{Y a la que conservó su virginidad. Infundimos en ella de Nuestro Espíritu e hicimos de ella y de su hijo signo para todo el mundo.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmdlxxv{«Ésta es vuestra comunidad, es una sola comunidad. Y Yo soy vuestro Señor. ¡Servidme, pues!»\qt@no{92}}
\qt@newcmd\qurantrans@es@mmdlxxvi{Se dividieron en sectas, pero volverán todos a Nosotros.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmdlxxvii{El esfuerzo del creyente que obra bien no será ignorado. Nosotros tomamos nota.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmdlxxviii{Cuando destruimos una ciudad, les está prohibido a sus habitantes regresar a ella,\qt@no{95}}
\qt@newcmd\qurantrans@es@mmdlxxix{hasta que se suelte a Gog y Magog y se precipiten por toda colina abajo.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmdlxxx{Se acerca la amenaza verdadera. Los infieles, desorbitados los ojos: «¡Ay de nosotros, que no sólo nos traía esto sin cuidado, sino que obrábamos impíamente!»\qt@no{97}}
\qt@newcmd\qurantrans@es@mmdlxxxi{Vosotros y lo que servís en lugar de servir a Alá, seréis combustible para la gehena. ¡Bajaréis a ella!\qt@no{98}}
\qt@newcmd\qurantrans@es@mmdlxxxii{Si ésos hubieran sido dioses, no habrían bajado a ella. Estarán todos en ella eternamente.\qt@no{99}}
\qt@newcmd\qurantrans@es@mmdlxxxiii{Gemirán en ella, pero no oirán en ella.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmdlxxxiv{Aquéllos que ya hayan recibido de Nosotros lo mejor, serán mantenidos lejos de de ella.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmdlxxxv{No oirán el más leve ruido de ella y estarán eternamente en lo que tanto ansiaron.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmdlxxxvi{No les entristecerá el gran terror y los ángeles saldrán a su encuentro: «¡Éste es vuestro día, que se os había prometido!»\qt@no{103}}
\qt@newcmd\qurantrans@es@mmdlxxxvii{Día en que plegaremos el cielo como se pliega un pergamino de escritos. Como creamos una vez primera, crearemos otra. ¡Es promesa que nos obliga y la cumpliremos!\qt@no{104}}
\qt@newcmd\qurantrans@es@mmdlxxxviii{Hemos escrito en los Salmos, después de la Amonestación, que la tierra la heredarán Mis siervos justos.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmdlxxxix{He aquí un comunicado para gente que rinde culto a Alá.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmdxc{Nosotros no te hemos enviado sino como misericordia para todo el mundo.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmdxci{Di: «Sólo se me ha revelado que vuestro Dios es un Dios Uno ¡,Os someteréis, pues, a Él?»\qt@no{108}}
\qt@newcmd\qurantrans@es@mmdxcii{Si se desvían, di:«Os he informado a todos con equidad. Y no sé si aquello con que se os amenaza es inminente o remoto.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmdxciii{Él sabe tanto lo que decís abiertamente como lo que ocultáis»\qt@no{110}}
\qt@newcmd\qurantrans@es@mmdxciv{No sé. Quizás eso constituya para vosotros tentación y disfrute por algún tiempo».\qt@no{111}}
\qt@newcmd\qurantrans@es@mmdxcv{Dice: «¡Señor, decide según justicia! Nuestro Señor es el Compasivo, Aquél Cuya ayuda se implora contra lo que contáis».\qt@no{112}}
\qt@newcmd\qurantrans@es@mmdxcvi{\basmalahes ¡Hombres! ¡Temed a vuestro Señor! El terremoto de la Hora será algo terrible.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdxcvii{Cuando eso ocurra, toda nodriza olvidará a su lactante, toda embarazada abortará. Los hombres parecerán, sin estarlo, ebrios. El castigo de Alá será severo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdxcviii{Hay algunos hombres que discuten de Alá sin tener conocimiento, y siguen a todo demonio rebelde.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdxcix{Se le ha prescrito que extravíe y guíe al castigo del fuego de la gehena a quien le tome por dueño.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdc{¡Hombres! Si dudáis de la resurrección, Nosotros os hemos creado de tierra; luego, de una gota; luego, de un coágulo de sangre; luego, de un embrión formado o informe. Para aclararos. Depositamos en las matrices lo que queremos por un tiempo determinado; luego, os hacemos salir como criaturas para alcanzar, más tarde, la madurez. Algunos de vosotros mueren prematuramente; otros viven hasta alcanzar una edad decrépita, para que, después de haber sabido, terminen no sabiendo nada. Ves la tierra reseca, pero, cuando hacemos que el agua baje sobre ella, se agita, se hincha y hace brotar toda especie primorosa.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdci{Esto es así porque Alá es la Verdad, devuelve la vida a los muertos y es omnipotente.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdcii{Es que la Hora llega, no hay duda de ella, y Alá resucitará a quienes se encuentren en las sepulturas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdciii{Hay algunos hombres que discuten de Alá sin tener conocimiento, ni dirección, ni Escritura luminosa,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdciv{contoneándose para extraviar a otros del camino de Alá. Esos tales sufrirán la ignominia en la vida de acá y el día de la Resurrección les haremos gustar el castigo del fuego de la gehena:\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdcv{«¡Ahí tienes, por las obras que has cometido!» Alá no es injusto con Sus siervos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdcvi{Hay entre los hombres quien vacila en servir a Alá. Si recibe un bien, lo disfruta tranquilamente. Pero, si sufre una tentación, gira en redondo, perdiendo así la vida de acá y la otra: es una pérdida irreparable.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdcvii{Invoca, en lugar de invocar a Alá, lo que no puede dañarle ni aprovecharle. Ése es el profundo extravío.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdcviii{Invoca, ciertamente, a quien puede más fácilmente dañar que aprovechar. ¡Qué mal protector! y ¡qué mal compañero!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdcix{Alá introducirá a los creyentes que obraron bien en jardines por cuyos bajos fluyen arroyos. Alá hace lo que quiere.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdcx{Quien crea que Alá no va a auxiliarle en la vida de acá ni en la otra, que tienda una cuerda al cielo y luego la corte. ¡Que vea si su ardid acaba con lo que le irritaba!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdcxi{Así lo hemos revelado en aleyas‚ claras. Alá guía a quien Él quiere.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcxii{El día de la Resurrección, Alá fallará acerca de los creyentes, los judíos, los sabeos, los cristianos, los zoroastrianos y los asociadores. Alá es testigo de todo.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcxiii{¿No ves que se prosternan ante Alá los que están en los cielos y en la tierra, así como el sol, la luna, las estrellas, las montañas, los árboles, los animales y muchos de los hombres? Esto no obstante, muchos merecen el castigo. No hay quien honre a quien Alá desprecia. Alá hace lo que Él quiere.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcxiv{Estos son dos grupos rivales que disputan sobre su Señor. A los infieles se les cortarán trajes de fuego y se les derramará en la cabeza agua muy caliente,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcxv{que les consumirá las entrañas y la piel;\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcxvi{se emplearán en ellos focinos de hierro.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcxvii{Siempre que, de atribulados, quieran salir de ella se les hará volver. «¡Gustad el castigo del fuego de la gehena!»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcxviii{Pero a los creyentes y a los que obraron bien, Alá les introducirá en jardines por cuyos bajos fluyen arroyos. Allí se les ataviará con brazaletes de oro y con perlas, allí vestirán de seda.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcxix{Habrán sido guiados a la bella Palabra y a la vía del Digno de Alabanza.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcxx{Los infieles que apartan a otros del camino de Alá y de la Mezquita Sagrada, que hemos establecido para los hombres -tanto si residen en ella como si no-...Y a quien quiera impíamente profanarla, le haremos que guste un doloroso castigo.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcxxi{Y cuando preparamos para Abraham el emplazamiento de la Casa: «¡No Me asocies nada! ¡Purifica Mi Casa para los que dan las vueltas y para los que están de pie, para los que se inclinan y prosternan!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcxxii{¡Llama a los hombres a la peregrinación para que vengan a ti a pie o en todo flaco camello, venido de todo paso ancho y profundo,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcxxiii{para atestiguar los beneficios recibidos y para invocar el nombre de Alá en días determinados sobre las reses de que Él les ha proveído!: «¡Comed de ellas y alimentad al desgraciado, al pobre!»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdcxxiv{Luego, ¡que den fin a sus prohibiciones, que cumplan sus votos y que den las vueltas alrededor de la Casa Antigua!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcxxv{¡Así es! Y quien respete las cosas sagradas de Alá, será mejor para él ante su Señor. Se os han declarado lícitos los rebaños, excepto lo que se os recita. ¡Evitad la contaminación que viene de los ídolos! ¡Evitad el decir falsedades!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcxxvi{¡Como hanifes para con Alá y no como asociadores! Quien asocia a Alá otros dioses es como si cayera del cielo: las aves se lo llevarán o el viento lo arrastrará a un lugar lejano.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdcxxvii{Así es. Y quien respeta las cosas sagradas de Alá... Pues proceden del temor de Alá que tienen los corazones.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdcxxviii{Os aprovecharéis de ello hasta un día determinado. Luego, la inmolación tendrá lugar en la Casa Antigua.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdcxxix{Y hemos establecido un ritual para cada comunidad, a fin de que invoquen el nombre de Alá sobre las reses de que Él les ha proveído. Vuestro Dios es un Dios Uno. ¡Someteos, pues, a Él! ¡Y anuncia la buena nueva a los humildes,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcxxx{cuyo corazón tiembla a la mención de Alá, a los que tienen paciencia ante la adversidad, a los que hacen la azalá, a los que dan limosna de lo que les hemos proveído!\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcxxxi{Entre las cosas sagradas de Alá os hemos incluido los camellos de sacrificio. Tenéis en ellos bien. ¡Mencionad, pues, el nombre de Alá sobre ellos cuando están en fila! Y cuando yazcan sin vida, comed de ellos y alimentad al mendigo y al necesitado. Así los hemos sujetado a vuestro servicio. Quizás, así, seáis agradecidos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcxxxii{Alá no presta atención a su carne ni a su sangre, sino a vuestro temor de Él. Así os los ha sujetado a vuestro servicio, para que ensalcéis a Alá por haberos dirigido. ¡Y anuncia la buena nueva a quienes hacen el bien!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcxxxiii{Alá abogará en favor de los que han creído. Alá no ama a nadie que sea traidor contumaz, desagradecido.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcxxxiv{Les está permitido a quienes son atacados, porque han sido tratados injustamente. -Alá es, ciertamente, poderoso para auxiliarles-.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcxxxv{A quienes han sido expulsados injustamente de sus hogares, sólo por haber dicho: «¡Nuestro Señor es Alá!» Si Alá no hubiera rechazado a unos hombres valiéndose de otros, habrían sido demolidas ermitas, iglesias, sinagogas y mezquitas, donde se menciona mucho el nombre de Alá. Alá auxiliará, ciertamente, a quienes Le auxilien. Alá es, en verdad, fuerte, poderoso.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcxxxvi{A quienes, si les diéramos poderío en la tierra, harían la azalá, darían el azaque,, ordenarían lo que está bien y prohibirían lo que está mal. El fin de todo es Alá...\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcxxxvii{Y si te desmienten, también desmintieron antes el pueblo de Noé, los aditas y los tamudeos,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcxxxviii{el pueblo de Abraham, el pueblo de Lot\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcxxxix{y los madianitas. Y Moisés fue desmentido. Concedí una prórroga a los infieles. Luego, les sorprendí... Y ¡cuál no fue Mi reprobación!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdcxl{¡Qué de ciudades, impías, hemos destruido, que ahora yacen en ruinas...! ¡Qué de pozos abandonados...! ¡Qué de elevados palacios...!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdcxli{¿No han ido por la tierra con un corazón capaz de comprender y con un oído capaz de oír? ¡No son, no, sus ojos los que son ciegos, sino los corazones que sus pechos encierran!\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdcxlii{Te piden que adelantes la hora del b castigo, pero Alá no faltará a Su promesa. Un día junto a tu Señor vale por mil años de los vuestros.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdcxliii{A cuántas ciudades, impías, les concedí una prórroga. Luego, las sorprendí... ¡Soy Yo el fin de todo!\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdcxliv{Di: «¡Hombres! Yo sólo soy para vosotros un monitor que habla claro».\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdcxlv{Quienes crean y obren bien, obtendrán perdón y generoso sustento.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdcxlvi{Pero quienes se empeñen en hacer fracasar Nuestros signos, ésos morarán en el fuego de la gehena.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdcxlvii{Cuando mandábamos, antes de ti, a algún enviado o a algún profeta, siempre enturbiaba el Demonio sus deseos. Pero Alá invalida las sugestiones del Demonio y, luego, hace Sus aleyas unívocas. Alá es omnisciente, sabio.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdcxlviii{Para tentar por las sugestiones del Demonio a los enfermos de corazón y a los duros de corazón -los impíos están en marcada oposición-,\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdcxlix{y para que sepan quienes han recibido la Ciencia que esto es la Verdad venida de tu Señor, para que crean en ella y se humille ante ella su corazón. En verdad, Alá dirige a los creyentes a una vía recta.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdcl{Pero quienes no crean persistirán en sus dudas acerca de él, hasta que les llegue la Hora de repente o el castigo de un día nefasto.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdcli{Ese día el dominio será de Alá y Él decidirá entre ellos: quienes hayan creído y obrado bien, estarán en los jardines de la Delicia,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdclii{pero quienes no creyeron y desmintieron Nuestros signos tendrán un castigo humillante.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdcliii{A quienes, habiendo emigrado por Alá, sean muertos o mueran, Alá les proveerá de bello sustento. Alá es el Mejor de los proveedores.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdcliv{Ha de introducirles en un lugar que les placerá. Alá es, ciertamente, omnisciente, benigno.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdclv{Así es. Y si uno se desagravia en la medida del agravio recibido y es de nuevo tratado injustamente, Alá no dejará de auxiliarle. Alá, en verdad. perdona mucho, es indulgente.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdclvi{Esto es así porque Alá hace que la noche entre en el día y que el día entre en la noche. Alá todo lo oye, todo lo ve.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdclvii{Esto es así porque Alá es la Verdad, pero lo que ellos invocan en lugar de invocarle a Él es lo falso, y porque Alá es el Altísimo, el Grande.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdclviii{¿No ves cómo hace Alá bajar agua del cielo y la tierra verdea? Alá es sutil, está bien informado.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdclix{Suyo es lo que está en los cielos y en la tierra. Alá es, ciertamente, Quien Se basta a Sí mismo, el Digno de Alabanza.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdclx{¿No ves que Alá ha sujetado a vuestro servicio lo que hay en la tierra, así como las naves que navegan siguiendo Su orden? Sostiene el cielo para que no se desplome sobre la tierra, si no es con Su permiso. En verdad, Alá es con los hombres manso, misericordioso.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdclxi{Él es Quien os dio la vida; luego, os hará morir, luego, os volverá a la vida. El hombre es, ciertamente, desagradecido.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdclxii{Hemos establecido para cada comunidad un ritual, que ellos siguen. ¡Que no discutan contigo sobre este asunto! ¡Llama a tu Señor! Sí, sigues una dirección recta.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdclxiii{Y, si discuten contigo, di: «¡Alá sabe bien lo que hacéis!\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdclxiv{Alá decidirá entre vosotros el día de la Resurreción sobre aquello en que discrepabais».\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdclxv{¿No sabes que Alá sabe lo que está en el cielo y en la tierra? Eso está en una Escritura. Es cosa fácil para Alá.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdclxvi{Sirven, en lugar de servir a Alá, algo a lo que Él no ha conferido autoridad y de lo que no tienen ningún conocimiento. Los impíos no tendrán quien les auxilie.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdclxvii{Cuando se les recitan Nuestras aleyas como pruebas claras, adviertes la disconformidad en los rostros de los infieles. Poco les falta para arremeter contra quienes les recitan Nuestras aleyas. Di: «No sé si informaros de algo peor aún que eso: el Fuego, con que Alá ha amenazado a los infieles». ¡Qué mal fin...!\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdclxviii{¡Hombres! Se propone una parábola. ¡Escuchadla! Los que invocáis en lugar de invocar a Alá serían incapaces de crear una mosca, aun si se aunaran para ello. Y, si una mosca se les llevara algo, serían incapaces de recuperarlo. ¡Qué débiles son el suplicante y el suplicado!\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdclxix{No han valorado a Alá debidamente. Alá es, en verdad, fuerte, poderoso.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdclxx{Alá escoge enviados entre los ángeles y entre los hombres. Alá todo lo oye, todo lo ve.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdclxxi{Conoce su pasado y su futuro. Y todo será devuelto a Alá.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdclxxii{¡Creyentes! ¡Inclinaos, prosternaos, servid a vuestro Señor y obrad bien! Quizás, así, prosperéis.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdclxxiii{¡Luchad por Alá como Él se merece! Él os eligió y no os ha impuesto ninguna carga en la religión! ¡La religión de vuestro padre Abraham! Él os llamó 'musulmanes' anteriormente y aquí, para que el Enviado sea testigo de vosotros y que vosotros seáis testigos de los hombres. ¡Haced la azalá y, dad el azaque! ¡Y aferraos a Alá! ¡Él es vuestro Protector! ¡Es un protector excelente, un auxiliar excelente!\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdclxxiv{\basmalahes ¡Bienaventurados los creyentes,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdclxxv{que hacen su azalá con humildad,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdclxxvi{que evitan el vaniloquio,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdclxxvii{que dan el azaque,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdclxxviii{que se abstienen de comercio carnal,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdclxxix{salvo con sus esposas o con sus esclavas en cuyo caso no incurren en reproche,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdclxxx{mientras que quienes desean a otras mujeres, ésos son los que violan la ley-,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdclxxxi{que respetan los depósitos que se les confían y las promesas que hacen,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdclxxxii{que observan sus azalás!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdclxxxiii{Ésos son los herederos\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdclxxxiv{que heredarán el paraíso, en el que estarán eternamente.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdclxxxv{Hemos creado al hombre de arcilla fina.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdclxxxvi{Luego, le colocamos como gota en un receptáculo firme.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdclxxxvii{Luego, creamos de la gota un coágulo de sangre, del coágulo un embrión y del embrión huesos, que revestimos de carne. Luego, hicimos de él otra criatura. ¡Bendito sea Alá, el Mejor de los creadores!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdclxxxviii{Luego, después de esto, habéis de morir.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdclxxxix{Luego, el día de la Resurrección, seréis resucitados.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcxc{Encima de vosotros, hemos creado siete cielos. No hemos descuidado la creación.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcxci{Hemos hecho bajar del cielo agua en la cantidad debida y hecho que cale la tierra. Y también habríamos sido bien capaces de hacerla desaparecer.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcxcii{Por medio de ella os hemos creado palmerales y viñedos en los que hay frutos abundantes, de los que coméis.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcxciii{Y un árbol que crece en el monte Sinaí y que produce aceite y condimento para la comida.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcxciv{Tenéis, ciertamente, en los rebaños motivo de reflexión: os damos a beber del contenido de sus vientres, deriváis de ellos muchos beneficios, coméis de ellos.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcxcv{Ellos y las naves os sirven de medios de transporte.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcxcvi{Enviamos Noé a su pueblo y dijo: «¡Pueblo! ¡Servid a Alá! No tenéis a ningún otro dios que a Él. ¿Y no Le temeréis?»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcxcvii{Los dignatarios del pueblo, que no creían, dijeron: «Éste no es sino un mortal como vosotros, que quiere imponerse a vosotros. Si Alá hubiera querido, habría hecho descender a ángeles. No hemos oído que ocurriera tal cosa en tiempo de nuestros antepasados.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcxcviii{No es más que un poseso. ¡Observadle durante algún tiempo!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcxcix{«¡Señor!» dijo: «¡Auxíliame, que me desmienten!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcc{Y le inspiramos: «¡Construye la nave bajo Nuestra mirada y según Nuestra inspiración ! Y cuando venga Nuestra orden y el horno hierva, haz entrar en ella a una pareja de cada y a tu familia, salvo a aquél de ellos cuya suerte ha sido ya echada. ¡Y no me hables de los que hayan obrado impíamente! ¡Van a ser anegados!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcci{Cuando tú y los tuyos estéis instalados en la nave, di: '¡Alabado sea Alá, Que nos ha salvado del pueblo impío!'\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdccii{Y di: '¡Señor! ¡Haz que desembarque en un lugar bendito! Tú eres Quien mejor puede hacerlo'\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcciii{Ciertamente, hay en ello signos. En verdad, ponemos a prueba...»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcciv{Luego, después de ellos, suscitamos otra generación\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdccv{y les mandamos un enviado salido de ellos: «¡Servid a Alá! No tenéis a ningún otro dios que a Él ¿Y no Le temeréis?»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdccvi{Pero los dignatarios del pueblo, que no creían y desmentían la existencia de la otra vida y a los cuales habíamos enriquecido en la vida de acá, dijeron: «Éste no es sino un mortal como vosotros, que come de lo mismo que vosotros coméis y bebe de lo mismo que vosotros bebéis».\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdccvii{Si obedecéis a un mortal como vosotros, estáis perdidos.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdccviii{¿Os ha prometido que se os sacará cuando muráis y seáis tierra y huesos?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdccix{¡Está bien lejos de ocurrir lo que se os ha prometido!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdccx{¡No hay más vida que la nuestra de acá! Morimos y vivimos, pero no se nos resucitará.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdccxi{No es más que un hombre, que se ha inventado una mentira contra Alá. No tenemos fe en él.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdccxii{Dijo: «¡Señor! ¡Auxíliame, que me desmienten!»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdccxiii{Dijo: «Un poco más y se arrepentirán».\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdccxiv{El Grito les sorprendió merecidamente y les convertimos en detrito. ¡Atrás el pueblo impío!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdccxv{Luego, después de ellos, suscitamos otras generaciones.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdccxvi{Ninguna comunidad puede adelantar ni retrasar su plazo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdccxvii{Luego, mandamos a Nuestros enviados, uno tras otro. Siempre que venía un enviado a su comunidad, le desmentían. Hicimos que a unas generaciones les siguieran otras y las hicimos legendarias. ¡Atrás una gente que no cree!\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdccxviii{Luego, enviamos Moisés y su hermano Aarón con Nuestros signos y con una autoridad manifiesta\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdccxix{a Faraón y a sus dignatarios, que fueron altivos. Eran gente arrogante.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdccxx{Dijeron: «¿Vamos a creer a dos mortales como nosotros, mientras su pueblo nos sirve de esclavos?»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdccxxi{Les desmintieron y fueron hechos perecer.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdccxxii{Dimos a Moisés la Escritura. Quizás, así, fueran bien dirigidos.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdccxxiii{Hicimos del hijo de María y de su madre un signo y les ofrecimos refugio en una colina tranquila y provista de agua viva.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdccxxiv{«¡Enviados! ¡Comed de las cosas buenas y obrad bien! ¡Yo sé bien lo que hacéis!\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdccxxv{Y ésta es vuestra comunidad. Es una sola comunidad. Y Yo soy vuestro Señor. ¡Temedme, pues!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdccxxvi{Pero se dividieron en sectas, con Escrituras, contento cada grupo con lo suyo.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdccxxvii{Déjales por algún tiempo en su abismo.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdccxxviii{¿Creen que, al proveerles de hacienda y de hijos varones,\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdccxxix{estamos anticipándoles las cosas buenas? No, no se dan cuenta.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdccxxx{Los imbuidos del miedo de su Señor,\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdccxxxi{que creen en los signos de su Señor,\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdccxxxii{que no asocian a otros dioses a su Señor,\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdccxxxiii{que dan lo que dan con corazón tembloroso, a la idea de que volverán a su Señor,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdccxxxiv{ésos rivalizan en buenas obras y son los primeros en practicarlas.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdccxxxv{No pedimos a nadie sino según sus posibilidades. Tenemos al lado una Escritura que dice la verdad. Y no serán tratados injustamente.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdccxxxvi{Pero sus corazones están en un abismo respecto a esto y, en lugar de aquellas obras, hacen otras.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdccxxxvii{Cuando, al fin, inflijamos un castigo a sus ricos, gemirán.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdccxxxviii{«¡No gimáis hoy, que no se os va a salvar de Nosotros!\qt@no{65}}
\qt@newcmd\qurantrans@es@mmdccxxxix{Se os recitaban Mis aleyas y vosotros dabais media vuelta,\qt@no{66}}
\qt@newcmd\qurantrans@es@mmdccxl{altivos con él, y pasabais la noche parloteando».\qt@no{67}}
\qt@newcmd\qurantrans@es@mmdccxli{¿Es que no ponderan lo que se dice para ver si han recibido lo que sus antepasados no recibieron?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmdccxlii{¿No han conocido, acaso, a su Enviado para que le nieguen?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmdccxliii{¿O dicen que es un poseso? ¡No! Ha venido a ellos con la Verdad, pero la mayoría sienten aversión a la Verdad.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmdccxliv{Si la Verdad se hubiera conformado a sus pasiones, los cielos, la tierra y los que en ellos hay se habrían corrompido. Nosotros, en cambio, les hemos traído su Amonestación, pero ellos se apartan de su Amonestación.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmdccxlv{¿Les pides, acaso, una retribución? La retribución de tu Señor es mejor. Él es el Mejor de los proveedores.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmdccxlvi{Sí, tú les llamas a una vía recta,\qt@no{73}}
\qt@newcmd\qurantrans@es@mmdccxlvii{pero quienes no creen en la otra vida se desvían, sí, de la vía.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmdccxlviii{Si nos apiadáramos de ellos y les retiráramos la desgracia que tienen, persistirían, ciegos, en su rebeldía.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmdccxlix{Les infligimos un castigo, pero no se sometieron a su Señor y no se humillaron.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmdccl{Hasta que abramos contra ellos una puerta de severo castigo y, entonces, sean presa de la desesperación.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmdccli{Él es Quien ha creado para vosotros el oído, la vista y el intelecto. ¡Qué poco agradecidos sois!\qt@no{78}}
\qt@newcmd\qurantrans@es@mmdcclii{Él es Quien os ha diseminado por la tierra. Y hacia Él- seréis congregados.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmdccliii{Él es Quien da la vida y da la muerte. Él ha hecho que se sucedan la noche y el día. ¿Es que no comprendéis?\qt@no{80}}
\qt@newcmd\qurantrans@es@mmdccliv{Al contrario, dicen lo mismo que dijeron los antiguos.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmdcclv{Dicen: «Cuando muramos y seamos tierra y huesos, ¿se nos resucitará acaso?\qt@no{82}}
\qt@newcmd\qurantrans@es@mmdcclvi{Ya antes se nos había prometido esto a nosotros y a nuestros padres. No son más que patrañas de los antiguos».\qt@no{83}}
\qt@newcmd\qurantrans@es@mmdcclvii{Di: «¿De quién es la tierra y quien en ella hay? Si es que lo sabéis...»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmdcclviii{Dirán: «¡De Alá!» Di: «¿Es que no os dejaréis amonestar?»\qt@no{85}}
\qt@newcmd\qurantrans@es@mmdcclix{Di: «¿Quién es el Señor de los siete cielos, el Señor del Trono augusto?»\qt@no{86}}
\qt@newcmd\qurantrans@es@mmdcclx{Dirán: «¡Alá!» Di: «¿Y no Le teméis?»\qt@no{87}}
\qt@newcmd\qurantrans@es@mmdcclxi{Di: «¿Quién tiene en Sus manos la realeza de todo, protegiendo sin que nadie pueda proteger contra Él? Si es que lo sabéis...»\qt@no{88}}
\qt@newcmd\qurantrans@es@mmdcclxii{Dirán: «¡Alá!» Di: «Y ¿cómo podéis estar tan sugestionados?»\qt@no{89}}
\qt@newcmd\qurantrans@es@mmdcclxiii{Vinimos a ellos con la Verdad, pero mienten, si.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmdcclxiv{Alá no ha adoptado un hijo, ni hay otro dios junto con Él. Si no, cada dios se habría atribuido lo que hubiera creado y unos habrían sido superiores a otros. ¡Gloria a Alá, Que está por encima de lo que cuentan!\qt@no{91}}
\qt@newcmd\qurantrans@es@mmdcclxv{El conocedor de lo oculto y de lo patente. ¡Está por encima de lo que Le asocian!\qt@no{92}}
\qt@newcmd\qurantrans@es@mmdcclxvi{Di: «¡Señor! Si me mostraras aquello con que se les ha amenazado...\qt@no{93}}
\qt@newcmd\qurantrans@es@mmdcclxvii{¡No me pongas, Señor, con el pueblo impío!»\qt@no{94}}
\qt@newcmd\qurantrans@es@mmdcclxviii{Nosotros somos bien capaces, ciertamente, de mostrarte aquello con que les hemos amenazado.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmdcclxix{Repele el mal con algo que sea mejor Sabemos bien lo que cuentan.\qt@no{96}}
\qt@newcmd\qurantrans@es@mmdcclxx{Di: «¡Señor! Me refugio en Ti contra las sugestiones de los demonios.\qt@no{97}}
\qt@newcmd\qurantrans@es@mmdcclxxi{Me refugio en Ti, Señor, contra su acoso».\qt@no{98}}
\qt@newcmd\qurantrans@es@mmdcclxxii{Cuando, al fin, viene la muerte a uno de ellos, dice: «¡Señor! ¡Hazme volver!\qt@no{99}}
\qt@newcmd\qurantrans@es@mmdcclxxiii{Quizás, así, pueda hacer el bien que dejé de hacer». ¡No! No son sino meras palabras. Pero, detrás de ellos, hay una barrera hasta el día que sean resucitados.\qt@no{100}}
\qt@newcmd\qurantrans@es@mmdcclxxiv{Y, cuando se toque la trompeta, ese día, no valdrá ningún parentesco, ni se preguntarán unos a otros.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmdcclxxv{Aquéllos cuyas obras pesen mucho serán los que prosperen.\qt@no{102}}
\qt@newcmd\qurantrans@es@mmdcclxxvi{Aquéllos cuyas obras pesen poco, serán los que se hayan perdido y estarán en la gehena eternamente.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmdcclxxvii{El fuego abrasará su rostro; tendrán allí los labios contraídos.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmdcclxxviii{«¿No se os recitaron Mis aleyas y vosotros las desmentisteis?»\qt@no{105}}
\qt@newcmd\qurantrans@es@mmdcclxxix{«¡Señor!», dirán, «nuestra miseria nos pudo y fuimos gente extraviada.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmdcclxxx{¡Señor! ¡Sácanos de ella! Si reincidimos, seremos unos impíos».\qt@no{107}}
\qt@newcmd\qurantrans@es@mmdcclxxxi{Dirá: «¡Quedaos en ella y no Me habléis!»\qt@no{108}}
\qt@newcmd\qurantrans@es@mmdcclxxxii{Algunos de Mis siervos decían: «¡Señor! ¡Creemos! ¡Perdónanos, pues, y ten misericordia de nosotros! ¡Tú eres el Mejor de quienes tienen misericordia!»\qt@no{109}}
\qt@newcmd\qurantrans@es@mmdcclxxxiii{Pero os burlasteis tanto de ellos que hicieron que os olvidarais de Mí. Os reíais de ellos.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmdcclxxxiv{Hoy les retribuyo por la paciencia que tuvieron. Ellos son los que triunfan.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmdcclxxxv{Dirá: «¿Cuántos años habéis permanecido en la tierra?»\qt@no{112}}
\qt@newcmd\qurantrans@es@mmdcclxxxvi{Dirán: «Hemos permanecido un día o parte de un día. ¡Interroga a los encargados de contar!»\qt@no{113}}
\qt@newcmd\qurantrans@es@mmdcclxxxvii{Dirá: «No habéis permanecido sino poco tiempo. Si hubierais sabido...\qt@no{114}}
\qt@newcmd\qurantrans@es@mmdcclxxxviii{¿Os figurabais que os habíamos creado para pasar el rato y que no ibais a ser devueltos a Nosotros?»\qt@no{115}}
\qt@newcmd\qurantrans@es@mmdcclxxxix{¡Exaltado sea Alá, el Rey verdadero! No hay más dios que Él, el Señor del Trono noble.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmdccxc{Quien invoque a otro dios junto con Alá, sin tener prueba de ello, tendrá que dar cuenta sólo a su Señor. Los infieles no prosperarán\qt@no{117}}
\qt@newcmd\qurantrans@es@mmdccxci{Y di: «¡Señor! ¡Perdona y ten misericordia! ¡Tú eres el Mejor de quienes tienen misericordia!»\qt@no{118}}
\qt@newcmd\qurantrans@es@mmdccxcii{\basmalahes He aquí una sura que hemos revelado e impuesto. En ella hemos revelado aleyas claras. Quizás, así, os dejéis amonestar.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdccxciii{Flagelad a la fornicadora y al fornicador con cien azotes cada uno. Por respeto a la ley de Alá, no uséis de mansedumbre con ellos, si es que créeis en Alá y en el último Día. Y que un grupo de creyentes sea testigo de su castigo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdccxciv{El fornicador no podrá casarse más que con una fornicadora o con una asociadora. La fornicadora no podrá casarse más que con un fornicador o con un asociador. Eso les está prohibido a los creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdccxcv{A quienes difamen a las mujeres honestas sin poder presentar cuatro testigos, flageladles con ochenta azotes y nunca más aceptéis su testimonio. Ésos son los perversos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdccxcvi{Se exceptúan aquéllos que, después, se arrepientan y se enmienden. Alá es indulgente, misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdccxcvii{Quienes difamen a sus propias esposas sin poder presentar a más testigos que a sí mismos, deberán testificar jurando por Alá cuatro veces que dicen la verdad,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdccxcviii{e imprecando una quinta la maldición de Alá sobre sí si mintieran.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdccxcix{Pero se verá libre del castigo la mujer que atestigüe jurando por Alá cuatro veces que él miente,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdccc{e imprecando una quinta la ira de Alá sobre sí si él dijera la verdad.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdccci{Si no llega a ser por el favor de Alá y Su misericordia para con vosotros y porque Alá es indulgente, sabio...\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdcccii{Los mentirosos forman un grupo entre vosotros. No creáis que se resolverá en mal para vosotros, antes, al contrario, en bien. Todo aquél que peque recibirá conforme a su pecado; pero el que se cargue con más culpa tendrá un castigo terrible.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdccciii{Cuando los creyentes y las creyentes lo han oído, ¿por qué no han pensado bien en sus adentros y dicho: «¡Es una mentira manifiesta!»?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdccciv{¿Por qué no han presentado cuatro testigos? Como no han presentado testigos, para Alá que mienten.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdcccv{Si no llega a ser por el favor de Alá y Su misericordia para con vosotros en la vida de acá y en la otra, habríais sufrido un castigo terrible por vuestras habladurías.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdcccvi{Cuando las habéis recibido en vuestras lenguas, y vuestras bocas han dicho algo de que no teníais ningún conocimiento, creyendo que era cosa de poca monta, siendo así que para Alá era grave.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdcccvii{Cuando lo habéis oído, ¿por qué no habéis dicho: «¡No tenemos que hablar de eso! ¡Gloria a Ti! ¡Es una calumnia enorme!»?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdcccviii{Alá os exhorta, si sois creyentes, a que nunca reincidáis.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdcccix{Alá os aclara las aleyas. Alá es omnisciente, sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdcccx{Quienes deseen que se extienda la torpeza entre los creyentes, tendrán un castigo doloroso en la vida de acá y en la otra. Alá sabe, mientras que vosotros no sabéis.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdcccxi{Si no llega a ser por el favor de Alá y Su misericordia para con vosotros y porque Alá es manso, misericordioso...\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdcccxii{¡Creyentes! ¡No sigáis las pisadas del Demonio! A quien sigue las pisadas del Demonio, éste le ordena lo deshonesto y lo reprobable. Si no fuera por el favor de Alá y Su misericordia para con vosotros, ninguno de vosotros sería puro jamás. Pero Alá purifica a quien Él quiere. Alá todo lo oye, todo lo sabe.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdcccxiii{Quienes de vosotros gocen del favor y de una vida acomodada, que no juren que no darán más a los parientes, a los pobres y a los que han emigrado por Alá. Que perdonen y se muestren indulgentes. ¿Es que no queréis que Alá os perdone? Alá es indulgente, misericordioso.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdcccxiv{Malditos sean en la vida de acá y en la otra quienes difamen a las mujeres honestas, incautas pero creyentes. Tendrán un castigo terrible\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdcccxv{el día que sus lenguas, manos y pies atestigüen contra ellos por las obras que cometieron.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdcccxvi{Ese día, Alá les retribuirá en su justa medida y sabrán que Alá es la Verdad manifiesta.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdcccxvii{Las mujeres malas para los hombres malos, los hombres malos para las mujeres malas. Las mujeres buenas para los hombres buenos, los hombres buenos para las mujeres buenas. Estos son inocentes de lo que se les acusa. Obtendrán perdón y generoso sustento.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdcccxviii{¡Creyentes! No entréis en casa ajena sin daros a conocer y saludar a sus moradores. Es mejor para vosotros. Quizás, así, os amonestar.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdcccxix{Si no encontráis en ella a nadie, no entréis sin que se os dé permiso. Si se os dice que os vayáis, ¡idos! Es más correcto. Alá sabe bien lo que hacéis.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdcccxx{No hacéis mal si entráis en casa deshabitada que contenga algo que os pertenece. Alá sabe lo que manifestáis y lo que ocultáis.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdcccxxi{Di a los creyentes que bajen la vista con recato y que sean castos. Es más correcto. Alá está bien informado de lo que hacen.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdcccxxii{Y di a las creyentes que bajen la vista con recato, que sean castas y no muestren más adorno que los que están a la vista, que cubran su escote con el velo y no exhiban sus adornos sino a sus esposos, a sus padres, a sus suegros, a sus propios hijos, a sus hijastros, a sus hermanos, a sus sobrinos carnales, a sus mujeres, a sus esclavas, a sus criados varones fríos, a los niños que no saben aún de las partes femeninas. Que no batan ellas con sus pies de modo que se descubran sus adornos ocultos. ¡Volvéos todos a Alá, creyentes! Quizás, así, prosperéis.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdcccxxiii{Casad a aquéllos de vosotros que no estén casados y a vuestros esclavos y esclavas honestos. Si son pobres, Alá les enriquecerá con Su favor. Alá es inmenso, omnisciente.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdcccxxiv{Que los que no puedan casarse observen la continencia hasta que Alá les enriquezca con Su favor. Extended la escritura a los esclavos que lo deseen si reconocéis en ellos bien, y dadles de la hacienda que Alá os ha concedido. Si vuestras esclavas prefieren vivir castamente, no les obliguéis a prostituirse para procuraros los bienes de la vida de acá. Si alguien les obliga, luego de haber sido obligadas Alá se mostrará indulgente, misericordioso.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdcccxxv{Os hemos revelado aleyas aclaratorias, un ejemplo sacado de vuestros antecesores y una exhortación para los temerosos de Alá.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcccxxvi{Alá es la Luz de los cielos y de la tierra. Su Luz es comparable a una hornacina en la que hay un pabilo encendido. El pabilo está en un recipiente de vidrio, que es como si fuera una estrella fulgurante. Se enciende de un árbol bendito, un olivo, que no es del Oriente ni del Occidente, y cuyo aceite casi alumbra aun sin haber sido tocado por el fuego. ¡Luz sobre Luz! Alá dirige a Su Luz a quien Él quiere. Alá propone parábolas a los hombres. Alá es omnisciente.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcccxxvii{En casas que Alá ha permitido erigir y que se mencione en ellas Su nombre. En ellas Le glorifican, mañana y tarde,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcccxxviii{hombres a quienes ni los negocios ni el comercio les distraen del recuerdo de Alá, de hacer la azalá y de dar el azaque. Temen un día en que los corazones y las miradas sean puestos del revés.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcccxxix{Para que Alá les retribuya por sus mejores obras y les dé más de Su favor. Alá provee sin medida a quien Él quiere.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcccxxx{Las obras de los infieles son como espejismo en una llanura: el muy sediento cree que es agua, hasta que, llegado allá, no encuentra nada. Sí encontrará, en cambio, a Alá junto a sí y Él le saldará su cuenta. Alá es rápido en ajustar cuentas.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcccxxxi{O como tinieblas en un mar profundo, cubierto de olas, unas sobre otras, con nubes por encima, tinieblas sobre tinieblas. Si se saca la mano, apenas se la distingue. No dispone de luz ninguna aquél a quien Alá se la niega.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcccxxxii{¿No ves que glorifican a Alá quienes están en los cielos y en la tierra, y las aves con las alas desplegadas? Cada uno sabe cómo orar y cómo glorificarle. Alá sabe bien lo que hacen.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcccxxxiii{El dominio de los cielos y de la tierra pertenece a Alá. ¡Es Alá el fin de todo!\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcccxxxiv{¿No ves que Alá empuja las nubes y las agrupa y, luego, forma nubarrones? Ves, entonces, que el chaparrón sale de ellos. Hace bajar del cielo montañas de granizo y hiere o no con él según que quiera o no quiera. El resplandor del relámpago que acompaña deja casi sin vista.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcccxxxv{Alá hace que se sucedan la noche y el día. Sí, hay en ello motivo de reflexión para los que tienen ojos.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmdcccxxxvi{Alá ha creado a todos los animales de agua: de ellos unos se arrastran, otros caminan a dos patas, otros a cuatro. Alá crea lo que quiere. Alá es omnipotente.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmdcccxxxvii{Hemos revelado aleyas aclaratorias. Alá dirige a quien Él quiere a una vía recta.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmdcccxxxviii{Y dicen: «¡Creemos en Alá y en el Enviado y obedecemos!» Pero luego, después de eso, algunos de ellos vuelven la espalda. Esos tales no son creyentes.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmdcccxxxix{Cuando se les llama ante Alá y su Enviado para que decida entre ellos, he aquí que algunos se van.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmdcccxl{Cuando les asiste la razón, vienen a él sumisos.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmdcccxli{¡,Tienen, acaso, el corazón enfermo? ¿Dudan? ¡Temen, acaso, que Alá y Su Enviado sean injustos con ellos? Antes bien, ellos son los injustos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmdcccxlii{Cuando se llama a los creyentes ante Alá y Su Enviado para que decida entre ellos, se contentan con decir: «¡Oímos y obedecemos!» Ésos son los que prosperarán.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmdcccxliii{Quienes obedecen a Alá y a Su Enviado, tienen miedo de Alá y Le temen, ésos son los que triunfarán.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmdcccxliv{Han jurado solemnemente por Alá que si tú se lo ordenaras, sí que saldrían a campaña. Di: «¡No juréis! Una obediencia como se debe. Alá está bien informado de lo que hacéis».\qt@no{53}}
\qt@newcmd\qurantrans@es@mmdcccxlv{Di: «¡Obedeced a Alá y obedeced al Enviado!» Si volvéis la espalda... Él es responsable de lo que se le ha encargado y vosotros de lo que se os ha encargado. Si le obedecéis, seguís la buena dirección. Al Enviado no le incumbe más que la transmisión clara.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmdcccxlvi{A quienes de vosotros crean y obren bien, Alá les ha prometido que ha de hacerles sucesores en la tierra, como ya había hecho con sus antecesores. Y que ha de consolidar la religión que le plugo profesaran. Y que ha de trocar su temor en seguridad. Me servirán sin asociarme nada. Quienes, después de esto, no crean, ésos son los perversos.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmdcccxlvii{¡Haced la azalá, dad el azaque y obedeced al Enviado! Quizás, así, se os tenga piedad.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmdcccxlviii{No creas, no, que los infieles puedan escapar en la tierra. Su morada será el Fuego. ¡Qué mal fin...!\qt@no{57}}
\qt@newcmd\qurantrans@es@mmdcccxlix{¡Creyentes! Los esclavos y los impúberes, en tres ocasiones, deben pediros permiso: antes de levantaros, cuando os quitáis la ropa al mediodía y después de acostaros. Son para vosotros tres momentos íntimos. Fuera de ellos, no hacéis mal, ni ellos tampoco, si vais de unos a otros, de acá para allá. Así os aclara Alá las aleyas. Alá es omnisciente, sabio.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmdcccl{Cuando vuestros niños alcancen la pubertad, deberán pedir permiso, como hicieron quienes les precedieron. Así os aclara Alá Sus aleyas. Alá es omnisciente, sabio.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmdcccli{Las mujeres que han alcanzado la edad crítica y no cuentan ya con casarse, no hacen mal si se quitan la ropa, siempre que no exhiban sus adornos. Pero es mejor para ellas si se abstienen. Alá todo lo oye, todo lo sabe.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmdccclii{El ciego, el cojo, el enfermo, vosotros mismos, no tengáis escrúpulos en comer en vuestras casas o en casa de vuestros padres o de vuestras madres, en casa de vuestros hermanos o de vuestras hermanas, en casa de vuestros tíos paternos o de vuestras tías paternas, en casa de vuestros tíos maternos o de vuestras tías maternas, en casa cuyas llaves poseéis o en casa de un amigo. No tengáis escrúpulos en comer juntos o por separado. Y, cuando entréis en una casa, saludaos unos a otros empleando una fórmula venida de Alá, bendita buena, Así os aclara Alá las aleyas. Quizás, así, comprendáis.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmdcccliii{Los creyentes son, en verdad, quienes creen en Alá y en su Enviado. Cuando están con éste por un asunto de interés común, no se retiran sin pedirle permiso. Quienes te piden ese permiso son los que de verdad creen en Alá y en Su Enviado. Si te piden permiso por algún asunto suyo, concédeselo a quien de ellos quieras y pide a Alá que les perdone. Alá es indulgente, misericordioso.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmdcccliv{No equiparéis entre vosotros el llamamiento del Enviado a un llamamiento que podáis dirigiros unos a otros. Alá sabe quiénes de vosotros se escabullen a escondidas. ¡Que tengan cuidado los que se hurtan a Su orden, no sea que les aflija una prueba o que les aflija un castigo doloroso!\qt@no{63}}
\qt@newcmd\qurantrans@es@mmdccclv{¿No es de Alá lo que está en los cielos y en la tierra? Él conoce vuestra situación. Y el día que sean devueltos a Él, ya les informará de lo que hicieron. Alá es omnisciente.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmdccclvi{\basmalahes ¡Bendito sea Quien ha revelado el Criterio a Su siervo a fin de que sea monitor para todo el mundo.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmdccclvii{Quien posee el dominio de los cielos y de la tierra, no ha adoptado un hijo ni tiene asociado en el dominio, lo ha creado todo y lo ha determinado por completo!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmdccclviii{En lugar de tomarle a Él, han tomado a dioses que no crean nada, sino que ellos mismos son creados, que no disponen, ni siquiera para sí mismos, de lo que puede dañar o aprovechar, y no tienen poder sobre la muerte, ni sobre la vida, ni sobre la resurrección.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmdccclix{Dicen los infieles: «Esto no es sino una mentira, que él se ha inventado y en la que otra gente le ha ayudado». Obran impía y dolosamente.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmdccclx{Y dicen: «Patrañas de los antiguos que él se ha apuntado. Se las dictan mañana y tarde».\qt@no{5}}
\qt@newcmd\qurantrans@es@mmdccclxi{Di: «Lo ha revelado Quien conoce el secreto en los cielos y en la tierra. Es indulgente, misericordioso».\qt@no{6}}
\qt@newcmd\qurantrans@es@mmdccclxii{Y dicen: «¿Qué clase de Enviado es éste que se alimenta y pasea por los mercados? ¿Por qué no se le ha mandado de lo alto un ángel que sea, junto a él, monitor...?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmdccclxiii{¿Por qué no se le ha dado un tesoro o por qué no tiene un jardín de cuyos frutos pueda comer...?» Los impíos dicen: «No seguís sino a un hombre hechizado».\qt@no{8}}
\qt@newcmd\qurantrans@es@mmdccclxiv{¡ Mira a qué te comparan! Se extravían y no pueden encontrar un camino.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmdccclxv{¡Bendito sea Quien, si quiere, puede darte algo mejor que eso: jardines por cuyos bajos fluyen arroyos, palacios!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmdccclxvi{Pero ¡no! Desmienten la Hora y hemos preparado fuego de la gehena para quienes desmienten la Hora.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmdccclxvii{Cuando les vea, lejos aún, oirán su furor y bramido.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmdccclxviii{Cuando, atados unos a otros, sean precipitados en un lugar estrecho de él, invocarán entonces la destrucción.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmdccclxix{«¡No invoquéis hoy una sola destrucción sino muchas destrucciones!»\qt@no{14}}
\qt@newcmd\qurantrans@es@mmdccclxx{Di: «¿Vale más esto que el Jardín de inmortalidad que se ha prometido a los temerosos de Alá como retribución y fin último?»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmdccclxxi{Inmortales, tendrán cuanto deseen. Es una promesa que obliga a tu Señor.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmdccclxxii{El día que Él les congregue, a ellos y a los que servían en lugar de servir a Alá, dirá: «¿Sois vosotros los que habéis extraviado a estos Mis siervos o ellos solos se han extraviado del Camino?»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmdccclxxiii{Dirán: «¡Gloria a Ti! No nos estaba bien que tomáramos a otros como amigos, en lugar de tomarte a Ti. Pero les permitiste gozar tanto, a ellos y a sus padres, que olvidaron la Amonestación y fueron gente perdida».\qt@no{18}}
\qt@newcmd\qurantrans@es@mmdccclxxiv{«Os desmienten lo que decís. No podréis escapar al castigo ni encontrar quien os auxilie. A quien de vosotros obre impíamente le haremos gustar un gran castigo».\qt@no{19}}
\qt@newcmd\qurantrans@es@mmdccclxxv{Antes de ti no mandamos más que a enviados que se alimentaban y paseaban por los mercados. Hemos puesto a algunos de vosotros como prueba para los demás, a ver si tenéis paciencia. Tu Señor todo lo ve.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmdccclxxvi{Los que no cuentan con encontrarnos, dicen: «¿Por qué no se nos han enviado de lo alto ángeles o por qué no vemos a nuestro Señor?» Fueron altivos en sus adentros y se insolentaron sobremanera.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmdccclxxvii{El día que vean a los ángeles, no habrá, ese día, buenas nuevas para los pecadores. Dirán: «¡Límite infranqueable!»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmdccclxxviii{Examinaremos sus obras y haremos de ellas polvo disperso en el aire.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmdccclxxix{Ese día los moradores del Jardín gozarán de la mejor morada y del más bello descansadero.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmdccclxxx{El día que se desgarre el nubarrón del cielo y sean enviados abajo los ángeles.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmdccclxxxi{ese día, el dominio, el verdadero, será del Compasivo, y será un día difícil para los infieles.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmdccclxxxii{el día que el impío se muerda las manos diciendo: «¡Ojalá hubiera seguido un mismo camino que el Enviado!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmdccclxxxiii{¡Ay de mí! ¡Ojalá no hubiera tomado a fulano como amigo!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmdccclxxxiv{Me ha desviado de la Amonestación, después de haber venido a mí». El Demonio siempre deja colgado al hombre.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmdccclxxxv{El Enviado dice: «¡Señor! ¡Mi pueblo ha cobrado aversión a este Corán !»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmdccclxxxvi{Así hemos asignado a cada profeta un enemigo de entre los pecadores. Pero tu Señor basta como guía y auxilio.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmdccclxxxvii{Los infieles dicen: «¿Por qué no se le ha revelado el Corán de una vez?» Para, así, confirmar con él tu corazón. Y lo hemos hecho recitar lenta y claramente.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmdccclxxxviii{No te proponen ninguna parábola que no te aportemos Nosotros el verdadero sentido y la mejor interpretación.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmdccclxxxix{Aquéllos que sean congregados, boca abajo, hacia la gehena serán los que se encuentren en la situación peor y los más extraviados del Camino.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmdcccxc{Dimos a Moisés la Escritura y pusimos a su hermano Aarón como ayudante suyo.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmdcccxci{Y dijimos: «¡Id al pueblo que ha desmentido Nuestros signos!» Y los aniquilamos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmdcccxcii{Y al pueblo de Noé. Cuando desmintió a los enviados, le anegamos e hicimos de él un signo para los hombres. Y hemos preparado un castigo doloroso para los impíos.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmdcccxciii{A los aditas, a los tamudeos, a los habitantes de ar-Rass y a muchas generaciones intermedias...\qt@no{38}}
\qt@newcmd\qurantrans@es@mmdcccxciv{A todos les dimos ejemplos y a todos les exterminamos.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmdcccxcv{Han pasado por las ruinas de la ciudad sobre la que cayó una lluvia maléfica. Se diría que no la han visto, porque no esperan una resurrección.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmdcccxcvi{Cuando te ven, no hacen sino tomarte a burla: «¿Es éste el que Alá ha mandado como enviado?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmdcccxcvii{Si no llega a ser porque nos hemos mantenido fieles a nuestros dioses, nos habría casi desviado de ellos». Pero, cuando vean el castigo, sabrán quién se ha extraviado más del Camino.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmdcccxcviii{¿Qué te parece quien ha divinizado su pasión? ¿Vas a ser tú su protector?\qt@no{43}}
\qt@newcmd\qurantrans@es@mmdcccxcix{¿Crees que la mayoría oyen o entienden? No son sino como rebaños. No, más extraviados aún del Camino.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcm{¿No ves cómo hace tu Señor que se deslice la sombra? Si quisiera, podría hacerla fija. Además, hemos hecho del sol guía para ella.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcmi{Luego, la atraemos hacia Nosotros con facilidad.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcmii{Él es Quien ha hecho para vosotros de la noche vestidura, del sueño descanso, del día resurrección.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcmiii{Él es Quien envía los vientos como nuncios que preceden a Su misericordia. Hacemos bajar del cielo agua pura,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcmiv{para vivificar con ella un país muerto y dar de beber, entre lo que hemos creado, a la multitud de rebaños y seres humanos.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcmv{La hemos distribuido entre ellos para que se dejen amonestar, pero la mayoría de los hombres no quieren sino ser infieles.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcmvi{Si hubiéramos querido, habríamos enviado a cada ciudad un monitor.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcmvii{No obedezcas, pues, a los infieles y lucha esforzadamente contra ellos, por medio de él.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcmviii{Él es Quien ha hecho que las dos grandes masas de agua fluyan: una, dulce, agradable; otra, salobre, amarga. Ha colocado entre ellas una barrera y límite infranqueable.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcmix{Él es quien ha creado del agua un ser humano, haciendo de él el parentesco por consanguinidad o por afinidad. Tu Señor es omnipotente.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcmx{Pero, en lugar de servir a Alá, sirven lo que no puede aprovecharles ni dañarles. El infiel es un auxiliar contra su Señor.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcmxi{A ti no te hemos enviado sino como nuncio de buenas nuevas y como monitor.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcmxii{Di: «No os pido a cambio ningún salario. Sólo que, quien quiera, ¡que emprenda camino hacia su Señor!»\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcmxiii{Y ¡confía en el Viviente, Que no muere! ¡Celebra Sus alabanzas! El está suficientemente informado de los pecados de Sus siervos.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcmxiv{Él es Quien ha creado en seis días los cielos, la tierra y lo que entre ellos hay. Luego, se ha instalado en el Trono. El Compasivo. ¡Interroga a quien esté bien informado de Él!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcmxv{Cuando se les dice: «¡Prosternaos ante el Compasivo!», dicen: «Y ¿qué es 'el Compasivo'? ¿Vamos a prosternarnos sólo porque tú lo ordenes?» Y esto acrecienta su repulsa.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcmxvi{¡Bendito sea Quien ha puesto constelaciones en el cielo y entre ellas un luminar y una luna luminosa!\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcmxvii{Él es Quien ha dispuesto que se sucedan la noche y el día para quien quiera dejarse amonestar o quiera dar gracias.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcmxviii{Los siervos del Compasivo son los que van por la tierra humildemente y que, cuando los ignorantes les dirigen la palabra, dicen: «¡Paz!»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcmxix{Pasan la noche ante su Señor, postrados o de pie.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcmxx{Dicen: «¡Señor! ¡Aleja de nosotros el castigo de la gehena!» Su castigo es perpetuo.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcmxxi{Sí es mala como morada y residencia.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcmxxii{Cuando gastan, no lo hacen con prodigalidad ni con tacañería, -el término medio es lo justo-.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmcmxxiii{No invocan a otro dios junto con Alá, no matan a nadie que Alá haya prohibido, si no es con justo motivo, no fornican. Quien comete tal, incurre en castigo.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmcmxxiv{El día de la Resurrección se le doblará el castigo y lo sufrirá eternamente humillado.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmcmxxv{No así quien se arrepienta, crea y haga buenas obras. A éstos Alá les cambiará sus malas obras en buenas. Alá es indulgente, misericordioso.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmcmxxvi{Quien se arrepienta y obre bien dará muestras de un arrepentimiento sincero.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmcmxxvii{No prestan falso testimonio y, cuando pasan y oyen vaniloquio, prosiguen la marcha dígnamente.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmcmxxviii{Cuando se les amonesta con los signos de su Señor, no caen al suelo ante ellos, sordos y ciegos.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmcmxxix{Dicen: «¡Señor! ¡Haznos el regalo de que nuestras esposas y descendencia sean nuestra alegría, haz que seamos modelo para los temerosos de Alá!»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmcmxxx{Éstos serán retribuidos con una cámara alta porque tuvieron paciencia. Se les acogerá allí con palabras de salutación y de paz.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmcmxxxi{Eternos allí... ¡Qué bello lugar como morada y como residencia!\qt@no{76}}
\qt@newcmd\qurantrans@es@mmcmxxxii{Di: «Mi Señor no se cuidaría de vosotros si no Le invocarais. Pero habéis desmentido y es ineludible».\qt@no{77}}
\qt@newcmd\qurantrans@es@mmcmxxxiii{\basmalahes tsm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmcmxxxiv{Éstas son las aleyas de la Escritura sabia.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmcmxxxv{Tú, quizá, te consumas de pena porque no creen.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmcmxxxvi{Si quisiéramos, haríamos bajar del cielo sobre ellos un signo y doblarían ante él la cerviz.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmcmxxxvii{No les llega una nueva amonestación del Compasivo que no se aparten de ella.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmcmxxxviii{Han desmentido, pero recibirán noticias de aquello de que se burlaban.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmcmxxxix{¿No han visto cuánta especie generosa de toda clase hemos hecho crecer en la tierra?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmcmxl{Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmcmxli{En verdad, tu Señor es el Poderoso, el Misericordioso.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmcmxlii{Y cuando tu Señor llamó a Moisés: «Ve al pueblo impío,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmcmxliii{al pueblo de Faraón. ¿No van a temerme ?»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmcmxliv{Dijo: «¡Señor! Temo que me desmientan.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmcmxlv{Me angustio, se me traba la lengua. ¡Envía por Aarón!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmcmxlvi{Me acusan de un crimen y temo que me maten».\qt@no{14}}
\qt@newcmd\qurantrans@es@mmcmxlvii{Dijo: «¡No! ¡Id los dos con Nuestros signos! Estamos con vosotros, escuchamos.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmcmxlviii{Id a Faraón y decid: '¡Nos ha enviado el Señor del universo:\qt@no{16}}
\qt@newcmd\qurantrans@es@mmcmxlix{¡Deja marchar con nosotros a los Hijos de Israel!'»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmcml{Dijo: «¿No te hemos educado, cuando eras niño, entre nosotros? ¿No has vivido durante años de tu vida entre nosotros?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmcmli{Desagradecido, hiciste lo que hiciste»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmcmlii{Dijo: «Lo hice cuando estaba extraviado.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmcmliii{Tuve miedo de vosotros y me escapé. Mi Señor me ha regalado juicio y ha hecho de mí uno de los enviados.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmcmliv{¿Es ésta una gracia que me echas en cara, tú que has esclavizado a los Hijos de Israel?»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmcmlv{Faraón dijo: «Y ¿qué es 'el Señor del universo'?»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmcmlvi{Dijo: «Es el Señor de los cielos, de la tierra y de lo que entre ellos está. Si estuvierais convencidos...»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmcmlvii{Dijo a los circunstantes: «¡Habéis oído?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmcmlviii{Dijo. «Es vuestro Señor y Señor de vuestros antepasados...»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmcmlix{Dijo: «¡El enviado que se os ha mandado es; ciertamente, un poseso!»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmcmlx{Dijo: «...el Señor del Oriente y del Occidente y de lo que entre ellos está. Si razonarais...»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmcmlxi{Dijo: «¡Si tomas por dios a otro diferente de mí, he de enviarte a la cárcel!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmcmlxii{Dijo: «¿Y si te trajera algo claro?»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmcmlxiii{Dijo: «¡Tráelo‚ si es verdad lo que dices!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmcmlxiv{Moisés tiró su vara y he aquí que ésta se convirtió en una auténtica serpiente.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmcmlxv{Sacó su mano y he aquí que apareció blanca a los ojos de los presentes.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmcmlxvi{Dijo a los dignatarios que le rodeaban: «Sí, éste es un mago muy entendido,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmcmlxvii{que quiere expulsaros de vuestra tierra con su magia. ¿Qué ordenáis?»\qt@no{35}}
\qt@newcmd\qurantrans@es@mmcmlxviii{Dijeron: «Dales largas, a él y a su hermano, y envía a las ciudades a agentes que convoquen,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmcmlxix{que te traigan a los magos más entendidos, a todos».\qt@no{37}}
\qt@newcmd\qurantrans@es@mmcmlxx{Los magos fueron convocados para una determinada hora del día convenido\qt@no{38}}
\qt@newcmd\qurantrans@es@mmcmlxxi{y se dijo a la gente: «¿No queréis asistir?\qt@no{39}}
\qt@newcmd\qurantrans@es@mmcmlxxii{Quizás, así, sigamos a los magos, si son ellos los que ganan»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmcmlxxiii{Cuando llegaron los magos dijeron a Faraón: «Si ganamos, recibiremos una recompensa, ¿no?»\qt@no{41}}
\qt@newcmd\qurantrans@es@mmcmlxxiv{Dijo: «¡Sí! Y seréis entonces, ciertamente, de mis allegados».\qt@no{42}}
\qt@newcmd\qurantrans@es@mmcmlxxv{Moisés les dijo: «¡Tirad lo que vayáis a tirar!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmcmlxxvi{Y tiraron sus cuerdas y varas, y dijeron: «¡Por el poder de Faraón, que venceremos!»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmcmlxxvii{Moisés tiró su vara y he aquí que ésta engulló sus mentiras.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmcmlxxviii{Y los magos cayeron prosternados.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmcmlxxix{Dijeron: «¡Creemos en el Señor del universo,\qt@no{47}}
\qt@newcmd\qurantrans@es@mmcmlxxx{el Señor de Moisés y de Aarón!»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmcmlxxxi{Dijo: «¡Le habéis creído antes de que yo os autorizara a ello! ¡Es vuestro maestro, que os ha enseñado la magia! ¡Vais a ver! ¡He de haceros amputar las manos y los pies opuestos! ¡Y he de haceros crucificar a todos!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmcmlxxxii{Dijeron: «¡No importa! ¡Nos volvemos a nuestro Señor!\qt@no{50}}
\qt@newcmd\qurantrans@es@mmcmlxxxiii{Anhelamos que nuestro Señor nos perdone nuestros pecados, ya que hemos sido los primeros en creer».\qt@no{51}}
\qt@newcmd\qurantrans@es@mmcmlxxxiv{E inspiramos a Moisés: «¡Parte de noche con Mis siervos! ¡Seréis perseguidos!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmcmlxxxv{Faraón envió a las ciudades a agentes que convocaran:\qt@no{53}}
\qt@newcmd\qurantrans@es@mmcmlxxxvi{«Son una banda insignificante\qt@no{54}}
\qt@newcmd\qurantrans@es@mmcmlxxxvii{y, ciertamente, nos han irritado.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmcmlxxxviii{Nosotros, en cambio, somos todo un ejército y estamos bien prevenidos».\qt@no{56}}
\qt@newcmd\qurantrans@es@mmcmlxxxix{Les expulsamos de sus jardines y fuentes,\qt@no{57}}
\qt@newcmd\qurantrans@es@mmcmxc{de sus tesoros y suntuosas residencias.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmcmxci{Así fue, y se lo dimos en herencia a los Hijos de Israel.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmcmxcii{A la salida del sol, les persiguieron.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmcmxciii{Cuando los dos grupos se divisaron, dijeron los compañeros de Moisés: «¡Nos ha alcanzado!»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmcmxciv{Dijo: «¡No! ¡Mi Señor está conmigo, el me dirigirá!»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmcmxcv{E inspiramos a Moisés: «¡Golpea el mar con tu vara!» El mar, entonces, se partió y cada parte era como una imponente montaña.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmcmxcvi{Hicimos que los otros se acercaran allá,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmcmxcvii{y salvamos a Moisés y a todos los que con él estaban.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmcmxcviii{Luego, anegamos a los otros.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmcmxcix{Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmm{¡Sí, tu Señor es el Poderoso, el Misericordioso!\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmi{¡Cuéntales la historia de Abraham!\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmii{Cuando dijo a su padre y a su pueblo: «¿Qué servís?»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmiii{Dijeron: «Servimos a ídolos y continuaremos entregándonos a su culto».\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmiv{Dijo: «Y ¿os escuchan cuando les invocáis?\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmv{¿Pueden aprovecharos o haceros daño?»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmvi{Dijeron: «¡No, pero encontramos que nuestros antepasados hacían lo mismo!»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmvii{Dijo: «¿Y habéis visto lo que servíais,\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmviii{vosotros y vuestros lejanos antepasados?\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmix{Son mis enemigos, a diferencia del Señor del universo.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmx{Que me ha creado y me dirige,\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmxi{me da de comer y de beber,\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmxii{me cura cuando enfermo,\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmxiii{me hará morir y, luego, me volverá a la vida,\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmxiv{de Quien anhelo el perdón de mis faltas el día del Juicio.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmxv{¡Señor! ¡Regálame juicio y reúneme con los justos!\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmxvi{¡Haz que tenga una buena reputación en mi posteridad!\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmxvii{¡Cuéntame entre los herederos del Jardín de la Delicia!\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmxviii{¡Perdona a mi padre, estaba extraviado!\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmxix{No me avergüences el día de la Resurrección,\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmxx{el día que no aprovechen hacienda ni hijos varones,\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmxxi{excepto a quien vaya a Alá con corazón sano».\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmxxii{El Jardín será acercado a quienes hayan temido a Alá\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmxxiii{y el fuego de la gehena aparecerá ante los descarriados.\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmxxiv{Se les dirá: «¿Dónde está lo que servíais\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmxxv{en lugar de servir a Alá? ¿Pueden auxiliaros o auxiliarse a sí mismos?»\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmxxvi{Ellos y los descarriados serán precipitados en él,\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmxxvii{así como las huestes de Iblis, todas.\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmxxviii{Ya en él dirán mientras disputan:\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmxxix{«¡Por Alá, que estábamos, sí, evidentemente extraviados\qt@no{97}}
\qt@newcmd\qurantrans@es@mmmxxx{cuando os equiparábamos al Señor del universo!\qt@no{98}}
\qt@newcmd\qurantrans@es@mmmxxxi{Nadie sino los pecadores nos extraviaron\qt@no{99}}
\qt@newcmd\qurantrans@es@mmmxxxii{y, ahora, no tenemos a nadie que interceda,\qt@no{100}}
\qt@newcmd\qurantrans@es@mmmxxxiii{a ningún amigo ferviente.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmmxxxiv{Si pudiéramos volver para ser creyentes...»\qt@no{102}}
\qt@newcmd\qurantrans@es@mmmxxxv{Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{103}}
\qt@newcmd\qurantrans@es@mmmxxxvi{Tu Señor es, ciertamente, el Poderoso, el Misericordioso.\qt@no{104}}
\qt@newcmd\qurantrans@es@mmmxxxvii{El pueblo de Noé desmintió a los enviados.\qt@no{105}}
\qt@newcmd\qurantrans@es@mmmxxxviii{Cuando su hermano Noé les dijo: «¿Es que no vais a temer a Alá?\qt@no{106}}
\qt@newcmd\qurantrans@es@mmmxxxix{Tenéis en mí a un enviado digno de confianza.\qt@no{107}}
\qt@newcmd\qurantrans@es@mmmxl{¡Temed, pues, a Alá y obedecedme!\qt@no{108}}
\qt@newcmd\qurantrans@es@mmmxli{No os pido por ello ningún salario. Mi salario no incumbe sino al Señor del universo.\qt@no{109}}
\qt@newcmd\qurantrans@es@mmmxlii{¡Temed, pues, a Alá y obedecedme!»\qt@no{110}}
\qt@newcmd\qurantrans@es@mmmxliii{Dijeron: «¿Vamos a creerte a ti, siendo así que son los más viles los que te siguen?»\qt@no{111}}
\qt@newcmd\qurantrans@es@mmmxliv{Dijo: «¿Y qué sé yo de sus obras?\qt@no{112}}
\qt@newcmd\qurantrans@es@mmmxlv{Sólo a mi Señor tienen que dar cuenta. Si os dierais cuenta...\qt@no{113}}
\qt@newcmd\qurantrans@es@mmmxlvi{¡No voy yo a rechazar a los creyentes!\qt@no{114}}
\qt@newcmd\qurantrans@es@mmmxlvii{¡Yo no soy más que un monitor que habla claro!»\qt@no{115}}
\qt@newcmd\qurantrans@es@mmmxlviii{Dijeron: «¡Noé! Si no paras, ¡hemos de lapidarte!»\qt@no{116}}
\qt@newcmd\qurantrans@es@mmmxlix{Dijo: «¡Señor! Mi pueblo me desmiente.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmml{¡Falla, pues, entre yo y ellos, y sálvame, junto con los creyentes que están conmigo!»\qt@no{118}}
\qt@newcmd\qurantrans@es@mmmli{Les salvamos, pues, a él y a quienes estaban con él en la nave abarrotada.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmmlii{Luego, después, anegamos al resto.\qt@no{120}}
\qt@newcmd\qurantrans@es@mmmliii{Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmmliv{En verdad, tu Señor es el Poderoso. el Misericordioso.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmmlv{Los aditas desmintieron a los enviados.\qt@no{123}}
\qt@newcmd\qurantrans@es@mmmlvi{Cuando su hermano Hud les dijo: «¿Es que no vais a temer a Alá?\qt@no{124}}
\qt@newcmd\qurantrans@es@mmmlvii{Tenéis en mí a un enviado digno de confianza.\qt@no{125}}
\qt@newcmd\qurantrans@es@mmmlviii{¡Temed, pues, a Alá y obedecedme!\qt@no{126}}
\qt@newcmd\qurantrans@es@mmmlix{No os pido por ello ningún salario. Mi salario no incumbe sino al Señor del universo.\qt@no{127}}
\qt@newcmd\qurantrans@es@mmmlx{¡Construís en cada colina un monumento para divertiros\qt@no{128}}
\qt@newcmd\qurantrans@es@mmmlxi{y hacéis construcciones esperando, quizá, ser inmortales?\qt@no{129}}
\qt@newcmd\qurantrans@es@mmmlxii{Cuando usáis de violencia lo hacéis sin piedad.\qt@no{130}}
\qt@newcmd\qurantrans@es@mmmlxiii{¡Temed, pues, a Alá y obedecedme!\qt@no{131}}
\qt@newcmd\qurantrans@es@mmmlxiv{¡Temed a Quien os ha proveído de lo que sabéis:\qt@no{132}}
\qt@newcmd\qurantrans@es@mmmlxv{de rebaños e hijos varones,\qt@no{133}}
\qt@newcmd\qurantrans@es@mmmlxvi{de jardines y fuentes!\qt@no{134}}
\qt@newcmd\qurantrans@es@mmmlxvii{¡Temo por vosotros el castigo de un día terrible!»\qt@no{135}}
\qt@newcmd\qurantrans@es@mmmlxviii{Dijeron: «¡Nos da lo mismo que nos amonestes o no!\qt@no{136}}
\qt@newcmd\qurantrans@es@mmmlxix{No hacemos sino lo que acostumbraban a hacer los antiguos.\qt@no{137}}
\qt@newcmd\qurantrans@es@mmmlxx{¡No se nos castigará!»\qt@no{138}}
\qt@newcmd\qurantrans@es@mmmlxxi{Le desmintieron y les aniquilamos. Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{139}}
\qt@newcmd\qurantrans@es@mmmlxxii{En verdad, tu Señor es el Poderoso, el Misericordioso.\qt@no{140}}
\qt@newcmd\qurantrans@es@mmmlxxiii{Los tamudeos desmintieron a los enviados.\qt@no{141}}
\qt@newcmd\qurantrans@es@mmmlxxiv{Cuando su hermano Salih les dijo: «¿Es que no vais a temer a Alá?\qt@no{142}}
\qt@newcmd\qurantrans@es@mmmlxxv{Tenéis en mí a un enviado digno de confianza.\qt@no{143}}
\qt@newcmd\qurantrans@es@mmmlxxvi{¡Temed, pues, a Alá y obedecedme!\qt@no{144}}
\qt@newcmd\qurantrans@es@mmmlxxvii{No os pido por ello ningún salario. Mi salario no incumbe sino al Señor del universo.\qt@no{145}}
\qt@newcmd\qurantrans@es@mmmlxxviii{¿Se os va a dejar en seguridad con lo que aquí abajo tenéis,\qt@no{146}}
\qt@newcmd\qurantrans@es@mmmlxxix{entre jardines y fuentes,\qt@no{147}}
\qt@newcmd\qurantrans@es@mmmlxxx{entre campos cultivados y esbeltas palmeras,\qt@no{148}}
\qt@newcmd\qurantrans@es@mmmlxxxi{y continuaréis excavando, hábilmente, casas en las montañas?\qt@no{149}}
\qt@newcmd\qurantrans@es@mmmlxxxii{¡Temed, pues, a Alá y obedecedme!\qt@no{150}}
\qt@newcmd\qurantrans@es@mmmlxxxiii{¡No obedezcáis las órdenes de los inmoderados,\qt@no{151}}
\qt@newcmd\qurantrans@es@mmmlxxxiv{que corrompen en la tierra y no la reforman!»\qt@no{152}}
\qt@newcmd\qurantrans@es@mmmlxxxv{Dijeron: «¡Eres sólo un hechizado!\qt@no{153}}
\qt@newcmd\qurantrans@es@mmmlxxxvi{¡No eres sino un mortal como nosotros! ¡Trae un signo, si es verdad lo que dices!»\qt@no{154}}
\qt@newcmd\qurantrans@es@mmmlxxxvii{Dijo: «He aquí una camella. Un día le tocará beber a ella y otro día a vosotros.\qt@no{155}}
\qt@newcmd\qurantrans@es@mmmlxxxviii{¡No le hagáis mal! ¡Si no, os sorprenderá el castigo de un día terrible!»\qt@no{156}}
\qt@newcmd\qurantrans@es@mmmlxxxix{Pero ellos la desjarretaron... y se arrepintieron.\qt@no{157}}
\qt@newcmd\qurantrans@es@mmmxc{Y les sorprendió el Castigo. Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{158}}
\qt@newcmd\qurantrans@es@mmmxci{¡En verdad, tu Señor es el Poderoso, el Misericordioso!\qt@no{159}}
\qt@newcmd\qurantrans@es@mmmxcii{El pueblo de Lot desmintió a los enviados.\qt@no{160}}
\qt@newcmd\qurantrans@es@mmmxciii{Cuando su hermano Lot les dijo: «¿Es que no vais a temer a Alá?\qt@no{161}}
\qt@newcmd\qurantrans@es@mmmxciv{Tenéis en mí a un enviado digno de confianza.\qt@no{162}}
\qt@newcmd\qurantrans@es@mmmxcv{¡Temed, pues, a Alá y obedecedme!\qt@no{163}}
\qt@newcmd\qurantrans@es@mmmxcvi{No os pido por ello ningún salario. Mi salario no incumbe sino al Señor del universo.\qt@no{164}}
\qt@newcmd\qurantrans@es@mmmxcvii{¿Os llegáis a los varones, de las criaturas,\qt@no{165}}
\qt@newcmd\qurantrans@es@mmmxcviii{y descuidáis a vuestras esposas, que vuestro Señor ha creado para vosotros? Sí, sois gente que viola la ley».\qt@no{166}}
\qt@newcmd\qurantrans@es@mmmxcix{Dijeron: «Si no paras, Lot, serás, ciertamente, expulsado».\qt@no{167}}
\qt@newcmd\qurantrans@es@mmmc{Dijo: «Detesto vuestra conducta.\qt@no{168}}
\qt@newcmd\qurantrans@es@mmmci{¡Señor! ¡Sálvanos, a mí y a mi familia, de lo que hacen!»\qt@no{169}}
\qt@newcmd\qurantrans@es@mmmcii{Y les salvamos, a él y a su familia, a todos,\qt@no{170}}
\qt@newcmd\qurantrans@es@mmmciii{salvo a una vieja entre los que se rezagaron.\qt@no{171}}
\qt@newcmd\qurantrans@es@mmmciv{Luego, aniquilamos a los demás.\qt@no{172}}
\qt@newcmd\qurantrans@es@mmmcv{E hicimos llover sobre ellos una lluvia. ¡Lluvia fatal para los que habían sido advertidos!\qt@no{173}}
\qt@newcmd\qurantrans@es@mmmcvi{Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{174}}
\qt@newcmd\qurantrans@es@mmmcvii{¡En verdad tu Señor es el Poderoso, el Misericordioso!\qt@no{175}}
\qt@newcmd\qurantrans@es@mmmcviii{Los habitantes de la Espesura desmintieron a los enviados.\qt@no{176}}
\qt@newcmd\qurantrans@es@mmmcix{Cuando Suayb les dijo: «¡Es que no vais a temer a Alá?\qt@no{177}}
\qt@newcmd\qurantrans@es@mmmcx{Tenéis en mí a un enviado digno de confianza.\qt@no{178}}
\qt@newcmd\qurantrans@es@mmmcxi{¡Temed, pues, a Alá y obedecedme!\qt@no{179}}
\qt@newcmd\qurantrans@es@mmmcxii{No os pido por ello ningún salario. Mi salario no incumbe sino al Señor del universo.\qt@no{180}}
\qt@newcmd\qurantrans@es@mmmcxiii{¡Dad la medida justa, no hagáis trampa!\qt@no{181}}
\qt@newcmd\qurantrans@es@mmmcxiv{¡Pesad con una balanza exacta!\qt@no{182}}
\qt@newcmd\qurantrans@es@mmmcxv{¡No dañeis a nadie en sus cosas y no obréis mal en la tierra corrompiendo!\qt@no{183}}
\qt@newcmd\qurantrans@es@mmmcxvi{¡Temed a Quien os ha creado, a vosotros y a las generaciones antiguas!»\qt@no{184}}
\qt@newcmd\qurantrans@es@mmmcxvii{Dijeron: «Eres sólo un hechizado.\qt@no{185}}
\qt@newcmd\qurantrans@es@mmmcxviii{No eres sino un mortal como nosotros. Creemos que mientes.\qt@no{186}}
\qt@newcmd\qurantrans@es@mmmcxix{Si es verdad lo que dices, ¡haz que caiga sobre nosotros parte del cielo!»\qt@no{187}}
\qt@newcmd\qurantrans@es@mmmcxx{Dijo: «Mi Señor sabe bien lo que hacéis».\qt@no{188}}
\qt@newcmd\qurantrans@es@mmmcxxi{Le desmintieron. Y el castigo del día de la Sombra les sorprendió: fue el castigo de un día terrible.\qt@no{189}}
\qt@newcmd\qurantrans@es@mmmcxxii{Ciertamente, hay en ello un signo, pero la mayoría no creen.\qt@no{190}}
\qt@newcmd\qurantrans@es@mmmcxxiii{¡En verdad, tu Señor es el Poderoso, el Misericordioso!\qt@no{191}}
\qt@newcmd\qurantrans@es@mmmcxxiv{Es, en verdad, la Revelación del Señor del universo.\qt@no{192}}
\qt@newcmd\qurantrans@es@mmmcxxv{El Espíritu digno de confianza lo ha bajado\qt@no{193}}
\qt@newcmd\qurantrans@es@mmmcxxvi{a tu corazón, para que seas uno que advierte.\qt@no{194}}
\qt@newcmd\qurantrans@es@mmmcxxvii{En lengua árabe clara,\qt@no{195}}
\qt@newcmd\qurantrans@es@mmmcxxviii{y estaba, ciertamente, en las Escrituras de los antiguos.\qt@no{196}}
\qt@newcmd\qurantrans@es@mmmcxxix{¿No es para ellos un signo que los doctores de los Hijos de Israel lo conozcan?\qt@no{197}}
\qt@newcmd\qurantrans@es@mmmcxxx{Si lo hubiéramos revelado a uno no árabe\qt@no{198}}
\qt@newcmd\qurantrans@es@mmmcxxxi{y éste se lo hubiera recitado, no habrían creído en él.\qt@no{199}}
\qt@newcmd\qurantrans@es@mmmcxxxii{Así se lo hemos insinuado a los pecadores,\qt@no{200}}
\qt@newcmd\qurantrans@es@mmmcxxxiii{pero no creerán en él hasta que vean el castigo doloroso,\qt@no{201}}
\qt@newcmd\qurantrans@es@mmmcxxxiv{que les vendrá de repente, sin presentirlo.\qt@no{202}}
\qt@newcmd\qurantrans@es@mmmcxxxv{Entonces, dirán: «¿Se nos diferirá?»\qt@no{203}}
\qt@newcmd\qurantrans@es@mmmcxxxvi{¿Quieren, entonces, adelantar Nuestro castigo?\qt@no{204}}
\qt@newcmd\qurantrans@es@mmmcxxxvii{Y ¿qué te parece? Si les dejáramos gozar durante años\qt@no{205}}
\qt@newcmd\qurantrans@es@mmmcxxxviii{y, luego, se cumpliera en ellos la amenaza,\qt@no{206}}
\qt@newcmd\qurantrans@es@mmmcxxxix{no les serviría de nada el haber disfrutado tanto.\qt@no{207}}
\qt@newcmd\qurantrans@es@mmmcxl{No hemos destruido nunca una ciudad sin haberle enviado antes quienes advirtieran,\qt@no{208}}
\qt@newcmd\qurantrans@es@mmmcxli{como amonestación. No somos injustos.\qt@no{209}}
\qt@newcmd\qurantrans@es@mmmcxlii{No son los demonios quienes lo han bajado:\qt@no{210}}
\qt@newcmd\qurantrans@es@mmmcxliii{ni les estaba bien, ni podían hacerlo.\qt@no{211}}
\qt@newcmd\qurantrans@es@mmmcxliv{Están, en verdad, lejos de oírlo.\qt@no{212}}
\qt@newcmd\qurantrans@es@mmmcxlv{No invoques a otros dioses junto con Alá si no, serás castigado.\qt@no{213}}
\qt@newcmd\qurantrans@es@mmmcxlvi{Advierte a los miembros más allegados de tu tribu.\qt@no{214}}
\qt@newcmd\qurantrans@es@mmmcxlvii{Sé benévolo con los creyentes que te siguen.\qt@no{215}}
\qt@newcmd\qurantrans@es@mmmcxlviii{Si te desobedecen, di: «Soy inocente de lo que hacéis».\qt@no{216}}
\qt@newcmd\qurantrans@es@mmmcxlix{Confía en el Poderoso, el Misericordioso,\qt@no{217}}
\qt@newcmd\qurantrans@es@mmmcl{Que te ve cuando estás de pie\qt@no{218}}
\qt@newcmd\qurantrans@es@mmmcli{y ve las posturas que adoptas entre los que se prosternan.\qt@no{219}}
\qt@newcmd\qurantrans@es@mmmclii{Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{220}}
\qt@newcmd\qurantrans@es@mmmcliii{¿Tengo que informaros de sobre quién descienden los demonios?\qt@no{221}}
\qt@newcmd\qurantrans@es@mmmcliv{Descienden sobre todo mentiroso pecador.\qt@no{222}}
\qt@newcmd\qurantrans@es@mmmclv{Aguzan el oído... Y la mayoría mienten.\qt@no{223}}
\qt@newcmd\qurantrans@es@mmmclvi{En cuanto a los poetas, les siguen los descarriados.\qt@no{224}}
\qt@newcmd\qurantrans@es@mmmclvii{¿No has visto que van errando por todos los valles\qt@no{225}}
\qt@newcmd\qurantrans@es@mmmclviii{y que dicen lo que no hacen?\qt@no{226}}
\qt@newcmd\qurantrans@es@mmmclix{No son así los que creen, obran bien, recuerdan mucho a Alá y se defienden cuando son tratados injustamente. ¡Los impíos verán pronto la suerte que les espera!\qt@no{227}}
\qt@newcmd\qurantrans@es@mmmclx{\basmalahes ts. Éstas son las aleyas del Corán y de una Escritura clara,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmclxi{dirección y buena nueva para los creyentes,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmclxii{que hacen la azalá, dan el azaque y están convencidos de la otra vida.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmclxiii{Hemos engalanado a sus propios ojos las acciones de los que no creen en la otra vida. Yerran ciegos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmclxiv{Esos tales son los que sufrirán el castigo peor y los que perderán más en la otra vida.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmclxv{En verdad tú recibes el Corán de Uno que es sabio, omnisciente.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmclxvi{Cuando Moisés dijo a su familia: «Distingo un fuego. Voy a informaros de qué se trata u os traeré un tizón ardiente. Quizás, así, podáis calentaros».\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmclxvii{Al llegar a él, le llamaron: «¡Bendito sea Quien está en el fuego y quien está en torno a él! ¡Gloria a Alá, Señor del universo!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmclxviii{¡Moisés! ¡Yo soy Alá, el Poderoso, el Sabio!»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmclxix{Y: «¡Tira tu vara!» Y cuando vio que se movía como si fuera una serpiente, dio media vuelta para escapar, sin volverse. «¡Moisés! ¡No tengas miedo! Ante Mí, los enviados no temen.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmclxx{Sí, en cambio, quien haya obrado impíamente; pero, si sustituye su mala acción por una buena... Yo soy indulgente, misericordioso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmclxxi{Introduce la mano por la escotadura de tu túnica y saldrá blanca, sana. Esto formará parte de los nueve signos destinados a Faraón y su pueblo. Son gente perversa».\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmclxxii{Cuando Nuestros signos vinieron a ellos para abrirles los ojos, dijeron: «¡Esto es manifiesta magia!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmclxxiii{Y los negaron injusta y altivamente, a pesar de estar convencidos de ellos. ¡Y mira cómo terminaron los corruptores!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmclxxiv{Dimos ciencia a David y a Salomón. Y dijeron: «¡Alabado sea Alá, que nos ha preferido a muchos de Sus siervos creyentes!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmclxxv{Salomón heredó a David y dijo: «¡Hombres! Se nos ha enseñado el lenguaje de los pájaros y se nos ha dado de todo. ¡ Es un favor manifiesto!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmclxxvi{Las tropas de Salomón, compuestas de genios, de hombres y pájaros, fueron agrupadas ante él y formadas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmclxxvii{Hasta que, llegados al Valle de las Hormigas, una hormiga dijo: «¡Hormigas! ¡Entrad en vuestras viviendas, no sea que Salomón y sus tropas os aplasten sin darse cuenta!»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmclxxviii{Sonrió al oír lo que ella decía y dijo: «¡Señor! ¡Permíteme que Te agradezca la gracia que nos has dispensado, a mí y a mis padres! ¡Haz que haga obras buenas que Te plazcan! ¡Haz que entre a formar parte, por Tu misericordia, de Tus siervos justos!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmclxxix{Pasó revista a los pájaros y dijo: «¿Cómo es que no veo a la abubilla? ¿O es que está ausente?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmclxxx{He de castigarla severamente o degollarla, a menos que me presente, sin falta, una excusa satisfactoria».\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmclxxxi{No tardó en regresar y dijo: «Sé algo que tú no sabes, y te traigo de los saba una noticia segura.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmclxxxii{He encontrado que reina sobre ellos una mujer, a quien se ha dado de todo y que posee un trono augusto.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmclxxxiii{He encontrado que ella y su pueblo se postran ante el sol, no ante Alá. El Demonio les ha engalanado sus obras y, habiéndoles apartado del camino, no siguen la buena dirección,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmclxxxiv{de modo que no se prosternan ante Alá, Que pone de manifiesto lo que está escondido en los cielos y en la tierra, y sabe lo que ocultáis y lo que manifestáis.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmclxxxv{Alá, fuera del Cual no hay otro dios, es el Señor del Trono augusto».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmclxxxvi{Dijo él: «Vamos a ver si dices verdad o mientes.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmclxxxvii{Lleva este escrito mío y échaselo. Luego, mantente aparte y mira qué responden».\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmclxxxviii{Dijo ella: «¡Dignatarios! Me han echado un escrito respetable.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmclxxxix{Es de Salomón y dice: '¡En el nombre de Alá el Compasivo el Misericordioso!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcxc{¡No os mostréis altivos conmigo y venid a mí sumisos!'»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcxci{Dijo ella: «¡Dignatarios! ¡Aconsejadme en mi asunto! No voy a decidir nada sin que seáis vosotros testigos».\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcxcii{Dijeron: «Poseemos fuerza y poseemos gran valor, pero a ti te toca ordenar. ¡Mira, pues, qué ordenas!»\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcxciii{Dijo ella: «Los reyes, cuando entran en una ciudad, la arruinan y reducen a la miseria a sus habitantes más poderosos. Así es como hacen.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcxciv{Yo, en cambio, voy a enviarles un regalo y ver con qué regresan los enviados».\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcxcv{Cuando llegó a Salomón. dijo: «¿Queréis colmarme de hacienda? Lo que Alá me ha dado vale más que lo que él os ha dado. No, sino que sois vosotros quienes están contentos con vuestros regalos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcxcvi{¡Regresa a los tuyos! Hemos de marchar contra ellos con tropas a las que no podrán contener y hemos de expulsarles de su ciudad, abatidos y humillados».\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmcxcvii{Dijo él: «¡Dignatarios! ¿Quién de vosotros me traerá su trono antes de que vengan a mí sumisos?»\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmcxcviii{Uno de los genios, un ifrit, dijo: «Yo te lo traeré antes de que hayas tenido tiempo de levantarte de tu asiento. Soy capaz de hacerlo, digno de confianza».\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmcxcix{El que tenía ciencia de la Escritura dijo: «Yo te lo traeré en un abrir y cerrar de ojos». Cuando lo vio puesto junto a sí, dijo: «éste es un favor de mi Señor para probarme si soy o no agradecido. Quien es agradecido, lo es en realidad, en provecho propio. Y quien es desagradecido... Mi Señor Se basta a Sí mismo, es generoso».\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmcc{Dijo: «¡Desfiguradle su trono y veremos si sigue la buena dirección o no!»\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmcci{Cuando ella llegó, se dijo: «¿Es así su trono?» Dijo ella: «Parece que sí». «Hemos recibido la ciencia antes que ella. Nos habíamos sometido.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccii{Pero lo que ella servía, en lugar de servir a Alá, la ha apartado. Pertenecía a un pueblo infiel».\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmcciii{Se le dijo: «¡Entra en el palacio!» Cuando ella lo vio, creyó que era un estanque de agua y se descubrió las piernas. Dijo él: «Es un palacio pavimentado de cristal». Dijo ella: «¡Señor! He sido injusta conmigo misma, pero, como Salomón, me someto a Alá, Señor del universo».\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmcciv{Y a los tamudeos les enviamos su hermano Salih: «¡Servid a Alá!» Y he aquí que se escindieron en dos grupos, que se querellaron.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccv{Dijo: «¡Pueblo! ¿Por qué precipitáis el mal antes que el bien? ¿Por qué no pedís perdón a Alá? Quizás, así, se os tenga piedad».\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccvi{Dijeron: «Os tenemos, a ti y a los que te siguen, por aves de mal agüero». Dijo: «Vuestro augurio está en manos de Alá. Sí, sois gente sujeta a prueba».\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccvii{En la ciudad había un grupo de nueve hombres, que corrompían en la tierra y no la reformaban.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccviii{Dijeron: «¡Juramentémonos ante Alá que hemos de atacarles de noche, a él y a su familia! Luego, diremos a su pariente próximo que no presenciamos el asesinato de su familia y que decimos la verdad».\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmccix{Urdieron una intriga sin sospechar que Nosotros urdíamos otra.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmccx{Y ¡mira cómo terminó su intriga! Les aniquilamos a ellos y a su pueblo, a todos.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmccxi{Ahí están sus casas en ruinas, en castigo de su impiedad. Ciertamente, hay en ello un signo para gente que sabe.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmccxii{Salvamos, en cambio, a los que creían y temían a Alá.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmccxiii{Y a Lot. Cuando dijo a su pueblo: «¿Cometéis deshonestidad a sabiendas?\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmccxiv{¿Os llegáis a los hombres, por concupiscencia, en lugar de llegaros a las mujeres? Sí, sois gente ignorante».\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmccxv{Lo único que respondió su pueblo fue: «¡Expulsad de la ciudad a la familia de Lot! Son gente que se las dan de puros».\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmccxvi{Les preservamos del castigo, a él y a su familia, salvo a su mujer. Determinamos que fuera de los que se rezagaran.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmccxvii{E hicimos llover sobre ellos una lluvia. ¡Lluvia fatal para los que habían sido advertidos...!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmccxviii{Di: «¡Alabado sea Alá! ¡Paz sobre Sus siervos, que Él ha elegido! ¿Quién es mejor: Alá o lo que Le asocian?»\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmccxix{¡ Quién, si no, ha creado los cielos y la tierra y hecho bajar para vosotros agua del cielo, mediante la cual hacemos crecer primorosos jardines allí donde vosotros no podríais hacer crecer árboles? ¿Hay un dios junto con Alá? Pero es gente que equipara.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmccxx{¿Quién, si no, ha estabilizado la tierra, colocado por ella ríos, fijado montañas y puesto una barrera entre las dos grandes masas de agua? ¿Hay un dios junto con Alá? Pero la mayoría no saben.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmccxxi{¿Quién, si no, escucha la invocación del necesitado, quita el mal y hace de vosotros sucesores en la tierra? ¿Hay un dios junto con Alá? ¡Qué poco os dejáis amonestar!\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmccxxii{¿Quién, si no, os guía por entre las tinieblas de la tierra y del mar, quién envía los vientos como nuncios que preceden a Su misericordia? ¿Hay un dios junto con Alá? ¡Alá está por encima de lo que Le asocian!\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmccxxiii{¿Quién, si no, inicia la creación y luego la repite? ¿Quién os sustenta de los bienes del cielo y de la tierra? ¿ Hay un dios junto con Alá? Di: «¡Aportad vuestra prueba, si es verdad lo que decís!»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmccxxiv{Di: «Nadie en los cielos ni en la tierra conoce lo oculto, fuera de Alá. Y no presienten cuándo van a ser resucitados.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmccxxv{Al contrario, su ciencia no alcanza la otra vida. Dudan de ella, más aún, están ciegos en cuanto a ella se refiere».\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmccxxvi{Los infieles dicen: «Cuando nosotros y nuestros padres seamos tierra, ¿se nos sacará?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmccxxvii{¡Esto es lo que antes se nos prometió, a nosotros y a nuestros padres! ¡No son más que patrañas de los antiguos!»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmccxxviii{Di: «¡Id por la tierra y mirad cómo terminaron los pecadores!»\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmccxxix{¡No estés triste por ellos ni te angusties por sus intrigas!\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmccxxx{Dicen: «¡Cuándo se cumplirá esta amenaza, si es verdad lo que decís?»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmccxxxi{Di: «Quizás algo de aquello cuya venida queréis apresurar esté ya pisándoos los talones».\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmccxxxii{Sí, tu Señor dispensa Su favor a los hombres, pero la mayoría no agradecen.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmccxxxiii{En verdad, tu Señor conoce lo que ocultan sus pechos y lo que manifiestan.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmccxxxiv{No hay nada escondido en el cielo ni en la tierra que no esté en una Escritura clara.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmccxxxv{Este Corán cuenta a los Hijos de Israel la mayor parte de aquello en que discrepan.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmccxxxvi{Es, sí, dirección y misericordia para los creyentes.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmccxxxvii{Tu Señor decidirá entre ellos con Su fallo. Es el Poderoso, el Omnisciente.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmccxxxviii{¡Confía en Alá! Posees la verdad manifiesta.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmccxxxix{Tú no puedes hacer que los muertos oigan, ni que los sordos oigan el llamamiento si vuelven la espalda.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmccxl{Ni puedes dirigir a los ciegos, sacándolos de su extravío. Tú no puedes hacer que oigan sino quienes creen en Nuestros signos y están sometidos a Nosotros.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmccxli{Cuando se pronuncie contra ellos la sentencia, les sacaremos de la tierra una bestia que proclamará ante ellos que los hombres no estaban convencidos de Nuestros signos.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmccxlii{El día que, de cada comunidad, congreguemos a una muchedumbre de los que desmentían Nuestros signos, serán divididos en grupos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmccxliii{Hasta que, cuando vengan, diga: «¿Habéis desmentido Mis signos sin haberlos abarcado en vuestra ciencia? ¿Qué habéis hecho si no?»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmccxliv{Se pronunciará contra ellos la sentencia por haber obrado impíamente y no tendrán qué decir.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmccxlv{¿No ven que hemos establecido la noche para que descansen y el día para que puedan ver claro? Ciertamente, hay en ello signos para gente que cree.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmccxlvi{El día que se toque la trompeta, se aterrorizarán quienes estén en los cielos y en la tierra, salvo aquéllos que Alá quiera. Todos vendrán a Él humildes.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmccxlvii{Verás pasar las montañas, que tú creías inmóviles, como pasan las nubes: obra de Alá, Que todo lo hace perfecto. Él está bien informado de lo que hacéis.\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmccxlviii{Quienes presenten una obra buena obtendrán una recompensa mejor aún y se verán, ese día, libres de terror,\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmccxlix{mientras que quienes presenten una obra mala serán precipitados de cabeza en el Fuego: «¿Se os retribuye por algo que no hayáis cometido?»\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmccl{«He recibido sólo la orden de servir al Señor de esta ciudad, que Él ha declarado sagrada. ¡Todo Le pertenece! He recibido la orden de ser de los sometidos a Él,\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmccli{y de recitar el Corán. Quien sigue la vía recta la sigue, en realidad, en provecho propio. Pero quien se extravía... Di: «Yo no soy sino uno que advierte».\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmcclii{Di también: «¡Alabado sea Alá! él os mostrará Sus signos y vosotros los reconoceréis. Tu Señor está atento a lo que hacéis».\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmccliii{\basmalahes tsm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmccliv{éstas son las aleyas de la Escritura clara.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcclv{Te recitamos la historia de Moisés y de Faraón, conforme a la verdad, para gente que cree.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcclvi{Faraón se condujo altivamente en el país y dividió a sus habitantes en clanes. Debilitaba a un grupo de ellos, degollando a sus hijos varones y dejando con vida a sus mujeres. Era de los corruptores.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcclvii{Quisimos agraciar a los que habían sido humillados en el país y hacer de ellos jefes, hacer de ellos herederos,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcclviii{darles poderío en el país y servirnos de ellos para hacer que Faraón. Hamán y sus ejércitos experimentaran lo que ya recelaban.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcclix{Inspiramos a la madre de Moisés: «Dale de mamar y, en caso de peligro, ponlo en el río! ¡No temas por él, no estés triste! Te lo devolveremos y haremos de él un enviado».\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcclx{Lo recogió la familia de Faraón, para terminar siendo para ellos enemigo y causa de tristeza. Faraón, Hamán y sus ejércitos eran pecadores.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcclxi{La mujer de Faraón dijo: «Mi alegría y la tuya. ¡No le mates! Quizá nos sea útil o le adoptemos como hijo». No presentían...\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcclxii{La madre de Moisés quedó desolada y estuvo a punto de revelar lo ocurrido, si no llega a ser porque fortalecimos su corazón para que tuviera fe.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcclxiii{Dijo a su hermana: «¡Síguele!» Y le observaba de lejos, a hurtadillas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcclxiv{Antes, le habíamos vedado los pechos. Dijo ella: «¿Queréis que os indique una familia que os lo cuide y eduque?»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcclxv{Así, lo devolvimos a su madre, para, que se alegrara y no estuviera triste, para que supiera que lo que Alá promete es verdad. Pero la mayoría no saben.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcclxvi{Cuando alcanzó la madurez y completó su crecimiento, le dimos juicio y ciencia: así retribuimos a quienes hacen el bien.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcclxvii{Sin que se enteraran sus habitantes, entró en la ciudad y encontró a dos hombres que peleaban, uno de su propio clan y otro del clan adverso. El de su clan le pidió auxilio contra el del otro. Moisés dio a éste un puñetazo y le mató. Dijo: «Esto es obra del Demonio, que es un enemigo, extra viador declarado».\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcclxviii{Dijo: «¡Señor! He sido injusto conmigo mismo. ¡Perdóname!» Y le perdonó. Él es el Indulgente, el Misericordioso.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcclxix{Dijo: «¡Señor! Por las gracias que me has dispensado, no respaldaré a los pecadores».\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcclxx{A la mañana siguiente se encontraba en la ciudad, temeroso, cauto, y he aquí que el que la víspera había solicitado su auxilio le llamó a gritos. Moisés le dijo: «¡Estás evidentemente descarriado!»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcclxxi{Habiendo querido, no obstante, poner las manos en el enemigo de ambos, éste le dijo: «¡Moisés! ¿Es que quieres matarme a mí como mataste ayer a aquél? Tú no quieres sino tiranizar el país, no reformarlo».\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcclxxii{Entonces, de los arrabales, vino corriendo un hombre. Dijo: «¡Moisés!» los dignatarios están deliberando sobre ti para matarte. ¡Sal! Te aconsejo bien».\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcclxxiii{Y salió de ella, temeroso, cauto. «¡Señor!», dijo: «¿Sálvame del pueblo impío!»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcclxxiv{Y, dirigiéndose hacia Madián, dijo: «Quizá mi Señor me conduzca por el camino recto».\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcclxxv{Cuando llegó a la aguada de Madián, encontró allí a un grupo de gente que abrevaba sus rebaños. Encontró, además, a dos mujeres que mantenían alejado el de ellas. Dijo: «¿Qué os pasa?» Dijeron ellas: «No podemos abrevar el rebaño mientras estos pastores no se lleven los suyos. Y nuestro padre es muy anciano».\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcclxxvi{Y abrevó su rebaño. Luego, se retiró a la sombra. Y dijo: «¡Señor! Me hace mucha falta cualquier bien que quieras hacerme».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcclxxvii{Una de las dos vino a él con paso tímido y dijo: «Mi padre te llama para retribuirte por habernos abrevado el rebaño». Cuando llegó ante él y le contó lo que le había ocurrido, dijo: «¡No temas! Estás a salvo del pueblo impío».\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcclxxviii{Una de ellas dijo: «¡Padre! ¡Dale un empleo! No podrás emplear a nadie mejor que este hombre, fuerte, de confianza».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcclxxix{Dijo: «Quisiera casarte con una de estas dos hijas mías, pero a condición de que trabajes para mí durante ocho años. Si completas diez, es ya cosa tuya. No quiero coaccionarte. Encontrarás, si Alá quiere, que soy de los justos».\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcclxxx{Dijo: «¡Trato hecho! Y cualquiera que sea el plazo que yo decida, no seré objeto de hostilidad. Alá responde de nuestras palabras».\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcclxxxi{Y, cuando Moisés cumplió el tiempo convenido y se fue con su familia, distinguió un fuego del lado del monte y dijo a su familia: «¡Quedaos aquí! Distingo un fuego. Quizá pueda informaros de qué se trata u os traiga un tizón. Quizás, así podáis calentaros».\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcclxxxii{Llegado a él, le llamaron desde la vertiente derecha del valle, desde el sitio bendito, desde el árbol: «¡Moisés! ¡Soy Alá, Señor del universo!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcclxxxiii{¡Tira tu vara!» Y cuando vio que se movía como si fuera una serpiente, dio media vuelta para escapar, sin volverse. «¡Moisés! ¡Avanza y no temas! ¡No va a pasarte nada!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcclxxxiv{Introduce la mano por la escotadura de tu túnica y saldrá blanca, sana. Frente al miedo, ¡mantente sereno! He aquí dos pruebas de tu Señor, destinadas a Faraón y a sus dignatarios, que son gente perversa».\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcclxxxv{Dijo: «¡Señor! He matado a uno de los suyos y temo que me maten.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcclxxxvi{Mi hermano Aarón es más elocuente que yo. Envíale conmigo como ayudante, para que confirme lo que yo diga. Temo que me desmientan».\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcclxxxvii{Dijo: «Fortaleceremos tu brazo con tu hermano y os daremos autoridad. Así no se llegarán a vosotros. Gracias a Nuestros signos, vosotros dos y quienes os sigan ganaréis».\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcclxxxviii{Cuando Moisés les trajo Nuestros signos como pruebas claras, dijeron: «¡Esto no es sino magia inventada! No hemos oído que ocurriera tal cosa en tiempo de nuestros antepasados».\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcclxxxix{Moisés dijo: «Mi Señor sabe bien quién ha traído la Dirección de Él y quién tendrá la Morada Postrera. Los impíos no prosperarán».\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmccxc{Faraón dijo: «¡Dignatarios! Yo no sé que tengáis a ningún otro dios que a mí. ¡Hamán! ¡Cuéceme unos ladrillos y hazme una torre! Quizás, así, pueda llegarme al dios de Moisés. Sí, creo que miente».\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmccxci{Y se condujeron, él y sus tropas, en el país altivamente sin razón. Creían que no iban a ser devueltos a Nosotros.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmccxcii{Entonces, les sorprendimos, a él y a sus tropas, y les precipitamos en el mar. ¡Y mira cómo terminaron los impíos!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmccxciii{Hicimos de ellos jefes que llaman al Fuego. Y el día de la Resurrección no serán auxiliados.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmccxciv{Hemos hecho que sean perseguidos por una maldición en la vida de acá. Y el día de la Resurrección serán vilipendiados.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccxcv{Después de haber hecho perecer a las generaciones precedentes, dimos a Moisés la Escritura como argumento evidente para los hombres, como dirección y misericordia. Quizás, así, se dejaran amonestar.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmccxcvi{Cuando decidimos la orden respecto a Moisés, tú no estabas en la ladera occidental del monte, ni eras testigo.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmccxcvii{Pero suscitamos generaciones que vivieron una vida larga. Tú no residías entre los madianitas para recitarles Nuestras aleyas. Pero enviamos.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccxcviii{Ni estabas en la ladera del monte cuando llamamos. Empero, por una misericordia venida de tu Señor, para que adviertas a un pueblo al que no ha venido monitor alguno antes de ti. Quizás, así, se dejen amonestar.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccxcix{Si como castigo a sus obras, les afligiera una desgracia, dirían: «¡Señor! ¿Por qué no nos has mandado un enviado? Habríamos seguido Tus signos y creído».\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccc{Pero, ahora que la Verdad ha venido a ellos de parte Nuestra, dicen: «¿Por qué no se le ha dado lo mismo que se dio a Moisés?» Pero ¿no se mostraron también incrédulos ante lo que se había dado antes a Moisés? Dicen: «Son dos casos de magia que se respaldan mutuamente». Y dicen: «No creemos en ninguna».\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccci{Di: «Entonces, si es verdad lo que decís ¡traed una Escritura de Alá que dirija a los hombres mejor que esas dos y la seguiré!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcccii{Y, si no te escuchan, sabe que no hacen sino seguir sus pasiones. ¿Y hay alguien más extraviado que quien sigue sus pasiones, sin ninguna dirección venida de Alá? Alá no dirige al pueblo impío.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmccciii{Les hemos hecho llegar la Palabra. Quizás, así se dejen amonestar.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmccciv{Aquéllos a quienes hemos dado la Escritura antes de él, creen en él.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcccv{Y, cuando se les recita éste, dicen: «¡Creemos en él! Es la Verdad que viene de nuestro Señor. Antes de él nos habíamos sometido».\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcccvi{Recibirán doble remuneración por haber tenido paciencia. Repelen el mal con el bien y dan limosna de lo que les hemos proveído.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcccvii{Cuando oyen vaniloquio, se desvían y dicen: «Nosotros responderemos de nuestros actos y vosotros de los vuestros. ¡Paz sobre vosotros! ¡No deseamos tratar con los ignorantes!»\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcccviii{Tú no puedes dirigir a quien amas. Alá es, más bien, Quien dirige a quien él quiere. Él sabe mejor que nadie quiénes son los que siguen la buena dirección.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcccix{Dicen: «Si seguimos la Dirección contigo, se nos despojará de nuestra tierra». Pero ¿es que no les hemos dado poder sobre un territorio sagrado y seguro, al que se traen frutos de todas clases como sustento de parte Nuestra? Pero la mayoría no saben.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcccx{¡Cuántas ciudades hemos hecho perecer, que se ufanaban de sus medios de subsistencia! Ahí tenéis sus viviendas, casi del todo deshabitadas después de ellos. Hemos sido Nosotros los Herederos.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcccxi{Tu Señor nunca ha destruido ciudades sin haber antes mandado a su metrópoli a un enviado que les recitara Nuestras aleyas. Nunca hemos destruido ciudades, a menos que sus habitantes fueran impíos.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcccxii{Lo que habéis recibido no es más que breve disfrute de la vida de acá y ornato suyo. En cambio, lo que Alá tiene es mejor y más duradero. ¿Es que no razonáis?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcccxiii{Uno a quien hemos prometido algo bello, que verá cumplirse, ¿es comparable a aquel otro a quien hemos permitido el breve disfrute de la vida de acá y a quien luego, el día de la Resurrección, se hará comparecer?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmcccxiv{El día que les llame, dirá: «¡Dónde están aquéllos que pretendíais que eran Mis asociados?»\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmcccxv{Aquéllos contra quienes se pronuncie la sentencia dirán: «¡Señor! éstos son los que nosotros descarriamos. Les descarriamos como nosotros también estábamos descarriados. Somos inocentes ante Ti. No es a nosotros a quienes servían».\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmcccxvi{Se dirá: «¡Invocad a vuestros asociados!» Les invocarán, pero no les escucharán y verán el castigo. Si hubieran seguido la buena dirección...\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmcccxvii{El día que les llame, dirá: «¿Qué repondisteis a los enviados?»\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmcccxviii{Ese día, como no sabrán qué responder, ni se preguntarán unos a otros.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmcccxix{En cuanto a quien se arrepienta, crea y obre bien, es posible que se cuente entre los que prosperen.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmcccxx{Tu Señor crea y elige lo que quiere. El elegir no les incumbe. ¡Gloria a Alá! ¡Está por encima de lo que Le asocian!\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmcccxxi{Tu Señor conoce lo que ocultan sus pechos y lo que manifiestan.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmcccxxii{¡Es Alá ¡No hay más dios que Él! ¡Alabado sea en esta vida y en la otra! ¡Suya es la decisión ! ¡Y a Él seréis devueltos!\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmcccxxiii{Di: «¿Qué os parece si Alá os impusiera una noche perpetua hasta el día de la Resurrección? ¿Qué otro dios que Alá podría traeros la claridad? ¿Es que no oís?»\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmcccxxiv{Di: «¿Qué os parece si Alá os impusiera un día perpetuo hasta el día de la Resurrección? ¿Qué otro dios que Alá podría traeros la noche para reposaros? ¿Es que no veis?»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmcccxxv{Como muestra de Su misericordia, ha establecido la noche para vosotros para que descanséis y el día para que busquéis Su favor. Y quizás así, seáis agradecidos.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmcccxxvi{El día que les llame, dirá: «¿Dónde están aquéllos que pretendíais que eran Mis asociados?»\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmcccxxvii{Haremos comparecer un testigo de cada comunidad y diremos: «¡Aportad vuestra prueba!» Y sabrán que la Verdad es de Alá. Y se esfumarán sus invenciones.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmcccxxviii{Coré formaba parte del pueblo de Moisés y se insolentó con ellos. Le habíamos dado tantos tesoros que un grupo de hombres forzudos apenas podía cargar con las llaves. Cuando su pueblo le dijo: «No te regocijes, que Alá no ama a los que se regocijan!\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmcccxxix{¡Busca en lo que Alá te ha dado la Morada Postrera, pero no olvides la parte que de la vida de acá te toca! ¡Sé bueno, como Alá lo es contigo! ¡No busques corromper en la tierra, que Alá no ama a los corruptores!»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmcccxxx{Dijo: «Lo que se me ha dado lo debo sólo a una ciencia que tengo». Pero ¿es que no sabía que Alá había hecho perecer antes de él a otras generaciones más poderosas y opulentas que él? Pero a los pecadores no se les interrogará acerca de sus pecados.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmcccxxxi{Apareció ante su pueblo, rodeado de pompa. Los que deseaban la vida de acá dijeron: «¡Ojalá se nos hubiera dado otro tanto de lo que se ha dado a Coré! Tiene una suerte extraordinaria».\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmcccxxxii{Pero los que habían recibido la Ciencia, dijeron: «¡Ay de vosotros! La recompensa de Alá es mejor para el que cree y obra bien. Y no lo conseguirán sino los que tengan paciencia».\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmcccxxxiii{Hicimos que la tierra se tragara a él y su vivienda. No hubo ningún grupo que, fuera de Alá, le auxiliara, ni pudo defenderse a sí mismo.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmcccxxxiv{A la mañana siguiente, los que la víspera habían envidiado su posición dijeron: «¡Ah! Alá dispensa el sustento a quien Él quiere de sus Siervos: a unos con largueza, a otros con mesura. Si Alá no nos hubiera agraciado, habría hecho que nos tragara. ¡Ah! ¡Los infieles no prosperarán!»\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmcccxxxv{Asignamos esa Morada Postrera a quienes no quieren conducirse con altivez en la tierra ni corromper. El fin es para los que temen a Alá.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmcccxxxvi{Quien venga habiendo obrado bien tendrá como recompensa algo aún mejor. Y quien venga habiendo obrado mal,... Quienes hayan obrado mal no serán retribuidos sino conforme a sus obras.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmcccxxxvii{Sí, Quien te ha impuesto el Corán, te devolverá a un lugar de retorno. Di: «Mi Señor sabe bien quién ha traído la Dirección y quién está evidentemente extraviado».\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmcccxxxviii{Tú no podías esperar que se te transmitiera a ti la Escritura. No ha sido así más que por misericordia venida de tu Señor. ¡No respaldes a los infieles!\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmcccxxxix{¡Que no te desvíen de las aleyas de Alá, después de haberte sido reveladas! ¡Llama a tu Señor y no seas de los asociadores!\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmcccxl{¡No invoques a otro dios junto con Alá! ¡No hay más dios que Él! ¡Todo perece, salvo Él! ¡Suya es la decisión! ¡Y a Él seréis devueltos!\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmcccxli{\basmalahes 'lm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcccxlii{Piensan los hombres que se les dejará decir: «¡Creemos!», sin ser probados?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcccxliii{Ya probamos a sus predecesores. Alá, sí, conoce perfectamente a los sinceros y conoce perfectamente a los que mienten.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcccxliv{¿Piensan quienes obran mal que podrán escapar de Nosotros? ¡Qué mal juzgan!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcccxlv{Quien cuente con encontrar a Alá sepa que el plazo fijado por Alá vendrá ciertamente, Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcccxlvi{Quien combate por Alá combate, en realidad, en provecho propio. Alá, ciertamente, puede prescindir de las criaturas.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcccxlvii{A quienes hayan creído y obrado bien les borraremos, sí, sus malas obras y les retribuiremos, sí, con arreglo a sus mejores obras.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcccxlviii{Hemos ordenado al hombre que se porte bien con sus padres. Pero si éstos te insisten en que Me asocies algo de lo que no tienes conocimiento, ¡no les obedezcas! Volveréis a Mí y ya os informaré de lo que hacíais.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcccxlix{A quienes hayan creído y obrado bien hemos de hacer que entren a formar parte de los justos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcccl{Hay algunos que dicen: «¡Creemos en Alá!» Pero, en cuanto sufren algo por Alá, toman la prueba a que los hombres les somenten como castigo de Alá. Si, en cambio, tu Señor les auxilia, seguro que dicen: «¡Estábamos con vosotros!» ¿Es que Alá no sabe bien lo que hay en los pechos de la Humanidad?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcccli{Alá, sí, conoce perfectamente a los que creen y conoce perfectamente a los hipócritas.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmccclii{Los infieles dicen a los creyentes: «¡Seguid nuestro camino y cargaremos con vuestros pecados!» Pero, si ni con sus propios pecados cargan nada... ¡Mienten, ciertamente!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcccliii{Llevarán, ciertamente, su carga juntamente con la ajena. El día de la Resurrección tendrán que responder de lo que se inventaban.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcccliv{Enviamos Noé a su pueblo y permaneció con él durante mil años menos cincuenta. Luego, el diluvio les sorprendió en su impiedad.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmccclv{Les salvamos, a él y a los de la nave, e hicimos de ella un signo para todo el mundo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmccclvi{Y a Abraham. Cuando dijo a su pueblo: «¡Servid a Alá y temedle! Es mejor para vosotros. Si supierais...»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmccclvii{Servís, en lugar de servir a Alá, sólo ídolos, y creáis una mentira. Los que vosotros servís, en lugar de servir a Alá, no pueden procuraros sustento. ¡Buscad, pues, en Alá el sustento! ¡Servidle, dadle gracias! ¡A Él seréis devueltos!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmccclviii{Si desmentís, ya otras generaciones, antes de vosotros, desmintieron. Al Enviado sólo le incumbe la transmisión clara.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmccclix{¿Es que no ven cómo inicia Alá la creación y, luego, la repite? Es cosa fácil para Alá.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmccclx{Di: «¡Id por la tierra y mirad cómo inició la creación! Luego, Alá creará por última vez. Alá es omnipotente».\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmccclxi{Castiga a quien Él quiere y se apiada de quien Él quiere. A Él seréis devueltos.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmccclxii{No podéis escapar en la tierra ni en el cielo. No tenéis, fuera de Alá, amigo ni auxiliar.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmccclxiii{Quienes no crean en los signos de Alá y en que Le encontrarán, ésos son quienes desesperarán de Mi misericordia, ésos son quienes sufrirán un castigo doloroso.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmccclxiv{Lo único que respondió su pueblo fue: «¡Matadle o quemadle!» Pero Alá le libró del fuego. Ciertamente hay en ello signos para gente que cree.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmccclxv{Dijo: «Habéis tomado ídolos en lugar de tomar a Alá, sólo por el afecto mutuo que os tenéis en la vida de acá. Luego, el día de la Resurrección, renegaréis unos de otros y os maldeciréis mutuamente. Vuestra morada será el Fuego y no tendréis quien os auxilie».\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmccclxvi{Lot creyó en Él y dijo: «Me refugio en mi Señor. Él es el Poderoso, el Sabio».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmccclxvii{Le regalamos Isaac y Jacob, e instituimos en su descendencia el profetismo y la Escritura. Le recompensamos en la vida de acá, y en la otra es de los justos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmccclxviii{Y a Lot. Cuando dijo a su pueblo: «Ciertamente cometéis una deshonestidad que ninguna criatura ha cometido antes.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmccclxix{¿Os llegáis a los hombres, salteáis y cometéis actos reprobables en vuestras reuniones?». Lo único que respondió su pueblo fue: «¡Tráenos el castigo de Alá, si es verdad lo que dices!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmccclxx{Dijo: «¡Señor! ¡Auxíliame contra el pueblo corruptor!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmccclxxi{Cuando Nuestros mensajeros vinieron a Abraham con la buena nueva, dijeron: «Vamos a hacer perecer a la población de esta ciudad. Son unos impíos».\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmccclxxii{Dijo: «Pero Lot está en ella». Dijeron: «Sabemos bien quién está en ella. Les salvaremos, ciertamente, a él y a su familia, excepto a su mujer, que será de los que se rezaguen».\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmccclxxiii{Habiendo llegado nuestros mensajeros a Lot, éste se afligió por ellos y se sintió impotente para protegerles. Pero ellos dijeron: «¡No temas ni estés triste! Vamos a salvaros, a ti y a tu familia, excepto a tu mujer, que será de los que se rezaguen.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmccclxxiv{Vamos a hacer bajar un castigo del cielo sobre la población de esta ciudad, porque han sido unos perversos».\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmccclxxv{E hicimos de ella un signo claro para gente que razona.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmccclxxvi{A los madianitas su hermano Suayb. Dijo: «¡Pueblo! ¡Servid a Alá y contad con el último Día! ¡No obréis mal en la tierra corrompiendo!»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmccclxxvii{Le desmintieron y el Temblor les sorprendió, amaneciendo muertos en sus casas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmccclxxviii{¡Y a los aditas y a los tamudeos! Por sus viviendas se os muestra claramente... El Demonio engalanó sus obras y los apartó del Camino, a pesar de su perspicacia.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmccclxxix{¡Y a Coré, a Faraón y a Hamán! Moisés vino a ellos con las pruebas claras y ellos se condujeron en el país altivamente. Pero no consiguieron escapar.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmccclxxx{Sorprendimos a cada uno por su pecado. Contra unos enviamos una tempestad de arena. A otros les sorprendió el Grito. A otros hicimos que la tierra se los tragara. A otros les anegamos. No fue Alá quien fue injusto con ellos, sino que ellos lo fueron consigo mismos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmccclxxxi{Quienes toman amigos en lugar de tomar a Alá son semejantes a la araña que se ha hecho una casa. Y la casa más frágil es la de la araña. Si supieran...\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmccclxxxii{Alá sabe todo lo que invocan en lugar de invocarle a Él. Es el Poderoso, el Sabio.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmccclxxxiii{Proponemos estas parábolas a los hombres, pero no las comprenden sino los que saben.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmccclxxxiv{Alá ha creado con un fin los cielos y la tierra. Ciertamente, hay en ello un signo para los creyentes.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmccclxxxv{¡Recita lo que se te ha revelado de la Escritura ! ¡Haz la azalá! La azalá prohíbe la deshonestidad y lo reprobable. Pero el recuerdo de Alá es más importante aún. Alá sabe lo que hacéis.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmccclxxxvi{No discutáis sino con buenos modales con la gente de la Escritura, excepto con los que hayan obrado impíamente. Y decid: «Creemos en lo que se nos ha revelado a nosotros y en lo que se os ha revelado a vosotros. Nuestro Dios y vuestro Dios es Uno. Y nos sometemos a él».\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmccclxxxvii{Y, así, te hemos revelado la Escritura. Aquéllos a quienes revelamos la Escritura creen en ella. Entre éstos hay algunos que creen en ella. Nadie rechaza Nuestros signos sino los infieles.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmccclxxxviii{Tú no leías, antes de recibirla, ninguna Escritura, ni copiabas ninguna con tu diestra. Los falsarios, si no, habrían sospechado...\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmccclxxxix{Antes bien, es un conjunto de aleyas claras en los pechos de quienes han recibido la Ciencia. No niegan Nuestros signos sino los impíos.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcccxc{Dicen: «¿Por qué no se le han revelado signos procedentes de su Señor?» Di: «Sólo Alá dispone de los signos. Yo soy solamente un monitor que habla claro».\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmcccxci{¿Es que no les basta que te hayamos revelado la Escritura que se les recita? Hay en ello una misericordia y una amonestación para gente que cree.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmcccxcii{Di: «¡Alá basta como testigo entre yo y vosotros! Conoce lo que está en los cielos y en la tierra. Quienes crean en lo falso y no crean en Alá, ésos serán los que pierdan».\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcccxciii{Y te piden que adelantes el castigo. Si no fuera porque ha sido prefijado, les habría ya alcanzado. Les vendrá, en verdad, de repente, sin presentirlo.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcccxciv{Te piden que adelantes el castigo. Sí, la gehena cercará a los infieles.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcccxcv{El día que el castigo les cubra de pies a cabeza y diga: «¡Gustad el fruto de vuestras obras!»\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcccxcvi{¡Siervos creyentes! ¡Mi tierra es vasta! ¡Servidme, pues, a Mí solo!\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcccxcvii{Cada uno gustará la muerte. Luego, seréis devueltos a Nosotros.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcccxcviii{A quienes hayan creído y hecho el bien hemos de alojarles en el Jardín, eternamente, en cámaras altas, a cuyos pies fluyen arroyos. ¡Qué grata es la recompensa de los que obran bien,\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcccxcix{que tienen paciencia y confían en su Señor!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcd{¡Cuántas bestias hay que no pueden proveerse del sustento! Alá se encarga de él y del vuestro. Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcdi{Si les preguntas: «¿Quién ha creado los cielos y la tierra y sujetado el sol y la luna?», seguro que dicen: «¡Alá!» ¡Cómo pueden, pues, ser tan desviados!\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmcdii{Alá dispensa el sustento a quien Él quiere de Sus siervos: a unos con largueza, a otros con mesura. Alá es omnisciente.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmcdiii{Si les preguntas: «¿Quién hace bajar agua del cielo, vivificando con ella la tierra después de muerta?», seguro que dicen: «¡Alá!» Di: «¡Alabado sea Alá!» No, la mayoría no comprenden.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmcdiv{Esta vida de acá no es sino distracción y juego, pero la Morada Postrera, ésa sí que es la Vida. Si supieran...\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmcdv{Cuando se embarcan, invocan a Alá rindiéndole culto sincero. Pero, en cuanto les salva, llevándoles a tierra firme, al punto Le asocian otros dioses,\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmcdvi{para terminar negando lo que les hemos dado. ¡Que gocen por breve tiempo! ¡Van a ver...!\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmcdvii{¿No ven que hemos hecho un territorio sagrado y seguro, mientras, alrededor de ellos, secuestran a la gente? ¿Creen, pues, en lo falso y no creerán en la gracia de Alá?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmcdviii{¿Hay alguien que sea más impío que quien inventa una mentira contra Alá o que, cuando viene a él la Verdad, la desmiente? ¿No hay en la gehena una morada para los infieles?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmcdix{A quienes hayan combatido por Nosotros ¡hemos de guiarles por Nuestros caminos! ¡Alá está, en verdad, con quienes hacen el bien!\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmcdx{\basmalahes 'lm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcdxi{Los bizantinos han sido vencidos\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcdxii{en los confines del país. Pero, después de su derrota, vencerán\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcdxiii{dentro de varios años. Todo está en manos de Alá, tanto el pasado como el futuro. Ese día, los creyentes se regocijarán\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcdxiv{del auxilio de Alá. Auxilia a quien Él quiere. Es el Poderoso, el Misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcdxv{¡Promesa de Alá! Alá no falta a Su promesa. Pero la mayoría de los hombres no saben.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcdxvi{Conocen lo externo de la vida de acá, pero no se preocupan por la otra vida.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcdxvii{¿Es que no reflexionan en su interior? Alá no ha creado los cielos, la tierra y lo que entre ellos está sino con un fin y por un período determinado. Pero muchos hombres se niegan, sí, a creer en el encuentro de su Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcdxviii{¿No han ido por la tierra y mirado cómo terminaron sus antecesores? Eran más poderosos, araban la tierra y la poblaban más que ellos. Sus enviados vinieron a ellos con las pruebas claras. No fue Alá quien fue injusto con ellos, sino que ellos lo fueron consigo mismos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcdxix{Y el fin de los que obraron mal fue el peor, porque desmintieron los signos de Alá y se burlaron de ellos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcdxx{Alá inicia la creación y luego la repite, después de lo cual seréis devueltos a Él.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcdxxi{Cuando suene la Hora, los pecadores serán presa de la desesperación.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcdxxii{Sus asociados no intercederán por ellos y éstos renegarán de aquéllos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcdxxiii{El día que suene la Hora se dividirán:\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcdxxiv{quienes hayan creído y obrado bien, serán regocijados en un prado;\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcdxxv{pero quienes no hayan creído y hayan desmentido Nuestros signos y la existencia de la otra vida serán entregados al castigo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcdxxvi{¡Gloria a Alá tarde y mañana!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcdxxvii{¡Alabado sea en los cielos y en la tierra, por la tarde y al mediodía!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcdxxviii{Saca al vivo del muerto, al muerto del vivo. Vivifica la tierra después de muerta. Así es como se os sacará.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcdxxix{Y entre Sus signos está el haberos creado de tierra. Luego, hechos hombres, os diseminasteis...\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcdxxx{Y entre Sus signos está el haberos creado esposas nacidas entre vosotros, para que os sirvan de quietud, y el haber suscitado entre vosotros el afecto y la bondad. Ciertamente, hay en ellos signos para gente que reflexiona.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcdxxxi{Y entre Sus signos está la creación de los cielos y de la tierra, la diversidad de vuestras lenguas y de vuestros colores. Ciertamente hay en ello signos para los que saben.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcdxxxii{Y entre Sus signos está vuestro sueño, de noche o de día, vuestra solicitud en recibir Su favor. Ciertamente, hay en ello signos para gente que oye.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcdxxxiii{Y entre Sus signos está el haceros ver el relámpago, motivo de temor y de anhelo, y el hacer bajar agua del cielo, vivificando con ella la tierra después de muerta. Ciertamente, hay en ello signos para gente que razona.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcdxxxiv{Y entre sus Signos está el que los cielos y la tierra se sostengan por una orden Suya. Al final, apenas Él os llame de la tierra, saldréis inmediatamente.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcdxxxv{Suyos son quienes están en los cielos y en la tierra. Todos Le obedecen.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcdxxxvi{Es Él Quien inicia la creación y, luego, la repite. Es cosa fácil para Él. Representa el ideal supremo en los cielos y en la tierra. Es el Poderoso, el Sabio.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcdxxxvii{Os propone una parábola tomada de vuestro mismo ambiente: ¿Hay entre vuestros esclavos quienes participen del mismo sustento de que os hemos proveído, de modo que podáis equipararos en ello con ellos y les temáis tanto cuanto os teméis unos a otros? Así explicamos detalladamente los signos a gente que razona.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcdxxxviii{Los impíos, al contrario, siguen sus pasiones sin conocimiento. ¿Quién podrá dirigir a aquéllos a quienes Alá ha extraviado? No tendrán quien les auxilie.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcdxxxix{¡Profesa la Religión como hanif, según la naturaleza primigenia que Alá ha puesto en los hombres! No cabe alteración en la creación de Alá. Ésa es la religión verdadera. Pero la mayoría de los hombres no saben.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmcdxl{volviéndoos a Él arrepentidos. ¡Temedle, haced la azalá y no seáis de los asociadores,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmcdxli{de los que escinden su religión en sectas, contento cada grupo con lo suyo!\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmcdxlii{Cuando los hombres sufren una desgracia, invocan a su Señor, volviéndose a Él arrepentidos. Luego, cuando les ha hecho gustar una misericordia venida de Él, algunos de ellos asocian otros dioses a su Señor,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmcdxliii{para terminar negando lo que les hemos dado. ¡Gozad, pues, brevemente! ¡Vais a ver...!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmcdxliv{¿Acaso les hemos conferido una autoridad que hable de lo que ellos Le asocian?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmcdxlv{Cuando hacemos gustar a los hombres una misericordia, se regocijan de ella. Pero, si les sucede un mal como castigo a sus obras, ahí les tenéis desesperados.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmcdxlvi{¿Es que no ven que Alá dispensa el sustento a quienes Él quiere: a unos con largueza, a otros con mesura? Ciertamente, hay en ello signos para gente que cree.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmcdxlvii{Da lo que es de derecho al pariente, al pobre y al viajero. Es lo mejor para quienes desean agradar a Alá. Esos son los que prosperarán.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmcdxlviii{Lo que prestáis con usura para que os produzca a costa de la hacienda ajena no os produce ante Alá. En cambio, lo que dais de azaque por deseo de agradar a Alá... Ésos son los que recibirán el doble.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmcdxlix{Alá es Quien os ha creado y, luego proveído del sustento, Quien os hará morir y, luego, volveros a la vida. ¿Hay alguno de vuestros asociados que sea capaz de hacer algo de eso? ¡Gloria a Él! ¡Está por encima de lo que Le asocian!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmcdl{Ha aparecido la corrupción en la tierra y en el mar como consecuencia de las acciones de los hombres, para hacerles gustar parte de lo que han hecho. Quizás, así, se conviertan.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmcdli{Di: «¡Id por la tierra y mirad cómo terminaron sus antecesores: fueron, en su mayoría, asociadores!»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmcdlii{Profesa la religión verdadera antes de que llegue un día que Alá no evitará. Ese día serán separados:\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmcdliii{quienes no hayan creído sufrirán las consecuencias de su incredulidad, pero quienes hayan obrado bien se habrán preparado un lecho.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmcdliv{Para retribuir con Su favor a los que hayan creído y obrado bien. Él no ama a los infieles.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmcdlv{Entre Sus signos, está el envío de los vientos como nuncios de la buena nueva, para daros a gustar de Su misericordia, para que naveguen las naves siguiendo Sus órdenes y para que busquéis Su favor. Y quizás, así, seáis agradecidos.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmcdlvi{Antes de ti, hemos mandado enviados a su pueblo. Les aportaron las pruebas claras. Nos vengamos de los que pecaron, era deber Nuestro auxiliar a los creyentes.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmcdlvii{Alá es Quien envía los vientos y éstos levantan nubes. Y Él las extiende como quiere por el cielo, las fragmenta y ves que sale de dentro de ellas el chaparrón. Cuando favorece con éste a los siervos que Él quiere, he aquí que éstos se regocijan,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmcdlviii{mientras que, antes de haberles sido enviado desde arriba, habían sido presa de la desesperación.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmcdlix{¡Y mira las huellas de la misericordia de Alá, cómo vivifica la tierra después de muerta! Tal es, en verdad, el Vivificador de los muertos. Es omnipotente.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmcdlx{Y si enviamos un viento y ven que amarillea, se obstinan, no obstante, en su incredulidad.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmcdlxi{Tú no puedes hacer que los muertos oigan ni que los sordos oigan el llamamiento, si vuelven la espalda.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmcdlxii{Ni puedes dirigir a los ciegos, sacándoles de su extravío. Tú no puedes hacer que oigan sino quienes creen en Nuestros signos y están sometidos a Nosotros.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmcdlxiii{Alá es Quien os creó débiles; luego, después de ser débiles, os fortaleció luego, después de fortaleceros, os debilitó y os encaneció. Crea lo que Él quiere. Es el Omnisciente, el Omnipotente.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmcdlxiv{El día que llegue la Hora, jurarán los pecadores que no han permanecido sino una hora. Así estaban de desviados...\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmcdlxv{Quienes habían recibido la Ciencia y la fe dirán: «Habéis permanecido el tiempo previsto en la Escritura de Alá: hasta el día de la Resurrección, y hoy es el día de la Resurrección. Pero no sabíais...»\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmcdlxvi{Ese día, no les servirán de nada a los impíos sus excusas y no serán agraciados.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmcdlxvii{En este Corán hemos dado a los hombres toda clase de ejemplos. Si les vienes con una aleya, seguro que dicen los infieles: «¡No sois más que unos falsarios!»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmcdlxviii{Así es como sella Alá los corazones de los que no saben.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmcdlxix{¡Ten, pues, paciencia! ¡Lo que Alá promete es verdad! ¡Que no te encuentren ligero quienes no están convencidos!\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmcdlxx{\basmalahes 'lm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcdlxxi{Éstas son las aleyas de la Escritura sabia,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcdlxxii{como dirección y misericordia para quienes hacen el bien.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcdlxxiii{que hacen la azalá, dan el azaque y están convencidos de la otra vida.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcdlxxiv{Esos tales están dirigidos por su Señor, ésos son los que prosperarán.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcdlxxv{Hay entre los hombres quien compra historietas divertidas para, sin conocimiento, extraviar a otros del camino de Alá y para tomarlo a burla. Quienes tal hagan tendrán un castigo humillante.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcdlxxvi{Cuando se le recitan Nuestras aleyas, se aleja altivamente, como si no las hubiera oído, como si hubiera estado sordo. ¡Anúnciale un castigo doloroso!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcdlxxvii{Quienes, en cambio, hayan creído y obrado bien tendrán los jardines de la Delicia.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcdlxxviii{en los que estarán eternamente. ¡Promesa de Alá verdad! Él es el Poderoso, el Sabio.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcdlxxix{Ha creado los cielos sin pilares visibles. Ha fijado en la tierra las montañas para que ella y vosotros no vaciléis. Ha diseminado por ella toda clase de bestias. Hemos hecho bajar agua del cielo y crecer en ella toda especie generosa.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcdlxxx{Ésta es la creación de Alá. ¡Mostradme, pues, qué han creado los otros dioses que hay fuera de Él! Sí, los impíos están evidentemente extraviados.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcdlxxxi{Dimos a Luqmán la sabiduría: «¡Sé agradecido con Alá! Quien es agradecido lo es, en realidad, en provecho propio. Quien es desagradecido... Alá Se basta a Sí mismo, es digno de alabanza».\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcdlxxxii{Y cuando Luqmán amonestó a su hijo, diciéndole: «¡Hijito! ¡No asocies a Alá otros dioses, que la asociación es una impiedad enorme!».\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcdlxxxiii{Hemos ordenado al hombre con respecto a sus padres -su madre le llevó sufriendo pena tras pena y le destetó a los dos años-: «Sé agradecido conmigo y con tus padres. ¡Soy Yo el fin de todo!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcdlxxxiv{Pero, si te insisten en que Me asocies aquello de que no tienes conocimiento, ¡no les obedezcas! En la vida de acá ¡pórtate amablemente con ellos! ¡Sigue el camino de quien vuelve a Mí arrepentido! Luego, volveréis a Mí y ya os informaré de lo que hacíais».\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcdlxxxv{«¡Hijito! Aunque se trate de algo del peso de un grano de mostaza y esté escondido en una roca, en los cielos o en la tierra, Alá lo sacará a luz. Alá es sutil, está bien informado.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcdlxxxvi{¡Hijito! ¡Haz la azalá! ¡Ordena lo que está bien y prohíbe lo que está mal! ¡Ten paciencia ante la adversidad! ¡Eso sí que es dar muestras de resolución!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcdlxxxvii{¡No pongas mala cara a la gente, ni pises la tierra con insolencia! Alá no ama a nadie que sea presumido, jactancioso.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcdlxxxviii{¡Sé modesto en tus andares! ¡Habla en voz baja! ¡La voz más desagradable es, ciertamente, la del asno!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcdlxxxix{¿No veis que Alá ha sujetado a vuestro servicio lo que está en los cielos y en la tierra, y os ha colmado de Sus gracias, visibles u ocultas? Pero hay algunos hombres que discuten de Alá sin tener conocimiento, ni dirección, ni Escritura luminosa.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcdxc{Y, cuando se les dice: «¡Seguid lo que Alá ha revelado!», dicen: «¡No, sino que seguiremos lo mismo que nuestros padres seguían!» ¿Y si el Demonio les llamara al castigo del fuego de la gehena?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcdxci{Quien se somete a Alá y hace el bien se ase del asidero más firme. El fin de todo es Alá.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcdxcii{Si alguien no cree, ¡que su incredulidad no te entristezca! Volverán a Nosotros y ya les informaremos de lo que hacían. Alá sabe bien lo que encierran los pechos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcdxciii{Les dejaremos que gocen por breve tiempo. Luego, les arrastraremos a un duro castigo.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcdxciv{Si les preguntas: «¿Quién ha creado los cielos y la tierra?», seguro que dicen: «¡Alá!» Di: «¡Alabado sea Alá!» No, la mayoría no saben.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcdxcv{Es de Alá lo que está en los cielos y en la tierra. Alá es Quien Se basta a Sí mismo, el Digno de Alabanza.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcdxcvi{Si se hicieran cálamos de los árboles de la tierra, y se añadieran al mar, luego de él, otros siete mares más, no se agotarían las palabras de Alá. Alá es poderoso, sabio.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcdxcvii{Crearos y resucitaros cuesta a Alá tanto como si se tratara de una sola persona. Alá todo lo oye, todo lo ve.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcdxcviii{¿No ves que Alá hace que la noche entre en el día y que el día entre en la noche, ha sujetado el sol y la luna, prosiguiendo los dos su curso hasta un término fijo, y que Alá está bien informado de lo que hacéis?\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmcdxcix{Esto es así porque Alá es la Verdad, pero lo que ellos invocan en lugar de invocarle a Él es lo falso. Alá es el Altísimo, el Grande.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmd{¿No ves que las naves navegan por la gracia de Alá, para que Él os muestre algunos de Sus signos? Ciertamente, hay en ello signos para todo aquél que tenga mucha paciencia, mucha gratitud.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdi{Y, cuando las olas les cubren cual pabellones, invocan a Alá rindiéndole culto sincero. Pero, en cuanto les salva, llevándolos a tierra firme, algunos de ellos vacilan. Nadie niega Nuestros signos sino todo aquél que es pérfido, desagradecido.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdii{¡Hombres! ¡Temed a vuestro Señor y tened miedo de un día en que el padre no pueda satisfacer por su hijo, ni el hijo por su padre! ¡Lo que Alá promete es verdad! ¡Que la vida de acá no os engañe, y que el Engañador no os engañe acerca de Alá!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdiii{Alá tiene conocimiento de la Hora. Envía abajo la lluvía. Sabe lo que encierran las entrañas de la madre, mientras que nadie sabe lo que el día siguiente le deparará, nadie sabe en qué tierra morirá. Alá es omnisciente, está bien informado.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdiv{\basmalahes 'lm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdv{La revelación de la Escritura, exenta de dudas, procede del Señor del universo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdvi{O dicen: «Él la ha inventado». ¡No! es la Verdad venida de tu Señor, para que adviertas a un pueblo al que no ha venido monitor alguno antes de ti. Quizás, así, sean bien dirigidos.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdvii{Alá es Quien ha creado los cielos, la tierra y lo que entre ellos está en seis días. Luego, se ha instalado en el Trono. Fuera de É, no tenéis amigo ni intercesor. ¿Es que no os dejaréis amonestar?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdviii{Él dispone en el cielo todo lo de la tierra. Luego, todo ascenderá a Él en un día equivalente en duración a mil años de los vuestros.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdix{Tal es el Conocedor de lo oculto y de lo patente, el Poderoso, el Misericordioso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdx{Que ha hecho bien todo cuanto ha creado y ha comenzado la creación del hombre de arcilla\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdxi{-luego, ha establecido su descendencia de una gota de líquido vil-;\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdxii{luego, le ha dado forma armoniosa e infundido en él de Su Espíritu. Os ha dado el oído, la vista y el intelecto. ¡Qué poco agradecidos sois!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdxiii{Dicen: «Cuando nos hayamos perdido en la tierra, ¿es verdad que se nos creará de nuevo?» No, no creen en el encuentro de su Señor.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdxiv{Di: «El ángel de la muerte, encargado de vosotros, os llamara y, luego, seréis devueltos a vuestro Señor».\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdxv{Si pudieras ver a los pecadores, cabizbajos ante su Señor: «¡Señor! ¡Hemos visto y oído! ¡Haznos volver para que hagamos obras buenas! ¡Estamos convencidos!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdxvi{Si hubiéramos querido, habríamos dirigido a cada uno. Pero se ha realizado Mi sentencia: «¡He de llenar la gehena de genios y de hombres, de todos ellos!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdxvii{¡Gustad, pues, por haber olvidado que os llegaría este día! Nosotros también os hemos olvidado. ¡Gustad el castigo eterno por lo que habéis hecho!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdxviii{Sólo creen en Nuestras aleyas quienes, al ser amonestados con ellas, caen al suelo en adoración y glorifican a su Señor, sin mostrarse altivos.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdxix{Se alzan del lecho para invocar a su Señor con temor y anhelo y dan limosna de lo que les hemos proveído.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdxx{Nadie sabe la alegría reservada a ellos en retribución a sus obras.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdxxi{¿Es que el creyente es como el perverso? No son iguales.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdxxii{Quienes crean y obren bien tendrán los jardines de la Morada como alojamiento en premio a sus obras.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdxxiii{Pero los que obren con perversidad tendrán el Fuego como morada. Siempre que quieran salir de él, serán devueltos a él y se les dirá:«¡Gustad el castigo del Fuego que desmentíais!»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdxxiv{Hemos de darles a gustar del castigo de aquí abajo antes del castigo mayor. Quizás, así, se conviertan.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdxxv{¿Hay alguien que sea más impío que quien, habiéndosele recordado los signos de su Señor, se desvía luego de ellos? Nos vengaremos de los pecadores.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdxxvi{Hemos dado a Moisés la Escritura -no dudes, pues, en encontrarle- e hicimos de ella dirección para los Hijos de Israel.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdxxvii{Elegimos de entre ellos a jefes que les dirigieran siguiendo Nuestra orden como premio por haber perseverado y por haber estado convencidos de Nuestros signos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdxxviii{Tu Señor fallará entre ellos el día de la Resurrección sobre aquello en que discrepaban.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdxxix{¿Es que no les dice nada que hayamos hecho perecer a tantas generaciones precedentes, cuyas viviendas huellan ellos ahora? Ciertamente, hay en ello signos. ¿No oirán, pues?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdxxx{¿Es que no ven cómo conducimos el agua a la tierra pelada y, gracias a ella, sacamos los cereales de que se alimentan sus rebaños y ellos mismos? ¿No verán, pues?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdxxxi{Y dicen: «¿Para cuándo ese fallo, si es verdad lo que decís?»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdxxxii{Di: «El día del fallo, la fe ya no aprovechará a los infieles y no les será dado esperar».\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdxxxiii{¡Apártate, pues, de ellos y espera! ¡Ellos esperan!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdxxxiv{\basmalahes ¡Profeta! ¡Teme a Alá y no obedezcas a los infieles y a los hipócritas! Alá es omnisciente, sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdxxxv{¡Sigue lo que tu Señor te revela! Alá está bien informado de lo que hacéis.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdxxxvi{¡Confía en Alá! ¡Alá basta como protector!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdxxxvii{Alá no ha puesto dos corazones en el pecho de ningún hombre. Ni ha hecho que las esposas que repudiáis por la fórmula: «¡Eres para mí como la espalda de mi madre!» sean vuestras madres. Ni ha hecho que vuestros hijos adoptivos sean vuestros propios hijos. Eso es lo que vuestras bocas dicen. Alá, empero, dice la verdad y conduce por el Camino.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdxxxviii{Llamadles por su padre. Es más equitativo ante Alá. Y, si no sabéis quién es su padre, que sean vuestros hermanos en religión y vuestros protegidos. No incurrís en culpa si en ello os equivocáis, pero sí si lo hacéis deliberadamente. Alá es indulgente, misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdxxxix{El Profeta está más cerca de los creyentes que ellos lo están de sí mismos. Las esposas de aquél son las madres de éstos. Los unidos por lazos de consanguinidad están más cerca unos de otros, según la Escritura de Alá, que los creyentes y los emigrados, a menos que hagáis un favor a vuestros amigos. Eso está anotado en la Escritura.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdxl{Y cuando concertamos un pacto con los profetas, contigo, con Noé, con Abraham, con Moisés y con Jesús, hijo de María -pacto solemne,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdxli{para pedir cuenta de su sinceridad a los sinceros. Y para los infieles ha preparado un castigo doloroso.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdxlii{¡Creyentes! Recordad la gracia que Alá os dispensó cuando vinieron las legiones contra vosotros y Nosotros enviamos contra ellas un viento y legiones invisibles a vuestros ojos. Alá ve bien lo que hacéis.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdxliii{Cuando os acosaban por todas partes, cuando el terror os desvió la mirada, se os hizo un nudo en la garganta y conjeturasteis sobre Alá.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdxliv{En esa ocasión, los creyentes fueron puestos a prueba y sufrieron una violenta conmoción.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdxlv{Y cuando los hipócritas y los enfermos de corazón decían: «¡Alá y Su Enviado no han hecho sino engañarnos con sus. promesas!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdxlvi{Y cuando un grupo de ellos dijo: «¡Gente de Yatrib! ¡No os quedéis aquí! ¡Regresad!» Parte de ellos pidió autorización al Profeta, diciendo: «¡Nuestras casas están indefensas!» En realidad, no es que sus casa estuvieran indefensas, lo que querían era huir.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdxlvii{Si les hubieran entrado por sus arrabales y se les hubiera pedido que apostataran, habrían aceptado casi sin demora.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdxlviii{Pero habían concertado antes con Alá una alianza: no volver la espalda. Y hay que responder de la alianza con Alá...\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdxlix{Di: «No sacaréis nada con huir si es que pretendéis con ello no morir o que no os maten. De todas maneras, se os va a dejar gozar sólo por poco tiempo».\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdl{Di: «¿Quién podrá protegeros de Alá, tanto si quiere haceros mal como si quiere haceros objeto de misericordia?» No encontrarán, fuera de Alá, amigo ni auxiliar.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdli{Alá sabe quiénes son, entre vosotros, los que levantan obstáculos y los que dicen a sus hermanos: «¡Venid a nosotros!», pero sin mostrar gran ardor para combatir.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdlii{Os regatean la ayuda. Cuando viene el miedo, les ves que te miran, girándoles los ojos, como mira aquél a quien ronda la muerte. Pero, cuando ha desaparecido el miedo, os hieren con sus afiladas lenguas, ávidos de botín. Esos tales no son creyentes. Alá hará vanas sus obras. Es cosa fácil t para Alá.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdliii{Creen que los coalicionistas no se han ido. Pero, si los coalicionistas regresaran, querrían retirarse al desierto entre los beduinos, preguntando qué ha sido de vosotros. Si se quedaran con vosotros, combatirían pero poco.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdliv{En el Enviado de Alá tenéis, ciertamente, un bello modelo para quien cuenta con Alá y con el último Día y que recuerda mucho a Alá.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdlv{Y cuando los creyentes vieron a los coalicionistas, dijeron: «Esto es lo que Alá y su Enviado nos habían prometido. ¡Dios y su Enviado decían la verdad!» Esto no hizo sino aumentar su fe y su adhesión.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdlvi{Hubo creyentes que se mantuvieron fieles a la alianza concertada con Alá. Algunos de ellos dieron ya su vida. Otros esperan aún, sin mudar su actitud.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdlvii{Para que Alá retribuya a los sinceros por su sinceridad y castigue a los hipócritas, si quiere, o se vuelva a ellos. Alá es indulgente, misericordioso.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdlviii{Alá despidió a los infieles llenos de ira, sin que consiguieran triunfar. Alá evitó el combate a los creyentes. Alá es fuerte, poderoso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdlix{Hizo bajar de sus fortalezas a los de la gente de la Escritura que habían apoyado a aquéllos. Sembró el terror en sus corazones. A unos matasteis, a otros les hicisteis cautivos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdlx{Os ha dado en herencia su tierra, sus casas, sus bienes y un territorio que nunca habíais pisado. Alá es omnipotente.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdlxi{¡Profeta! Di a tus esposas: «Si deseáis la vida de acá y su ornato, ¡venid, que os proveeré y os dejaré en libertad decorosamente!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdlxii{Pero, si buscáis a Alá, a Su Enviado y la Morada Postrera, entonces, Alá ha preparado una recompensa magnífica para aquéllas de vosotras que hagan el bien».\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdlxiii{¡Mujeres del Profeta! A la que de vosotras sea culpable de deshonestidad manifiesta, se le doblará el castigo. Es cosa fácil para Alá.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdlxiv{Pero a la que de vosotras obedezca a Alá y a Su Enviado y obre bien, le daremos doble remuneración y le prepararemos generoso sustento.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdlxv{¡Mujeres del Profeta! Vosotras no sois como otras mujeres cualesquiera. Si teméis a Alá, no seáis tan complacientes en vuestras palabras que llegue a anhelaros el enfermo de corazón. ¡Hablad, más bien, como se debe!\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdlxvi{¡Quedaos en vuestras casas! ¡No os acicaléis como se acicalaban las natiguas paganas! ¡Haced la azalá! ¡Dad el azaque! ¡Obedeced a Alá y a Su Enviado! Alá sólo quiere libraros de la mancha, gente de la casa, y purificaros por completo.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdlxvii{Recordad lo que de las aleyas de Alá y de la Sabiduría se recita en vuestras casas. Alá es sutil, está bien informado.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdlxviii{Alá ha preparado perdón y magnífica recompensa para los musulmanes y las musulmanas, los creyentes y las creyentes, los devotos y las devotas, los sinceros y las sinceras, los pacientes y las pacientes, los humildes y las humildes, los que y las que dan limosna, los que y las que ayunan, los castos y las castas, los que y las que recuerdan mucho a Alá.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdlxix{Cuando Alá y Su Enviado han decidido un asunto, ni el creyente ni la creyente tienen ya opción en ese asunto. Quien desobedece a Alá y a su Enviado está evidentemente extraviado.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdlxx{Y cuando decías al que había sido objeto de una gracia de Alá y de una gracia tuya: «¡Conserva a tu esposa y teme a Alá!», y ocultabas en tu alma lo que Alá iba a revelar, y tenías miedo de los hombres, siendo así que Alá tiene más derecho a que Le tengas miedo. Cuando Zayd había terminado con ella, te la dimos por esposa para que no se pusiera reparo a los creyentes que se casan con las esposas de sus hijos adoptivos, cuando éstos han terminado con ellas. ¡La orden de Alá se cumple!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdlxxi{Que no tenga reparos el Profeta por algo que le ha sido impuesto por Alá. conforme a la práctica de Alá para los que vivieron antes -la orden de Alá es un decreto decidido-,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdlxxii{que transmitían los mensajes de Alá y Le tenían miedo, no teniendo miedo de nadie más que de Alá. ¡Basta Alá para ajustar cuentas!\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdlxxiii{Mahoma no es el padre de ninguno de vuestros varones, sino el Enviado de Alá y el sello de los profetas. Alá es omnisciente.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdlxxiv{¡Creyentes! ¡Recordad mucho a Alá!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdlxxv{¿Glorificadle mañana y tarde!\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdlxxvi{Él es Quien, con Sus ángeles, os a bendice para sacaros de las tinieblas a la luz. Es misericordioso con los creyentes.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdlxxvii{El día que Le encuentren, serán saludados con: «¡Paz!» Les habrá preparado una recompensa generosa.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdlxxviii{¡Profeta! Te hemos enviado como testigo, como nuncio de buenas nuevas, como monitor,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdlxxix{como voz que llama a Alá con Su permiso, como antorcha luminosa.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdlxxx{Anuncia a los creyentes que recibirán un gran favor de Alá.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdlxxxi{¡No obedezcas a los infieles y a los hipócritas! ¡Haz caso omiso de sus ofensas y confía en Alá! ¡Alá basta como protector!\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdlxxxii{¡Creyentes! Si os casáis con mujeres creyentes y, luego, las repudiáis antes de haberlas tocado, no tenéis por qué exigirles un período de espera. ¡Proveedlas de lo necesario y dejadlas en libertad decorosamente!\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdlxxxiii{¡Profeta! Hemos declarado lícitas para ti a tus esposas, a las que has dado dote, a las esclavas que Alá te ha dado como botín de guerra, a las hijas de tu tío y tías paternos y de tu tío y tías maternos que han emigrado contigo y a toda mujer creyente, si se ofrece al Profeta y el Profeta quiere casarse con ella. Es un privilegio tuyo, no de los otros creyentes -ya sabemos lo que hemos impuesto a estos últimos con respecto a sus esposas y esclavas, para que no tengas reparo. Alá es indulgente, misericordioso.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdlxxxiv{Puedes dejar para otra ocasión a la que de ellas quieras, o llamar a ti a la que quieras, o volver a llamar a una de las que habías separado. No haces mal. Esto contribuye a su alegría, a evitar que estén tristes y a que todas ellas estén contentas con lo que tú les des. Alá sabe lo que encierran vuestros corazones. Alá es omnisciente, benigno.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdlxxxv{En adelante, no te será lícito tomar otras mujeres, ni cambiar de esposas, aunque te guste su belleza, a excepción de tus esclavas. Alá todo lo observa.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdlxxxvi{¡Creyentes! No entréis en las habitaciones del Profeta a menos que se os autorice a ello para una comida. No entréis hasta que sea hora. Cuando se os llame, entrad y, cuando hayáis comido, retiraos sin poneros a hablar como si fueráis de la familia. Esto molestaría al Profeta y, por vosotros, le daría vergüenza. Alá, en cambio, no Se avergüenza de la verdad. Cuando les pidáis un objeto hacedlo desde detrás de una cortina. Es más decoroso para vosotros y para ellas. No debéis molestar al Enviado de Alá, ni casaros jamás con las que hayan sido sus esposas. Esto, para Alá, sería grave.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdlxxxvii{Si mostráis algo o lo ocultáis,... Alá lo sabe todo.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdlxxxviii{No pecan si se trata de sus padres, sus hijos, sus hermanos, los hijos de sus hermanos, los hijos de sus hermanas, sus mujeres o sus esclavas. ¡Temed a Alá! Alá es testigo de todo.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdlxxxix{Alá y sus ángeles bendicen al Profeta. ¡Creyentes! ¡Bendecidle vosotros también y saludadle como se debe!\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdxc{A los que molestan a Alá y a Su Enviado, Alá les ha maldecido en la vida de acá y en la otra y les ha preparado un castigo humillante.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdxci{Los que molestan a los creyentes y a las creyentes, sin haberlo éstos merecido, son culpables de infamia y de pecado manifiesto.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdxcii{¡Profeta! Di a tus esposas, a tus hijas y a las mujeres de los creyentes que se cubran con el manto. Es lo mejor para que se las distinga y no sean molestadas. Alá es indulgente, misericordioso.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdxciii{Si los hipócritas, los enfermos de corazón y los agitadores de la ciudad no cesan, hemos de incitarte contra ellos y pronto dejarán tu vecindad.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdxciv{Malditos, serán capturados y muertos sin piedad donde quiera que se dé con ellos,\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdxcv{conforme a la practica de Alá con los que vivieron antes. Y encontrarás la práctica de Alá irreemplazable.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdxcvi{Los hombres te preguntan por la Hora. Di: «Sólo Alá tiene conocimiento de ella». ¿Quién sabe? Quizá la Hora esté próxima...\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdxcvii{Alá ha maldecido a los infieles y les ha preparado fuego de la gehena,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdxcviii{en el que estarán eternamente, para siempre. No encontrarán amigo ni auxiliar.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdxcix{El día que, en el Fuego, se desencajen sus rostros de dolor, dirán: «¿Ojalá hubiéramos obedecido a Alá! ¡Ojalá hubiéramos obedecido al Enviado!».\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdc{Y dirán: «¡Señor! ¡Hemos obedecido a nuestros señores y a nuestros grandes y nos han extraviado del Camino!\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdci{¡Dóblales, Señor, el castigo y échales una gran maldición!»\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdcii{¡Creyentes! ¡No seáis como los que molestaron a Moisés! Alá le declaró inocente de lo que le habían acusado. Alá le tenía consideración.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdciii{¡Creyentes! ¡Temed a Alá y no digáis despropósitos,\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdciv{para que haga prosperar vuestras obras y os perdone vuestros pecados! Quien obedezca a Alá y a Su Enviado tendrá un éxito grandioso.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdcv{Propusimos el depósito a los cielos, a la tierra y a las montañas, pero se negaron a hacerse cargo de él, tuvieron miedo. El hombre, en cambio, se hizo cargo. Es, ciertamente, muy impío, muy ignorante.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdcvi{Para que Alá castigue a los hipócritas y a las hipócritas, a los asociadores y a las asociadoras, y para que Alá se vuelva a los creyentes y a las creyentes. Alá es indulgente, misericordioso.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdcvii{\basmalahes ¡Alabado sea Alá, a Quien pertenece lo que está en los cielos y en la tierra! ¡Alabado sea también en la otra vida! Él es el Sabio, el Bien Informado.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdcviii{Sabe lo que penetra en la tierra y lo que de ella sale, lo que desciende del cielo y lo que a él asciende. Él es el Misericordioso, el Indulgente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdcix{Los infieles dicen: «La Hora no nos llegará». Di: «¡Claro que sí! ¡Por mi Señor, el Conocedor de lo oculto, que ha de llegaros! No se Le pasa desapercibido el peso de un átomo en los cielos ni en la tierra. No hay nada, menor o mayor que eso, que no esté en una Escritura clara,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdcx{para retribuir a los que creyeron y obraron bien. Esos tales tendrán perdón y generoso sustento.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdcxi{Quienes, en cambio, se hayan esforzado por dejar sin efecto Nuestros signos, tendrán el castigo de un suplicio doloroso».\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdcxii{Quienes han recibido la Ciencia ven que lo que tu Señor te ha revelado es la Verdad y dirige a la vía del Poderoso, del Digno de Alabanza.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdcxiii{Los infieles dicen: «¿Queréis que os indiquemos un hombre que os anuncie que, cuando estéis completamente descompuestos, de verdad se os creará de nuevo?»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdcxiv{¿Ha inventado una mentira contra Alá o es un poseso? ¡No, no es así! Los que no creen en la otra vida están destinados al castigo y profundamente extraviados.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdcxv{¿Es que no ven lo que les rodea en los cielos y en la tierra? Si quisiéramos, haríamos que la tierra se los tragara o que cayera sobre ellos parte del cielo. Ciertamente, hay en ello un signo para todo siervo arrepentido.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdcxvi{Dimos a David un favor Nuestro: «¡Montañas! ¡Resonad acompañándole, y vosotros también, pájaros!» Por él, hicimos blando el hierro.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdcxvii{«¡Fabrica cotas de malla y mide bien la malla!» ¡Obrad bien! Yo veo bien lo que hacéis.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdcxviii{A Salomón el viento, que por la mañana hacía el camino de un mes y por la tarde de otro mes. Hicimos manar para él la fuente de bronce fundido. De los genios, algunos trabajaban a su servicio, con permiso de su Señor. Al que hubiera desobedecido Nuestras órdenes, le habríamos hecho gustar el castigo del fuego de la gehena.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdcxix{Le hacían todo lo que él quería: palacios, estatuas, calderos grandes como cisternas, firmes marmitas. ¡Familiares de David, sed agradecidos! Pero pocos de Mis siervos son muy agradecidos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdcxx{Y cuando decretamos su muerte, no tuvieron más indicio de ella que la carcoma, que se puso a roer su cayado. Y, cuando se desplomó, vieron claramente los genios que, si hubieran conocido lo oculto, no habrían permanecido tanto tiempo en el humillante castigo.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdcxxi{Los saba tenían un signo en su territorio: dos jardines, uno a la derecha y otro a la izquierda. «¡Comed del sustento de vuestro Señor y dadle gracias! Tenéis un buen país y un Señor indulgente».\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdcxxii{Pero se desviaron y enviamos contra ellos la inundación de los diques. Y les cambiamos aquellos dos jardines por otros dos que producían frutos amargos, tamariscos y unos pocos azufaifos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdcxxiii{Así les retribuimos por su ingratitud. No castigamos sino al desagradecido.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdcxxiv{Entre ellos y las ciudades que Nosotros hemos bendecido establecimos otras ciudades, cerca unas de otras, y determinamos el tránsito entre ellas: «¡Id de una a otra, de día o de noche, en seguridad!»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdcxxv{Pero dijeron: «¡Señor! ¡Alarga nuestros recorridos!» Y fueron injustos consigo mismos. Los hicimos legendarios y los dispersamos por todas partes. Ciertamente, hay en ello signos para todo aquél que tenga mucha paciencia, mucha gratitud.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdcxxvi{Iblis confirmó la opinión que se había formado de ellos. Le siguieron todos, menos un grupo de creyentes.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdcxxvii{No tenía poder sobre ellos. Queríamos sólo distinguir a los que creían en la otra vida de los que dudaban de ella. Tu Señor cuida de todo.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdcxxviii{Di: «Invocad a los que, en lugar de Alá, pretendéis. No pueden el peso de un átomo en los cielos ni en la tierra, ni tienen allí participación, ni Él encuentra en ellos ayuda.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdcxxix{Es inútil interceder por nadie ante Él, excepto por quien Él lo permita. Hasta que, cuando el terror haya desaparecido de sus corazones, digan: '¿Qué ha dicho vuestro Señor?' Dirán: 'La verdad' Él es el Altísimo, el Grande».\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdcxxx{Di: «¿Quién os procura el sustento de los cielos y de la tierra?» Di: «¡Alá! O nosotros o vosotros, unos siguen la buena dirección y otros están evidentemente extraviados».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdcxxxi{Di: «Ni vosotros tendréis que responder de nuestros delitos, ni nosotros de lo que hagáis».\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdcxxxii{Di: «Nuestro Señor nos reunirá y fallará entre nosotros según justicia. Él es Quien falla, el Omnisciente».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdcxxxiii{Di: «Mostradme los que Le habéis agregado como asociados. Pero ¡no! El es Alá, el Poderoso, el Sabio».\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdcxxxiv{No te hemos enviado sino como nuncio de buenas nuevas y como monitor a todo el género humano. Pero la mayoría de los hombres no saben.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdcxxxv{Dicen: «¿Cuándo se cumplirá esta amenaza, si es verdad lo que decís?»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcxxxvi{Di: «Se os ha fijado ya un día que no podréis retrasar ni adelantar una hora».\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcxxxvii{Los infieles dicen: «No creemos en este Corán ni en sus precedentes». Si pudieras ver a los impíos, de pie ante su Señor, recriminándose unos a otros. Los que fueron débiles dirán a los que fueron altivos: «Si no llega a ser por vosotros, habríamos creído».\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcxxxviii{Los que fueron altivos dirán a los que fueron débiles: «¿Somos, acaso, nosotros los que os desviaron de la Dirección cuando se os indicó ésta? ¡No, fuisteis culpables!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcxxxix{Los que fueron débiles dirán a los que fueron altivos: «¡No!, que fueron vuestras maquinaciones de noche y de día, cuando nos instabais a que no creyéramos en Alá y a que Le atribuyéramos iguales...» Y, cuando vean el castigo, disimularán su pena. Pondremos argollas al cuello de los que no hayan creído. ¿Serán retribuidos por otra cosa que por lo que hicieron?\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcxl{No hemos enviado monitor a una ciudad que no dijeran sus ricos: «No creemos en vuestro mensaje».\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcxli{Y que no dijeran: «Nosotros tenemos más hacienda e hijos. No se nos castigará».\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcxlii{Di: «Mi Señor dispensa el sustento a quien Él quiere: a unos con largueza, a otros con mesura. Pero la mayoría de los hombres no saben».\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcxliii{Ni vuestra hacienda ni vuestros hijos podrán acercaros bien a Nosotros. Sólo quienes crean y obren bien recibirán una retribución doble por sus obras y morarán seguros en las cámaras altas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcxliv{En cambio, quienes se esfuercen por dejar sin efecto Nuestros signos, serán entregados al castigo.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcxlv{Di: «Mi Señor dispensa el sustento a quien Él quiere de Sus siervos: a unos con largueza, a otros con mesura. No dejará de restituiros ninguna limosna que deis. Él es el Mejor de los proveedores».\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcxlvi{El día que Él los congregue a todos, dirá a los ángeles: «¿Es a vosotros a quienes servían?»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcxlvii{Dirán: «¡Gloria a Ti! Tú eres nuestro Amigo, no ellos. ¡No! Ellos servían a los genios, en los que la mayoría creían».\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdcxlviii{Ese día no podréis ya aprovecharos ni dañaros unos a otros. Y diremos a los impíos: «¡Gustad el castigo del Fuego que desmentíais!»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcxlix{Y cuando se les recitan Nuestras aleyas como pruebas claras, dicen: «éste no es sino un hombre que quiere apartaros de lo que vuestros padres servían». Y dicen: «Esto no es sino una mentira inventada». Y de la Verdad, luego que ha venido ésta a ellos, dicen los infieles: «¡Esto no es sino manifiesta magia!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcl{No les dimos ningunas Escrituras que estudiaran, ni les enviamos a ningún monitor antes de ti.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdcli{Sus antecesores desmintieron y no han obtenido ni la décima parte de lo que dimos a aquéllos, que desmintieron, no obstante, a Mis enviados. Y ¡cuál no fue Mi reprobación!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdclii{Di: «Sólo os exhorto a una cosa: a que os pongáis ante Alá, de dos en dos o solos, y meditéis. Vuestro paisano no es un poseso; no es sino un monitor que os previene contra un castigo severo».\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcliii{Di: «El salario que yo pueda pediros ¡quedáoslo! Mi salario no incumbe sino a Alá. Él es testigo de todo».\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdcliv{Di: «Mi Señor despide Verdad. Él conoce a fondo las cosas ocultas».\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdclv{Di: «Ha venido la Verdad. Lo falso no crea ni re-crea».\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdclvi{Di: «Si me extravío, me extravío, en realidad, en detrimento propio. Si sigo el camino recto, lo debo a lo que mi Señor me revela. Él lo oye todo, está cerca».\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdclvii{Si pudieras ver cuando, sobrecogidos de espanto, sin escape posible, sean arrebatados de un lugar próximo.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdclviii{Dirán: «¡Creemos en É!» Pero ¿como podrán alcanzar estando tan lejos,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdclix{si antes no creyeron en É y, desde lejos, lanzaban injurias contra lo oculto?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdclx{Se interpondrá una barrera entre ellos y el objeto de su deseo, como ocurrió antes con sus semejantes: estaban en duda grave.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdclxi{\basmalahes ¡Alabado sea Alá, creador de los cielos y de la tierra, Que de los ángeles ha hecho enviados de dos, tres o cuatro alas! Añade a la creación lo que Él quiere. Alá es omnipotente.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdclxii{No hay quien pueda retener la misericordia que Alá dispensa a los hombres, ni hay quien pueda soltar, fuera de Él, lo que Él retiene. Él es el Poderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdclxiii{¡Hombres! Recordad la gracia que Alá os ha dispensado. ¿Hay algún otro creador distinto de Alá, que os provea del cielo y de la tierra el sustento? No hay más dios que É. ¿Cómo podéis, pues, ser tan desviados!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdclxiv{Si te desmienten, ya antes de ti fueron desmentidos enviados. Pero todo será devuelto a Alá.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdclxv{¡Hombres! ¡Lo que Alá promete es verdad! ¡Que la vida de acá no os engañe! ¡Que el Engañador no os engañe acerca de Alá!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdclxvi{El Demonio es para vosotros un enemigo. Tenedle, pues, por tal. Llama a sus partidarios sólo para que moren en el fuego de la gehena.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdclxvii{Los que no hayan creído tendrán un castigo severo. En cambio, los que hayan creído y obrado bien tendrán perdón y una gran recompensa.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdclxviii{¿Es que aquél cuya mala conducta ha sido engalanada y la ve como buena...? Alá extravía a quien Él quiere y dirige a quien Él quiere. ¡No te consumas por ellos de pesar! Alá sabe bien lo que hacen.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdclxix{Alá es Quien envía los vientos y éstos levantan nubes, que Nosotros conducimos a un país árido. Con ellas vivificamos la tierra después de muerta. Así será la Resurrección.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdclxx{Quien quiera el poder... El poder pertenece, en su totalidad, a Alá. Hacia Él se eleva la buena palabra y Él realza la obra buena. En cambio, quienes tramen males tendrán un castigo severo, y la trama de ésos se malogrará.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdclxxi{Alá os ha creado de tierra; luego, de una gota; luego, hizo de vosotros parejas. Ninguna hembra concibe o pare sin que Él lo sepa. Nadie muere a edad avanzada o prematura que no esté eso en una Escritura. Es cosa fácil para Alá.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdclxxii{No son iguales las dos grandes masas de agua: una potable, dulce, agradable de beber; otra salobre, amarga. Pero de cada una coméis una carne fresca y obtenéis adornos que os ponéis. Y ves que las naves las surcan. Para que busquéis Su favor. Quizás, así, seáis agradecidos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdclxxiii{Hace que la noche entre en el día y que el día entre en la noche. Ha sujetado el sol y la luna, prosiguiendo los dos su curso hacia un término fijo. Ése es Alá, vuestro Señor. Suyo es el dominio. Los que invocáis en lugar de invocarle a Él no pueden lo más mínimo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdclxxiv{Si les invocáis, no oyen vuestra súplica y, aun si la oyeran, no os escucharían. El día de la Resurrección renegarán de que les hayáis asociado a Alá. Y nadie te informará como Quien está bien informado.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdclxxv{¡Hombres! Sois vosotros los necesitados de Alá, mientras que Alá es Quien Se basta a Sí mismo, el Digno de Alabanza.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdclxxvi{Si Él quisiera, os haría desaparecer y os sustituiría por nuevas criaturas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdclxxvii{Y eso no sería difícil para Alá.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdclxxviii{Nadie cargará con la carga ajena. Y si alguien, abrumado por su carga, pide ayuda a otro, no se le ayudará nada, aunque sea pariente. Tú sólo debes advertir a los que tienen miedo de su Señor en secreto y hacen la azalá. Quien se purifica se purifica en realidad, en provecho propio. ¡Es Alá el fin de todo!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdclxxix{No son iguales el ciego y el vidente,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdclxxx{las tinieblas y la luz,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdclxxxi{la fresca sombra y el calor ardiente.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdclxxxii{No son iguales los vivos y los muertos. Alá hace que oiga quien Él quiere. Tú no puedes hacer que quienes estén en las sepulturas oigan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdclxxxiii{Tú no eres sino un monitor.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdclxxxiv{Te hemos enviado con la Verdad como nuncio de buenas nuevas y como monitor. No hay comunidad por la que no haya pasado un monitor.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdclxxxv{Y si te desmienten, también sus antecesores desmintieron. Sus enviados vinieron a ellos con las pruebas claras, con las Escrituras y con la Escritura luminosa.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdclxxxvi{Luego, sorprendí a los infieles y ¡cuál no fue Mi reprobación!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdclxxxvii{¿No ves cómo ha hecho Alá bajar agua del cielo, mediante la cual hemos sacado frutos de diferentes clases? En las montañas hay vetas de diferentes colores: blancas, rojas y de un negro intenso.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdclxxxviii{Los hombres, bestias y rebaños son también de diferentes clases. Sólo tienen miedo de Alá aquéllos de Sus siervos que saben. Alá es poderoso, indulgente.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdclxxxix{Quienes recitan la Escritura de Alá, hacen la azalá y dan limosna, en secreto o en público, de lo que les hemos proveído, pueden esperar una ganancia imperecedera,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcxc{para que Él les dé su recompensa y aún más de Su favor. Es indulgente, muy agradecido.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcxci{Lo que de la Escritura te hemos revelado es la Verdad, en confirmación de los mensajes anteriores. Sí, Alá está bien informado de Sus siervos, los ve bien.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcxcii{Luego, hemos dado en herencia la Escritura a aquéllos de Nuestros siervos que hemos elegido. Algunos de ellos son injustos consigo mismos; otros, siguen una vía media; otros, aventajan en el bien obrar, con permiso de Alá. Ése es el gran favor.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcxciii{Entrarán en los jardines del edén. Allí se les ataviará con brazaletes de oro y con perlas, allí vestirán de seda.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcxciv{Y dirán: «¡Alabado sea Alá, Que ha retirado de nosotros la tristeza! En verdad, nuestro Señor es indulgente, muy agradecido\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcxcv{Nos ha instalado. por favor Suyo, en la Morada de la Estabilidad. No sufriremos en ella pena, no sufriremos cansancio».\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcxcvi{Los infieles, en cambio, sufrirán el fuego de la gehena. Agonizarán sin acabar de morir y no se les aliviará su castigo. Así retribuimos a todo desagradecido.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcxcvii{Gritarán allí: «¡Señor! ¡Sácanos y obraremos bien, no como solíamos hacer!». «¿Es que no os dimos una vida suficientemente larga como para que se dejara amonestar quien quisiera? El monitor vino a vosotros... ¡Gustad, pues! Los impíos no tendrán quien les auxilie».\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcxcviii{Alá es el Conocedor de lo oculto de los cielos y de la tierra. Él sabe bien lo que encierran los pechos.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcxcix{Él es Quien os ha hecho sucesores en la tierra. Quien no crea, sufrirá las consecuencias de su incredulidad. La incredulidad servirá sólo para hacer a los infieles más aborrecibles ante su Señor. La incredulidad servirá sólo para perder más a los infieles.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcc{Di: «¿Veis a vuestros asociados, a los que invocáis en lugar de invocar a Alá? Mostradme qué han creado de la tierra o si tienen participación en los cielos. O ¿les hemos dado una Escritura, en cuya prueba clara puedan basarse?» ¡No! Las promesas que los impíos se hacen mutuamente no son sino falacias.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcci{Alá sostiene los cielos y la tierra para que no se desplomen. Si se desplomaran no habría nadie, fuera de Él, que pudiera sostenerlos. Es benigno, indulgente.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdccii{Juraron solemnemente por Alá que, si venía un monitor a ellos, iban a ser dirigidos mejor que ninguna otra comunidad. Y, cuando ha venido a ellos un monitor, esto no ha hecho sino acrecentar su repulsa,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcciii{portándose altivamente en la tierra y tramando maldad. Pero el tramar maldad no recae sino en sus propios autores. ¿Es que esperan una suerte diferente de la que cupo a los antiguos? Pues encontrarás la práctica de Alá irreemplazable, y encontrarás la práctica de Alá inmutable.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcciv{¿No han ido por la tierra y mirado cómo terminaron sus antecesores, aun siendo más poderosos? Nada, ni en los cielos ni en la tierra, puede escapar a Él. Es omnisciente, omnipotente.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdccv{Si Alá diera a los hombres su merecido, no dejaría ningún ser vivo sobre su superficie. Remite, sin embargo, su castigo a un plazo fijo. Y cuando vence su plazo... Alá ve bien a Sus siervos.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdccvi{\basmalahes ys.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdccvii{¡Por el sabio Corán,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdccviii{que tú eres, ciertamente, uno de los enviados\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdccix{y estás en una vía recta!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdccx{como Revelación del Poderoso, del Misericordioso,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdccxi{para que adviertas a un pueblo cuyos antepasados no fueron advertidos y que, por eso, no se preocupa.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdccxii{Se ha cumplido la sentencia contra la mayoría: no creen.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdccxiii{Les hemos puesto al cuello argollas, hasta la barbilla, de tal modo que no pueden mover la cabeza.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdccxiv{Les hemos puesto una barrera por delante y otra por detrás, cubriéndoles de tal modo que no pueden ver.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdccxv{Les da lo mismo que les adviertas o no: no creerán.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdccxvi{Pero tú sólo tienes que advertir a quien sigue la Amonestación y tiene miedo del Compasivo en secreto. Anúnciale el perdón y una recompensa generosa.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdccxvii{Nosotros resucitamos a los muertos. Inscribimos todo lo que antes hicieron, así como las consecuencias de sus actos. Todo lo tenemos en cuenta en un Libro claro.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdccxviii{Propónles una parábola: los habitantes de la ciudad. Cuando vinieron a ella los enviados.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdccxix{Cuando les enviamos a dos y les desmintieron. Reforzamos con un tercero y dijeron: «Se nos ha enviado a vosotros».\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdccxx{Dijeron: «No sois sino unos mortales como nosotros. El Compasivo no ha revelado nada. No decís sino mentiras».\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdccxxi{Dijeron: «Nuestro Señor sabe: en verdad, se nos ha enviado a vosotros,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdccxxii{encargados sólo de la transmisión clara».\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdccxxiii{Dijeron: «No presagiamos de vosotros nada bueno. Si no desistís hemos de lapidaros y haceros sufrir un castigo doloroso».\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdccxxiv{Dijeron: «De vosotros depende vuestra suerte. Si os dejarais amonestar... Sí, sois gente inmoderada».\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdccxxv{Entonces, de los arrabales, vino corriendo un hombre. Dijo: «¡Pueblo! ¡Seguid a los enviados!\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdccxxvi{¡Seguid a quienes no os piden salario y siguen la buena dirección!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdccxxvii{¿Por qué no voy a servir a Quien me ha credado y a Quien seréis devueltos?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdccxxviii{¿Voy a tomar, en lugar de tomarle a É, dioses cuya intercesión, si el Compasivo me desea una desgracia, de nada me aprovechará y tales que no podrán salvarme?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdccxxix{Si eso hiciera, estaría, sí, evidentemente extraviado.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdccxxx{¡Creo en vuestro Señor! ¡Escuchadme!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdccxxxi{Se dijo: «¡Entra en el Jardín!» Dijo: «¡Ah! Si mi pueblo supiera\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdccxxxii{que mi Señor me ha perdonado y me ha colocado entre los honrados».\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdccxxxiii{Después de él, no hicimos bajar del cielo ninguna legión contra su pueblo. No hicimos bajar.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdccxxxiv{No hubo más que un solo Grito y ¡helos sin vida!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdccxxxv{¡Pobres siervos! No vino a ellos enviado que no se burlaran de él.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdccxxxvi{¿No ven cuántas generaciones antes de ellos hemos hecho perecer, que ya no volverán a ellos...?\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdccxxxvii{¡Y a todos, sin falta, se les hará comparecer ante Nosotros!\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdccxxxviii{Tienen un signo en la tierra muerta, que hemos hecho revivir y de la que hemos sacado el grano que les alimenta.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdccxxxix{Hemos plantado en ella palmerales y viñedos, hemos hecho brotar de ella manantiales,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdccxl{para que coman de sus frutos. No son obra de sus manos. ¿No darán, pues, gracias?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdccxli{¡Gloria al Creador de todas las parejas: las que produce la tierra, las de los mismos hombres y otras que ellos no conocen!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdccxlii{Y tienen un signo en la noche, de la que quitamos el día, quedando los hombres a oscuras.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdccxliii{Y el sol. Corre a una parada suya por decreto del Poderoso, del Omnisciente.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdccxliv{Hemos determinado para la luna fases, hasta que se pone como la palma seca.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdccxlv{No le está bien al sol alcanzar a la luna, ni la noche adelanta al día. Cada uno navega en una órbita.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdccxlvi{Tienen un signo en el hecho de que hayamos llevado a sus descendientes en la nave abarrotada.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdccxlvii{Y creamos para ellos otras naves semejantes en las que se embarcan.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdccxlviii{Si quisiéramos, los anegaríamos. Nadie podría ayudarles y no se salvarían,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdccxlix{a menos que mediara una misericordia venida de Nosotros y para disfrute por algún tiempo.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdccl{Y cuando se les dice: «¡Temed el castigo en esta vida y en la otra! Quizás, así, se os tenga piedad»...\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdccli{No viene a ellos ninguno de los signos de su Señor que no se aparten de él.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcclii{Y cuando se les dice: «¡Dad limosna de lo que Alá os ha proveído!» dicen los infieles a los creyentes: «¿Vamos a dar de comer a quien Alá, si Él quisiera, podría dar de comer? Estáis evidentemente extraviados».\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdccliii{Dicen: «¿Cuándo se cumplirá esta amenaza, si es verdad lo que decís?»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdccliv{No esperarán más que un solo Grito, que les sorprenderá en plena disputa,\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdcclv{y no podrán hacer testamento, ni volver a los suyos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdcclvi{Se tocará la trompeta y se precipitarán de las sepulturas a su Señor.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdcclvii{Dirán: «¡Ay de nosotros! ¿Quién nos ; ha despertado de nuestro lecho? Esto es aquello con que el Compasivo nos había amenazado. Los enviados decían la verdad».\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdcclviii{No habrá más que un solo Grito y a todos se les hará comparecer ante Nosotros.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdcclix{Ese día, nadie será tratado injustamente en nada y no se os retribuirá sino conforme a vuestras obras.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdcclx{Ese día, los moradores del Jardín tendrán una ocupación feliz.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdcclxi{Ellos y sus esposas estarán a la sombra, reclinados en sofás.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdcclxii{Tendrán allí fruta y lo que deseen.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdcclxiii{Les dirán de parte de un Señor misericordioso: «¡Paz!»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdcclxiv{En cambio: «¡Pecadores! ¡Apartaos hoy!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdcclxv{¿No he concertado una alianza con vosotros, hijos de Adán: que no ibais a servir al Demonio, que es para vosotros un enemigo declarado,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdcclxvi{sino que ibais a servirme a Mí? Esto es una vía recta.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdcclxvii{Ha extraviado a muchísimos de vosotros. ¿Es que no comprendíais?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdcclxviii{ésta es la gehena con que se os había amenazado.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdcclxix{¡Arded hoy en ella por no haber creído!»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdcclxx{Ese día sellaremos sus bocas, pero sus manos Nos hablarán y sus pies atestiguarán lo que han cometido».\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdcclxxi{Si quisiéramos, les apagaríamos los ojos. Entonces se abalanzarían a la Vía, pero ¿cómo iban a ver?\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdcclxxii{Si quisiéramos, les clavaríamos en su sitio de modo que no pudieran avanzar ni retroceder.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdcclxxiii{A quien prolongamos la vida, le hacemos encorvarse. ¿Es que no comprenden?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdcclxxiv{No le hemos enseñado la poesía, que no le está bien. Esto no es más que una amonestación y un Corán claro,\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdcclxxv{para que advierta a todo vivo y se cumpla la sentencia contra los infieles.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdcclxxvi{¿Es que no ven que, entre las obras de Nuestras manos, hemos creado a su intención rebaños que les pertenecen?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdcclxxvii{Los hemos hecho dóciles a ellos: unos les sirven de montura, otros de alimento.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdcclxxviii{Obtienen provecho de ellos y bebidas. ¿No darán, pues, las gracias?\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdcclxxix{Pero han tomado dioses en lugar de tomar a Alá. Quizás, así, sean auxiliados...\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmdcclxxx{No podrán auxiliarles. Al contrario, formarán un ejército al que se hará comparecer contra ellos.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmdcclxxxi{¡Que no te entristezca lo que digan! Nosotros sabemos tanto lo que ocultan como lo que manifiestan.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmdcclxxxii{¿No ve el hombre que le hemos creado de una gota? Pues ¡ahí le tienes, porfiador declarado!\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmdcclxxxiii{Nos propone una parábola y se olvida de su propia creación. Dice: «¿Quién dará vida a los huesos, estando podridos?»\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmdcclxxxiv{Di: «Les dará vida Quien los creó una vez primera -Él conoce bien toda creación-,\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmdcclxxxv{Quien os ha hecho fuego de un árbol verde del que, así, encendéis».\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmdcclxxxvi{¿Es que Quien ha creado los cielos y la tierra no será capaz de crear semejantes a ellos? ¡Claro que sí! Él es el Creador de todo, el Omnisciente.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmdcclxxxvii{Su orden, cuando quiere algo, le dice tan sólo: «¡Se!» Y es.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmdcclxxxviii{¡Gloria a Quien posee la realeza de todo! Y a Él seréis devueltos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmdcclxxxix{\basmalahes ¡Por los puestos en fila.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmdccxc{que ahuyentan violentamente\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmdccxci{y recitan una amonestación!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmdccxcii{En verdad, vuestro Dios es Uno:\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmdccxciii{Señor de los cielos, de la tierra y de lo que entre ellos está, Señor de los Orientes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmdccxciv{Hemos engalanado el cielo más bajo con estrellas,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmdccxcv{como protección contra todo demonio rebelde.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmdccxcvi{Así, los demonios no pueden oír al Consejo Supremo, porque por todas partes se ven hostigados,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmdccxcvii{repelidos. Tendrán un castigo perpetuo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmdccxcviii{A menos que alguno se entere de algo por casualidad: a ese tal le perseguirá una llama de penetrante luz.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmdccxcix{Pregúntales si crearlos a ellos ha resultado más difícil para Nosotros que crear a los otros. Los hemos creado de arcilla pegajosa.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmdccc{Pero ¡no! Te asombras y ellos se mofan.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmdccci{Si se les recuerda algo, no se acuerdan.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmdcccii{Y, si ven un signo, lo ponen en ridículo,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmdccciii{y dicen: «¡Esto no es sino manifiesta magia!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmdccciv{Cuando muramos y seamos tierra y huesos, ¿se nos resucitará acaso?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmdcccv{¿Y también a nuestros antepasados?»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmdcccvi{Di: «¡Sí, y vosotros os humillaréis!»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmdcccvii{Un solo Grito, nada más, y verán...\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmdcccviii{Dirán: «¡Ay de nosotros! ¡Este es el día del Juicio!»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmdcccix{«Este es el día del Fallo, que vosotros desmentíais».\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmdcccx{«¡Congregad a los impíos, a sus consocios y lo que ellos servían,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmdcccxi{en lugar de servir a Alá, y conducidles a la vía del fuego de la gehena!\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmdcccxii{¡Detenedles, que se les va a pedir cuentas!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmdcccxiii{«¿Por qué no os auxiliáis ahora mutuamente?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmdcccxiv{Pero ¡no! Ese día querrán hacer acto de sumisión.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmdcccxv{Y se volverán unos a otros para preguntarse.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmdcccxvi{Dirán: «Venías a nosotros por la derecha».\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmdcccxvii{Dirán: «¡No, no erais creyentes!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmdcccxviii{Y no teníamos ningún poder sobre vosotros. ¡No! Erais un pueblo rebelde.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmdcccxix{La sentencia de nuestro Señor se ha cumplido contra nosotros. Vamos, sí, a gustar...\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmdcccxx{Os descarriamos. ¡Nosotros mismos estábamos descarriados!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmdcccxxi{Ese día compartirán el castigo.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmdcccxxii{Así haremos con los pecadores.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmdcccxxiii{Cuando se les decía: «¡No hay más dios que Alá!» se mostraban altivos,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmdcccxxiv{y decían: «¿Vamos a dejar a nuestros dioses por un poeta poseso?»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmdcccxxv{Pero ¡no! Él ha traído la Verdad y ha confirmado a los enviados.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmdcccxxvi{¡Vais, sí, a gustar el castigo doloroso!\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmdcccxxvii{No se os retribuirá, empero, sino por las obras que hicisteis.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmdcccxxviii{En cambio, los siervos escogidos de Alá\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmdcccxxix{tendrán un sustento conocido:\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmdcccxxx{fruta. Y serán honrados\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmdcccxxxi{en los Jardines de la Delicia,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmdcccxxxii{en lechos, unos enfrente de otros,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmdcccxxxiii{haciéndose circular entre ellos una copa de agua viva,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmdcccxxxiv{clara, delicia de los bebedores,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmdcccxxxv{que no aturdirá ni se agotará.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmdcccxxxvi{Tendrán a las de recatado mirar, de grandes ojos,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmdcccxxxvii{como huevos bien guardados.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmdcccxxxviii{Y se volverán unos a otros para preguntarse.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmdcccxxxix{Uno de ellos dirá: «Yo tenía un compañero\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmdcccxl{que decía: '¿Acaso eres de los que confirman?\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmdcccxli{Cuando muramos y seamos tierra y huesos, ¿se nos juzgará acaso?'»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmdcccxlii{Dirá: «¿Veis algo desde ahí arriba?»\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmdcccxliii{Mirará abajo y le verá en medio del fuego de la gehena.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmdcccxliv{Y dirá: «¡Por Alá, que casi me pierdes!\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmdcccxlv{Si no llega a ser por la gracia de mi Señor, habría figurado yo entre los réprobos.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmdcccxlvi{Pues ¡que! ¿No hemos muerto\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmdcccxlvii{sólo una vez primera sin haber sufrido castigo?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmdcccxlviii{¡Sí, éste es el éxito grandioso!»\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmdcccxlix{¡Vale la pena trabajar por conseguir algo semejante!\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmdcccl{¿Es esto mejor como alojamiento o el árbol de Zaqqum?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmdcccli{Hemos hecho de éste tentación para los impíos.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmdccclii{Es un árbol que crece en el fondo del fuego de la gehena,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmdcccliii{de frutos parecidos a cabezas de demonios.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmdcccliv{De él comerán y llenarán el vientre.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmdccclv{Luego, deberán, además, una mezcla de agua muy caliente\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmdccclvi{y volverán, luego, al fuego de la gehena.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmdccclvii{Encontraron a sus padres extraviados\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmdccclviii{y corrieron tras sus huellas.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmdccclix{Ya se extraviaron la mayoría de los antiguos,\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmdccclx{aunque les habíamos enviado quienes advirtieran.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmdccclxi{¡Y mira cómo terminaron aquéllos que habían sido advertidos!\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmdccclxii{No, en cambio, los siervos escogidos de Alá.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmdccclxiii{Noé Nos había invocado. ¡Qué buenos fuimos escuchándole!\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmdccclxiv{Les salvamos, a él y a su familia, del grave apuro.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmdccclxv{Hicimos que sus descendientes sobrevivieran\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmdccclxvi{y perpetuamos su recuerdo en la posteridad.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmdccclxvii{¡Paz sobre Noé, entre todas las criaturas!\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmdccclxviii{Así retribuimos a quienes hacen el bien.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmdccclxix{Es uno de Nuestros siervos creyentes.\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmdccclxx{Luego, anegamos a los otros.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmdccclxxi{Abraham era, sí, de los suyos.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmdccclxxii{Cuando vino a su Señor con corazón sano.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmdccclxxiii{Cuando dijo a su padre y a su pueblo: «¿Qué servís?\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmdccclxxiv{¿Queréis, mentirosamente, dioses en lugar de a Alá?\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmdccclxxv{¿Qué opináis, pues, del Señor del universo?»\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmdccclxxvi{Dirigió una mirada a los astros\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmdccclxxvii{y dijo: «Voy a encontrarme indispuesto».\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmdccclxxviii{y dieron media vuelta, apartándose de él.\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmdccclxxix{Entonces, se volvió hacia sus dioses y dijo: «¿No coméis?\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmdccclxxx{¿Por qué no habláis?»\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmdccclxxxi{Y se precipitó contra ellos golpeándolos con la diestra.\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmdccclxxxii{Corrieron hacia él.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmdccclxxxiii{Dijo: «¿Servís lo que vosotros mismos habéis esculpido,\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmdccclxxxiv{mientras que Alá os ha creado, a vosotros y lo que hacéis?»\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmdccclxxxv{Dijeron: «¡Hacedle un horno y arrojadle al fuego llameante!»\qt@no{97}}
\qt@newcmd\qurantrans@es@mmmdccclxxxvi{Quisieron emplear mañas contra él, pero hicimos que fueran ellos los humillados.\qt@no{98}}
\qt@newcmd\qurantrans@es@mmmdccclxxxvii{Dijo: «¡Voy a mi Señor! ¡Él me dirigirá!\qt@no{99}}
\qt@newcmd\qurantrans@es@mmmdccclxxxviii{¡Señor! ¡Regálame un hijo justo!»\qt@no{100}}
\qt@newcmd\qurantrans@es@mmmdccclxxxix{Entonces, le dimos la buena nueva de un muchacho benigno.\qt@no{101}}
\qt@newcmd\qurantrans@es@mmmdcccxc{Y, cuando tuvo bastante edad como para ir con su padre, dijo: «¡Hijito! He soñado que te inmolaba. ¡Mira, pues, qué te parece!» Dijo: «¡Padre! ¡Haz lo que se te ordena! Encontrarás, si Alá quiere, que soy de los pacientes».\qt@no{102}}
\qt@newcmd\qurantrans@es@mmmdcccxci{Cuando ya se habían sometido los dos y le había puesto contra el suelo...\qt@no{103}}
\qt@newcmd\qurantrans@es@mmmdcccxcii{Y le llamamos: «¡Abraham!\qt@no{104}}
\qt@newcmd\qurantrans@es@mmmdcccxciii{Has realizado el sueño. Así retribuimos a quienes hacen el bien».\qt@no{105}}
\qt@newcmd\qurantrans@es@mmmdcccxciv{Si, ésta era la prueba manifiesta.\qt@no{106}}
\qt@newcmd\qurantrans@es@mmmdcccxcv{Le rescatamos mediante un espléndido sacrificio\qt@no{107}}
\qt@newcmd\qurantrans@es@mmmdcccxcvi{y perpetuamos su recuerdo en la posteridad.\qt@no{108}}
\qt@newcmd\qurantrans@es@mmmdcccxcvii{¡Paz sobre Abraham!\qt@no{109}}
\qt@newcmd\qurantrans@es@mmmdcccxcviii{Así retribuimos a quienes hacen el bien.\qt@no{110}}
\qt@newcmd\qurantrans@es@mmmdcccxcix{Es uno de Nuestros siervos creyentes.\qt@no{111}}
\qt@newcmd\qurantrans@es@mmmcm{Y le anunciamos el nacimiento de Isaac, profeta, de los justos.\qt@no{112}}
\qt@newcmd\qurantrans@es@mmmcmi{Les bendijimos, a él y a Isaac. Y entre sus descendientes unos hicieron el bien, pero otros fueron claramente injustos consigo mismos.\qt@no{113}}
\qt@newcmd\qurantrans@es@mmmcmii{Ya agraciamos a Moisés y a Aarón.\qt@no{114}}
\qt@newcmd\qurantrans@es@mmmcmiii{Les salvamos, a ellos y a su pueblo, de un grave apuro.\qt@no{115}}
\qt@newcmd\qurantrans@es@mmmcmiv{Les auxiliamos y fueron ellos los que ganaron.\qt@no{116}}
\qt@newcmd\qurantrans@es@mmmcmv{Les dimos la Escritura clara.\qt@no{117}}
\qt@newcmd\qurantrans@es@mmmcmvi{Les dirigimos por la vía recta\qt@no{118}}
\qt@newcmd\qurantrans@es@mmmcmvii{y perpetuamos su recuerdo en la posteridad.\qt@no{119}}
\qt@newcmd\qurantrans@es@mmmcmviii{¡Paz sobre Moisés y Aarón!\qt@no{120}}
\qt@newcmd\qurantrans@es@mmmcmix{Así retribuimos a quienes hacen el bien.\qt@no{121}}
\qt@newcmd\qurantrans@es@mmmcmx{Fueron dos de Nuestros siervos creyentes.\qt@no{122}}
\qt@newcmd\qurantrans@es@mmmcmxi{Elías fue, ciertamente, uno de los enviados.\qt@no{123}}
\qt@newcmd\qurantrans@es@mmmcmxii{Cuando dijo a su pueblo: «¿Es que no vais a temer a Alá?\qt@no{124}}
\qt@newcmd\qurantrans@es@mmmcmxiii{¿Vais a invocar a Baal, dejando al Mejor de los creadores:\qt@no{125}}
\qt@newcmd\qurantrans@es@mmmcmxiv{a Alá, Señor vuestro y Señor de vuestros antepasados?»\qt@no{126}}
\qt@newcmd\qurantrans@es@mmmcmxv{Le desmintieron y se les hará, ciertamente, comparecer;\qt@no{127}}
\qt@newcmd\qurantrans@es@mmmcmxvi{no, en cambio, a los siervos escogidos de Alá.\qt@no{128}}
\qt@newcmd\qurantrans@es@mmmcmxvii{Y perpetuamos su recuerdo en la posteridad.\qt@no{129}}
\qt@newcmd\qurantrans@es@mmmcmxviii{¡Paz sobre Elías!\qt@no{130}}
\qt@newcmd\qurantrans@es@mmmcmxix{Así retribuimos a quienes hacen el bien.\qt@no{131}}
\qt@newcmd\qurantrans@es@mmmcmxx{Fue uno de Nuestros siervos creyentes.\qt@no{132}}
\qt@newcmd\qurantrans@es@mmmcmxxi{Lot fue, ciertamente, uno de los enviados.\qt@no{133}}
\qt@newcmd\qurantrans@es@mmmcmxxii{Cuando les salvamos, a él y a su familia, a todos,\qt@no{134}}
\qt@newcmd\qurantrans@es@mmmcmxxiii{salvo a una vieja entre los que se rezagaron.\qt@no{135}}
\qt@newcmd\qurantrans@es@mmmcmxxiv{Luego, aniquilamos a los demás.\qt@no{136}}
\qt@newcmd\qurantrans@es@mmmcmxxv{Pasáis, sí, sobre ellos, mañana\qt@no{137}}
\qt@newcmd\qurantrans@es@mmmcmxxvi{y tarde. ¿Es que no comprendéis?\qt@no{138}}
\qt@newcmd\qurantrans@es@mmmcmxxvii{Jonás fue, ciertamente, uno de los enviados.\qt@no{139}}
\qt@newcmd\qurantrans@es@mmmcmxxviii{Cuando se escapó a la nave abarrotada.\qt@no{140}}
\qt@newcmd\qurantrans@es@mmmcmxxix{Echó suertes y perdió.\qt@no{141}}
\qt@newcmd\qurantrans@es@mmmcmxxx{El pez se lo tragó, había incurrido en censura.\qt@no{142}}
\qt@newcmd\qurantrans@es@mmmcmxxxi{Si no hubiera sido de los que glorifican,\qt@no{143}}
\qt@newcmd\qurantrans@es@mmmcmxxxii{habría permanecido en su vientre hasta el día de la Resurrección.\qt@no{144}}
\qt@newcmd\qurantrans@es@mmmcmxxxiii{Le arrojamos, indispuesto, a una costa desnuda\qt@no{145}}
\qt@newcmd\qurantrans@es@mmmcmxxxiv{e hicimos crecer sobre él una calabacera.\qt@no{146}}
\qt@newcmd\qurantrans@es@mmmcmxxxv{Y le enviamos a cien mil o más.\qt@no{147}}
\qt@newcmd\qurantrans@es@mmmcmxxxvi{Creyeron y les permitimos gozar por algún tiempo.\qt@no{148}}
\qt@newcmd\qurantrans@es@mmmcmxxxvii{¡Pregúntales, pues, si tu Señor tiene hijas como ellos tienen hijos,\qt@no{149}}
\qt@newcmd\qurantrans@es@mmmcmxxxviii{si hemos creado a los ángeles de sexo femenino en su presencia!\qt@no{150}}
\qt@newcmd\qurantrans@es@mmmcmxxxix{Mienten tanto que llegan a decir:\qt@no{151}}
\qt@newcmd\qurantrans@es@mmmcmxl{«Alá ha engendrado». ¡Mienten, ciertamente!\qt@no{152}}
\qt@newcmd\qurantrans@es@mmmcmxli{¿Iba Él a preferir tener hijas a tener hijos?\qt@no{153}}
\qt@newcmd\qurantrans@es@mmmcmxlii{¿Qué os pasa? ¿Qué manera de juzgar es ésa?\qt@no{154}}
\qt@newcmd\qurantrans@es@mmmcmxliii{¿Es que no os dejaréis amonestar?\qt@no{155}}
\qt@newcmd\qurantrans@es@mmmcmxliv{O ¿es que tenéis una autoridad clara?\qt@no{156}}
\qt@newcmd\qurantrans@es@mmmcmxlv{¡Traed, pues, vuestra Escritura, si es verdad lo que decís!\qt@no{157}}
\qt@newcmd\qurantrans@es@mmmcmxlvi{Han establecido un parentesco entre Él y los genios. Pero saben los genios que se les hará comparecer\qt@no{158}}
\qt@newcmd\qurantrans@es@mmmcmxlvii{-¡gloria a Alá, que está por encima de lo que Le atribuyen!-;\qt@no{159}}
\qt@newcmd\qurantrans@es@mmmcmxlviii{no, en cambio, a los siervos escogidos de Alá.\qt@no{160}}
\qt@newcmd\qurantrans@es@mmmcmxlix{Vosotros y lo que servís,\qt@no{161}}
\qt@newcmd\qurantrans@es@mmmcml{no podréis seducir contra Él\qt@no{162}}
\qt@newcmd\qurantrans@es@mmmcmli{sino a quien vaya a arder en el fuego de la gehena.\qt@no{163}}
\qt@newcmd\qurantrans@es@mmmcmlii{«No hay nadie entre nosotros que no tenga un lugar señalado.\qt@no{164}}
\qt@newcmd\qurantrans@es@mmmcmliii{Sí, somos nosotros los que están formados.\qt@no{165}}
\qt@newcmd\qurantrans@es@mmmcmliv{Sí, somos nosotros los que glorifican».\qt@no{166}}
\qt@newcmd\qurantrans@es@mmmcmlv{Sí, solían decir:\qt@no{167}}
\qt@newcmd\qurantrans@es@mmmcmlvi{«Si tuviéramos una amonestación que viniera de los antiguos,\qt@no{168}}
\qt@newcmd\qurantrans@es@mmmcmlvii{seríamos siervos escogidos de Alá».\qt@no{169}}
\qt@newcmd\qurantrans@es@mmmcmlviii{Pero no creen en ella. ¡Van a ver...!\qt@no{170}}
\qt@newcmd\qurantrans@es@mmmcmlix{Ha precedido ya Nuestra palabra a Nuestros siervos, los enviados:\qt@no{171}}
\qt@newcmd\qurantrans@es@mmmcmlx{son ellos los que serán, ciertamente, auxiliados,\qt@no{172}}
\qt@newcmd\qurantrans@es@mmmcmlxi{y es Nuestro ejército el que, ciertamente, vencerá.\qt@no{173}}
\qt@newcmd\qurantrans@es@mmmcmlxii{¡Apártate, pues, de ellos, por algún tiempo,\qt@no{174}}
\qt@newcmd\qurantrans@es@mmmcmlxiii{y obsérvales! ¡Van a ver...!\qt@no{175}}
\qt@newcmd\qurantrans@es@mmmcmlxiv{¿Quieren, entonces, adelantar Nuestro castigo?\qt@no{176}}
\qt@newcmd\qurantrans@es@mmmcmlxv{Cuando descargue sobre ellos, mal despertar tendrán los que ya habían sido advertidos.\qt@no{177}}
\qt@newcmd\qurantrans@es@mmmcmlxvi{¡Apártate, pues, de ellos, por algún tiempo,\qt@no{178}}
\qt@newcmd\qurantrans@es@mmmcmlxvii{y observa! ¡Van a ver...!\qt@no{179}}
\qt@newcmd\qurantrans@es@mmmcmlxviii{¡Gloria a tu Señor, Señor del Poder, que está por encima de lo que Le atribuyen!\qt@no{180}}
\qt@newcmd\qurantrans@es@mmmcmlxix{Y ¡paz sobre los enviados!\qt@no{181}}
\qt@newcmd\qurantrans@es@mmmcmlxx{Y ¡alabado sea Alá, Señor del universo!\qt@no{182}}
\qt@newcmd\qurantrans@es@mmmcmlxxi{\basmalahes s. ¡Por el Corán, que contiene la Amonestación...!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmcmlxxii{Por los infieles están llenos de orgullo y en oposición.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmcmlxxiii{¡A cuántas generaciones, antes de ellos, hemos hecho perecer! Invocaron cuando ya no había tiempo para salvarse.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmcmlxxiv{Se asombran de que uno salido de ellos haya venido a advertirles. Y dicen los infieles: «¡Éste es un mago mentiroso!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmcmlxxv{¡Quiere reducir los dioses a un Dios Uno? ¡Es algo, ciertamente, asombroso!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmcmlxxvi{Sus dignatarios se fueron: «¡Id y manteneos fieles a vuestros dioses! ¡Esto es algo deseable!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmcmlxxvii{No oímos que ocurriera tal cosa en la última religión. Esto no es más que una superchería.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmcmlxxviii{¿Se le ha revelado la Amonestación a él, de entre nosotros?» ¡Sí! ¡Dudan de Mi Amonestación! ¡No, aún no han gustado Mi castigo!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmcmlxxix{¿O tienen los tesoros de misericordia de tu Señor, el Poderoso, el Munífico?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmcmlxxx{¿O poseen el dominio de los cielos; de la tierra y de lo que entre ellos hay? Pues que suban por las cuerdas.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmcmlxxxi{Todo un ejército de coalicionistas será aquí mismo derrotado.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmcmlxxxii{Antes de ellos, otros desmintieron: el pueblo de Noé, los aditas y Faraón, el de las estacas,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmcmlxxxiii{los tamudeos, el pueblo de Lot, los habitantes de la Espesura. Ésos eran los coalicionistas.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmcmlxxxiv{No hicieron todos sino desmentir a los enviados y se cumplió Mi castigo.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmcmlxxxv{No esperarán éstos más que un solo Grito, que no se repetirá.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmcmlxxxvi{Dicen: «¡Señor! ¡Anticípanos nuestra parte antes del día de la Cuenta!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmcmlxxxvii{Ten paciencia con lo que dicen y recuerda a Nuestro siervo David, el fuerte. Su arrepentimiento era sincero.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmcmlxxxviii{Sujetamos, junto con él, las montañas para que glorificaran por la tarde y por la mañana.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmcmlxxxix{Y los pájaros, en bandadas. Todo vuelve a Él.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmcmxc{Consolidamos su dominio y le dimos la sabiduría y la facultad de arbitrar.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmcmxci{¿Te has enterado de la historia de los litigantes? Cuando subieron a palacio.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmcmxcii{Cuando entraron adonde estaba David y éste se asustó al verles. Dijeron: «¡No tengas miedo! Somos dos partes litigantes, una de las cuales ha ofendido a la otra. Decide, pues, entre nosostros según justicia, imparcialmente, y dirígenos a la vía recta.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmcmxciii{éste es mi hermano. Tiene noventa y nueve ovejas y yo una oveja. Dijo: '¡Confíamela!' Y me gana a discutir».\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmcmxciv{Dijo: «Sí, ha sido injusto contigo pidiéndote que agregaras tu oveja a las suyas». En verdad, muchos consocios se causan daño unos a otros; no los que creen y obran bien, pero ¡que pocos son éstos! David comprendió que sólo habíamos querido probarle y pidió perdón a su Señor. Cayó de rodillas y se arrepintió.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmcmxcv{Se lo perdonamos y tiene un sitio junto a Nosotros y un bello lugar de retorno.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmcmxcvi{¡David! Te hemos hecho sucesor en la tierra. ¡Decide, pues, entre los hombres según justicia! ¡No sigas la pasión! Si no, te extraviará del camino de Alá. Quienes se extravíen del camino de Alá tendrán un severo castigo. Por haber olvidado el día de la Cuenta.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmcmxcvii{No hemos creado en vano el cielo, la tierra y lo que entre ellos está. Así piensan los infieles. Y ¡ay de los infieles, por el Fuego...!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmcmxcviii{¿Trataremos a quienes creen y obran bien igual que a quienes corrompen en la tierra, a los temerosos de Alá igual que a los pecadores?\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmcmxcix{Una Escritura que te hemos revelado, bendita, para que mediten en sus aleyas y para que los dotados de intelecto se dejen amonestar.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmm{A David le regalamos Salomón. ¡Qué siervo tan agradable! Su arrepentimiento era sincero.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmi{Cuando un anochecer le presentaron unos corceles de raza.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmii{Y dijo: «Por amor a los bienes he descuidado el recuerdo de mi Señor hasta que se ha escondido tras el velo.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmiii{¡Traédmelos!» Y se puso a desjarretarlos y degollarlos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmiv{Aún probamos a Salomón cuando asentamos en su trono a su sosia. Luego, se arrepintió.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmv{«¡Señor!» dijo. «¡Perdóname y regálame un dominio tal que a nadie después de mí le esté bien. Tú eres el Munífico».\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmvi{Sujetamos a su servicio el viento, que soplaba suavemente allí donde él quería, a una orden suya.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmvii{Y los demonios, constructores y buzos de toda clase,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmviii{y otros, encadenados juntos.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmix{«¡Esto es don Nuestro! ¡Agracia, pues, o retén, sin limitación!»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmx{Tiene un sitio junto a Nosotros y un bello lugar de retorno.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmxi{¡Y recuerda a nuestro siervo Job! Cuando invocó a su Señor. «El Demonio me ha infligido una pena y un castigo».\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmxii{«¡Golpea con el pie! Ahí tienes agua fresca para lavarte y para beber».\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmxiii{Le regalamos su familia y otro tanto, como misericordia venida de Nosotros y como amonestación para los dotados de intelecto.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmxiv{Y: «¡Toma en tu mano un puñado de hierba, golpea con él y no cometas perjurio!» Le encontramos paciente. ¡Qué siervo tan agradable! Su arrepentimiento era sincero.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmxv{Y recuerda a Nuestros siervos Abraham, Isaac y Jacob, fuertes y clarividentes.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmxvi{Les hicimos objeto de distinción al recordarles la Morada.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmxvii{Están junto a Nosotros, de los elegidos mejores.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmxviii{Y recuerda a Ismael, Eliseo y Dulkifl, todos ellos de los mejores.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmxix{Esto es una amonestación. Los que teman a Alá tendrán, ciertamente, un bello lugar de retorno:\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmxx{los jardines del edén, cuyas puertas estarán abiertas para ellos,\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmxxi{y en los que, reclinados, pedirán fruta abundante y bebida.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmxxii{Junto a ellos estarán las de recatado mirar, de una misma edad.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmxxiii{Esto es lo que se os promete para el día de la Cuenta.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmxxiv{En verdad, éste será Nuestro sustento, sin fin.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmxxv{Así será. Los rebeldes, en cambio, tendrán un mal lugar de retorno:\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmxxvi{la gehena, en la que arderán. ¡Qué mal lecho...!\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmxxvii{Esto ¡que lo gusten!: agua muy caliente, hediondo líquido\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmxxviii{y otras muchas cosas por el estilo.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmxxix{«He ahí a otra muchedumbre que se precipita con vosotros. No hay bienvenida para ellos. Arderán en el Fuego».\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmxxx{Dirán: «¡No! ¡No hay bienvenida para vosotros! ¡Sois vosotros los que nos habéis preparado esto! ¡Qué mala morada...!»\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmxxxi{«¡Señor!» dirán, «a los que nos han preparado esto ¡dóblales el castigo en el Fuego!»\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmxxxii{Dirán: «¿Cómo es que no vemos aquí a hombres que teníamos por malvados,\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmxxxiii{de los que nos burlábamos? ¿O es que se desvían de ellos las miradas?»\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmxxxiv{Sí, esto es verdad: la discusión entre los moradores del Fuego.\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmxxxv{Di: «Yo no soy más que uno que advierte. No hay ningún otro dios que Alá, el Uno, el Invicto,\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmxxxvi{el Señor de los cielos, de la tierra y de lo que entre ellos está, el Poderoso, el Indulgente».\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmxxxvii{Di: «es una noticia enorme,\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmxxxviii{de la cual os apartáis.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmxxxix{Yo no tenía conocimiento del Consejo Supremo, cuando discutían unos con otros.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmxl{Lo único que se me ha revelado es que soy un monitor que habla claro».\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmxli{Cuando tu Señor dijo a los ángeles: «Voy a crear a un mortal de arcilla\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmxlii{y, cuando lo haya formado armoniosamente e infundido en él de Mi Espíritu, ¡caed prosternados ante él!»\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmxliii{Los ángeles se prosternaron, todos juntos,\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmxliv{salvo Iblis, que se mostró altivo y fue de los infieles.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmxlv{Dijo: «¡Iblis! ¿Qué es lo que te ha impedido prosternarte ante lo que con Mis manos he creado? ¿Ha sido la altivez, la arrogancia?»\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmxlvi{Dijo: «Yo soy mejor que él. A mí me creaste de fuego, mientras que a él le creaste de arcilla».\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmxlvii{Dijo: «¡Sal de aquí! ¡Eres un maldito!\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmxlviii{¡Mi maldición te perseguirá hasta el día del Juicio!»\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmxlix{Dijo: «¡Señor, déjame esperar hasta el día de la Resurrección!»\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmml{Dijo: «Entonces, serás de aquéllos a quienes se ha concedido una prórroga\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmli{hasta el día del tiempo señalado».\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmlii{Dijo: «¡Por Tu poder, que he de descarriarles a todos,\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmliii{salvo a aquéllos que sean siervos Tuyos escogidos!»\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmliv{Dijo: «La verdad es -y digo verdad-\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmlv{que he de llenar la gehena contigo y con todos aquéllos que te hayan seguido».\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmlvi{Di: «Yo no os pido, a cambio, ningún salario ni me arrogo nada.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmlvii{Ello no es más que una amonestación dirigida a todo el mundo.\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmlviii{Y os enteraréis, ciertamente, de lo que anuncia dentro de algún tiempo».\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmlix{\basmalahes La revelación de la Escritura procede de Alá, el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmlx{Te hemos revelado la Escritura con la verdad. ¡Sirve, pues, a Alá, rindiéndole culto sincero!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmlxi{El culto puro ¿no se debe a Alá? Los que han tomado amigos en lugar de tomarle a Él -«Sólo les servimos para que nos acerquen bien a Alá»-... Alá decidirá entre ellos sobre aquello en que discrepaban. Alá no guía al que miente, al infiel pertinaz.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmlxii{Si Alá hubiera deseado adoptar un hijo, habría elegido entre lo que ha creado lo que hubiera querido. ¡Gloria a Él! Es Alá, el Uno, el Invicto.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmlxiii{Ha creado con un fin los cielos y la tierra. Hace que la noche suceda al día y el día a la noche. Ha sujetado el sol y la luna, prosiguiendo cada uno su curso hacia un término fijo. ¿No es Él el Poderoso, el Indulgente?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmlxiv{Os ha creado de una sola persona, de la que ha sacado a su cónyuge. Os ha dado, de los rebaños, cuatro parejas. Os ha creado en el seno de vuestras madres, creación tras creación, en triple oscuridad. Tal es Alá, vuestro Señor. Suyo es el domino. No hay más dios que Él. ¡Cómo, podéis pues, ser tan desviados!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmlxv{Si sois ingratos,... Alá puede prescindir de vosotros. No acepta la ingratitud de Sus siervos. En cambio, si sois agradecidos, os lo aceptará complacido. Nadie cargará con la carga ajena. Al final, volveréis a vuestro Señor y ya os informará Él de lo que hacíais. Él sabe bien lo que los pechos encierran.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmlxvi{Cuando sufre el hombre una desgracia, invoca a su Señor, volviéndose a Él arrepentido. Luego, cuando Él le ha dispensado una gracia Suya, se olvida del objeto de su invocación anterior y atribuye iguales a Alá para extraviar a otros de Su camino. Di: «¡Goza un poco de tu incredulidad! Serás de los moradores del Fuego».\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmlxvii{¿Es el devoto, que vela por la noche, postrado o de pie, que teme la otra vida y espera en la misericordia de su Señor...? Di: «¿Son iguales los que saben y los que no saben?» Sólo se dejan amonestar los dotados de intelecto.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmlxviii{Di: «¡Siervos Míos que creéis! ¡Temed a vuestro Señor! Quienes obren bien tendrán en la vida de acá una bella recompensa. La tierra de Alá es vasta. Los pacientes recibierán una recompensa ilimitada».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmlxix{Di: «He recibido la orden de servir a Alá, rindiéndole culto sincero.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmlxx{He recibido la orden de ser el primero en someterse a Él».\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmlxxi{Di: «Temo, si desobedezco a mi Señor, el castigo de un día terrible».\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmlxxii{Di: «A Alá sirvo, rindiéndole culto sincero.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmlxxiii{¡Servid, pues, en lugar de servirle a Él, lo que queráis!» Di: «Perderán quienes se pierdan a sí mismos y pierdan a sus familias el día de la Resurrección. ¿No es ésa una pérdida manifiesta?»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmlxxiv{Por encima y por debajo, tendrán pabellones de fuego. Así atemoriza Alá Sus siervos. «¡Temedme, pues, siervos!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmlxxv{¡Buena nueva para quienes hayan evitado a los taguts, rehusando sevirles, y se hayan vuelto arrepentidos a Alá! ¡Y anuncia la buena nueva a Mis siervos,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmlxxvi{que escuchan la Palabra y siguen lo mejor de ella! ¡ésos son los que Alá ha dirigido! ¡ésos son los dotados de intelecto!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmlxxvii{Aquél contra quien se cumpla la sentencia del castigo... ¿Podrás salvar tú a quien está en el Fuego?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmlxxviii{Pero los que temieron a su Señor estarán en cámaras altas sobre las que hay construidas otras cámaras altas, a cuyos pies fluyen arroyos. ¡Promesa de Alá! Alá no falta a Su promesa.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmlxxix{¿No ves cómo hace Alá bajar agua del cielo y Él la conduce a manantiales en la tierra? Mediante ella saca cereales de clases diversas, que, más tarde, se marchitan y ves que amarillean. Luego, hace de ellos paja seca. Hay en ello, sí, una amonestación para los dotados de intelecto.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmlxxx{¿Es que aquél cuyo pecho Alá ha abierto al islam y camina así a la luz de su Señor...? ¡Ay de los que tienen un corazón insensible a la amonestación de Alá! Están evidentemente extraviados.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmlxxxi{Alá ha revelado el más bello relato, una Escritura cuyas aleyas armonizan y se reiteran. Al oírla, se estremecen quienes tienen miedo de su Señor; luego, se calman en cuerpo y en espíritu al recuerdo de Alá. Ésa es la dirección de Alá, por la que dirige a quien Él quiere. En cambio, aquél a quien Alá extravía no podrá encontrar quien le dirija.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmlxxxii{¿Es que quien trata de protegerse con su propia persona contra el mal castigo del día de la Resurrección...? Se dirá a los impíos: «¡Gustad lo que habéis merecido!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmlxxxiii{Sus predecesores desmintieron y el castigo les vino de donde no lo presentían.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmlxxxiv{Alá les hizo gustar la ignominia en la vida de acá, pero, ciertamente, el castigo de la otra vida es mayor. Si supieran...\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmlxxxv{En este Corán hemos dado a los hombres toda clase de ejemplos. Quizás, así, se dejen amonestar.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmlxxxvi{Es un Corán árabe, exento de recovecos. Quizás, así, teman a Alá.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmlxxxvii{Alá propone el símil de un hombre que pertenece a socios que no están de acuerdo y el hombre que pertenece exclusivamente a uno. ¿Son ambos similares? ¡Alabado sea Alá! Pero la mayoría no saben.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmlxxxviii{Tú tienes que morir y ellos tienen que morir.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmlxxxix{Luego, el día de la Resurrección, disputaréis junto a vuestro Señor.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmxc{¿Hay alguien que sea más impío que , quien miente contra Alá y que, cuando viene a él la Verdad, la desmiente? ¿No hay en la gehena una morada para los infieles?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmxci{Quienes traen la Verdad y la confirman, ésos son los temerosos de Alá.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmxcii{Tendrán junto a su Señor lo que deseen -ésa será la retribución de quienes hacen el bien-:\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmxciii{que Alá borre sus peores obras y les retribuya con arreglo a sus mejores obras.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmxciv{¿No basta Alá a Su siervo? Quieren intimidarte con otros fuera de Él. Pero aquél a quien Alá extravía no podrá encontrar quien le dirija.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmxcv{Y a aquél a quien Alá dirija nadie podrá extraviar. ¿Acaso no es Alá poderoso, vengador?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmxcvi{Si les preguntas: «¿Quién ha creado los cielos y la tierra?», seguro que dicen: «¡Alá!» Di: «Y ¿qué os parece? Si Alá me deseara una desgracia, las que invocáis en lugar de invocarle a Él ¿podrían impedirlo? Y, si Él quisiera hacerme objeto de una misericordia, podrían ellas evitarlo?» Di: «¡Alá me basta! Quienes confían, confían en É».\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmxcvii{Di: «¡Pueblo! ¡Obrad según vuestra situación! Yo también obraré... Y pronto veréis\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmxcviii{quién recibirá un castigo humillante y sobre quién recaerá un castigo permanente».\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmxcix{Te hemos revelado la Escritura destinada a los hombres con la Verdad. Quien sigue la vía recta, la sigue en provecho propio y quien se extravía se extravía, en realidad, en detrimento propio. Tú no eres su protector.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmc{Alá llama a las almas cuando mueren y cuando, sin haber muerto, duermen. Retiene aquéllas cuya muerte ha decretado y remite las otras a un plazo fijo. Ciertamente, hay en ello signos para gente que reflexiona.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmci{¿Tomarán los infieles a otros intercesores en lugar de tomar a Alá? Di: «¿Y si no pudieran nada ni razonaran?»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcii{Di: «Toda intercesión proviene de Alá. Suyo es el dominio de los cielos y de la tierra. Al fin, a Él seréis devueltos».\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmciii{Cuando Alá Solo es mencionado, se oprime el corazón de quienes no creen en la otra vida, pero cuando se mencionan otros fuera de Él, he aquí que se regocijan.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmciv{Di: «¡Alá, creador de los cielos y de la tierra! ¡El Conocedor de lo oculto y de lo patente! Tú decidirás entre Tus siervos sobre aquello en que discrepaban».\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcv{Si los impíos poseyeran todo cuanto hay en la tierra y aun otro tanto, lo ofrecerían como rescate el día de la Resurrección para librarse del mal castigo. Alá les manifestará aquello con que no contaban.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcvi{Se les mostrará el mal que cometieron y se verán cercados por aquello de que se burlaban.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcvii{Cuando el hombre sufre una desgracia, Nos invoca. Luego, cuando le dispensamos una gracia Nuestra, dice: «¡Lo que se me ha dado lo debo sólo a ciencia!» ¡No! Es una prueba, pero la mayoría no saben.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcviii{Lo mismo decían los que fueron antes de ellos y sus posesiones no les sirvieron de nada.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcix{Les alcanzó el mal resultante de sus acciones y los que de éstos hayan sido impíos serán alcanzados por el mal resultante de sus acciones y no podrán escapar.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcx{¿No saben que Alá dispensa el sustento a quien Él quiere: a unos con largueza, a otros con mesura? Ciertamente, hay en ello signos para gente que cree.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcxi{Di: «¡Siervos que habéis prevaricado en detrimento propio! ¡No desesperéis de la misericordia de Alá! Alá perdona todos los pecados. Él es el Indulgente, el Misericordioso».\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcxii{¡Volveos a vuestro Señor arrepentidos! ¡Someteos a Él antes de que os alcance el castigo, porque luego no seréis auxiliados!\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcxiii{¡Seguid lo mejor que vuestro Señor os ha revelado, antes de que os venga el castigo de repente, sin presentirlo!\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcxiv{No sea que alguien diga; «¡Ay de mí que fui tan remiso para con Alá! ¡Yo era de los que se burlaban!»,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcxv{o diga: «¡Si Alá me hubiera dirigido, habría sido de los que Le temen!»,\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcxvi{o diga, al ver el castigo: «¡Si pudiera regresar, sería de quienes hacen el bien!»\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcxvii{«Pero, si ya te vinieron Mis signos y los desmentiste, mostrándote altivo y siendo de los infieles...»\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcxviii{El día de la Resurrección verás a quienes mintieron contra Alá, hosco el rostro. ¿No hay en la gehena una morada para los soberbios?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcxix{Alá salvará a quienes Le hayan temido, librándoles del castigo: no sufrirán mal ni estarán tristes.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcxx{Alá es creador de todo y vela por todo.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcxxi{Suyas son las llaves de los cielos y de la tierra. Los que no crean en los signos de Alá, ésos serán los que pierdan.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcxxii{Di: «¿Es que me ordenáis que sirva a otro diferente de Alá, ¡ignorantes!?»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcxxiii{A ti y a los que te precedieron se os ha revelado: «Si asocias a Alá otros dioses, tus obras serán vanas y serás, sí, de los que pierdan.\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcxxiv{Antes bien, ¡a Alá sirve y sé de los agradecidos!»\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcxxv{No han valorado a Alá debidamente. El día de la Resurrección, contendrá toda la tierra en Su puño, los cielos estarán plegados en Su diestra. ¡Gloria a É! ¡Está por encima de lo que Le asocian!\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcxxvi{Se tocará la trompeta y los que estén en los cielos y en la tierra caerán fulminados, excepto los que Alá quiera. Se tocará la trompeta otra vez y he aquí que se pondrán en pie, mirando.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcxxvii{La tierra brillará con la luz de su Señor. Se sacará la Escritura. Se hará venir a los profetas y a los testigos. Se decidirá entre ellos según justicia y no serán tratados injustamente.\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcxxviii{Cada uno recibirá conforme a sus obras. Él sabe bien lo que hacen.\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcxxix{Los infieles serán conducidos en grupos a la gehena. Hasta que, llegados a ella, se abrirán las puertas y sus guardianes les dirán: «¿No vinieron a vosotros enviados, salidos de vosotros, para recitaros las aleyas de vuestro Señor y preveniros contra el encuentro de éste vuestro día?» Dirán: «¡Claro que sí!» Pero se cumplirá la sentencia del castigo contra los infieles.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcxxx{Se dirá: «¡Entrad por las puertas de la gehena, para estar en ella eternamente!» ¡Qué mala es la morada de los soberbios!\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcxxxi{Pero los que hayan temido a su Señor, serán conducidos en grupos al Jardín. Hasta que, llegados a él, se abrirán sus puertas y sus guardianes les dirán: «¡Paz sobre vosotros! Fuisteis buenos. ¡Entrad, pues, en él, por toda la eternidad!»\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcxxxii{Y dirán: «¡Alabado sea Alá, Que nos ha cumplido Su promesa y nos ha dado la tierra en herencia. Podemos establecernos en el Jardín donde queramos». ¡Qué grata es la recompensa de los que obran bien!\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcxxxiii{Verás a los ángeles, yendo alrededor del Trono, celebrando las alabanzas de su Señor. Se decidirá entre ellos según justicia y se dirá: «¡Alabado sea Alá, Señor del universo!»\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcxxxiv{\basmalahes hm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcxxxv{La revelación de la Escritura procede de Alá, el Poderoso, el Omnisciente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcxxxvi{Que perdona el pecado, acepta el arrepentimiento, es severo en castigar y lleno de poder. No hay más dios que Él. ¡Él es el fin de todo!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcxxxvii{No discuten sobre los signos de Alá sino los infieles. ¡Que sus idas y venidas por el país no te turben!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcxxxviii{Antes de ellos, ya el pueblo de Noé había desmentido. Luego, también los coalicionistas. Los miembros de cada comunidad habían planeado apoderarse del enviado que se les había mandado. Y discutieron con argucias para, así, derribar la Verdad. Entonces, Yo me los llevé y ;¡cuál no fue Mi castigo!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcxxxix{Así se cumplió la sentencia de tu Señor contra los infieles: que serían los moradores del Fuego.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcxl{Los que llevan el Trono y los que están a su alrededor celebran las alabanzas de su Señor, creen en Él y Le piden que perdone a los creyentes: «¡Señor! Tú lo abarcas todo en Tu misericordia y en Tu ciencia. ¡Perdona, pues, a los que se arrepienten y siguen Tu camino! ¡Líbrales del castigo del fuego de la gehena!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcxli{¡Señor! ¡Introdúceles en los jardines del edén que les prometiste, junto con aquéllos de sus padres, esposas y descendientes que fueron buenos! Tú eres el Poderoso, el Sabio.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcxlii{¡Líbrales de mal! Ese día, aquél a quien hayas librado de mal será objeto de Tu misericordia. ¡Ése es el éxito grandioso!»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcxliii{A los que no hayan creído se les gritará: «El aborrecimiento que Alá os tiene es mayor que el aborrecimiento que os tenéis a vosotros mismos, por cuanto, invitados a creer, no creísteis».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcxliv{Dirán: «¡Señor! Nos has hecho morir dos veces y vivir otras dos. Confesamos, pues, nuestros pecados. ¿Hay modo de salir?»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcxlv{Esto os pasa porque, cuando se invocaba a Alá Solo, no creíais, mientras que, si se Le asociaban otros dioses, creíais. La decisión, pues, pertenece a Alá, el Altísimo, el Grande.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcxlvi{Él es Quien os muestra Sus signos, Quien os hace bajar del cielo sustento. Pero no se deja amonestar sino quien vuelve a Él arrepentido.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcxlvii{Invocad, pues, a Alá, rindiéndole culto sincero, a despecho de los infieles.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcxlviii{De elevada dignidad y Señor del Trono, echa el Espíritu que procede de Su orden sobre quien Él quiere de Sus siervos, para que prevenga contra el día del Encuentro.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcxlix{Ese día surgirán, sin que nada de ellos pueda ocultarse a Alá. Ese día, ¿de quién será el dominio? ¡De Alá, el Uno, el Invicto!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcl{Ese día cada uno será retribuido según sus méritos. ¡Nada de injusticias ese día! Alá es rápido en ajustar cuentas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcli{Prevénles contra el día de la Inminente, cuando, angustiados, se les haga un nudo en la garganta. No tendrán los impíos ningún amigo ferviente ni intercesor que sea escuchado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmclii{Conoce la perfidia de los ojos y lo que ocultan los pechos.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcliii{Alá decide según justicia. En cambio, los otros que ellos invocan en lugar de invocarle a Él no pueden decidir nada. Alá es Quien todo lo oye, Quien todo lo ve.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcliv{Pues, ¡qué! ¿No han ido por la tierra y mirado cómo terminaron sus antecesores? Eran más poderosos y dejaron más huellas en la tierra. Entonces, Alá les sorprendió por sus pecados y no hubo quien pudiera protegerles contra Alá.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmclv{Es que cuando los enviados vinieron a ellos con las pruebas claras, no creyeron y Alá les sorprendió. Es fuerte y castiga severamente.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmclvi{Enviamos Moisés con Nuestros signos y con una autoridad manifiesta\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmclvii{a Faraón, a Hamán y a Coré. Ellos dijeron: «Un mago mentiroso».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmclviii{Cuando les trajo la verdad de Nosotros, dijeron: «¡Matad a los hijos varones de los que creen como él y dejad con vida a sus mujeres!» Pero la artimaña de los infieles fue inútil.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmclix{Faraón dijo: «¡Dejadme que mate a Moisés, y que invoque él a su Señor! Temo que cambie vuestra religión, o que haga aparecer la corrupción en el país».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmclx{Moisés dijo: «Me refugio en mi Señor y Señor vuestro contra todo soberbio que no cree en el día de la Cuenta».\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmclxi{Un hombre creyente de la familia de Faraón, que ocultaba su fe, dijo: «¿Vais a matar a un hombre por el mero hecho de decir 'Mi Señor es Alá' siendo así que os ha traído las pruebas claras de vuestro Señor? Si miente, su mentira recaerá sobre él. Pero, si dice verdad, os alcanzará algo de aquello con que os amenaza. Alá no dirige al inmoderado, al mentiroso.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmclxii{¡Pueblo! Habiendo vencido en la tierra, vuestro es el dominio hoy. Pero, cuando nos alcance el rigor de Alá, ¿quién nos librará de él?» Faraón dijo: «Yo no os hago ver sino lo que yo veo y no os dirijo sino por el camino recto».\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmclxiii{El que creía dijo: «¡Pueblo! Temo por vosotros un día como el de los coalicionistas,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmclxiv{como ocurrió al pueblo de Noé, a los aditas, a los tamudeos y a los que vinieron después de ellos. Alá no quiere la injusticia para Sus siervos.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmclxv{¡Pueblo! Temo que viváis el día de la Llamada Mutua,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmclxvi{día en que volveréis la espalda y no tendréis a nadie que os proteja de Alá. Aquél a quien Alá extravía no tendrá quien le dirija.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmclxvii{Ya antes había venido José a vosotros con las pruebas claras y siempre dudasteis de lo que os trajo. Hasta que, cuando pereció dijisteis: 'Alá no mandará a ningún enviado después de él'. Así extravía Alá al inmoderados al escéptico».\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmclxviii{Quienes discuten sobre los signos de Alá sin haber recibido autoridad... Es muy aborrecible para Alá y para los creyentes. Así sella Alá el corazón de todo soberbio, de todo tirano.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmclxix{Faraón dijo: «¡Hamán! ¡Constrúyeme una torre! Quizás, así, alcance las vías,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmclxx{Las vías que conducen al cielo, y suba al Dios de Moisés. Sí, creo que éste miente». Así se engalanó a Faraón la maldad de su acto y fue apartado del Camino. Pero se malograron sus artimañas.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmclxxi{El que creía dijo: «¡Pueblo! ¡Seguidme! Os dirigiré por el camino recto.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmclxxii{¡Pueblo! Esta vida de acá no es sino breve disfrute, mientras que la otra vida es la Morada de la Estabilidad.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmclxxiii{Quien obre mal no será retribuido sino con una pena similar. En cambio, los creyentes, varones o hembras, que obren bien entrarán en el Jardín y serán proveídos en él sin medida.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmclxxiv{¡Pueblo! ¿Como es que yo os llamo a la salvación, mientras que vosotros me llamáis al Fuego?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmclxxv{Me llamáis a que sea infiel a Alá y a que Le asocie algo de lo que no tengo conocimiento, mientras que yo os llamo al Poderoso, al Indulgente.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmclxxvi{¡En verdad, aquello a lo que me llamáis no merece ser invocado, ni en la vida de acá ni en la otra! Sí, volveremos a Alá y los inmoderados serán los moradores del Fuego.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmclxxvii{Entonces, os acordaréis de lo que os digo. En cuanto a mí, me pongo en manos de Alá. Alá ve bien a Sus siervos».\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmclxxviii{Alá le preservó de los males que habían tramado y sobre la gente de Faraón se abatió el mal castigo:\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmclxxix{el Fuego, al que se verán expuestos mañana y tarde. El día que llegue la Hora: «¡Haced que la gente de Faraón reciba el castigo más severo!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmclxxx{Cuando discutan, ya en el Fuego, los que fueron débiles dirán a los que fueron altivos: «Os hemos seguido. ¿Vais a librarnos de parte del Fuego?»\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmclxxxi{Los altivos dirán: «Estamos todos en él. Alá ha decidido entre Sus siervos».\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmclxxxii{Los que estén en el Fuego dirán a los guardianes de la gehena: «¡Rogad a vuestro Señor que nos abrevie un día del castigo!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmclxxxiii{Dirán: «¡Cómo! ¿No vinieron a vosotros vuestros enviados con las pruebas claras?» Dirán: «¡Claro que sí!» Dirán: «Entonces, ¡invocad vosotros!» Pero la invocación de los infieles será inútil.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmclxxxiv{Sí, a Nuestros enviados y a los que crean les auxiliaremos en la vida de acá y el día que depongan los testigos,\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmclxxxv{el día que ya no sirvan de nada a los impíos sus excusas, sino que sean malditos y tengan la Morada Mala.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmclxxxvi{Dimos la Dirección a Moisés y dimos en herencia la Escritura a los Hijos de Israel,\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmclxxxvii{como dirección y amonestación para los dotados de intelecto.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmclxxxviii{¡Ten paciencia! ¡Lo que Alá promete es verdad! Pide perdón por tu pecado y celebra al anochecer y al alba las alabanzas de tu Señor.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmclxxxix{Quienes discuten de los signos de Alá sin haber recibido autoridad, no piensan sino en grandezas, que no alcanzarán. ¡Busca, pues, refugio en Alá! Él es Quien todo lo oye, Quien todo lo ve.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcxc{Crear los cielos y la tierra es más Q grande aún que crear a los hombres. Pero la mayoría de los hombres no saben.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcxci{No son iguales el ciego y el vidente. Ni los que han creído y obrado bien y los que han obrado mal. ¡Qué poco os dejáis amonestar!\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcxcii{Sí, la Hora llega, no hay duda de ella, pero la mayoría de los hombres no creen.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcxciii{Vuestro Señor ha dicho: «¡Invocadme y os escucharé! Los que, llevados de su altivez, no Me sirvan entrarán, humillados, en la gehena».\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcxciv{Alá es quien ha dispuesto para vosotros la noche para que descanséis en ella, y el día para que podáis ver claro. Sí, Alá dispensa Su favor a los hombres, pero la mayoría de los hombres no agradecen.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcxcv{ése es Alá, vuestro Señor, creador de todo. ¡No hay más dios que É! ¡Cómo podéis, pues, ser tan desviados!\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcxcvi{Del mismo modo fueron desviados quienes rechazaron los signos de Alá.\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcxcvii{Alá es Quien os ha estabilizado la tierra y hecho del cielo un edificio, os ha formado armoniosamente y os ha proveído de cosas buenas. ése es Alá, vuestro Señor. ¡Bendito sea, pues, Alá, Señor del universo!\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcxcviii{Él es el Vivo. No hay más dios que É. ¡Invocadle rindiéndole culto sincero! ¡Alabado sea Alá, Señor del universo!\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcxcix{Di: «Cuando he recibido de mi Señor las pruebas claras, se me ha prohibido que sirva a aquéllos que invocáis en lugar de invocar a Alá. He recibido la orden de someterme al Señor del universo».\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcc{Él es Quien os ha creado de tierra; luego, de una gota; luego, de un coágulo de sangre. Luego, os hace salir como criaturas para alcanzar, más tarde, la madurez, luego la vejez -aunque algunos de vosotros mueren prematuramente- y llegar a un término fijo. Quizás, así, razonéis.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcci{Él es Quien da la vida y da la muerte. Y cuando decide algo, le dice tan sólo: «¡Sé!» y es.\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmccii{¿No has visto a quienes discuten de los signos de Alá? ¡Cómo pueden ser tan desviados!\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcciii{Que han desmentido la Escritura y el mensaje confiado a Nuestros enviados. ¡Van a ver...,\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcciv{cuando, argolla al cuello y encadenados, sean arrastrados\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmccv{al agua muy caliente y, luego, sean atizados en el Fuego!\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmccvi{Luego, se les dirá: «¿Dónde está lo que asociabais\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmccvii{en lugar de Alá?» Dirán: «¡Nos han abandonado! Mejor dicho, antes no invocábamos nada». Así extravía Alá a los infieles.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmccviii{«Eso es por haberos regocijado en la tierra sin razón y por haberos conducido insolentemente.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmccix{¡Entrad por las puertas de la gehena, para estar en ella eternamente! ¡Qué mala es la morada de los soberbios!»\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmccx{¡Ten, pues, paciencia! ¡Lo que Alá promete es verdad! Lo mismo si te hacemos ver algo de aquello con que les amenazamos, que si te llamamos, serán devueltos a Nosotros.\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmccxi{Ya mandamos a otros enviados antes de ti. De algunos de ellos ya te hemos contado, de otros no. Ningún enviado pudo traer signo alguno, sino con permiso de Alá. Cuando llegue la orden de Alá, se decidirá según justicia y, entonces, los falsarios estarán perdidos.\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmccxii{Alá es Quien ha puesto para vosotros los rebaños, para que montéis en unos y de otros os alimentéis,\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmccxiii{-tenéis en ellos provecho-, y para que, por ellos, consigáis vuestros propósitos. Ellos y las naves os sirven de medios de transporte.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmccxiv{Él os hace ver Sus signos. ¿Cuál, pues, de los signos de Alá negaréis?\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmccxv{¿No han ido por la tierra y mirado cómo terminaron sus antecesores? Fueron más numerosos que ellos, más poderosos, dejaron más huellas en la tierra, pero sus posesiones no les sirvieron de nada.\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmccxvi{Cuando sus enviados vinieron a ellos con las pruebas claras, se alegraron de la ciencia que poseían, pero se vieron cercados por aquello de que se burlaban.\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmccxvii{Y, cuando vieron Nuestro rigor, dijeron: «¡Creemos en Alá Solo y renegamos de lo que Le asociábamos!»\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmccxviii{Pero, entonces, su fe no les sirvió de nada, después de haber visto Nuestro rigor. Tal es la práctica de Alá, que ya se había aplicado a Sus siervos. Y entonces salieron perdiendo los infieles.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmccxix{\basmalahes hm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmccxx{Revelación procedente del Compasivo, del Misericordioso.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmccxxi{Escritura cuyas aleyas han sido explicadas detalladamente como Corán árabe para gente que sabe.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmccxxii{como nuncio de buenas nuevas y como monitor. La mayoría, empero, se desvían y, así, no oyen.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmccxxiii{Y dicen: «Una envoltura oculta a nuestros corazones aquello a que nos llamas, nuestros oídos padecen sordera, un velo nos separa de ti. ¡Haz, pues, lo que juzgues oportuno, que nosotros haremos también lo que juzguemos oportuno!»\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmccxxiv{Di: «Yo soy sólo un mortal como vosotros, a quien se ha revelado que vuestro Dios es un Dios Uno. ¡Id, pues, derechos a Él y pedidle perdón! ¡Ay de los asociadores,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmccxxv{que no dan el azaque y niegan la otra vida!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmccxxvi{Quienes crean y obren bien, recibirán una recompensa ininterrumpida».\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmccxxvii{Di: «¿No vais a creer en Quien ha creado la tierra en dos días y Le atribuís iguales? ¡Tal es el Señor del universo!»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmccxxviii{En cuatro días iguales: ha puesto en ella, encima, montañas firmes, la ha bendecido y ha determinado sus alimentos. Para los que inquieren...\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmccxxix{Luego, se dirigió al cielo, que era humo, y dijo a éste y a la tierra: «¡Venid, queráis o no!» Dijeron: «¡Venimos de buen grado!»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmccxxx{«Decretó que fueran siete cielos, en dos días, e inspiró a cada cielo su cometido. Hemos engalanado el cielo más bajo con luminares, como protección. Tal es la decisión del Poderoso, del Omnisciente».\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmccxxxi{Si se desvían, di: «Os prevengo contra un rayo como el de los aditas y los tamudeos».\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmccxxxii{Cuando vinieron a ellos los enviados antes y después. «¡No sirváis sino a Alá!» Dijeron: «Si nuestro Señor hubiera querido, habría enviado de lo alto a ángeles. No creemos en vuestro mensaje».\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmccxxxiii{En cuanto a los aditas, sin razón, se condujeron en el país altivamente y dijeron: «¿Hay alguien más fuerte que nosotros?» ¿No veían que Alá, Que les había creado, era más fuerte que ellos? Pero negaron Nuestros signos.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmccxxxiv{Enviamos contra ellos un viento, glacial en días nefastos, para hacerles gustar el castigo de la ignominia en la vida de acá. Pero el castigo de la otra vida es aún más ignominioso y no serán auxiliados.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmccxxxv{Y en cuanto a los tamudeos, les dirigimos, pero prefirieron la ceguera a la Dirección, y el Rayo del castigo degradante les sorprendió por lo que habían cometido.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmccxxxvi{Y salvamos a los que creían y temían a Alá.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmccxxxvii{El día que los enemigos de Alá sean congregados hacia el Fuego, serán divididos en grupos.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmccxxxviii{Hasta que, llegados a él, sus oídos, sus ojos y su piel atestiguarán contra ellos de sus obras.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmccxxxix{Dirán a su piel: «¿Por qué has atestiguado contra nosotros?» Y ella dirá: «Alá, Que ha concedido a todos la facultad de hablar, nos la ha concedido a nosotros. Os ha creado una vez primera y a Él seréis devueltos.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmccxl{No podíais esconderos tan bien que no pudieran luego atestiguar contra vosotros vuestros oídos, vuestros ojos y vuestra piel. Creíais que Alá no sabía mucho de lo que hacíais.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmccxli{Lo que vosotros pensabais de vuestro Señor os ha arruinado y ahora sois de los que han perdido».\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmccxlii{Aunque tengan paciencia, el Fuego será su morada. Y, aunque pidan gracia, no se les concederá.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmccxliii{Les hemos asignado compañeros, que han engalanado su estado actual y su estado futuro. Se ha cumplido en ellos la sentencia que también alcanzó a otras comunidades de genios y de mortales que les precedieron. Han perdido.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmccxliv{Los infieles dicen: «¡No hagáis caso de este Corán ! ¡Parlotead cuando lo lean. Quizás, así, os salgáis con la vuestra!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccxlv{A los infieles les haremos gustar, sí, un severo castigo y les retribuiremos, sí, con arreglo a sus peores obras.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmccxlvi{ésa es la retribución de los enemigos de Alá: el Fuego, en el que tendrán la Morada de la Eternidad, como retribución de haber negado Nuestros signos.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmccxlvii{Los infieles dirán: «¡Señor! ¡Muéstranos a los genios y a los mortales que nos han extraviado y los pondremos bajo nuestros pies para que estén en lo más profundo!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmccxlviii{A los que hayan dicho: «¡Nuestro Señor es Alá!» y se hayan portado correctamente, descenderán los ángeles: «¡No temáis ni estéis tristes! ¡Regocijaos, más bien, por el Jardín que se os había prometido!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccxlix{Somos vuestros amigos en la vida de acá y en la otra. Tendréis allí todo cuanto vuestras almas deseen, todo cuanto pidáis,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccl{como alojamiento venido de Uno Que es indulgente, misericordioso».\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmccli{¿Quién hay, pues, que hable mejor que quien llama a Alá, obra bien y dice: «Soy de los que se someten a Alá»?\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcclii{No es igual obrar bien y obrar mal. ¡Repele con lo que sea mejor y he aquí que aquél de quien te separe la enemistad se convetirá en amigo ferviente!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmccliii{Esto sólo lo consiguen los pacientes, sólo lo consigue el de suerte extraordinaria.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmccliv{Si el Demonio te incita al mal, busca refugio en Alá. Él es Quien todo lo oye, Quien todo lo sabe.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcclv{Entre Sus signos figuran la noche el día, el sol y la luna. ¡No os prosternéis ante el sol ni ante la luna! ¡Prosternaos ante Alá, Que los ha creado! Si es a Él a Quien servís...\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcclvi{Si se muestran altivos, en cambio, quienes están junto a tu Señor Le glorifican, incansables, noche y día.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcclvii{Ves entre Sus signos que la tierra está seca. Luego, se reanima y reverdece cuando hacemos llover sobre ella. En verdad, Quien la vivifica puede también, vivificar a los muertos. Es omnipotente.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcclviii{Los que niegan Nuestros signos no pueden ocultarse a Nosotros. Qué es mejor: ¿ser arrojado al Fuego o venir en seguridad: el día de la Resurrección? ¡Haced lo que queráis! Él ve bien lo que hacéis.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcclix{Los que no creen en la Amonestación cuando ésta viene a ellos... Y eso que es una Escritura excelente,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcclx{completamente inaccesible a lo falso, revelación procedente de uno Que es sabio, digno de alabanza.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcclxi{No se te dice sino lo que ya se dijo a los enviados que te precedieron: que tu Señor está dispuesto a perdonar, pero también a castigar dolorosamente.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcclxii{Si hubiéramos hecho de ella un Corán no árabe, habrían dicho: «¿Por qué no se han explicado detalladamente sus aleyas? ¿No árabe y árabe?» Di: «Es dirección y curación para quienes creen. Quienes, en cambio, no creen son duros de oído y, ante él, padecen ceguera. Es como si se les llamara desde lejos».\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcclxiii{Ya dimos a Moisés la Escritura. Y discreparon acerca de ella. Y, si no llega a ser por una palabra previa de tu Señor, se habría decidido entre ellos. Dudan seriamente de ella.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcclxiv{Quien obra bien, lo hace en su propio provecho. Y quien obra mal, lo hace en detrimento propio. Tu Señor no es injusto con Sus siervos.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcclxv{A Él se le remite el conocimiento de la Hora. Ningún fruto deja su cubierta, ninguna hembra concibe o pare sin que Él lo sepa. Cuando Él les llame: «¿Dónde están Mis asociados?». dirán: «Te aseguramos que ninguno de nosotros los ha visto».\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcclxvi{Lo que antes invocaban les abandonará. Creerán no tener escape.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcclxvii{No se cansa el hombre de pedir el bien, pero, si sufre un mal, se desanima, se desespera.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcclxviii{Si le hacemos gustar una misericordia venida de Nosotros, luego de haber sufrido una desgracia, dirá de seguro: «Esto es algo que se me debe. Y no creo que ocurra la Hora. Pero, si se me devolviera a mi Señor, tendría junto a Él lo mejor». Ya informaremos a los infieles, sí, de lo que hacían y les haremos gustar, sí, un duro castigo.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcclxix{Cuando agraciamos al hombre, éste se desvía y se aleja. Pero, si sufre un mal, no para de invocar.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcclxx{Di: «¿Qué os parece? Si procede de Alá y vosotros, luego, no creéis en él, ¿hay alguien que esté más extraviado que quien se opone tan marcadamente?»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcclxxi{Les mostraremos Nuestros signos fuera y dentro de sí mismos hasta que vean claramente que es la Verdad. ¿Es que no basta que tu Señor sea testigo de todo?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcclxxii{Pues ¿no dudan del encuentro de su Señor? Pues ¿no lo abarca Él todo?\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcclxxiii{\basmalahes hm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcclxxiv{'sq.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcclxxv{Así es como Alá, el Poderoso, el Sabio, hace una revelación, a ti y a quienes fueron antes de ti.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcclxxvi{Suyo es lo que está en los cielos y en la tierra. Él es el Altísimo, el Grandioso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcclxxvii{Casi se hienden los cielos allí arriba al celebrar los ángeles las alabanzas de su Señor y pedir Su perdón en favor de los que están en la tierra. ¿No es Alá el Indulgente, el Misericordioso?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcclxxviii{A los que han tomado amigos en lugar de tomarle a Él, Alá les vigila. Tú no eres su protector.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcclxxix{Así es como te revelamos un Corán árabe, para que adviertas a la metrópoli y a los que viven en sus alrededores y para que prevengas contra el día indubitable de la Reunión. Unos estarán en el Jardín y otros en el fuego de la gehena.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcclxxx{Alá, si hubiera querido, habría hecho de ellos una sola comunidad. Pero introduce en Su misericordia a quien Él quiere. Los impíos no tendrán amigo ni auxiliar.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcclxxxi{¿Han tomado amigos en lugar de tomarle a Él? Pues Alá es el Amigo. Él resucita a los muertos, es omnipotente.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcclxxxii{Alá es Quien arbitra vuestras discrepancias, cualesquiera que sean. Tal es Alá, mi Señor. En Él confio y a Él me vuelvo arrepentido.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcclxxxiii{Creador de los cielos y de la tierra. Os ha dado esposas salidas de vosotros y parejas salidas de vuestros rebaños, diseminándoos así. No hay nada que se Le asemeje. Él es Quien todo lo oye, Quien todo lo ve.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcclxxxiv{Suyas son las llaves de los cielos y de la tierra. Dispensa el sustento a quien Él quiere: a unos con largueza, a otros con mesura. Es omnisciente.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcclxxxv{Os ha prescrito en materia de religión lo que ya había ordenado a Noé, lo que Nosotros te hemos revelado y lo que ya habíamos ordenado a Abraham, a Moisés y a Jesús: «¡Que rindáis culto y que esto no os sirva de motivo de división!» A los asociadores les resulta difícil aquello a que tú les llamas. Alá elige para Sí a quien Él quiere y dirige a Él a quien se arrepiente.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcclxxxvi{No se dividieron, por rebeldía mutua, sino después de haber recibido la Ciencia. Y, si no llega a ser por una palabra previa de tu Señor, remitiendo a un término fijo, ya se habría decidido entre ellos. Quienes, después, heredaron la Escritura dudan seriamente de ella.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcclxxxvii{Así, pues, llama. Sigue la vía recta, como se te ha ordenado, y no sigas sus pasiones. Y di: «Creo en toda Escritura que Alá ha revelado. Se me ha ordenado que haga justicia entre vosotros. ¡Alá es nuestro Señor y Señor vuestro! Nosotros responderemos de nuestros actos y vosotros de los vuestros. ¡Que no haya disputas entre nosotros y vosotros! Alá nos reunirá... ¡Es Él el fin de todo!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcclxxxviii{Quienes disputan a propósito de Alá después de que se le ha escuchado, esgrimen un argumento sin valor para su Señor. Incurren en ira y tendrán un castigo severo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcclxxxix{Alá es quien ha hecho descender la Escritura con la Verdad, y la Balanza. ¿Quien sabe? Quizá la Hora esté próxima...\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmccxc{Los que no creen en ella desearían que se adelantara, mientras que los que creen tiemblan sólo de pensar en ella y saben que es un hecho. Los que disputan sobre la Hora ¿no están profundamente extraviados?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmccxci{Alá es bondadoso con Sus siervos. Provee a las necesidades de quien Él quiere. Él es el Fuerte, el Poderoso.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmccxcii{A quien desee labrar el campo de la vida futura se lo acrecentaremos. A quien, en cambio, desee labrar el campo de la vida de acá, le daremos de ella. pero no tendrá ninguna parte en la otra vida.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmccxciii{¿Tienen asociados que les hayan prescrito en materia de religión lo que Alá no ha sancionado? Si no se hubiera ya pronunciado la sentencia decisiva, se habría decidido entre ellos. Los impíos tendrán un castigo doloroso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmccxciv{Verás a los impíos temer por lo que han merecido, que recaerá en ellos, mientras que los que hayan creído y obrado bien estarán en los prados de los jardines y tendrán junto a su Señor lo que deseen. ¡Ése es el gran favor!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmccxcv{Ésta es la buena nueva que Alá anuncia a Sus siervos, que creen y obran bien. Di: «Yo no os pido salario a cambio, fuera de que améis a los parientes». A quien obre bien, le aumentaremos el valor de su obra. Alá es indulgente, muy agradecido.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmccxcvi{O dirán: «Se ha inventado una mentira contra Alá». Alá sellará, si quiere, tu corazón. Pero Alá disipa lo falso y hace triunfar la Verdad con Sus palabras. Él sabe bien lo que encierran los pechos.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmccxcvii{Él es Quien acepta el arrepentimiento de Sus siervos y perdona las malas acciones. Y sabe lo que hacéis.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmccxcviii{Escucha a quienes creen y obran bien y les da más de Su favor. Los infieles, en cambio, tendrán un castigo severo.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccxcix{Si Alá dispensara el sustento a Sus siervos con largueza, se insolentarían en la tierra. Lo que hace, en cambio, es concederles con mesura lo que quiere. Está bien informado sobre Sus siervos, les ve bien.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmccc{Él es Quien envía de lo alto la lluvia abundante, cuando ya han perdido toda esperanza, y difunde Su misericordia. Él es el Amigo, el Digno de Alabanza.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmccci{Entre Sus signos figuran la creación de los cielos y de la tierra, los seres vivos que en ellos ha diseminado y que, cuando quiere, puede reunir.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcccii{Cualquier desgracia que os ocurre, es como castigo a vuestras obras, pero perdona mucho.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccciii{No podéis escapar en la tierra y no tenéis, fuera de Alá, amigo ni auxiliar.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccciv{Entre sus signos figuran las embarcaciones en el mar como mojones.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcccv{Si quiere, calma el viento y se inmovilizan en su superficie. Ciertamente, hay en ello signos para todo aquél que tenga mucha paciencia, mucha gratitud.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcccvi{O bien les hace perecer, como castigo por lo que han merecido, pero perdona mucho.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcccvii{Para que sepan quienes discuten sobre Nuestros signos que no tendrán escape.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcccviii{Todo lo que habéis recibido es breve disfrute de la vida de acá. En cambio, lo que Alá tiene es mejor y más duradero para quienes creen y confían en su Señor,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcccix{evitan cometer pecados graves y deshonestidades y, cuando están airados, perdonan,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcccx{escuchan a su Señor, hacen la azalá, se consultan mutuamente, dan limosna de lo que les hemos proveído,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcccxi{se defienden cuando son víctimas de opresión.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcccxii{Una mala acción será retribuida con una pena igual, pero quien perdone y se reconcilie recibirá su recompensa de Alá. Él no ama a los impíos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcccxiii{Quienes, tratados injustamente, se defiendan, no incurrirán en reproche.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcccxiv{Sólo incurren en él quienes son injustos con los hombres y se insolentan en la tierra injustamente. Esos tales tendrán un castigo doloroso.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcccxv{Quien es paciente y perdona, eso sí que es dar muestras de resolución.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcccxvi{Aquél a quien Alá extravía no tendrá, después de Él, ningún amigo. Cuando los impíos vean el castigo, les verás que dicen: «¿Y no hay modo de regresar?»\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcccxvii{Les verás expuestos a él, abatidos de humillación, mirando con disimulo, mientras que quienes hayan creído dirán: «Quienes de verdad pierden son los que el día de la Resurrección se han perdido a sí mismos y han perdido a sus familias». ¿No tendrán los impíos un castigo permanente?\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcccxviii{Fuera de Alá. no tendrán ningunos amigos que les auxilien... Aquél a quien Alá extravía no podrá dar con camino.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcccxix{Escuchad a vuestro Señor antes de que llegue un día que Alá no evitará. Ese día no encontraréis refugio, ni podréis negar.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcccxx{Si se apartan, no te hemos mandado para ser su custodio, sino sólo para transmitir. Cuando hacemos gustar al hombre una misericordia venida de Nosotros, se regocija. Pero, si le sucede un mal como castigo a sus obras, entonces, el hombre es desagradecido.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcccxxi{El dominio de los cielos y de la tierra pertenece a Alá. Crea lo que quiere. Regala hijas a quien Él quiere y regala hijos a quien Él quiere.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcccxxii{o bien les da ambos, varones y hembras, o hace impotente a quien Él quiere. Es omnisciente, omnipotente.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcccxxiii{A ningún mortal le es dado que Alá le hable si no es por inspiración, o desde detrás de una cortina, o mandándole un enviado que le inspire, con Su autorización, lo que Él quiere. Es altísimo, sabio.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcccxxiv{Así es como te hemos inspirado un Espíritu que procede de Nuestra orden. Tú no sabías lo que eran la Escritura y la Fe, pero hemos hecho de él luz con la que guiamos a quienes queremos de Nuestros siervos. Ciertamente, tú guías a los hombres a una vía recta,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcccxxv{la vía de Alá, a quien pertenece lo que está en los cielos y en la tierra. ¿No es Alá el fin de todo?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcccxxvi{\basmalahes hm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcccxxvii{¡Por la Escritura clara!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcccxxviii{Hemos hecho de ella un Corán árabe. Quizás, así, razonéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcccxxix{Está en la Escritura Matriz que Nosotros tenemos, sublime, sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcccxxx{¿Es que, porque seáis gente inmoderada, vamos a privaros de la Amonestación?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcccxxxi{¡Cuántos profetas hemos enviado a los antiguos...!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcccxxxii{No vino a ellos profeta que no se burlaran de él.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcccxxxiii{Por eso, hemos hecho perecer a otros más temibles que ellos. Ya ha precedido el ejemplo de los antiguos...\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcccxxxiv{Si les preguntas: «¿Quién ha creado los cielos y la tierra?», seguro que dicen: «¡Los ha creado el Poderoso, el Omnisciente!»\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcccxxxv{Quien os ha puesto la tierra como cuna y os ha puesto en ella caminos. Quizás, así, seáis bien dirigidos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcccxxxvi{Quien ha hecho bajar agua del cielo con mesura para resucitar un país muerto. Del mismo modo se os sacará.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcccxxxvii{Quien ha creado todas las parejas y os ha dado las naves y los rebaños en que montáis,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcccxxxviii{para que os instaléis en ellos y, luego, cuando lo hayáis hecho, recordéis la gracia de vuestro Señor y digáis: «¡Gloria a Quien ha sujetado esto a nuestro servicio! ¡Nosotros no lo hubiéramos logrado!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcccxxxix{¡Sí, volveremos a nuestro Señor!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcccxl{Han equiparado a algunos de Sus siervos con Él. Sí. el hombre es manifiestamente desagradecido.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcccxli{¿Iba Alá a tomar hijas de entre Sus criaturas, y a vosotros concederos hijos?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcccxlii{Cuando se anuncia a uno de ellos lo que él asimila al Compasivo, se queda hosco y se angustia.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcccxliii{«¡Cómo! Un ser que crece entre perifollos, incapaz de discutir claramente...»\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcccxliv{Han considerado a los ángeles que son siervos del Compasivo, de sexo femenino. ¿Es que han sido testigos de la creación de éstos? Se hará constar su testimonio y tendrán que responder del mismo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcccxlv{Dicen: «Si el Compasivo hubiera querido, no les habríamos servido». No tienen ningún conocimiento de eso, no hacen sino conjeturar.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcccxlvi{¿Es que les trajimos otra Escritura a la que atenerse antes de ésta?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcccxlvii{¡Nada de eso! Dicen: «Encontramos a nuestros padres en una religión y, siguiendo sus huellas, estamos bien dirigidos».\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcccxlviii{Y así, no enviamos ningún monitor antes de ti a una ciudad que no dijeran los ricos: «Encontramos a nuestros padres en una religión e imitamos su ejemplo».\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcccxlix{Dijo: «¿Y si os trajera una dirección más recta que la que vuestros padres seguían?» Dijeron: «¡No creemos en vuestro mensaje!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcccl{Nos vengamos de ellos. ¡Y mira cómo terminaron los desmentidores!\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcccli{Y cuando Abraham dijo a su padre y a su gente: «Soy inocente de lo que servís.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmccclii{Yo no sirvo sino a Quien me ha creado. Él me dirigirá».\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcccliii{E hizo que esta palabra perdurara en su posteridad. Quizás, así, se convirtieran.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcccliv{No sólo eso, sino que les permití gozar, a ellos y a sus padres, hasta que viniera a ellos la Verdad y un Enviado que hablara claro.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmccclv{Pero, cuando la Verdad vino a ellos, dijeron: «¡Esto es magia y no creemos en ello!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmccclvi{Y dijeron: «¿Por qué no se ha revelado este Corán a un notable de una de las dos ciudades...»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmccclvii{¿Son ellos los encargados de dispensar la misericordia de tu Señor? Nosotros les dispensamos las subsistencias en la vida de acá y elevamos la categoría de unos sobre otros para que éstos sirvieran a aquéllos. Pero la misericordia de tu Señor es mejor que lo que ellos amasan.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmccclviii{Si no hubiera sido por evitar que los hombres formaran una sola comunidad, habríamos puesto en las casas de los que no creen en el Compasivo terrazas de plata y gradas de acceso,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmccclix{puertas y lechos en que reclinarse.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmccclx{y lujo. Pero todo esto no es sino breve disfrute de la vida de acá en tanto que la otra vida, junto a tu Señor, será para los que Le temen.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmccclxi{A quien se cierre a la Amonestación del Compasivo, le asignamos un demonio que será para él compañero.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmccclxii{Les apartan, sí, del Camino, mientras creen ser bien dirigidos.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmccclxiii{Hasta que, al comparecer ante Nosotros, diga: «¡Ojalá nos hubiera separado, a mí y a ti, la misma distancia que separa al Oriente del Occidente!» ¡Qué mal compañero...!\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmccclxiv{Hoy no os aprovechará compartir el castigo por haber sido impíos.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmccclxv{¿Es que puedes tú hacer que un sordo oiga, o dirigir a un ciego y al que se encuentra evidentemente extraviado?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmccclxvi{O te hacemos morir y, luego, Nos vengamos de ellos,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmccclxvii{o te mostramos aquello con que les amenazamos. Pues les podemos con mucho.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmccclxviii{¡Aténte a lo que se te ha revelado! Estás en una vía recta.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmccclxix{Es, ciertamente, una amonestación para ti y para tu pueblo y tendréis que responder.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmccclxx{Pregunta a los enviados que mandamos antes de ti si hemos establecido dioses a quienes servir en lugar de servir al Compasivo.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmccclxxi{Ya enviamos Moisés con Nuestros signos a Faraón y a sus dignatarios. Y dijo: «Yo soy el enviado del Señor del universo».\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmccclxxii{Pero cuando les presentó Nuestros signos, he aquí que se rieron de ellos,\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmccclxxiii{a pesar de que cada signo que les mostrábamos superaba al precedente. Les sorprendimos con el castigo. Quizás, así, se convirtieran.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmccclxxiv{Dijeron: «¡Mago! ;Ruega a tu Señor por nosotros, en virtud de la alianza que ha concertado contigo! Nos dejaremos dirigir».\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmccclxxv{Pero, cuando retiramos de ellos el castigo, he aquí que quebrantaron su promesa.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmccclxxvi{Faraón dirigió una proclama a su pueblo, diciendo: «¡Pueblo! ¿No es mío el dominio de Egipto, con estos ríos que fluyen a mis pies? ¿Es que no veis?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmccclxxvii{¿No soy yo mejor que éste, que es un vil y que apenas sabe expresarse?\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmccclxxviii{¿Por qué no se le han puesto brazaletes de oro...? ¿Por qué no ha venido acompañado de ángeles...?»\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmccclxxix{Extravió a su pueblo y éste le obedeció: era un pueblo perverso.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmccclxxx{Cuando Nos hubieron irritados, Nos vengamos de ellos anegándolos a todos,\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmccclxxxi{y sentamos con ellos un precedente, poniéndolos como ejemplo para la posteridad.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmccclxxxii{Y cuando el hijo de María es puesto como ejemplo, he aquí que tu pueblo se aparta de él.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmccclxxxiii{Y dicen: ¿Son mejores nuestros dioses o él? Si te lo ponen, no es sino por afán de discutir. Son, en efecto, gente contenciosa.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmccclxxxiv{El no es sino un siervo a quien hemos agraciado y a quien hemos puesto como ejemplo a los Hijos de Israel.\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmccclxxxv{Si quisiéramos, haríamos de vosotros ángeles, que sucederían en la tierra.\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmccclxxxvi{Será un medio de conocer la Hora. ¡No dudéis, pues, de ella y seguidme! ¡Esto es una vía recta!\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmccclxxxvii{¡Que el Demonio no os extravíe! Es para vosotros un enemigo declarado.\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmccclxxxviii{Cuando Jesús vino con las pruebas claras, dijo: «He venido a vosotros con la Sabiduría y para aclararos algo de aquello en que discrepáis. ¡Temed, pues, a Alá y obedecedme!\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmccclxxxix{Alá es mi Señor y Señor vuestro. ¡Servidle, pues! ¡Esto es una vía recta!»\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcccxc{Pero los grupos discreparon unos de otros. ¡Ay de los impíos, por el castigo de un día doloroso...!\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcccxci{No les queda más que esperar la Hora, que les vendrá de repente, sin presentirla.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcccxcii{Ese día. los amigos serán enemigos unos de otros, excepto los temerosos de Alá.\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcccxciii{«¡Siervos míos! ¡No tenéis que temer hoy! ¡Y no estaréis tristes!\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcccxciv{Los que creísteis en Nuestros signos y os sometisteis a Alá,\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcccxcv{¡entrad en el Jardín junto con vuestras esposas, para ser regocijados!»\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcccxcvi{Se harán circular entre ellos platos de oro y copas, que contendrán todo lo que cada uno desee, deleite de los ojos. «Estaréis allí eternamente.\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcccxcvii{Éste es el Jardín que habéis heredado como premio a vuestras obras.\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcccxcviii{Tenéis en él fruta abundante, de la que comeréis».\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcccxcix{Los pecadores, en cambio, tendrán la gehena como castigo, eternamente,\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcd{castigo que no se les remitirá, y serán presa de la desesperación.\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcdi{No seremos Nosotros quienes hayan sido injustos con ellos, sino que ellos serán los que lo hayan sido.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmcdii{Llamarán: «¡Malik! ¡Que tu Señor acabe con nosotros!» Él dirá: «¡Os quedaréis ahí!»\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmcdiii{«Os trajimos la Verdad, pero la mayoría sentisteis aversión a la Verdad».\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmcdiv{¿Han tramado algo? Pues Nosotros también.\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmcdv{¿O creen que no Nos enteramos de sus secretos y confidencias? ¡Claro que Nos enteramos! Y Nuestros enviados, junto a ellos, toman nota.\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmcdvi{Di: «Si el Compasivo tuviera un hijo, yo sería el primero en servirle».\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmcdvii{¡Gloria al Señor de los cielos y de la tierra. Señor del Trono! ¡Está por encima de lo que Le atribuyen!\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmcdviii{¡Déjales que parloteen y jueguen hasta que les llegue el Día con que se les ha amenazado!\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmcdix{¡El es Quien es dios en el cielo y dios en la tierra! Es el Sabio, el Omnisciente.\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmcdx{¡Bendito sea Quien posee el dominio de los cielos, de la tierra y de lo que entre ellos está! Él tiene conocimiento de la Hora y a Él seréis devueltos.\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmcdxi{Los que ellos invocan en lugar de invocarle a Él no pueden interceder, salvo, aquéllos que atestiguan la Verdad y saben.\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmcdxii{Si les preguntas: «¿Quién os ha creado?», seguro que dicen: «¡Ala!» ¡Cómo pueden, pues, ser tan desviados!\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmcdxiii{y de su dicho: «¡Señor! Ésta es gente que no cree».\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmcdxiv{Aléjate, pues, de ellos y di: «¡Paz!» ¡Van a ver...!\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmmcdxv{\basmalahes hm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcdxvi{¡Por la Escritura clara!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcdxvii{¡La hemos revelado en una noche bendita! ¡Hemos advertido!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcdxviii{En ella se decide todo asunto sabiamente,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcdxix{como cosa venida de Nosotros. Mandamos a enviados\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcdxx{como misericordia venida de tu Señor. Él es Quien todo lo oye, Quien todo lo sabe,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcdxxi{Señor de los cielos, de la tierra y de lo que entre ellos está. Si estuvierais convencidos...\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcdxxii{No hay más dios que Él. Él da la vida y da la muerte. Vuestro Señor y Señor de vuestros antepasados.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcdxxiii{Pero ¡no! Ellos dudan y no lo toman en serio.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcdxxiv{¡Espera, pues, el día que el cielo traiga un humo visible,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcdxxv{que cubra a los hombres! Será un castigo doloroso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcdxxvi{«¡Señor! ¡Aparta de nosotros el castigo! ¡Creemos!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcdxxvii{¿De qué les servirá la amonestación, si ha venido a ellos un Enviado que habla claro\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcdxxviii{y se han apartado de él y dicho: «¡Es uno a quien se ha instruido, un poseso!»?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcdxxix{«Vamos a apartar de vosotros el castigo por algún tiempo. Pero reincidiréis».\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcdxxx{El día que hagamos uso del máximo rigor, Nos vengaremos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcdxxxi{Antes que a ellos, habíamos probado al pueblo de Faraón. Un enviado noble vino a ellos:\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcdxxxii{«¡Entregadme a los siervos de Alá! Tenéis en mí a un enviado digno de confianza.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcdxxxiii{¡No os mostréis altivos con Alá! Vengo a vosotros con autoridad manifiesta.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcdxxxiv{Me refugio en mi Señor y Señor vuestro contra vuestro intento de lapidarme.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcdxxxv{Si no os fiáis de mí, ¡dejadme!»\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcdxxxvi{Entonces, invocó a su Señor. «¡Ésta es gente pecadora!»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcdxxxvii{«¡Sal de noche con Mis siervos! Os perseguirán.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcdxxxviii{¡Deja el mar en calma! Son un ejército que será anegado»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcdxxxix{¡Cuántos jardines y fuentes abandonaron,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcdxl{cuántos campos cultivados, cuántas suntuosas residencias,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmcdxli{cuánto bienestar, en el que vivían felices!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcdxlii{Así fue y se lo dimos en herencia a otro pueblo.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcdxliii{Ni el cielo ni la tierra les lloraron. No se les concedió prórroga.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcdxliv{Y salvamos a los Hijos de Israel del humillante castigo,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmcdxlv{de Faraón. Era altivo, de los inmoderados.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmcdxlvi{Les elegimos conscientemente de entre todos los pueblos.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcdxlvii{Les dimos signos con los que les pusimos claramente a prueba.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcdxlviii{Éstos dicen, sí:\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcdxlix{«No moriremos más que una sola vez y no seremos resucitados.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcdl{¡Haced, pues, volver a nuestros padres, si es verdad lo que decís!»\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcdli{¿Eran mejores ellos que el pueblo de Tubba y que sus antecesores? Les hicimos perecer, eran pecadores.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcdlii{No hemos creado los cielos, la tierra y lo que entre ellos está por puro juego.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcdliii{No los creamos sino con un fin, pero la mayoría no saben.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcdliv{El día del Fallo se darán todos cita.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcdlv{Día en que nadie podrá proteger nada a nadie, nadie será auxiliado,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcdlvi{salvo aquél de quien Alá se apiade. Él es el Poderoso, el Misericordioso.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcdlvii{El árbol de Zaqqum\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcdlviii{es el alimento del pecador.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcdlix{Es como metal fundido, hierve en las entrañas\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcdlx{como agua hirviente.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcdlxi{«¡Cogedle y llevadle en medio del fuego de la gehena!\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcdlxii{¡Castigadle, luego, derramando en su cabeza agua muy caliente!»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcdlxiii{«¡Gusta! ¡Tú eres 'el poderoso', 'el generoso'!»\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcdlxiv{¡Esto es aquello de que dudabais!\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcdlxv{Los que teman a Alá estarán, en cambio, en lugar seguro,\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcdlxvi{entre jardines y fuentes,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcdlxvii{vestidos de satén y de brocado, unos enfrente de otros.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcdlxviii{Así será. Y les daremos por esposas a huríes de grandes ojos.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcdlxix{Pedirán allí en seguridad, toda clase de frutas.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcdlxx{No gustarán alli otra muerte que la primera y Él les preservará del castigo del fuego de la gehena,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcdlxxi{como favor de tu Señor. ¡Ése es el éxito grandioso!\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcdlxxii{En verdad, lo hemos hecho fácil en tu lengua. Quizás, así, se dejen amonestar.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcdlxxiii{¡Observa, pues! Ellos observan....\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcdlxxiv{\basmalahes hm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcdlxxv{La revelación de la Escritura procede de Alá, el Poderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcdlxxvi{Hay, en verdad, en los cielos y en la tierra signos para los creyentes.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcdlxxvii{En vuestra creación y en las bestias que Él esparce hay signos para gente que está convencida.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcdlxxviii{También en la sucesión de la noche y el día, en lo que como sustento Alá hace bajar del cielo, vivificando con ello la tierra después de muerta, y en la variación de los vientos hay signos para gente que comprende.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcdlxxix{Estas son las aleyas de Alá, que te recitamos conforme a la verdad. Y ¿en qué anuncio van a creer si no creen en Alá y en Sus signos?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcdlxxx{¡Ay de todo aquél que sea mentiroso, pecador,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxi{que, a pesar de oír las aleyas de Alá que se le recitan, se obstina en su altivez como si no las hubiera oído! ¡Anúnciale un castigo doloroso!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxii{Los que, habiendo conocido algo de Nuestros signos, los hayan tomado a burla, tendrán un castigo humillante.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxiii{Les espera la gehena y sus posesiones no les servirán de nada, como tampoco los que tomaron como amigos en lugar de tomar a Alá. Tendrán un castigo terrible.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxiv{Esto es una dirección. Los que no crean en los signos de su Señor tendrán el castigo de un suplicio doloroso.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxv{Alá es Quien ha sujetado el mar a vuestro servicio para que las naves lo surquen a una orden Suya para que busquéis Su favor. Y quizás, así, seáis agradecidos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxvi{Y ha sujetado a vuestro servicio lo que está en los cielos y en la tierra. Todo procede de Él. Ciertamente, hay en ello signos para gente que reflexiona.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxvii{Di a los creyentes que perdonen a quienes no cuentan con los Días de Alá, instituidos para retribuir a la gente según sus méritos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxviii{Quien obra bien, lo hace en su propio provecho. Y quien obra mal, lo hace en detrimento propio. Luego, seréis devueltos a vuestro Señor.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcdlxxxix{Dimos a los Hijos de Israel la Escritura, el juicio y el profetismo. Les proveímos de cosas buenas y les distinguimos entre todos los pueblos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcdxc{Les dimos pruebas claras respecto a la Orden. Y no discreparon, por rebeldía mutua, sino después de haber recibido la Ciencia. Tu Señor decidirá entre ellos el día de la Resurrección sobre aquello en que discrepaban.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcdxci{Luego, te pusimos en una vía respecto a la Orden. Síguela, pues, y no sigas las pasiones de quienes no saben.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcdxcii{No te servirán de nada frente a Alá. Los impíos son amigos unos de otros, pero Alá es el Amigo de los que Le temen.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcdxciii{Esto es un conjunto de pruebas visibles para los hombres, dirección y misericordia para gente que esta convencida.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcdxciv{Quienes obran mal ¿creen que les trataremos igual que a quienes creen y obran bien, como si fueran iguales en vida y luego de muertos? ¡Qué mal juzgan!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcdxcv{Alá ha creado con un fin los cielos y la tierra. Y para que cada cual sea retribuido según sus méritos. Nadie será tratado injustamente.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcdxcvi{Y ¿qué te parece quien ha divinizado su pasión a quien Alá ha extraviado a sabiendas, sellando su oído y su corazón, vendando sus ojos? ¿Quién podrá dirigirle luego de Alá? ¿Es que no os dejaréis amonestar?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcdxcvii{Y dicen: «No hay más vida que ésta nuestra de acá. Morimos y vivimos, y nada sino la acción fatal del Tiempo nos hace perecer». Pero no tienen ningún conocimiento de eso, no hacen sino conjeturar.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcdxcviii{Y cuando se les recitan Nuestras aleyas como pruebas claras, lo único que arguyen es: «¡Haced volver a nuestros padres, si es verdad lo que decís!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcdxcix{Di: «Alá os da la vida y, después, os hará morir. Luego, os reunirá para el día indubitable de la Resurrección. Pero la mayoría de los hombres no saben».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmd{El dominio de los cielos y de la tierra pertenece a Alá. Cuando ocurra la Hora, ese día, los falsarios estarán perdidos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdi{Verás a cada comunidad arrodillada. Cada comunidad será emplazada ante su Escritura : «Hoy seréis retribuidos con arreglo a vuestras obras.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdii{He aquí Nuestra Escritura, que dice la verdad contra vosotros. Apuntábamos lo que hacíais».\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdiii{A quienes creyeron y obraron bien, su Señor les introducirá en Su misericordia. ¡Ése es el éxito manifiesto!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdiv{En cuanto a quienes no creyeron: «¿Es que no se os recitaron Mis aleyas? Pero fuisteis altivos y gente pecadora».\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdv{Cuando se decía: «Lo que Alá promete es verdad y no hay duda respecto a la Hora», decíais: «No sabemos qué es eso de 'la Hora'. No podemos sino conjeturar. No estamos convencidos».\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdvi{Se les mostrará el mal que cometieron y les cercará aquello de que se burlaban.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdvii{Se dirá: «Hoy os olvidamos Nosotros, como vosotros olvidasteis que os llegaría este día. Tendréis el Fuego por morada y no encontraréis quien os auxilie.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdviii{Y esto es así porque tomasteis a burla los signos de Alá y la vida de acá os engaño». Ese día no serán sacados de él ni serán agraciados.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdix{¡Alabado sea Alá, Señor de los cielos, Señor de la tierra, Señor del universo!\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdx{¡Suya es la majestad en los cielos y en la tierra! Él es el Poderoso, el Sabio.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdxi{\basmalahes hm.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdxii{La revelación de la Escritura procede de Alá, el Poderoso, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdxiii{No hemos creado sino con un fin los cielos, la tierra y lo que entre ellos está, y por un período determinado. Pero los infieles se desvían de las advertencias que se les han dirigido.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdxiv{Di: «¿Qué os parece lo que invocáis en lugar de invocar a Alá? ¡Mostradme qué han creado de la tierra o si tienen participación en los cielos! Si es verdad lo que decís, ¡traedme una Escritura anterior a ésta o un rastro de conocimiento!»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdxv{¿Hay alguien que esté más extraviado que quien, en lugar de invocar a Alá, invoca a quienes no van a escucharle hasta el día de la Resurrección, indiferentes a sus invocaciones,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdxvi{que, cuando los hombres sean congregados, serán sus enemigos y renegarán de que les hayan servido?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdxvii{Cuando se les recitan a los infieles Nuestras aleyas como pruebas claras, dicen de la Verdad que viene a ellos: «¡Esto es manifiesta magia!»\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdxviii{O dicen: «Él lo ha inventado». Di: «Si yo lo he inventado, no podéis hacer nada por mí contra Alá. Él sabe bien lo que divulgáis a este propósito. Basta Él como testigo entre yo y vosotros. Él es el Indulgente, el Misericordioso».\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdxix{Di: «Yo no soy el primero de los enviados. Y no sé lo que será de mí, ni lo que será de vosotros. No hago más que seguir lo que se me ha revelado. Yo no soy más que un monitor que habla claro».\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdxx{Di: «¿Qué os parece? Si procede de Alá y vosotros no creéis en él, mientras que un testigo de entre los Hijos de Israel atestigua su conformidad y cree, en tanto que vosotros sois altivos... Alá no dirige a la gente impía».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdxxi{Los infieles dicen de los creyentes: «Si hubiera sido algo bueno, no se nos habrían adelantado en ello». Y, como no son dirigidos por él, dicen: «¡Es una vieja mentira!»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdxxii{Antes de él, la Escritura de Moisés servía de guía y de misericordia. Y ésta es una Escritura que confirma, en lengua árabe, para advertir a los impíos y anunciar la buena nueva a quienes hacen el bien.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdxxiii{Quienes dicen: «¡Nuestro Señor es Alá!» y se portan correctamente no tienen que temer y no estarán tristes.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdxxiv{Esos tales morarán en el Jardín eternamente, como retribución a sus obras.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdxxv{Hemos ordenado al hombre que se porte bien con sus padres. Su madre le llevó con molestia y con molestia le dio a luz. El embarazo y la lactancia duran treinta meses. Hasta que, al alcanzar la madurez y cumplir cuarenta años, dice: «¡Señor! Permíteme que Te agradezca la gracia que nos has dispensado, a mí y a mis padres, y que haga obras buenas que Te plazcan! ¡Dame una descendencia próspera! Me vuelvo a Ti. Soy de los que se someten a Ti».\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdxxvi{Éstos son aquéllos de cuyas obras aceptaremos lo mejor y pasaremos por alto sus malas obras. Estarán entre los moradores del Jardín, promesa de verdad que se les hizo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdxxvii{En cambio, quien diga a sus padres -mientras éstos imploran a Alá y dicen: «¡Ay de ti! ¡Cree! ¡Lo que Alá promete es verdad!»-: «¡Uf! ¿Vais a prometerme que me sacarán, cuando han pasado tantas generaciones anteriores a mí?» y diga: «Éstas no son sino patrañas de los antiguos»,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdxxviii{en ésos será en quienes se cumpla la sentencia aplicada a las comunidades precedentes de genios y de mortales. Ésos serán los que pierdan.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdxxix{Todos tendrán su propia categoría, según sus obras. Les retribuirá plenamente sus acciones y no serán tratados injustamente.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdxxx{El día que los infieles sean expuestos al Fuego: «Disipasteis vuestros bienes en vuestra vida de acá y gozasteis de ellos. Hoy se os va a retribuir con un castigo degradante por haberos conducido altivamente en la tierra sin razón y por haber sido perversos».\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdxxxi{Y recuerda al hermano de los aditas, que advirtió a su pueblo en al- Ahqaf -y hubo otras advertencias antes y después de él-. «¡No sirváis sino a Alá! Temo por vosotros el castigo de un día terrible».\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdxxxii{Dijeron: «¿Has venido a nosotros para desviarnos de nuestros dioses? ¡Tráenos, pues, aquello con que nos amenazas, si es verdad lo que dices!»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdxxxiii{Dijo: «Sólo Alá tiene conocimiento de ello. Yo os comunico el objeto de mi misión, pero veo que sois gente ignorante».\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdxxxiv{Cuando lo vieron como una nube que se dirigía a sus valles, dijeron: «Es una nube que nos trae la lluvia». «¡No! Es más bien aquello cuya venida reclamabais, un viento que encierra un castigo doloroso,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdxxxv{que va a destruirlo todo a una orden de su Señor». A la mañana siguiente, no se veía más que sus viviendas. Así retribuimos a la gente pecadora.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdxxxvi{Les habíamos dado un poderío como no os hemos dado a vosotros. Les habíamos dado oído, vista, intelecto. Pero ni el oído, ni la vista, ni el intelecto les sirvieron de nada, pues negaron los signos de Alá. Y les cercó aquello de que se burlaban.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdxxxvii{Hemos destruido las ciudades que había alrededor de vosotros. Les habíamos expuesto los signos. Quizás, así, se convirtieran.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdxxxviii{¿Por qué no les auxiliaron aquéllos a los que, en lugar de tomar a Alá, habían tomado como dioses para que les acercaran? Al contrario, les abandonaron. Ésa fue su mentira y su invención.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdxxxix{Y cuando te llevamos un grupo de genios para que escucharan la Recitación. Cuando estaban presentes a ella, dijeron: «¡Callad!» Y, cuando se terminó, regresaron a los suyos para advertirles.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdxl{Dijeron: «¡Pueblo! Hemos oído una Escritura revelada después de Moisés, en confirmación de los mensajes anteriores, que dirige a la Verdad y a una vía recta».\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdxli{¡Pueblo! Aceptad al que llama a Alá y creed en Él, para que os perdone vuestros pecados y os preserve de un castigo doloroso.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdxlii{Los que no acepten al que llama a Alá no podrán escapar en la tierra, ni tendrán, fuera de Él, amigos. Esos tales están evidentemente extraviados.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdxliii{¿No han visto que Alá, Que ha creado los cielos y la tierra sin cansarse por ello, es capaz de devolver la vida a los muertos? Pues sí, es omnipotente.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdxliv{El día que los infieles sean expuestos al Fuego: «¿No es esto la Verdad?» Dirán: «¡Claro que sí, por nuestro Señor!» Dirá: «¡Gustad, pues, el castigo debido a vuestra incredulidad!»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdxlv{Ten, pues, paciencia, como la tuvieron otros enviados resueltos. Y no reclames para ellos el adelantamiento. El día que vean aquello con que se les amenaza, les parecerá no haber permanecido más de una hora de día. Éste es un comunicado. Y ¿quién será destruido sino el pueblo perverso?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdxlvi{\basmalahes A quienes no crean y aparten a otros del camino de Alá, Él les invalidará sus obras.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdxlvii{En cambio, borrará las malas obras y mejorará la condición de quienes hayan creído, obrado bien y creído en la revelación hecha a Mahoma, la cual es la Verdad que viene de su Señor.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdxlviii{Y esto es así porque los infieles siguen lo falso, mientras que los creyentes siguen la Verdad venida de su Señor. Así es como Alá los pone como ejemplo a los hombres.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdxlix{Cuando sostengáis, pues, un encuentro con los infieles, descargad los golpes en el cuello hasta someterlos. Entonces, atadlos fuertemente. Luego, devolvedles la libertad, de gracia o mediante rescate, para que cese la guerra. Es así como debéis hacer. Si Alá quisiera, se defendería de ellos, pero quiere probaros a unos por medio de otros. No dejará que se pierdan las obras de los que hayan caído por Alá.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdl{Él les dirigirá, mejorará su condición\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdli{y les introducirá en el Jardín, que Él les habrá dado ya a conocer.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdlii{¡Creyentes! Si auxiliáis a Alá, Él os, auxiliará y afirmará vuestros pasos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdliii{¡Ay de aquéllos, en cambio, que no hayan creído! Invalidará sus obras.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdliv{Y esto es así porque les repugnó la revelación de Alá. E hizo vanas sus obras.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdlv{¿No han ido por la tierra y mirado cómo terminaron sus antecesores? Alá los destruyó. Y los infieles tendrán un fin semejante.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdlvi{Y esto es así porque Alá es el Protector de los creyentes, mientras que los infieles no tienen protector.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdlvii{Alá introducirá a quienes hayan creído y obrado bien en jardines por cuyos bajos fluyen arroyos. Quienes, en cambio, hayan sido infieles, gozarán brevemente y comerán como comen los rebaños. Tendrán el Fuego por morada.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdlviii{¡Cuántas ciudades hemos hecho perecer, más fuertes que tu ciudad, que te ha expulsado, sin que hubiera quien les auxiliara!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdlix{¿Es que quien se basa en una prueba clara venida de su Señor es comparable a aquéllos cuya mala conducta ha sido engalanada y que siguen sus pasiones?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdlx{Imagen del Jardín prometido a quienes temen a Alá: habrá en él arroyos de agua incorruptible, arroyos de leche de gusto inalterable, arroyos de vino, delicia de los bebedores, arroyos de depurada miel. Tendrán en él toda clase de frutas y perdón de su Señor. ¿Serán como quienes están en el Fuego por toda la eternidad, a los que se da de beber un agua muy caliente que les roe las entrañas?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdlxi{Hay algunos de ellos que te escuchan, pero que, apenas salidos de tu casa, dicen a quienes han recibido la Ciencia: «¿Qué es lo que acaba de decir?» Éstos son aquéllos cuyo corazón Alá ha sellado y que siguen sus pasiones.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdlxii{A quienes se dejen dirigir, Él les dirigirá aún mejor y les dará que Le teman.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdlxiii{¡,Qué pueden esperar, sino que les llegue la Hora de repente? Ya se han manifestado síntomas de la misma. Pero ¿de qué les servirá que se les amoneste cuando ella les llegue?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdlxiv{Sabe, pues, que no hay más dios que Alá y pide perdón por tu pecado, así como por los creyentes y las creyentes. Alá conoce vuestras idas y venidas y dónde moráis.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdlxv{Los creyentes dicen: «¿Por qué no se revela una sura?» Pero, cuando se revela una sura unívoca en la que se menciona el combate, ves que los enfermos de corazón te miran como mira uno a quien ronda la muerte. Más les valdría\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdlxvi{obedecer y hablar como es debido. Y, una vez tomada una decisión, lo mejor para ellos sería que fuesen sinceros con Alá.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdlxvii{Si volvéis la espalda, os exponéis a corromper en la tierra y a cortar vuestros lazos de sangre.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdlxviii{A éstos es a quienes Alá maldice, volviéndoles sordos y ciegos.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdlxix{¿Es que no meditan en el Corán ¿O es que sus corazones están cerrados con candado?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdlxx{Quienes han vuelto sobre sus pasos, después de haberse manifestado a ellos la Dirección claramente, han sido seducidos por el Demonio, pero les ha concedido una tregua.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdlxxi{Esto es así porque dicen a quienes les repugna lo que Alá ha revelado: «En algunas cosas os obedeceremos». Alá, empero, sabe lo que ocultan.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdlxxii{¡Qué pasará cuando los ángeles les llamen, golpeándoles en el rostro y en la espalda?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdlxxiii{Esto es así porque van en pos de algo que irrita a Alá y, en cambio, les repugna lo que Le satisface. Por eso, hace vanas sus obras.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdlxxiv{¿Es que creen los enfermos de corazón que Alá no va a descubrir su odio?\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdlxxv{Si quisieramos, haríamos que les vieras: es reconocerías por sus rasgos: y, ciertamente, les reconocerás por el tono de sus palabras. Alá sabe lo que hacéis.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdlxxvi{Hemos de probaros para saber quiénes de vosotros luchan y perseveran, así como para comprobar lo que se cuenta de vosotros.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdlxxvii{Los infieles que hayan desviado a otros del camino de Alá y se hayan separado del Enviado, después de habérseles manifestado claramente la Dirección, no causarán ningún daño a Alá. Y hará vanas sus obras.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdlxxviii{¡Creyentes! ¡Obedeced a Alá y obedeced al Enviado! ¡No hagáis vanas vuestras obras!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdlxxix{Alá no perdonará a los infieles que hayan desviado a otros del camino de Alá y mueran siendo infieles.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdlxxx{¡No flaqueéis, pues, invitando a la paz, ya que seréis vosotros los que ganen! Alá está con vosotros y no dejará de premiar vuestras obras.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdlxxxi{La vida de acá es sólo juego y distracción. Pero, si creéis y teméis a Alá, Él os recompensará sin reclamaros vuestros bienes.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdlxxxii{Si os los reclamara con insistencia, os mostraríais avaros y descubriría vuestro odio.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdlxxxiii{He aquí que sois vosotros los invitados a gastar por la causa de Alá, pero hay entre vosotros algunos avaros. Y quien es avaro lo es, en realidad, en detrimento propio. Alá es Quien Se basta a Sí mismo, mientras que sois vosotros los necesitados. Y, si volvéis la espalda, hará que otro pueblo os sustituya, que no será como vosotros.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdlxxxiv{\basmalahes Te hemos concedido un claro éxito.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdlxxxv{Para perdonarte Alá tus primeros y tus últimos pecados, pefeccionar Su gracia en ti y dirigirte por una vía recta.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdlxxxvi{Para prestarte Alá un auxilio poderoso.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdlxxxvii{Él es Quien ha hecho descender la sakina en los corazones de los creyentes para incrementar su fe. Las legiones de los cielos y de la tierra son de Alá. Alá es omnisciente, sabio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdlxxxviii{Para introducir a los creyentes y a las creyentes en jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, y borrarles sus malas obras. Esto es, para Alá, un éxito grandioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdlxxxix{Para castigar a los hipócritas y a las hipócritas, a los asociadores y a las asociadoras que piensan mal de Alá. Sufrirán un revés. Alá se irritará con ellos, les maldecirá y les preparará la gehena. ¡Mal fin...!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdxc{Las legiones de los cielos y de la tierra son de Alá. Alá es poderoso, sabio.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdxci{Te hemos enviado como testigo, como nuncio de buenas nuevas y como monitor,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdxcii{para que los hombres crean en Alá y en Su Enviado, para que le ayuden y honren, para que Le glorifiquen mañana y tarde.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdxciii{Los que te juran fidelidad, la juran, en realidad, a Alá. La mano de Alá está sobre sus manos. Si uno quebranta una promesa la quebranta, en realidad, en detrimento propio. Si, en cambio, es fiel a la alianza concertada con Alá, Él le dará una magnífica recompensa.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdxciv{Los beduinos dejados atrás te dirán: «Nuestros bienes y familias nos han retenido. ¡Pide que nos perdone!» Dicen de palabra lo que no tienen en el corazón. Di: «¿Y quién podría impedir que Alá os hiciera mal o bien, si Él lo deseara?» ¡No! ¡Alá está bien informado de lo que hacéis!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdxcv{¡No! Creíais que el Enviado y los creyentes no iban a regresar nunca a los suyos y la idea os halagó. Pensasteis mal... Sois gente perdida...\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdxcvi{Quien no cree en Alá y en su Enviado... Hemos preparado para los infieles fuego de gehena.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdxcvii{El dominio de los cielos y de la tierra pertenece a Alá. Perdona a quien Él quiere y castiga a quien Él quiere. Alá es indulgente, misericordioso.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdxcviii{Cuando os pongáis en marcha para apoderaros de botín, los dejados atrás dirán: «¡Dejad que os sigamos!» Quisieran cambiar la Palabra de Alá. Di: «¡No nos seguiréis! ¡Así lo ha dicho Alá antes!» Ellos dirán: «¡No! ¡Es que tenéis celos de nosotros...!» ¡No! Comprenden, pero poco.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdxcix{Di a los beduinos dejados atrás: «Se os llamará contra un pueblo dotado de gran valor, contra el que tendréis que combatir a menos que se rinda. Si obedecéis, Alá os dará una bella recompensa. Pero, si volvéis la espalda, como ya hicisteis en otra ocasión, os infligirá un castigo doloroso».\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdc{«No hay por qué reprochar al ciego, al cojo o al enfermo. Y a quien obedezca a Alá y a Su Enviado, Él le introducirá en jardines por cuyos bajos fluyen arroyos. A quien, en cambio, vuelta la espalda, Él le infligirá un castigo doloroso»:\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdci{Alá ha estado satisfecho de los creyentes cuando éstos te han jurado fidelidad al pie del árbol. Él sabía lo que sus corazones encerraban e hizo descender sobre ellos la sakina, prometiéndoles, como recompensa, un éxito cercano\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcii{y mucho botín, del que se apoderarán. Alá es poderoso, sabio.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdciii{Alá os ha prometido mucho botín, del que os apoderaréis. Os ha acelerado éste y ha retirado de vosotros las manos de la gente, a fin de que sea signo para los creyentes y de dirigiros por una vía recta.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdciv{Y otro cuyo logro no está en vuestras manos pero sí en las de Alá. Alá es omnipotente.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcv{Si los infieles hubieran combatido contra vosotros, habrían vuelto la espalda. Luego, no encontrarán amigo ni auxiliar.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcvi{Tal es la práctica de Alá, que ya se había aplicado antes. Y encontrarás la práctica de Alá irreemplazable.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcvii{Él es Quien, en el valle de La Meca, retiró de vosotros sus manos y de ellos las vuestras, luego de haberos dado la victoria sobre ellos. Alá ve bien lo que hacéis.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcviii{Son ellos los infieles que os apartaron de la Mezquita Sagrada e impidieron que la víctima llegara al lugar del sacrificio. Y, si no llega a ser por hombres creyentes y por mujeres creyentes, a quienes no podíais reconocer, y que os exponíais, sin querer, a pisotear, provocando represalias por su parte... Para que Alá introduzca en Su misericordia a quien Él quiere. Si hubiera sido posible distinguirles, habríamos infligido un doloroso castigo a los infieles que entre ellos había.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcix{Cuando, dejados llevar los infieles de su fanatismo, el fanatismo propio del paganismo, Alá hizo descender Su sakina sobre Su Enviado y sobre los creyentes, y les impuso la palabra del temor de Alá. Tenían pleno derecho a ella y la merecían. Alá es omnisciente.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcx{Alá ha realizado, ciertamente, el sueño de su Enviado: «En verdad, que habéis de entrar en la Mezquita Sagrada, si Alá quiere, en seguridad, con la cabeza afeitada y el pelo corto, sin temor». Él sabía lo que vosotros no sabíais. Además, ha dispuesto un éxito cercano.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcxi{Él es Quien ha mandado a Su Enviado con la Dirección y con la religión verdadera, para que prevalezca sobre toda otra religión. ¡Alá basta como testigo!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcxii{Mahoma es el Enviado de Alá. Quienes están con él son severos con los infieles y cariñosos entre sí. Se les ve inclinados o prosternados, buscando favor de Alá y satisfacerle. Se les nota en el rostro que se prosternan. Tal es su imagen en la Tora. Y en el Evangelio se les compara con la semilla que, habiendo germinado, fortifica su brote y éste crece y se yergue en el tallo, constituyendo la alegría del sembrador, para terminar irritando a los infieles por su medio. A quienes de ellos crean y obren bien, Alá les ha prometido perdón y una magnífica recompensa.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcxiii{\basmalahes ¡Creyentes! ¡No os adelantéis a Alá y a su Enviado y temed a Alá! Alá todo lo oye, todo lo sabe.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcxiv{¡Creyentes! ¡No elevéis vuestra voz por encima de la del Profeta! ¡No le habléis en voz alta, como hacéis entre vosotros! Os expondríais a hacer vanas vuestras obras sin daros cuenta.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcxv{Quienes en presencia del Enviado de Alá bajan la voz son aquéllos cuyos corazones ha probado Alá para disponerlos a Su temor. Obtendrán perdón y magnífica recompensa.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcxvi{La mayoría de los que te llaman desde fuera de las habitaciones privadas no tienen entendimiento.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcxvii{Más les valdría esperar a que tú salieras adonde ellos están. Alá es indulgente, misericordioso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdcxviii{¡Creyentes! Si un malvado os trae una noticia, examinadla bien, no sea que lastiméis a gente por ignorancia y tengáis que arrepentiros de lo que habéis hecho.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcxix{Sabed que está entre vosotros el Enviado de Alá. En muchos casos, si os obedeciera, os veríais en apuro. Pero Alá os ha hecho amar la fe, engalanándola a vuestros corazones. En cambio, os ha hecho aborrecer la incredulidad, el vicio y la desobediencia. Ésos son los bien dirigidos,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcxx{por favor y gracia de Alá. Alá es omnisciente, sabio.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdcxxi{Si dos grupos de creyentes combaten unos contra otros, ¡reconciliadles! Y, si uno de ellos oprime al otro, ¡combatid contra el opresor hasta reducirle a la obediencia de Alá! Y, cuando sea reducido, ¡reconciliadles de acuerdo con la justicia y sed equitativos! Alá ama a los que observan la equidad.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdcxxii{Los creyentes son, en verdad, hermanos. ¡Reconciliad, pues, a vuestos hermanos y temed a Alá! Quizás, así, se os tenga piedad.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdcxxiii{¡Creyentes! ¡No os burléis unos de otros! Podría ser que los burlados fueran mejores que los que se burlan. Ni las mujeres unas de otras. Podría ser que las burladas fueran mejores que las que se burlan. ¡No os critiquéis ni os llaméis con motes ofensivos! ¡Mala cosa es ser llamado 'perverso' después de haber recibido la fe! Los que no se arrepienten, ésos son los impíos.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdcxxiv{¡Creyentes! ¡Evitad conjeturar demasiado! Algunas conjeturas son pecado. ¡No espiéis! ¡No calumniéis! ¿Os gustaría comer la carne de un hermano muerto? Os causaría horror... ¡Temed a Alá! Alá es indulgente, misericordioso.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdcxxv{¡Hombres! Os hemos creado de un varón y de una hembra y hemos hecho de vosotros pueblos y tribus, para que os conozcáis unos a otros. Para Alá, el más noble de entre vosotros es el que más Le teme. Alá es omnisciente, está bien informado.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdcxxvi{Los beduinos dicen: «¡Creemos!» Di: «¡No creéis! ¡Decid, más bien: 'Hemos abrazado el islam'! La fe no ha entrado aún en vuestros corazones. Pero, si obedecéis a Alá y a Su Enviado, no menoscabará nada vuestras obras. Alá es indulgente, misericordioso».\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxxvii{Son creyentes únicamente los que creen en Alá y en Su Enviado, sin abrigar ninguna duda, y combaten por Alá con su hacienda y sus personas. ¡Ésos son los veraces!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxxviii{Di: «¿Vais a enseñar a Alá en qué consiste vuestra religión, siendo así que Alá conoce lo que está en los cielos y en la tierra?» Alá es omnisciente.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxxix{Te recuerdan su conversión al islam como si, con ello, te hubieran agraciado. Di: «¡No me recordéis vuestra conversión al islam como si me hubiérais agraciado! ¡Al contrario! Es Alá quien os ha agraciado dirigiéndoos hacia la fe. Si es verdad lo que decíis...»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxxx{Alá conoce lo oculto de los cielos y de la tierra. Alá ve bien lo que hacéis.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxxxi{\basmalahes q. ¡Por el glorioso Corán!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcxxxii{Pero se asombran de que uno salido de ellos haya venido a advertirles. Y dicen los infieles: «¡Esto es algo asombroso!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcxxxiii{¿Es que cuando muramos y seamos tierra...? Es volver de lejos...»\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcxxxiv{Ya sabemos qué es lo que de ellos consume la tierra. Tenemos una Escritura que conserva.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcxxxv{Pero han desmentido la Verdad cuando ha venido a ellos y se encuentran en un estado de confusión.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdcxxxvi{¿No ven el cielo que tienen encima, cómo lo hemos edificado y engalanado y no se ha agrietado?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcxxxvii{Hemos extendido la tierra, colocado en ella firmes montañas y hecho crecer en ella toda especie primorosa,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcxxxviii{como ilustración y amonestación para todo siervo arrepentido.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdcxxxix{Hemos hecho bajar del cielo agua bendita, mediante la cual hacemos que crezcan jardines y el grano de la cosecha,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdcxl{esbeltas palmeras de apretados racimos,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdcxli{para sustento de los siervos. Y, gracias a ella, devolvemos la vida a un país muerto. Así será la Resurrección.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdcxlii{Antes de ello, ya habían desmentido el pueblo de Noé, los habitantes de ar-Ras, los tamudeos,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdcxliii{los aditas, Faraón, los hermanos de Lot,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdcxliv{los habitantes de la Espesura y el pueblo de Tubba. Todos ellos desmintieron a los enviados. Y se cumplió Mi amenaza.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxlv{¿Es que Nos cansó la primera creación? Pues ellos dudan de una nueva creación.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxlvi{Sí, hemos creado al hombre. Sabemos lo que su mente le sugiere. Estamos más cerca de él que su misma vena yugular.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxlvii{Cuando los dos encargados de recoger recojan, sentados el uno a la derecha y el otro a la izquierda,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxlviii{no pronunciará ninguna palabra que no tenga siempre a su lado a un observador preparado.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxlix{La agonía del moribundo traerá la Verdad: «¡Ahí tienes lo que rehuías!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcl{Se tocará la trompeta. Ése es el día de la Amenaza.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcli{Cada uno vendrá acompañado de un conductor y de un testigo.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdclii{«Estas cosas te traían sin cuidado. Te hemos quitado el velo y, hoy, tu vista es penetrante».\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcliii{Su compañero dirá: «Esto es lo que tengo preparado».\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcliv{«¡Arrojad a la gehena a todo infiel pertinaz, desviado,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdclv{adversario del bien, violador de la ley, escéptico,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdclvi{que ponía, junto con Alá, a otro dios! ¡Arrojadlo al castigo severo!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdclvii{Su compañero dirá: «¡Señor! No soy yo quien le hizo rebelarse, sino que él estaba ya profundamente extraviado».\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdclviii{Dirá: «¡No discutáis ante Mí! Ya os amenacé por anticipado.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdclix{Mi sentencia es inmutable. Yo no soy injusto con Mis siervos».\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdclx{El día que digamos a la gehena: «¿Estás ya llena?», ella dirá: «¿Aún hay más?»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdclxi{Y el Jardín será acercado a quienes hayan temido a Alá, bien cerca:\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdclxii{«Esto es lo que se os había prometido, a todo hombre sinceramente arrepentido, observador,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdclxiii{que tiene miedo secreto al Compasivo y viene con corazón contrito.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdclxiv{¡Entrad en él en paz! ¡Éste es el día de la Eternidad!»\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdclxv{Tendrán allí cuanto deseen y aún dispondremos de más.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdclxvi{¡A cuántas generaciones hemos hecho antes perecer, más temibles que ellos y que recorrieron el país en busca de escape.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdclxvii{Hay en ello, sí, una amonestación para quien tiene entendimiento, para quien aguza el oído y es testigo.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdclxviii{Creamos los cielos, la tierra y lo que entre ellos está en seis días, sin sufrir cansancio.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdclxix{¡Ten paciencia, pues, con lo que dicen y celebra las alabanzas de tu Señor antes de la salida del sol y de su puesta!\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdclxx{¡Glorifícale durante la noche y después de la azalá!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdclxxi{¡Estate atento al día que el pregonero llame de cerca,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdclxxii{al día que se oiga, de verdad, el Grito! Ése será el día de la Resurrección.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdclxxiii{Somos Nosotros Quienes damos la vida y damos la muerte. Somos Nosotros el fin de todo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdclxxiv{El día que la tierra se abra despidiéndolos, rápidos..., Ésa es una reunión fácil para Nosotros.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdclxxv{Sabemos bien lo que dicen... ¡No debes tú forzarles! ¡Amonesta, más bien, por el Corán a quien tema Mi amenaza!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdclxxvi{\basmalahes ¡Por los que aventan!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdclxxvii{¡Por las que llevan una carga!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdclxxviii{¡Por las que se deslizan ligeras!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdclxxix{¡Por los que distribuyen una orden!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdclxxx{¡Ciertamente, aquello con que se os amenaza es verdad!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdclxxxi{Y el Juicio, sí, tendrá lugar.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdclxxxii{¡Por el cielo surcado de órbitas!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdclxxxiii{Estáis en desacuerdo.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdclxxxiv{Algunos son desviados de él.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdclxxxv{¡Malditos sean los que siempre están conjeturando,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdclxxxvi{que están en un abismo, despreocupados,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdclxxxvii{que preguntan: «¿Cuándo llegará el día del Juicio?»!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdclxxxviii{El día que se les pruebe al fuego:\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdclxxxix{«¡Gustad vuestra prueba! Esto es lo que estabais impacientes por conocer».\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdcxc{Los que temen a Alá estarán entre jardines y fuentes,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdcxci{tomando lo que su Señor les dé. Hicieron el bien en el pasado;\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcxcii{de noche dormían poco;\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcxciii{al rayar el alba, pedían perdón,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdcxciv{y parte de sus bienes correspondía de derecho al mendigo y al indigente.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcxcv{En la tierra hay signos para los convencidos,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcxcvi{y en vosotros mismos también. ¿Es que no veis?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcxcvii{Y en el cielo tenéis vuestro sustento y lo que se os ha prometido.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcxcviii{¡Por el Señor del cielo y de la tierra, que es tanta verdad como que habláis!\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcxcix{¿Te has enterado de la historia de los huéspedes honrados de Abraham?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcc{Cuando entraron en su casa. Dijeron: «¡Paz!». Dijo: «¡Paz! Sois gente desconocida».\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcci{Se fue discretamente a los suyos y trajo un ternero cebado,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdccii{que les ofreció. Dijo: «¿Es que no coméis?»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcciii{Y sintió temor de ellos. Dijeron: «¡No temas!» Y le dieron la buena nueva de un muchacho lleno de ciencia.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcciv{Su mujer, entonces, se puso a gritar. Golpeóse el rostro y dijo: «Pero ¡si soy una vieja estéril!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdccv{Dijeron: «Así ha dicho tu Señor. Es Él el Sabio, el Omnisciente».\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdccvi{Dijo: «¿Qué es lo que os trae, ¡enviados!?»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdccvii{Dijeron: «Se nos ha enviado a un pueblo pecador\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdccviii{para enviar contra ellos piedras de barro cocido,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdccix{marcadas junto a tu Señor para los inmoderados».\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdccx{Y sacamos a los creyentes que en ella había,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdccxi{pero sólo encontramos en ella una casa de gente sometida a Alá.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdccxii{Y dejamos en ella un signo para los que temen el castigo doloroso.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdccxiii{Y en Moisés. Cuando le enviamos a Faraón con una autoridad manifiesta.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdccxiv{Pero, seguro de su poder, se volvió y dijo: «¡Es un mago o un poseso!»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdccxv{Entonces les sorprendimos, a él y a sus tropas, y los arrojamos al mar. Había incurrido en censura.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdccxvi{Y en los aditas. Cuando enviamos contra ellos el viento desvastador,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdccxvii{que pulverizaba todo cuanto encontraba a su paso.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdccxviii{Y en los tamudeos. Cuando se les dijo: «¡Gozad aún por algún tiempo!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdccxix{Pero infringieron la orden de su Señor y les sorprendió el Rayo, viéndolo venir.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdccxx{No pudieron tenerse en pie, ni defenderse.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdccxxi{Y al pueblo de Noé. Fue un pueblo perverso.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdccxxii{Y el cielo, lo construimos con fuerza. Y, ciertamente, asignamos un vasto espacio.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdccxxiii{Y la tierra, la extendimos. ¡Qué bien que la preparamos!\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdccxxiv{Todo lo creamos por parejas. Quizás, así, os dejéis amonestar.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdccxxv{«¡Refugiaos, pues, en Alá! Soy para vosotros, de Su parte, un monitor que habla claro.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdccxxvi{¡No pongáis a otro dios junto con Alá! Soy para vosotros, de Su parte, un monitor que habla claro».\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdccxxvii{Asimismo, no vino a los que fueron antes ningún enviado que no dijeran: «¡Es un mago o un poseso!»\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdccxxviii{¿Es que se han legado eso unos a otros? ¡No! ¡Son gente rebelde!\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmdccxxix{¡Apártate de ellos y, así, no incurrirás en censura!\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmdccxxx{¡Y amonesta, que la amonestación aprovecha a los creyentes!\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmdccxxxi{No he creado a los genios y a los hombres sino para que Me sirvan.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmdccxxxii{No quiero de ellos ningún sustento, no quiero que Me alimenten.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmdccxxxiii{Alá es el Proveedor de todo, el Fuerte, el Firme.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmdccxxxiv{Los impíos correrán la misma suerte que corrieron sus semejantes. ¡Que no Me den, pues, prisa!\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmdccxxxv{¡Ay de los que no creen, por el día con que se les amenaza!\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmdccxxxvi{\basmalahes ¡Por el Monte!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdccxxxvii{¡Por una Escritura, puesta por escrito\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdccxxxviii{en un pergamino desenrollado!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdccxxxix{¡Por la Casa frecuentada!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdccxl{¡Por la bóveda elevada!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccxli{¡Por el mar hinchado!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdccxlii{¡Sí, el castigo de tu Señor tendrá lugar,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdccxliii{nadie podrá rechazarlo!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccxliv{El día que el cielo gire vertiginosamente\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccxlv{y se pongan las montañas en marcha.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccxlvi{Ese día ¡ay de los desmentidores,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccxlvii{que parloteaban por pasar el rato!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccxlviii{El día que se les empuje, violentamente, al fuego de la gehena:\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccxlix{«¡Éste es el fuego que desmentíais!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccl{¿Es, pues, esto magia? ¿O es que no veis claro?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccli{¡Arded en él! Debe daros lo mismo que lo aguantéis o no. Sólo se os retribuye por vuestras obras».\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdcclii{Quienes temieron a Alá, en cambio, estarán en jardines y delicia,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdccliii{disfrutando de lo que su Señor les dé. Su Señor les habrá preservado del castigo del fuego de la gehena.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccliv{«¡Comed y bebed en paz! ¡Por lo que habéis hecho!»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdcclv{Reclinados en lechos alineados. Y les daremos por esposas a huríes de grandes ojos.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcclvi{Reuniremos con los creyentes a los descendientes que les siguieron en la fe. No les menoscabaremos nada sus obras. Cada uno será responsable de lo que haya cometido.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcclvii{Les proveeremos de la fruta y de la carne que apetezcan.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcclviii{Allí se pasarán unos a otros una copa cuyo contenido no incitará a vaniloquio ni a pecado.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcclix{Para servirles, circularán a su alrededor muchachos como perlas ocultas.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcclx{Y se volverán unos a otros para preguntarse.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcclxi{Dirán: «Antes vivíamos angustiados en medio de nuestra familia.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcclxii{Alá nos agració y preservó del castigo del viento abrasador.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcclxiii{Ya Le invocábamos antes. Es el Bueno, el Misericordioso».\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcclxiv{¡Amonesta, pues, porque, por la gracia de tu Señor, no eres adivino ni poseso!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcclxv{O dicen: «¡Un poeta...! ¡Esperaremos las vicisitudes de su sino!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdcclxvi{Di: «¡Esperad! Yo espero con vosotros».\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdcclxvii{¿Se les ordena en sueños que hablen así o es que son gente rebelde?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdcclxviii{O dicen: «¡Él se lo ha inventado!» ¡No, no creen!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdcclxix{Si es verdad lo que dicen, ¡que traigan un relato semejante!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdcclxx{¿Han sido creados de la nada? ¿O son ellos los creadores?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdcclxxi{¿O han creado los cielos y la tierra? No, no están convencidos.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdcclxxii{¿O tienen los tesoros de tu Señor? ¿O se creen unos potentados?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdcclxxiii{¿O tienen una escala que les permita escuchar? El que de ellos lo consiga ¡que aporte una autoridad manifesta!\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdcclxxiv{¿O tendrá Él hijas, como vosotros tenéis hijos?\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdcclxxv{¿O es que les reclamas un salario tal que se vean abrumados de deudas?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdcclxxvi{¿O es que conocen lo oculto y toman nota?\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdcclxxvii{¿O quieren urdir una estratagema? Los infieles serían sus víctimas.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdcclxxviii{¿O tienen un dios diferente de Alá? ¡Gloria a Alá, Que está por encima de lo que Le asocian!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcclxxix{Si vieran caer parte del cielo, dirían: «Son nubes que se han amontonado».\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcclxxx{Déjales hasta que les llegue su día, cuando sean fulminados,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxi{el día de su estratagema no les sirva de nada y nadie les auxilie.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxii{Los impíos sufrirán, además, otro castigo, pero la mayoría no saben.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxiii{¡Espera paciente la decisión de tu, Señor, pues te vemos! Y ¡celebra las alabanzas de tu Señor cuando estás de pie!\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxiv{¡Glorifícale durante la noche y al declinar las estrellas!\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxv{\basmalahes ¡Por la estrella, cuando declina!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxvi{Vuestro paisano no se extravía, ni se descarría.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxvii{No habla por propio impulso.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxviii{No es sino una revelación que se ha hecho.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcclxxxix{Se la ha enseñado el muy poderoso,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccxc{fuerte, majestuoso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdccxci{mientras él estaba en lo más alto del horizonte.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdccxcii{Luego, se acercó y quedó suspendido en el aire,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccxciii{estaba a dos medidas de arco o menos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccxciv{Reveló a Su siervo lo que reveló.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccxcv{No ha mentido el corazón en lo que vio.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccxcvi{¿Disputaréis, pues, con él sobre lo que ve?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccxcvii{Ya le había visto descender en otra ocasión,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccxcviii{junto al azufaifo del confín,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccxcix{junto al cual se encuentra el jardín de la Morada,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccc{cuando el azufaifo estaba cubierto por aquello.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdccci{No se desvió la mirada. Y no erró.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdcccii{Vio, ciertamente, parte de los signos tan grandes de su Señor.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccciii{Y ¿qué os parecen al-Lat, al-Uzza\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdccciv{y la otra, Manat, la tercera?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdcccv{¿Para vosotros los varones y para Él las hembras?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdcccvi{Sería un reparto injusto.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdcccvii{No son sino nombres que habéis puesto, vosotros y vuestros padres, a los que Alá no ha conferido ninguna autoridad. No siguen sino conjeturas y la concupiscencia de sus almas, siendo así que ya les ha venido de su Señor la Dirección.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdcccviii{¿Obtendrá el hombre lo que desea?\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdcccix{Pero la otra vida y esta vida pertenecen a Alá.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdcccx{¡Cuántos ángeles hay en los cielos, cuya intercesión no servirá de nada, a menos que antes dé Alá permiso a quien Él quiera, a quien Le plazca!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdcccxi{Quienes no creen en la otra vida ponen, sí, a los ángeles nombres femeninos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdcccxii{No tienen ningún conocimiento de ello. No siguen más que conjeturas, y éstas, frente a la Verdad, no sirven de nada.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdcccxiii{Apártate de quien vuelve la espalda a Nuestra Amonestación y no desea sino la vida de acá.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdcccxiv{Ésa es toda la ciencia que pueden alcanzar. Alá conoce bien a quien se extravía de Su camino y conoce bien a quien sigue la buena dirección.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdcccxv{De Alá es lo que está en los cielos y en la tierra, para retribuir a los que obren mal por lo que hagan y retribuir a los que obren bien dándoles lo mejor.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdcccxvi{Quienes evitan los pecados graves y las deshonestidades y sólo cometen pecados leves... Tu Señor es inmensamente indulgente. Os conocía bien cuando os creaba de la tierra y cuando erais un embrión en el seno de vuestra madre. ¡No os jactéis, pues, de puros! Él conoce bien a los que Le temen.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdcccxvii{Y, ¿qué te parece el que vuelve la espalda?\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdcccxviii{Da poco, es mezquino.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdcccxix{¿Tiene la ciencia de lo oculto, que le permita ver?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdcccxx{¿No se le ha informado del contenido de las Hojas de Moisés\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdcccxxi{y de Abraham, que cumplió:\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdcccxxii{que nadie cargará con la carga ajena,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdcccxxiii{que el hombre sólo será sancionado con arreglo a su propio esfuerzo,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdcccxxiv{que se verá el resultado de su esfuerzo,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdcccxxv{que será, luego, retribuido generosamente,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdcccxxvi{que el fin de todo es tu Señor,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdcccxxvii{que es Él Quien hace reír y hace llorar,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcccxxviii{que es Él Quien da la muerte y da la vida,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcccxxix{que Él crea la pareja, varón y hembra,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcccxxx{de una gota cuando es eyaculada,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxi{que a Él incumbe la otra creación,\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxii{que es Él Quien da riquezas y posesiones,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxiii{que es Él el Señor de Sirio,\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxiv{que Él hizo perecer a los antiguos aditas\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxv{y a los tamudeos, sin dejar uno solo con vida,\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxvi{y, antes, al pueblo de Noé, que fue tan impío y rebelde,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxvii{y aniquiló a la vuelta de arriba abajo.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxviii{cubriéndola como la cubrió?\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmdcccxxxix{¿Cuál, pues, de los beneficios de tu Señor pondrás en duda?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmdcccxl{Ésta es una advertencia al estilo de las advertencias antiguas.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmdcccxli{Amenaza la Inminente.\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmdcccxlii{Nadie, fuera de Alá, puede quitarla.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmdcccxliii{¿Os asombráis, pues, de este discurso?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmdcccxliv{¿Y reís, en lugar de llorar,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmdcccxlv{permaneciendo indiferentes?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmdcccxlvi{¡Prosternaos, pues, ante Alá y servidle!\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmdcccxlvii{\basmalahes Se acerca la Hora, se hiende la luna.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmdcccxlviii{Si ven un signo, se apartan y dicen: «¡Es una magia continua!»\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmdcccxlix{Desmienten y siguen sus pasiones. Pero todo está decretado.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmdcccl{Ya han recibido noticias disuasivas,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmdcccli{consumada sabiduría. Pero las advertencias no sirven.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmdccclii{¡Apártate, pues, de ellos! El día que el Pregonero les convoque para algo horrible,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmdcccliii{abatida la mirada, saldrán de las sepulturas como si fueran langostas esparcidas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmdcccliv{corriendo con el cuello extendido hacia el Pregonero. Dirán los infieles: «¡Éste es un día difícil!»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmdccclv{Antes de ello, ya el pueblo de Noé había desmentido. Desmintieron a Nuestro siervo y dijeron: «¡Un poseso!», y fue rechazado.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmdccclvi{Entonces, invocó a su Señor. «¡Estoy vencido! ¡Defiéndete!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmdccclvii{Abrimos las puertas del cielo a una lluvia torrencial\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmdccclviii{y en la tierra hicimos manar fuentes. Y el agua se encontró según una orden decretada.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmdccclix{Le embarcamos en aquello de planchas y de fibras,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmdccclx{que navegó bajo Nuestra mirada como retribución de aquél que había sido negado.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmdccclxi{La dejamos como signo. Pero ¿hay alguien que se deje amonestar?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmdccclxii{Y ¡cuáles no fueron Mi castigo y Mis advertencias!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmdccclxiii{Hemos facilitado el Corán para que pueda servir de amonestación. Pero ¿hay alguien que se deje amonestar?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmdccclxiv{Los aditas desmintieron y ¡cuáles no fueron Mi castigo y Mis advertencias!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmdccclxv{En un día nefasto e interminable enviamos contra ellos un viento glacial,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmdccclxvi{que arrancaba a los hombres como si hubieran sido troncos de palmeras descuajadas.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmdccclxvii{Y ¡cuáles no fueron Mi castigo y Mis advertencias!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmdccclxviii{Hemos facilitado el Corán para que pueda servir de amonestación. Pero ¿hay alguien que se deje amonestar?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmdccclxix{Los tamudeos desmintieron las advertencias\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmdccclxx{y dijeron: «¿Vamos a seguir a un solo mortal, salido de nosotros? ¡Estaríamos extraviados y deliraríamos!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmdccclxxi{¿A él, entre nosotros, se le iba a confiar la Amonestación? ¡No, sino que es un mentiroso, un insolente!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmdccclxxii{¡Mañana verán quién es el mentiroso, el insolente!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmdccclxxiii{Vamos a enviarles la camella para tentarles. ¡Obsérvales y ten paciencia!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmdccclxxiv{Infórmales de que el agua debe repartirse entre ellos y de que beberán por turno.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmdccclxxv{Llamaron a su paisano, que se hizo cargo y desjarretó.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmdccclxxvi{Y ¡cuáles no fueron Mi castigo y Mis advertencias!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmdccclxxvii{Les lanzamos un solo Grito y fueron como hierba seca que se emplea para levantar una cerca.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmdccclxxviii{Hemos facilitado el Corán para que pueda servir de amonestación. Pero ¿hay alguien que se deje amonestar?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmdccclxxix{El pueblo de Lot desmintió las advertencias.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmdccclxxx{Enviamos contra ellos una tempestad de arena. Exceptuamos a la familia de Lot, a la que salvamos al rayar el alba,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxi{en virtud de una gracia venida de Nosotros. Así retribuimos al agradecido.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxii{Les había prevenido contra Nuestro rigor, pero pusieron en duda las advertencias.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxiii{Le exigieron a sus huéspedes y les apagamos los ojos. «¡Gustad Mi castigo y Mis advertencias!»\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxiv{A la mañana siguiente, temprano, les sorprendió un castigo duradero.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxv{«¡Gustad Mi castigo y Mis advertencias!»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxvi{Hemos facilitado el Corán para que pueda servir de amonestación. Pero ¿hay alguien que se deje amonestar?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxvii{Y, ciertamente, la gente de Faraón fue advertida.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxviii{Desmintieron todos Nuestros signos y les sorprendimos como sorprende Uno poderoso, potísimo.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmdccclxxxix{¿Son vuestros infieles mejores que aquéllos? ¿O hay en las Escrituras algo que os inmunice?\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmdcccxc{¿O dicen: «Somos un conjunto capaz de defenderse»?\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmdcccxci{Todos serán derrotados y huirán.\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmdcccxcii{Pero la Hora es el tiempo que se les ha fijado y la Hora es crudelísima, amarguísima.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmdcccxciii{Los pecadores están extraviados y deliran.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmdcccxciv{El día que sean arrastrados boca abajo al Fuego: «¡Gustad el contacto del saqar !»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmdcccxcv{Todo lo hemos creado con medida.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmdcccxcvi{Nuestra orden no consiste sino en una sola palabra, como un abrir y cerrar de ojos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmdcccxcvii{Hemos hecho perecer a vuestros semejantes. Pero ¿hay alguien que se deje amonestar?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmdcccxcviii{Todo lo que han hecho consta en las Escrituras.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmdcccxcix{Todo, grande o pequeño, está con signado.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcm{Los temerosos de Alá estarán entre jardines y arroyos,\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcmi{en una sede buena, junto a un potísimo Monarca.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcmii{\basmalahes El Compasivo\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcmiii{ha enseñado el Corán.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcmiv{Ha creado al hombre,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcmv{le ha enseñado a explicar.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcmvi{El sol y la luna, para cómputo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcmvii{Las hierbas y los árboles se prosternan.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcmviii{Ha elevado el cielo. Ha establecido la balanza\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcmix{para que no faltéis al peso,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcmx{sino que deis la pesada equitativa, sin defraudar en el peso.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcmxi{La tierra la ha puesto al servicio de las criaturas.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcmxii{Hay en ella fruta y palmeras de fruto recubierto,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcmxiii{grano de vaina, plantas aromáticas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcmxiv{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcmxv{Creó al hombre de arcilla, como la cerámica;\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcmxvi{y creó a los genios de fuego puro.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcmxvii{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcmxviii{Señor de los dos Orientes y Señor de los dos Occidentes.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcmxix{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcmxx{Ha dejado fluir las dos grandes masas de agua, que se encuentran.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcmxxi{pero las separa una barrera que no rebasan.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmcmxxii{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmcmxxiii{De ambas provienen la perla y el coral.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmcmxxiv{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmcmxxv{Suyas son las embarcaciones, que sobresalen en el mar como mojones.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmcmxxvi{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmcmxxvii{Todo aquél que está sobre ella es perecedero.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmcmxxviii{Pero subsiste tu Señor, el Majestuoso y Honorable\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmcmxxix{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmcmxxx{Los que están en los cielos y en la tierra Le imploran. Siempre está ocupado en algo.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmcmxxxi{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmcmxxxii{Nos ocuparemos detenidamente de vosotros, dos cargas.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmcmxxxiii{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmcmxxxiv{¡Compañía de genios y de hombres! ¡Atravesad, si podéis, las regiones celestiales y terrestres! Pero no podréis atravesarlas sin ayuda de una autoridad...\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmcmxxxv{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmcmxxxvi{Serán lanzadas contra vosotros llamaradas de fuego sin humo y de bronce fundido, y no podréis defenderos.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmcmxxxvii{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmcmxxxviii{Cuando el cielo se hienda y se tiña de rojo coriáceo,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmcmxxxix{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmcmxl{ese día, ni los hombres ni los genios serán interrogados acerca de su pecado.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmcmxli{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmcmxlii{Los pecadores serán reconocidos por sus rasgos y se les cogerá por el copete y por los pies.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmcmxliii{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmcmxliv{¡Ésa es la gehena que los pecadores desmentían!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmcmxlv{No pararán de ir y venir entre ella y el agua muy caliente.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmcmxlvi{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmcmxlvii{Para quien, en cambio, haya temido comparecer ante su Señor. habrá dos jardines\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmcmxlviii{-¿cuál. pues, de los beneficios de vuestro Señor negaréis?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmcmxlix{frondosos,\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmcml{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmcmli{con dos fuentes manando.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmcmlii{-¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmcmliii{En ellos habrá dos especies de cada fruta.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmcmliv{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmcmlv{Estarán reclinados en alfombras forradas de brocado. Tendrán a su alcance la fruta de los dos jardines.\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmcmlvi{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmcmlvii{Estarán en ellos las de recatado mirar, no tocadas hasta entonces por hombre ni genio,\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmcmlviii{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmcmlix{cual jacinto y coral.\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmcmlx{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmcmlxi{La retribución del bien obrar ¿es otra que el mismo bien obrar?\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmcmlxii{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmcmlxiii{Además de esos dos, habrá otros dos jardines,\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmcmlxiv{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?-\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmcmlxv{verdinegros,\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmcmlxvi{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?-\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmcmlxvii{con dos fuentes abundantes.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmcmlxviii{-¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmcmlxix{En ambos habrá fruta, palmeras y granados,\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmcmlxx{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmcmlxxi{en ellos habrá buenas, bellas,\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmcmlxxii{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmcmlxxiii{huríes, retiradas en los pabellones,\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmcmlxxiv{-¿cuál, pues, de los beneficios de vuestro Señor negaréis?-\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmcmlxxv{no tocadas hasta entonces por hombre ni genio.\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmcmlxxvi{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmcmlxxvii{Reclinados en cojines verdes y bellas alfombras.\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmcmlxxviii{¿Cuál, pues, de los beneficios de vuestro Señor negaréis?\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmcmlxxix{¡Bendito sea el nombre de tu Señor, el Majestuoso y Honorable!\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmcmlxxx{\basmalahes Cuando suceda el Acontecimiento,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxi{nadie podrá negarlo.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxii{¡Abatirá, exaltará!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxiii{Cuando la tierra sufra una violenta sacudida\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxiv{y las montañas sean totalmente desmenuzadas,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxv{convirtiéndose en fino polvo disperso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxvi{y seáis divididos en tres grupos...\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxvii{Los de la derecha -¿qué son los de la derecha?-\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxviii{los de la izquierda -¿qué son los de la izquierda?-\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmcmlxxxix{y los más distinguidos, que son los más distinguidos.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmcmxc{Éstos son los allegados,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmcmxci{en los jardines de la Delicia.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmcmxcii{Habrá muchos de los primeros\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmcmxciii{y pocos de los últimos.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmcmxciv{En lechos entretejidos de oro y piedras preciosas,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmcmxcv{reclinados en ellos, unos enfrente de otros.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmcmxcvi{Circularán entre ellos jóvenes criados de eterna juventud\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmcmxcvii{con cálices. jarros y una copa de agua viva,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmcmxcviii{que no les dará dolor de cabeza ni embriagará,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmcmxcix{con fruta que ellos escogerán,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmm{con la carne de ave que les apetezca.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmi{Habrá huríes de grandes ojos,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmii{semejantes a perlas ocultas,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmiii{como retribución a sus obras.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmiv{No oirán allí vaniloquio ni incitación al pecado,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmv{sino una palabra: «¡Paz! ¡Paz!»\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmvi{Los de la derecha -¿qué son los de la derecha-\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmvii{estarán entre azufaifos sin espinas\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmviii{y liños de acacias,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmix{en una extensa sombra,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmx{cerca de agua corriente\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmxi{y abundante fruta,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmxii{inagotable y permitida,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmxiii{en lechos elevados.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmxiv{Nosotros las hemos formado de manera especial\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmxv{y hecho vírgenes,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmxvi{afectuosas, de una misma edad,\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmxvii{para los de la derecha.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmxviii{Habrá muchos de los primeros\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmxix{y muchos de los últimos.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmxx{Los de la izquierda -¿qué son los de la izquierda?-\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmxxi{estarán expuestos a un viento abrasador, en agua muy caliente,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmxxii{a la sombra de un humo negro,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmxxiii{ni fresca ni agradable.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmxxiv{Antes, estuvieron rodeados de lujo,\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmxxv{sin salir del enorme pecado.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmxxvi{Decían: «Cuando muramos y seamos tierra y huesos, ¿se nos resucitará acaso?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmxxvii{¿Y también a nuestros antepasados?»\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmxxviii{Di: «¡En verdad, los primeros y los últimos\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmxxix{serán reunidos en el momento fijado de un día determinado!»\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmxxx{Luego, vosotros, extraviados, desmentidores,\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmxxxi{comeréis, sí, de un árbol, del Zaqqum,\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmxxxii{de cuyos frutos llenaréis el vientre.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmmxxxiii{Y, además, beberéis agua muy caliente,\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmmxxxiv{sedientos como camellos que mueren de sed...,\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmmxxxv{Ese será su alojamiento el día del Juicio.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmmxxxvi{Nosotros os creamos. ¿Por qué, pues, no aceptáis?\qt@no{57}}
\qt@newcmd\qurantrans@es@mmmmmxxxvii{Y ¿qué os parece el semen que eyaculáis?\qt@no{58}}
\qt@newcmd\qurantrans@es@mmmmmxxxviii{¿Lo creáis vosotros o somos Nosotros los creadores?\qt@no{59}}
\qt@newcmd\qurantrans@es@mmmmmxxxix{Nosotros hemos determinado que muráis y nadie podrá escapársenos,\qt@no{60}}
\qt@newcmd\qurantrans@es@mmmmmxl{para que otros seres semejantes os sucedan y haceros renacer a un estado que no conocéis.\qt@no{61}}
\qt@newcmd\qurantrans@es@mmmmmxli{Ya habéis conocido una primera creación. ¿Por qué, pues, no os dejáis amonestar?\qt@no{62}}
\qt@newcmd\qurantrans@es@mmmmmxlii{Y ¿qué os parece vuestra siembra?\qt@no{63}}
\qt@newcmd\qurantrans@es@mmmmmxliii{¿La sembráis vosotros o somos Nosotros los sembradores?\qt@no{64}}
\qt@newcmd\qurantrans@es@mmmmmxliv{Si quisiéramos, de vuestro campo haríamos paja seca e iríais lamentándoos:\qt@no{65}}
\qt@newcmd\qurantrans@es@mmmmmxlv{«Estamos abrumados de deudas.\qt@no{66}}
\qt@newcmd\qurantrans@es@mmmmmxlvi{más aún, se nos ha despojado».\qt@no{67}}
\qt@newcmd\qurantrans@es@mmmmmxlvii{Y ¿qué os parece el agua que bebéis?\qt@no{68}}
\qt@newcmd\qurantrans@es@mmmmmxlviii{¿La hacéis bajar de las nubes vosotros o somos Nosotros Quienes la hacen bajar?\qt@no{69}}
\qt@newcmd\qurantrans@es@mmmmmxlix{Si hubiéramos querido, la habríamos hecho salobre. ¿Por qué, pues, no dais las gracias?\qt@no{70}}
\qt@newcmd\qurantrans@es@mmmmml{Y ¿qué os parece el fuego que encendéis?\qt@no{71}}
\qt@newcmd\qurantrans@es@mmmmmli{¿Habéis hecho crecer vosotros el árbol que lo alimenta o somos Nosotros Quienes lo han hecho crecer?\qt@no{72}}
\qt@newcmd\qurantrans@es@mmmmmlii{Nosotros hemos hecho eso como recuerdo y utilidad para los habitantes del desierto.\qt@no{73}}
\qt@newcmd\qurantrans@es@mmmmmliii{¡Glorifica, pues, el nombre de tu Señor, el Grandioso!\qt@no{74}}
\qt@newcmd\qurantrans@es@mmmmmliv{¡Pues no! ¡Juro por el ocaso de las estrellas!\qt@no{75}}
\qt@newcmd\qurantrans@es@mmmmmlv{Juramento en verdad-si supierais...-solemne).\qt@no{76}}
\qt@newcmd\qurantrans@es@mmmmmlvi{¡Es, en verdad, un Corán noble,\qt@no{77}}
\qt@newcmd\qurantrans@es@mmmmmlvii{contenido en una Escritura escondida\qt@no{78}}
\qt@newcmd\qurantrans@es@mmmmmlviii{que sólo los purificados tocan,\qt@no{79}}
\qt@newcmd\qurantrans@es@mmmmmlix{una revelación que procede del Señor del universo!\qt@no{80}}
\qt@newcmd\qurantrans@es@mmmmmlx{¡Tenéis en poco este discurso\qt@no{81}}
\qt@newcmd\qurantrans@es@mmmmmlxi{y hacéis de vuestra desmentida vuestro sustento?\qt@no{82}}
\qt@newcmd\qurantrans@es@mmmmmlxii{¿Por qué, pues, cuando se sube a la garganta,\qt@no{83}}
\qt@newcmd\qurantrans@es@mmmmmlxiii{viéndolo vosotros,\qt@no{84}}
\qt@newcmd\qurantrans@es@mmmmmlxiv{-y Nosotros estamos más cerca que vosotros de él, pero no percibís-,\qt@no{85}}
\qt@newcmd\qurantrans@es@mmmmmlxv{por qué, pues, si no vais a ser juzgados\qt@no{86}}
\qt@newcmd\qurantrans@es@mmmmmlxvi{y es verdad lo que decís, no la hacéis volver?\qt@no{87}}
\qt@newcmd\qurantrans@es@mmmmmlxvii{Si figura entre los allegados,\qt@no{88}}
\qt@newcmd\qurantrans@es@mmmmmlxviii{tendrá reposo, plantas aromáticas y jardín de delicia.\qt@no{89}}
\qt@newcmd\qurantrans@es@mmmmmlxix{Si es de los de la derecha:\qt@no{90}}
\qt@newcmd\qurantrans@es@mmmmmlxx{«¡Paz a ti, que eres de los de la derecha!»\qt@no{91}}
\qt@newcmd\qurantrans@es@mmmmmlxxi{Pero, si es de los extraviados desmentidores,\qt@no{92}}
\qt@newcmd\qurantrans@es@mmmmmlxxii{será alojado en agua muy caliente\qt@no{93}}
\qt@newcmd\qurantrans@es@mmmmmlxxiii{y arderá en fuego de gehena.\qt@no{94}}
\qt@newcmd\qurantrans@es@mmmmmlxxiv{¡Esto es algo, sí, absolutamente cierto!\qt@no{95}}
\qt@newcmd\qurantrans@es@mmmmmlxxv{¡Glorifica, pues, el nombre de tu Señor, el Grandioso!\qt@no{96}}
\qt@newcmd\qurantrans@es@mmmmmlxxvi{\basmalahes Lo que está en los cielos y en la tierra glorifica a Alá. Él es el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmlxxvii{Suyo es el dominio de los cielos y de la tierra. Él da la vida y da la muerte. Y es omnipotente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmlxxviii{Él es el Principio y el Fin, el Visible y el Escondido. Y es omnisciente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmlxxix{Él es Quien creó los cielos y la tierra en seis días. Luego, se instaló en el Trono. Sabe lo que penetra en la tierra y lo que de ella sale, lo que desciende del cielo y lo que a él asciende. Está con vosotros dondequiera que os encontréis. Alá ve bien lo que hacéis.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmlxxx{Suyo es el dominio de los cielos y de la tierra. ¡Y todo será devuelto a Alá!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmlxxxi{Hace que la noche entre en el día y que el día entre en la noche. Y Él sabe bien lo que encierran los pechos.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmlxxxii{¡Creed en Alá y en Su Enviado! Dad limosna de los bienes de los que Él os ha hecho últimos poseedores. Aquéllos de vosotros que hayan creído y dado limosna tendrán una gran recompensa.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmlxxxiii{Y ¿por qué no habéis de creer en Alá, siendo así que el Enviado os invita a creer en vuestro Señor y que ha concertado un pacto con vosotros? Si es que sois creyentes...\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmlxxxiv{Él es Quien revela a Su siervo signos claros para sacaros de las tinieblas a la luz. En verdad, Alá es manso, misericordioso con vosotros.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmlxxxv{Y ¿por qué no habéis de gastar por la causa de Alá, siendo así que la herencia de los cielos y de la tierra pertenece a Alá? No seréis todos iguales: unos, que han gastado y combatido antes del Éxito, tendrán una categoría más elevada que otros que han gastado y combatido después de ella. A todos, sin embargo, ha prometido Alá lo mejor. Alá está bien informado de lo que hacéis.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmlxxxvi{A quien haga a Alá un préstamo generoso, Él le devolverá el doble y le recompensará generosamente.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmlxxxvii{El día que veas la luz de los creyentes y de las creyentes correr ante ellos y a su derecha: «¡Buena nueva hoy para vosotros: jardines por cuyos bajos fluyen arroyos, en los que estaréis por toda la eternidad! ¡Ése es el éxito grandioso!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmlxxxviii{El día que los hipócritas y las hipócritas digan a los que creyeron: «¡Esperad a que tomemos de vuestra luz!» Se dirá: «¡Retroceded! ¡Buscad una luz!» Entre ellos se levantará una muralla con una puerta. Dentro estará la Misericordia y fuera, enfrente, el Castigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmlxxxix{Les llamarán: «¿No estábamos con vosotros?» Dirán: «¡Claro que sí! Pero os dejasteis seducir, os mantuvisteis a la expectativa, dudasteis. Vuestros anhelos os engañaron hasta que vino la orden de Alá. El Engañador os engañó acerca de Alá.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmxc{Hoy no se aceptará ningún rescate por parte vuestra ni por parte de los que no creyeron. Vuestra morada será el Fuego, que es vuestro lugar apropiado». ¡Qué mal fin...!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmxci{¿No es hora ya de que se humillen los corazones de los creyentes ante la Amonestación de Alá y ante la Verdad revelada y de que no sean como quienes, habiendo recibido antes la Escritura, dejaron pasar tanto tiempo que se endureció su corazón? Muchos de ellos eran unos perversos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmxcii{¡Sabed que Alá vivifica la tierra después de muerta. Os hemos explicado las aleyas. Quizás, así, comprendáis.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmxciii{A quienes den limosna, ellos y ellas, haciendo un préstamo generoso a Alá, les devolverá el doble y les recompensará generosamente.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmxciv{Los que crean en Alá y en Sus enviados serán los veraces y los testigos ante su Señor. Recibirán su recompensa y su luz. Pero quienes no crean y desmientan Nuestros signos morarán en el fuego de la gehena.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmxcv{¡Sabed que la vida de acá es juego, distracción y ornato, revalidad en jactancia, afán de más hacienda, de más hijos! Es como un chaparrón: la vegetación resultante alegra a los sembradores, pero luego se marchita y ves que amarillea; luego, se convierte en paja seca. En la otra vida habrá castigo severo o perdón y satisfacción de Alá, mientras que la vida de acá no es más que falaz disfrute.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmxcvi{¡Rivalizad en la obtención del perdón de vuestro Señor y de un Jardín tan vasto como el cielo y la tierra, preparado para los que creen en Alá y en Sus enviados! Ese es el favor de Alá, que da a quien Él quiere. Alá es el Dueño del favor in menso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmxcvii{No ocurre ninguna desgracia, ni a la tierra ni a vosotros mismos, que no esté en una Escritura antes de que la ocasionemos. Es cosa fácil para Alá.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmxcviii{Para que no desesperéis si no conseguís algo y para que no os regocijéis si lo conseguís. Alá no ama a nadie que sea presumido, jactancioso,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmxcix{a los avaros que ordenan avaricia a los hombres. Pero quien vuelve la espalda..., Alá es Quien Se basta a Sí mismo, el Digno de Alabanza.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmc{Ya hemos mandado a nuestros enviados con las pruebas claras. Y hemos hecho descender con ellos la Escritura y la Balanza, para que los hombres observen la equidad. Hemos hecho descender el hierro, que encierra una gran fuerza y ventajas para los hombres. A fin de que Alá sepa quiénes les auxilian en secreto, a Él y a Sus enviados. Alá es fuerte poderoso.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmci{Ya hemos enviado a Noé y a Abraham y confiado a su descendencia el profetismo y la Escritura. Entre sus descendientes los hubo bien dirigidos, pero muchos de ellos fueron unos perversos.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcii{Tras ellos, mandamos a Nuestros otros enviados, así como Jesús, hijo de María, a quien dimos el Evangelio. Pusimos en los corazones de quienes le siguieron mansedumbre, misericordia y monacato. Este último fue instaurado por ellos -no se lo prescribimos Nosotros- sólo por deseo de satisfacer a Alá, pero no lo observaron como debían. Remuneramos a quienes de ellos creyeron, pero muchos de ellos fueron unos perversos.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmciii{¡Creyentes! ¡Temed a Alá y creed en Su Enviado! Os dará, así, participación doble en Su misericordia, os pondrá una Luz que ilumine vuestra marcha y os perdonará. Alá es indulgente, misericordioso.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmciv{¡Que la gente de la Escritura sepa que no puede disponer nada del favor de Alá, que el favor está en la mano de Alá, que da a quien Él quiere! ¡Alá es el Dueño del favor inmenso!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcv{\basmalahes Alá ha oído lo que decía la que discutía contigo a propósito de su esposo y que se quejaba a Alá. Alá oye vuestro diálogo. Alá todo lo oye, todo lo ve.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcvi{Aquéllos de vosotros que repudian a sus mujeres mediante la fórmula: «¡Eres para mí como la espalda de mi madre!»... Ellas no son sus madres. Sólo son sus madres las que les han dado a luz. Dicen, ciertamente, algo reprobable y erróneo. Pero Alá es, sí, perdonador, indulgente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcvii{Quienes repudian a sus mujeres mediante la fórmula: «¡Eres para mí como la espalda de mi madre!» y la repiten, deben, antes de cohabitar de nuevo, manumitir a un esclavo. Se os exhorta a ello. Alá está bien informado de lo que hacéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcviii{Quien no pueda hacerlo, deberá ayunar durante dos meses consecutivos antes de cohabitar de nuevo. Quien no pueda, deberá alimentar a sesenta pobres. Para que creáis en Alá y en Su Enviado. Éstas son las leyes de Alá. Los infieles tendrán un castigo doloroso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcix{Quienes se oponen a Alá y a su Enviado serán derribados como lo fueron quienes les precedieron. Hemos revelado signos claros. Los infieles tendrán un castigo humillante.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcx{El día que Alá les resucite a todos, ya les informará de lo que hicieron. Alá lo habrá tenido en cuenta, mientras que ellos lo habrán olvidado. Alá es testigo de todo.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxi{¿No ves que Alá conoce lo que está en los cielos y en la tierra? No hay conciliábulo de tres personas en que no sea Él el cuarto, ni de cinco personas en que no sea Él el sexto. Lo mismo si son menos que si son más, Él siempre está presente, dondequiera que se encuentren. Luego, el día de la Resurrección, ya les informará de lo que hicieron. Alá es omnisciente.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxii{¿No ves a aquéllos a quienes se ha prohibido celebrar conciliábulos, que se obstinan en lo prohibido y los celebran, haciéndose culpables de pecado, de violación de la ley y de desobediencia al Enviado? Cuando vienen a ti, te saludan de manera distinta a como Alá te saluda y dicen para sí: «¿Cómo es que Alá no nos castiga por lo que decimos?» Les bastará con la gehena, en la que arderán. ¡Qué mal fin...!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxiii{¡Creyentes! Cuando celebréis un conciliábulo, no lo hagáis con ánimo de pecar, de violar la ley y de desobedecer al Enviado, sino con el ánimo de ser buenos y temerosos de Alá. ¡Y temed a Alá, hacia Quien seréis congregados!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxiv{El conciliábulo es sólo cosa del Demonio, para entristecer a los que creen, pero que no puede hacerles ningún daño, a menos que Alá lo permita. ¡Que los creyentes confíen en Alá!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxv{¡Creyentes! Cuando se os dice: «¡Haced sitio en las asambleas!» hacedlo así para que Alá os haga también sitio. Y si se os dice: «¡Levantaos!», hacedlo así para que Alá también eleve la categoría de aquéllos de vosotros que crean y reciban la Ciencia. Alá está informado de lo que hacéis.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcxvi{¡Creyentes! Cuando queráis tener una conversación a solas con el Enviado, hacedla preceder de una limosna. Es mejor para vosotros y más puro. Si no podéis, Alá es indulgente, misericordioso\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcxvii{¿Os arredra hacer preceder vuestra conversación a solas de limosnas? Si no lo hacéis y Alá se aplaca con vosotros, ¡haced la azalá, dad el azaque y obedeced a Alá y a su Enviado! Alá está bien informado de lo que hacéis.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcxviii{¿No has visto a quienes han tomado como protectores a gente que ha incurrido en la ira de Alá? No son ni de los vuestros ni de los suyos y juran en falso deliberadamente.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcxix{Alá ha preparado para ellos un castigo severo. Lo que han hecho está mal.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcxx{Se han escudado en sus juramentos y han desviado a otros del camino de Alá. Tendrán un castigo humillante.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcxxi{Ni su hacienda ni sus hijos le servirán de nada frente a Alá. Esos tales morarán en el Fuego eternamente.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcxxii{El día que Alá les resucite a todos, Le jurarán a Él como os juran a vosotros, creyendo apoyarse en algo sólido. ¿No son ellos los que mienten?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcxxiii{El Demonio se ha apoderado de ellos y les ha hecho olvidarse del recuerdo de Alá. Esos tales son los partidarios del Demonio. Y ¿no son los partidarios del Demonio los que pierden?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcxxiv{Los que se oponen a Alá y a Su Enviado estarán entre los más viles.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcxxv{Alá ha escrito: «¡Venceré, en verdad! ¡Yo y Mis enviados!» Alá es fuerte, poderoso.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcxxvi{No encontrarás a gente que crea en Alá y en el último Día y que tenga cariño a quienes se oponen a Alá y a Su Enviado, aunque éstos sean sus padres, sus hijos varones, sus hermanos o los miembros de su misma tribu. He inscrito la fe en sus corazones, les ha fortalecido con un espíritu de Él y les introducirá en jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente. Alá está satisfecho de ellos y ellos lo están de Él. Ésos constituyen el partido de Alá. Y ¿no son los partidarios de Alá los que prosperan?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcxxvii{\basmalahes Lo que está en los cielos y en la tierra glorifica a Alá. Él es el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcxxviii{Él es Quien expulsó de sus viviendas a los de la gente de la Escritura que no creían, cuando la primera reunión. No creíais que iban a salir y ellos creían que sus fortalezas iban a protegerles contra Alá. Pero Alá les sorprendió por donde menos lo esperaban. Sembró el terror en sus corazones y demolieron sus casas con sus propias manos y con la ayuda de los creyentes. Los que tengáis ojos ¡escarmentad!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcxxix{Si Alá no hubiera decretado su destierro, les habría castigado en la vida de acá. En la otra vida, no obstante, sufrirán el castigo del Fuego,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcxxx{por haberse separado de Alá y de Su Enviado. Quien se separa de Alá... Alá castiga severamente.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcxxxi{Cuando talabais una palmera o la dejabais en pie, lo hacíais con permiso de Alá y para confundir a los perversos.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcxxxii{No habéis contribuido ni con caballos ni con camellos a lo que, de ellos, ha concedido Alá a Su Enviado. Alá, empero, permite a Sus enviados que dominen a quien Él quiere. Alá es omnipotente.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxxxiii{Lo que Alá ha concedido a Su Enviado, de la población de las ciudades, pertenece a Alá, al Enviado. a sus parientes, a los huérfanos, a los pobres y al viajero. Para que no vaya de nuevo a parar a los que de vosotros ya son ricos. Pero, si el Enviado os da algo, aceptadlo. Y, si os prohíbe algo, absteneos. Y ¡temed a Alá! Alá castiga severamente.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxxxiv{A los emigrados necesitados, que fueron expulsados de sus hogares y despojados de sus bienes cuando buscaban favor de Alá y satisfacerle, auxiliar a Alá y a Su Enviado. Ésos son los veraces.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxxxv{Los ya establecidos en la Casa y en la fe desde antes de su llegada, aman a los que han emigrado a ellos, no codician lo que se les ha dado y les prefieren a sí mismos, aun si están en la penuria. Los que se guarden de su propia codicia, ésos son quienes prosperarán.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxxxvi{Quienes vinieron después de ellos, dicen: «¡Señor! ¡Perdónanos, a nosotros y a nuestros hermanos que nos han precedido en la fe! ¡Haz que no abriguen nuestros corazones rencor a los que creen! ¡Señor! Tú eres manso, misericordioso».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxxxvii{¿No has visto a los hipócritas, que dicen a sus hermanos infieles de los de la gente de la Escritura: «Si os expulsan, nos iremos, ciertamente, con vosotros, y nunca obedeceremos a nadie que nos mande algo contra vosotros. Y si os atacan, ciertamente, os auxiliaremos»? Alá es testigo de que mienten.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcxxxviii{Si son expulsados, no se irán con ellos. Si son atacados, no les auxiliarán. Y aun suponiendo que les auxiliaran, seguro que volvían la espalda. Luego, no serán auxiliados.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcxxxix{Infundís en sus pechos más terror que Alá. Es que son gente que no comprende.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcxl{No combatirán unidos contra vosotros, sino en poblados fortificados o protegidos por murallas. Sus disensiones internas son profundas. Les creéis unidos, pero sus corazones están desunidos. Es que son gente que no razona.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcxli{Como los que fueron poco antes que ellos. Gustaron la gravedad de su conducta y tendrán un castigo doloroso.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcxlii{Como el Demonio cuando dice al hombre: «¡No creas!». Y, cuando ya no cree, dice: «Yo no soy responsable de ti. Yo temo a Alá, Señor del universo».\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcxliii{Su fin será el Fuego, eternamente. Ésa es la retribución de los impíos.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcxliv{¡Creyentes! ¡Temed a Alá! ¡Que cada uno considere lo que prepara para Mañana! ¡Temed a Alá! Alá está bien informado de lo que hacéis.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcxlv{No seáis como quienes, habiendo olvidado a Alá, hace Él que se olviden de sí mismos. Esos tales son los perversos.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcxlvi{No son iguales los moradores del Fuego y los moradores del Jardín. Los moradores del Jardín son los que triunfan.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcxlvii{Si hubiéramos hecho descender este Corán en una montaña, habrías visto a ésta humillarse y henderse por miedo a Alá. Proponemos a los hombres estos símiles. Quizás, así, reflexionen.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcxlviii{Es Alá -no hay más dios que Él-, el Conocedor de lo oculto y de lo patente. Es el Compasivo, el Misericordioso.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcxlix{Es Alá -no hay más dios que Él-, el Rey, el Santísimo, la Paz, Quien da Seguridad, el Custodio, el Poderoso, el Fuerte, el Sumo. ¡Gloria a Alá! ¡Está por encima de lo que Le asocian!\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcl{Es Alá, el Creador, el Hacedor, el Formador. Posee los nombres más bellos. Lo que está en los cielos y en la tierra Le glorifica. Es el Poderoso, el Sabio.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcli{\basmalahes ¡Creyentes! ¡No toméis como amigos a los enemigos Míos y vuestros, dándoles muestras de afecto, siendo así que no creen en la Verdad venida a vosotros! Expulsan al Enviado y os expulsan a vosotros porque creéis en Alá vuestro Señor. Si salís para luchar por Mi causa y por deseo de agradarme, ¿les tendréis un afecto secreto? Yo sé bien lo que ocultáis y lo que manifestáis. Quien de vosotros obra así, se extravía del camino recto.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclii{Si dan con vosotros, son para vosotros enemigos y os maltratan de obra y de palabra. Querrían que no creyerais...\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcliii{El día de la Resurrección no os aprovecharán ni vuestros parientes ni vuestros hijos. Él fallará acerca de vosotros. Alá ve bien lo que hacéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcliv{Tenéis un bello modelo en Abraham y en los que con él estaban. Cuando dijeron a su pueblo: «No somos responsables de vosotros ni de lo que servís en lugar de servir a Alá. ¡Renegamos de vosotros! ¡Ha aparecido, entre nosotros y vosotros, hostilidad y odio para siempre mientras no creáis en Alá Solo!» No es de imitar, en cambio, Abraham cuando dijo a su padre: «He de pedir perdón para ti, aunque no pueda hacer nada por ti contra Alá. ¡Señor! Confiamos en Ti y a Ti nos volvemos arrepentidos. ¡Eres Tú el fin de todo!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclv{¡Señor! ¡No hagas de nosotros instrumento de tentación para los infieles! ¡Perdónanos, Señor! Eres Tú el Poderoso, el Sabio».\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclvi{Tenéis en ellos un bello modelo para quien cuenta con Alá y con el último Día. Pero quien vuelve la espalda,... Alá es Quien Se basta a Sí mismo, el Digno de Alabanza.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclvii{Quizá establezca Alá la amistad entre vosotros y los que de ellos tenéis por enemigos. Alá es capaz, Alá es indulgente, misericordioso.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclviii{Alá no os prohíbe que seáis buenos y equitativos con quienes no han combatido contra vosotros por causa de la religión, ni os han expulsado de vuestros hogares. Alá ama a los que son equitativos.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclix{Lo que sí os prohíbe Alá es que toméis como amigos a los que han combatido contra vosotros por causa de la religión y os han expulsado de vuestros hogares o han contribuído a vuestra expulsión. Quienes les tomen como amigos, ésos son los impíos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclx{¡Creyentes! Cuando vengan a vosotros mujeres creyentes que hayan emigrado, ¡examinadlas! Alá conoce bien su fe. Si comprobáis que de verdad son creyentes, no las devolváis a los infieles: ni ellas son lícitas para ellos ni ellos lo son para ellas. ¡Reembolsadles lo que hayan gastado! No tenéis nada que reprocharos si os casáis con ellas, con tal que les entreguéis su dote. Pero no retengáis a las infieles. Pedid lo que hayáis gastado, y que ellos también pidan lo que hayan gastado. Ésa es la decisión de Alá. Él decide entre vosotros. Alá es omnisciente, sabio.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxi{Si alguna de vuestras esposas se pasa a los infieles y, luego, os toca a vosotros vencer, dad a aquéllos cuyas esposas hayan huido otro tanto de lo que habían gastado. ¡Temed a Alá, en Quien creéis!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxii{¡Profeta! Cuando las creyentes vengan a ti a prestarte juramento de fidelidad, de que no asociarán nada a Alá, que no robarán, que no fornicarán, que no matarán a sus hijos, que no dirán calumnia forjada entre sus manos y pies, que no te desobedecerán en lo que se juzgue razonable, acepta su juramento y pide a Alá que les perdone. Alá es indulgente, misericordioso.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmclxiii{¡Creyentes! ¡No toméis como amigos a gente que ha incurrido en la ira de Alá! Desesperan de la otra vida, como los infieles desesperan de los sepultados.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmclxiv{\basmalahes Lo que está en los cielos y en la tierra glorifica a Alá. Él es el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclxv{¡Creyentes! ¿Por qué decís lo que no hacéis?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmclxvi{Alá aborrece mucho que digáis lo que no hacéis.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmclxvii{Alá ama a los que luchan en fila por Su causa, como si fueran un sólido edificio.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclxviii{Y cuando Moisés dijo a su pueblo: «¡Pueblo! ¿Por qué me molestáis sabiendo que soy el que Alá os ha enviado?» Y, cuando se desviaron, Alá desvió sus corazones. Alá no dirige al pueblo perverso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclxix{Y cuando Jesús, hijo de María, dijo: «¡Hijos de Israel! Yo soy el que Alá os ha enviado, en confirmación de la Tora anterior a mí, y como nuncio de un Enviado que vendrá después de mí, llamado Ahmad». Pero, cuando vino a ellos con las pruebas claras, dijeron: «¡Esto es manifiesta magia!»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclxx{¿Hay alguien más impío que quien inventa la mentira contra Alá, siendo llamado al islam? Alá no dirige al pueblo impío.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclxxi{Quisiera apagar de un soplo la Luz de Alá, pero Alá hará que resplandezca, a despecho de los infieles.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclxxii{Él es Quien ha mandado a Su Enviado con la Dirección y con la religión verdadera para que prevalezca sobre toda otra religión, a despecho de los asociadores.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclxxiii{¡Creyentes! ¿Queréis que os indique un negocio que os librará de un castigo doloroso?:\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxxiv{¡Creed en Alá y en Su Enviado y combatid por Alá con vuestra hacienda y vuestras personas! Es mejor para vosotros. Si supierais...\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxxv{Así, os perdonará vuestros pecados y os introducirá en jardines por cuyos bajos fluyen arroyos y en viviendas agradables en los jardines del edén. ¡Ese es el éxito grandioso!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmclxxvi{Y otra cosa, que amaréis: el auxilio de Alá y un éxito cercano. ¡Y anuncia la buena nueva a los creyentes!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmclxxvii{¡Creyentes! Sed los auxiliares de Alá como cuando Jesús, hijo de María, dijo a los apóstoles: «¿Quiénes son mis auxiliares en la vía que lleva a Alá?» Los apóstoles dijeron: «Nosotros somos los auxiliares de Alá». De los hijos de Israel unos creyeron y otros no. Fortalecimos contra sus enemigos a los que creyeron y salieron vencedores.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmclxxviii{\basmalahes Lo que está en los cielos y en la tierra glorifica a Alá, el Rey, el Santísimo, el Poderoso, el Sabio.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmclxxix{Él es quien ha mandado a los gentiles un Enviado salido de ellos, que les recita Sus aleyas, les purifica y les enseña la Escritura y la Sabiduría. Antes estaban, evidentemente, extraviados.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmclxxx{Y a otros de ellos, que no se les han incorporado aún. Es el Poderoso, el Sabio.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmclxxxi{Ése es el favor de Alá, que dispensa a quien Él quiere. Alá es el Dueño del favor inmenso.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmclxxxii{Aquéllos a quienes se había confiado la Tora pero no la observaron son semejantes a un asno que lleva libros. ¡Qué mal ejemplo da la gente que desmiente los signos de Alá! Alá no dirige al pueblo impío.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmclxxxiii{Di: «¡Judíos! Si pretendéis ser los amigos de Alá, con exclusión de otras gentes, entonces, ¡desead la muerte, si sois consecuentes!»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmclxxxiv{Pero nunca la desean por lo que sus manos han cometido. Alá conoce bien a los impíos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmclxxxv{Di: «La muerte, de la que huís, os saldrá al encuentro. Luego, se os devolverá al Conocedor de lo oculto y de lo patente y ya os informará Él de lo que hacíais».\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmclxxxvi{¡Creyentes! Cuando se llame el viernes a la azalá, ¡corred a recordar a Alá y dejad el comercio! Es mejor para vosotros. Si supierais...\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmclxxxvii{Terminada la azalá, ¡id a vuestras cosas, buscad el favor de Alá! ¡Recordad mucho a Alá! Quizás, así, prosperéis.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmclxxxviii{Cuando ven un negocio o una distracción, escapan allá y te dejan plantado. Di: «Lo que Alá tiene es mejor que la distracción y el negocio. Alá es el Mejor de los proveedores».\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmclxxxix{\basmalahes Cuando los hipócritas vienen a ti, dicen: «Atestiguamos que tú eres, en verdad, el Enviado de Alá». Alá sabe que tú eres el enviado. Pero Alá es testigo de que los hipócritas mienten.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcxc{Se han escudado en sus juramentos y han desviado a otros del camino de Alá. ¡Qué mal está lo que han hecho!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcxci{Porque primero creyeron y, luego, han descreído. Sus corazones han sido sellados, así que no entienden.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcxcii{Cuando se les ve, se admira su presencia. Si dicen algo, se escucha lo que dicen. Son como maderos apoyados. Creen que todo grito va dirigido contra ellos. Son ellos el enemigo. ¡Ten, pues, cuidado con ellos! ¡Que Alá les maldiga! ¡Cómo pueden ser tan desviados!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcxciii{Cuando se les dice: «¡Venid, que el Enviado de Alá pedirá perdon por vosotros!», vuelven la cabeza y se les ve retirarse altivamente.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcxciv{Da lo mismo que pidas o no que se les perdone. Alá no les perdonará. Alá no dirige a la gente perversa.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcxcv{Son ellos los que dicen: «No gastéis nada en favor de los que están con el Enviado de Alá; así, se escaparán de él». Los tesoros de los cielos y de la tierra pertenecen a Alá, pero los hipócritas no comprenden.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcxcvi{Dicen: «Si volvemos a la ciudad, los más poderosos, sin duda, expulsarán de ella a los más débiles». Pero el poder pertenece a Alá, a Su Enviado y a los creyentes. Los hipócritas, empero, no saben.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcxcvii{¡Creyentes! Que ni vuestra hacienda ni vuestros hijos os distraigan del recuerdo de Alá. Quienes eso hacen, son los que pierden.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcxcviii{Gastad de lo que os hemos proveído, antes de que la muerte venga a uno de vosotros y éste diga: «¡Señor! ¿Por qué no me das algo más de tiempo, para que dé limosna y sea de los justos?».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcxcix{Cuando le vence a uno su plazo, Alá no le concede prórroga. Alá está bien informado de lo que hacéis.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcc{\basmalahes Lo que está en los cielos y en la tierra glorifica a Alá. Suyo es el dominio, Suya la alabanza. Es omnipotente.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcci{Él es Quien os ha creado. Entre vosotros, unos son infieles, otros son creyentes. Alá ve bien lo que hacéis.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccii{Ha creado con un fin los cielos y la tierra y a vosotros os ha formado armoniosamente. ¡Es Él el fin de todo!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcciii{Conoce lo que está en los cielos y en la tierra, conoce lo que ocultáis y lo que manifestáis. Y Alá conoce bien lo que encierran los pechos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcciv{¿No os habéis enterado de lo que pasó a los que fueron antes infieles y gustaron la gravedad de su conducta? Tendrán un castigo doloroso.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccv{Porque vinieron a ellos sus enviados con las pruebas claras y dijeron: «¿Es que van a dirigirnos unos mortales?» No creyeron y volvieron la espalda. Pero Alá no necesitaba de ellos. Alá Se basta a Sí mismo, es digno de alabanza.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccvi{Los infieles pretenden que no van a ser resucitados. Di: «¡Claro que sí, por mi Señor!, que habéis de ser resucitados y, luego, habéis de ser informados de lo que hicisteis. Es cosa fácil para Alá».\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccvii{¡Creed, pues, en Alá, en Su Enviado y en la Luz que Nosotros hemos revelado! Alá está bien informado de lo que hacéis.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccviii{El día que Él os reúna para el día de la Reunión, ése será el día del Engaño Mutuo. Entonces, a quienes crean en Alá y obren bien, Él les borrará sus malas obras y les introducirá en jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, para siempre. ¡Ése es el éxito grandioso!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccix{Pero quienes no crean y desmientan Nuestros signos, ésos morarán en el Fuego eternamente. ¡Qué mal fin...!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccx{No sucede ninguna desgracia si Alá no lo permite. Él dirige el corazón de quien cree en Alá. Alá es omnisciente.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxi{¡Y obedeced a Alá, obedeced al Enviado! Si volvéis la espalda,... A Nuestro Enviado le incumbe sólo la transmisión clara.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxii{¡Alá! ¡No hay más dios que Él! ¡Que e los creyentes confíen en Alá!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmccxiii{¡Creyentes! En algunas de vuestras esposas y en algunos de vuestros hijos tenéis un enemigo. ¡Cuidado con ellos! Pero, si sois indulgentes, si sois tolerantes, si perdonáis,... Alá es indulgente, misericordioso.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmccxiv{Vuestra hacienda y vuestros hijos no son más que tentación, mientras que Alá tiene junto a Sí una magnífica recompensa.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmccxv{¡Temed cuanto podáis a Alá! ¡Escuchad! ¡Obedeced! ¡Gastad! Es en vuestro propio beneficio. Los que se guardan de su propia codicia, ésos son los que prosperarán.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmccxvi{Si hacéis un préstamo generoso a Alá, Él os devolverá el doble y os perdonará. Alá es muy agradecido, benigno.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmccxvii{El Conocedor de lo oculto y de lo patente, el Poderoso, el Sabio.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmccxviii{\basmalahes ¡Profeta! Cuando repudiáis a las mujeres, ¡hacedlo al terminar su período de espera! ¡Contad bien los días de ese período y temed a Alá, vuestro Señor! ¡No las expulséis de sus casas ni ellas salgan, a menos que sean culpables de deshonestidad manifiesta! Ésas son las leyes de Alá. Y quien viola las leyes de Alá es injusto consigo mismo. Tú no sabes... Quizá Alá, entre tanto, suscite algún imprevisto...\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxix{Cuando lleguen a su término, retenedlas decorosamente o separaos de ellas decorosamente. Y requerid el testimonio de dos personas justas de los vuestros y atestiguad ante Alá. A esto se exhorta a quien cree en Alá y en el último Día. A quien teme a Alá, Él le da una salida\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxx{y le provee de un modo insospechado por él. A quien confía en Alá, Él le basta. Alá consigue lo que se propone. Alá ha establecido una medida para cada cosa.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxxi{Para aquéllas de vuestras mujeres que ya no esperan tener la menstruación, si tenéis dudas, su período de espera será de tres meses; lo mismo para las impúberes. Para las embarazadas, su período de espera terminará cuando den a luz. A quien teme a Alá, Él le facilita sus cosas.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxxii{Ésta es la orden que Alá os ha revelado. Alá borra las malas obras de quien Le teme y le da una magnífica recompensa.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxxiii{¡Alojadlas, según vuestros medios, en vuestra misma vivienda! ¡No les hagáis daño con ánimo de molestarlas! Si están embarazadas, proveedles de lo necesario hasta que den a luz. Si la criatura que crían es vuestra, retribuidles como es debido y llegad a un acuerdo decoroso. Si encontráis alguna dificultad, entonces, tomad un ama a cuenta vuestra.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxxiv{¡Que el acomodado gaste según sus medios! Quien disponga de medios limitados ¡que gaste según lo que Alá le haya dado! Alá no pide a nadie sino lo que le ha dado. Alá hará que a la adversidad suceda la felicidad.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxxv{¡A cuántas ciudades, que desdeñaron la orden de su Señor y de Sus enviados, pedimos cuenta rigurosa e infligimos un castigo horroroso!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccxxvi{Gustaron la gravedad de su conducta, que acabó por perderles.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccxxvii{Alá ha preparado para ellos un castigo severo. ¡Temed, pues, a Alá, creyentes dotados de intelecto! Alá os ha enviado de lo alto una Amonestación,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccxxviii{un Enviado que os recita aleyas aclaratorias de Alá, para sacar de las tinieblas a la luz a quienes creen y obran bien. A quien cree en Alá y obra bien, Él le introducirá en jardines por cuyos bajos fluyen arroyos, en los que estarán eternamente, para siempre. Alá le ha reservado un bello sustento.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxxix{Alá es Quien ha creado siete cielos y otras tantas tierras. La orden desciende gradualmente entre ellos para que sepáis‚ que Alá es omnipotente y que Alá todo lo abarca en Su ciencia.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxxx{\basmalahes ¡Profeta! ¿Por qué, para agradar a tus esposas, declaras prohibido lo que Alá ha declarado lícito para ti? Pero Alá es indulgente, misericordioso.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxxxi{Alá os ha prescrito la anulación de vuestros juramentos. Alá es vuestro Protector. Él es el Omnisciente, el Sabio.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxxxii{Y cuando el Profeta dijo un secreto a una de sus esposas. Cuando, no obstante, ella lo reveló y Alá se lo descubrió, dio él a conocer parte y ocultó el resto. Y, cuando se lo reveló, dijo ella: «¿Quién te ha informado de esto?» Él dijo: «Me lo ha revelado el Omnisciente, el Bien Informado».\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxxxiii{Si os volvéis ambas, arrepentidas, a Alá, es señal de que vuestros corazones han cedido. Si, al contrario, os prestáis ayuda en contra de él, entonces, Alá es su Protector. Y le ayudarán Gabriel, los buenos creyentes y, además, los ángeles.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxxxiv{Si él os repudia, quizá su Señor le dé, a cambio, esposas mejores que vosotras, sometidas a É, creyentes, devotas, arrepentidas, que sirven a Alá, que ayunan, casadas de antes o vírgenes.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxxxv{¡Creyentes! Guardaos, vosotros y vuestras familias, de un Fuego cuyo combustible lo forman hombres y piedras, y sobre el que habrá ángeles gigantescos, poderosos, que no desobedecen a Alá en lo que les ordena, sino que hacen lo que se les ordena.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxxxvi{¡Infieles! ¡No os disculpéis hoy! Se os retribuirá tan sólo según vuestras obras.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxxxvii{¡Creyentes! ¡Volveos a Alá con sincero arrepentimiento! Quizá vuestro Señor borre vuestras malas obras y os introduzca en jardines por cuyos bajos fluyen arroyos. El día que Alá libre de vergüenza al Profeta y a los que con él creyeron... Su luz correrá ante ellos y a su derecha. Dirán: «¡Señor! ¡Perfecciónanos nuestra luz y perdónanos! Eres omnipotente».\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccxxxviii{¡Profeta! ¡Combate contra los infieles y los hipócritas! ¡Muéstrate duro con ellos! Tendrán la gehena por morada. ¡Qué mal fin...!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccxxxix{Alá pone como ejemplo para los infieles a la mujer de Noé y a la mujer de Lot. Ambas estaban sujetas a dos de Nuestros siervos justos, pero les traicionaron, aunque su traición no les sirvió de nada frente a Alá. Y se dijo: «¡Entrad ambas en el Fuego, junto con los demás que entran!»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccxl{Y Alá pone como ejemplo para los creyentes a la mujer de Faraón. Cuando dijo: «¡Señor! ¡Constrúyeme, junto a Ti, una casa en el Jardín y sálvame de Faraón y de sus obras! ¡Sálvame del pueblo impío!»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccxli{Y a María, hija de Imran, que conservó su virginidad y en la que infundimos de Nuestro Espíritu. Tuvo por auténticas las palabras y Escritura de su Señor y fue de las devotas.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccxlii{\basmalahes ¡Bendito sea Aquél en Cuya mano está el dominio! Es omnipotente.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccxliii{Es Quien ha creado la muerte y la vida para probaros, para ver quién de vosotros es el que mejor se porta. Es el Poderoso, el Indulgente.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccxliv{Es Quien ha creado siete cielos superpuestos. No ves ninguna contradición en la creación del Compasivo. ¡Mira otra vez! ¿Adviertes alguna falla?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccxlv{Luego, mira otras dos veces: tu mirada volverá a ti cansada, agotada.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccxlvi{Hemos engalanado el cielo más bajo con luminares, de los que hemos hecho proyectiles contra los demonios y hemos preparado para ellos el castigo del fuego de la gehena.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccxlvii{Quienes no hayan creído en su Señor tendrán el castigo de la gehena. ¡Qué mal fin...!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccxlviii{Cuando sean arrojados a ella, oirán su fragor, en plena ebullición,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccxlix{a punto de estallar de furor. Siempre que se le arroje una oleada, sus guardianes les preguntarán: «¿Es que no vino a vosotros un monitor?»\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccl{«¡Claro que sí!» dirán: «Vino a nosotros un monitor, pero desmentimos, y dijimos: 'Alá no ha revelado nada. No estáis sino muy extraviados'».\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccli{Y dirán: «Si hubiéramos oído o comprendido, no moraríamos ahora en el fuego de la gehena».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcclii{Confesarán su pecado. ¡Que Alá aleje a los moradores del fuego de la gehena!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccliii{Quienes hayan tenido miedo a su Señor en secreto tendrán perdón y una gran recompensa.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccliv{Da lo mismo que mantengáis ocultas vuestras palabras o que las divulguéis. Él conoce bien lo que encierran los pechos.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcclv{¿No va a saber Quien ha creado, Él, Que es el Sutil, el Bien Informado?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcclvi{Él es Quien os ha hecho dócil la tierra. Recorredla, pues, de acá para allá y comed de Su sustento. La Resurrección se hará hacia Él.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcclvii{¿Estáis a salvo de que Quien está en el cielo haga que la tierra os trague? He aquí que tiembla...\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcclviii{¿O estáis a salvo de que Quien está en el cielo envíe contra vosotros una tempestad de arena? Entonces veréis cómo era Mi advertencia...\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcclix{Quienes fueron antes que ellos desmintieron y ¡cuál no fue Mi reprobación!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcclx{¿Es que no han visto las aves encima de ellos, desplegando y recogiendo las alas? Sólo el Compasivo las sostiene. Lo ve bien todo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcclxi{O ¿quién es el que podría auxiliaros cual legión, fuera del Compasivo? Los infieles son presa de una ilusión.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcclxii{O ¿quien es el que os proveería de sustento si Él interrumpiera Su sustento? Sí, persisten en su insolencia y aversión.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcclxiii{Quien anda agachado ¿va mejor dirigido que quien anda erguido por una vía recta?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcclxiv{Di: «Él es Quien os ha creado, Quien os ha dado el oído, la vista y el intelecto. ¡Qué poco agradecidos sois!»\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcclxv{Di: «Él es Quien os ha diseminado por la tierra. Y hacia Él seréis congregados».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcclxvi{Y dicen: «¿Cuándo se cumplirá esta amenaza, si es verdad lo que decís?»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcclxvii{Di: «Sólo Alá lo sabe. Yo soy solamente un monitor que habla claro».\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcclxviii{Pero, en cuanto vean su inminencia, se afligirán los rostros de los infieles. Y se dirá: «Aquí tenéis lo que reclamabais».\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcclxix{Di: «¿Qué os parece? Lo mismo si Alá nos hace perecer, a mí y a los que están conmigo, que si se apiada de nosotros, ¿quién preservará a los infieles de un castigo doloroso?\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcclxx{Di: «¡Es el Compasivo! ¡Creemos en Él y confiamos en Él! Ya veréis quién es el que está evidentemente extraviado».\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcclxxi{Di: «¿Qué os parece? Si el agua se os agotara una mañana, ¿quien iba a traeros agua viva?»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcclxxii{\basmalahes n. ¡Por el cálamo y lo que escriban!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcclxxiii{¡Por la gracia de tu Señor, que tú no eres un poseso!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcclxxiv{Tendrás, ciertamente, una recompensa ininterrumpida.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcclxxv{Eres, sí, de eminente carácter.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcclxxvi{Tú verás y ellos verán\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcclxxvii{quién de vosotros es el tentado.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcclxxviii{Tu Señor sabe mejor que nadie quiénes se extravían de Su camino y sabe mejor que nadie quiénes siguen la buena dirección.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcclxxix{¡No obedezcas, pues, a los desmentidores!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcclxxx{Desearían que fueras condescendiente, para serlo ellos también.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxi{¡No obedezcas a ningún vil jurador.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxii{al pertinaz difamador, que va sembrando calumnias,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxiii{a quien impide el bien, al violador de la ley, al pecador,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxiv{al arrogante y, encima, bastardo,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxv{so pretexto de poseer hacienda e hijos varones!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxvi{Cuando se le recitan Nuestras aleyas, dice: «¡Patrañas de los antiguos!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxvii{¡Le marcaremos en el hocico!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxviii{Les hemos probado como probamos a los dueños del jardín. Cuando juraron que cogerían sus frutos por la mañana,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcclxxxix{sin hacer salvedad.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmccxc{Mientras dormían, cayó sobre él un azote enviado por tu Señor\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmccxci{y amaneció como si hubiera sido arrasado.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmccxcii{Por la mañana, se llamaron unos a otros:\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmccxciii{«¡Vamos temprano a nuestro campo, si queremos coger los frutos!»\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmccxciv{Y se pusieron en camino, cuchicheando:\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmccxcv{«¡Ciertamente, hoy no admitiremos a ningún pobre!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmccxcvi{Marcharon, pues, temprano, convencidos de que serían capaces de llevar a cabo su propósito.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmccxcvii{Cuando lo vieron, dijeron: «¡Seguro que nos hemos extraviado!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmccxcviii{¡No, se nos ha despojado!»\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmccxcix{El más moderado de ellos dijo: «¿No os lo había dicho? ¿Por qué no glorificáis?»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmccc{Dijeron: «¡Gloria a nuestro Señor! ¡Hemos obrado impíamente!»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmccci{Y pusiéronse a recriminarse.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcccii{Dijeron: «¡Ay de nosotros, que hemos sido rebeldes!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmccciii{Quizá nos dé nuestros Señor, a cambio, algo mejor que éste. Deseamos ardientemente a nuestro Señor».\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmccciv{Tal fue el castigo. Pero el castigo de la otra vida es mayor aún. Si supieran...\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmcccv{Los que temen a Alá tendrán, junto a su Señor. los jardines de la Delicia.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmcccvi{¿Vamos, pues, a tratar igual a los que se someten a Alá que a los pecadores?\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmcccvii{¿Qué os pasa? ¿Qué manera de juzgar es ésa?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmcccviii{¿O es que disponéis de una Escritura para estudiar?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmcccix{Tendríais en ella lo que deseáis.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmcccx{¿O es que nos atan a vosotros juramentos que nos obligan hasta el día de la Resurrección? Obtendríais lo que juzgarais.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmcccxi{Pregúntales quién responde de ello.\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmcccxii{¿O es que tienen asociados? Pues, ¡que traigan a sus asociados, si es verdad lo que dicen!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmcccxiii{El día que las cosas se pongan mal y sean invitados a prosternarse, no podrán.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmcccxiv{Abatida la mirada, cubiertos de humillación, porque fueron invitados a prosternarse cuando aún estaban en seguridad...\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmcccxv{¡Déjame a solas con quienes desmienten este discurso! Les conduciremos paso a paso, sin que sepan cómo.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmcccxvi{Les concedo una prórroga. ¡Mi estratagema es segura!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmcccxvii{¿O es que les reclamas un salario tal que se vean abrumados de deudas?\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmcccxviii{¿O es que conocen lo oculto y toman nota?\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmcccxix{Espera, pues, paciente la decisión de tu Señor y no hagas como el del pez, cuando clamó en medio de la angustia.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmcccxx{Si no llega a alcanzarle una gracia de su Señor, habría sido arrojado a una costa desnuda, reprobado.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmcccxxi{Pero su Señor le escogió y le hizo de los justos.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmcccxxii{Poco les falta a los infieles, cuando oyen la Amonestación, para clavar en ti su mirada. Y dicen: «¡Sí, es un poseso!»\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmcccxxiii{Pero no es sino una amonestación dirigida a todo el mundo.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmcccxxiv{\basmalahes La Inevitable.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcccxxv{¿Qué es la Inevitable?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcccxxvi{Y ¿cómo sabrás qué es la Inevitable?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcccxxvii{Los tamudeos y los aditas desmintieron la Calamidad.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcccxxviii{Los tamudeos fueron aniquilados por el Rayo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcccxxix{Los aditas fueron aniquilados por un viento glacial, impetuoso,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcccxxx{que desencadenó contra ellos para devastarlo todo durante siete noches y ocho días. Se veía a la gente yacer en ellas como troncos de palmeras derribadas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxi{¿Puedes tú ver algún rastro de ellos?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxii{Pecaron Faraón, los que fueron antes de él y las vueltas de arriba abajo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxiii{Desobedecieron al Enviado de su Señor y Éste les sorprendió de un modo irresistible.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxiv{Cuando las aguas lo inundaron todo, os llevamos en la embarcación,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxv{para hacer de ella un recuerdo para vosotros, para que el oído atento lo retuviera.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxvi{Cuando se toque la trompeta una sola vez,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxvii{y la tierra y las montañas sean alzadas y pulverizadas de un solo golpe,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxviii{ese día sucederá el Acontecimiento.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcccxxxix{El cielo se henderá, pues ese día estará quebradizo.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcccxl{Los ángeles estarán en sus confines y ese día ocho de ellos llevarán, encima, el Trono de tu Señor.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcccxli{Ese día se os expondrá: nada vuestro quedará oculto.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcccxlii{Aquél que reciba su Escritura en la diestra, dirá: «¡Tomad! ¡Leed mi Escritura!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcccxliii{¡Ya contaba con ser juzgado!»\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcccxliv{Gozará de una vida agradable\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcccxlv{en un Jardín elevado,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcccxlvi{cuyos frutos estarán al alcance de la mano.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcccxlvii{«¡Comed y bebed en paz el fruto de lo que hicisteis en días pasados!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcccxlviii{Aquél que reciba su Escritura en la siniestra, dirá: «¡Ojalá no se me hubiera entregado la Escritura\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcccxlix{y no hubiera conocido el resultado de mi juicio!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcccl{¡ Ojalá hubiera sido definitiva!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcccli{De nada me ha servido mi hacienda.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmccclii{Mi poder me ha abandonado»\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcccliii{«¡Cogedle y ponedle una argolla al cuello!\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcccliv{¡Que arda, luego, en el fuego de la gehena!\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmccclv{¡Sujetadle, luego, a una cadena de setenta codos!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmccclvi{No creía en Alá, el Grandioso,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmccclvii{ni animaba a dar de comer al pobre.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmccclviii{Hoy no tiene aquí amigo ferviente,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmccclix{ni más alimento que de guislin,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmccclx{que sólo los pecadores comen.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmccclxi{¡Pues no! ¡Juro por lo que veis\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmccclxii{y por lo que no veis,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmccclxiii{que es, ciertamente, la palabra de un Enviado noble!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmccclxiv{No es la palabra de un poeta -¡qué poca fe tenéis!-\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmccclxv{ni la palabra de un adivino -¡qué poco os dejáis amonestar!-.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmccclxvi{Es una revelación que procede del Señor del universo.\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmccclxvii{Si Nos hubiera atribuido algunos dichos,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmccclxviii{le habríamos tomado de la diestra;\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmccclxix{luego, le habríamos seccionado la aorta,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmccclxx{y ninguno de vosotros habría podido impedirlo.\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmccclxxi{Es, sí, un Recuerdo para los temerosos de Alá.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmccclxxii{Ya sabemos, sí, que hay entre vosotros desmentidores.\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmccclxxiii{Es, sí, un motivo de lamentación para los infieles.\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmccclxxiv{Pero es algo, sí, absolutamente cierto.\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmccclxxv{¡Glorifica, pues, el nombre de tu Señor, el Grandioso!.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmccclxxvi{\basmalahes Alguien ha pedido un castigo inmediato\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmccclxxvii{para los infieles, que nadie pueda rechazar,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmccclxxviii{que venga de Alá, Señor de las gradas.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmccclxxix{Los ángeles y el Espíritu ascienden a Él en un día que equivale a cincuenta mil años.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmccclxxx{¡Ten, pues, digna paciencia!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxi{Piensan que está lejos,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxii{pero Nosotros pensamos que está cerca.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxiii{El día que el cielo parezca metal fundido,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxiv{y las montañas, copos de lana,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxv{y nadie pregunte por su amigo ferviente.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxvi{Les será dado verles. El pecador querrá librarse del castigo de ese día ofreciendo como rescate a sus hijos varones,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxvii{a su compañera, a su hermano,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxviii{Al clan que lo cobijó,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmccclxxxix{a todos los de la tierra. Eso le salvaría.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcccxc{¡No! Será una hoguera,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcccxci{que arrancará el cuero cabelludo\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcccxcii{y reclamará a quien retroceda y vuelva la espalda,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcccxciii{a quien amase y atesore.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcccxciv{El hombre es de natural impaciente.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcccxcv{Pusilánime cuando sufre un mal,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcccxcvi{mezquino cuando la fortuna le favorece.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcccxcvii{Se exceptúa a quienes oran\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcccxcviii{perseverando en su azalá,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcccxcix{parte de cuyos bienes es de derecho\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcd{para el mendigo y el indigente,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdi{que tienen por auténtico el día del Juicio,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdii{que temen el castigo de su Señor\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdiii{-nadie debe sentirse seguro contra el castigo de su Señor-,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdiv{que se abstienen de comercio carnal,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmcdv{salvo con sus esposas o con sus esclavas -en cuyo caso no incurren en reproche,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmcdvi{mientras que quienes desean a otras mujeres, ésos son los que violan la ley-,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmcdvii{que respetan los depósitos que se les confían y las promesas que hacen,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmcdviii{que dicen la verdad en sus testimonios,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmcdix{que observan su azalá.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmcdx{Esos tales estarán en jardines, honrados.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmcdxi{¿Qué les pasa a los infieles, que vienen hacia ti corriendo con el cuello extendido,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmcdxii{en grupos, por la derecha y por la izquierda?\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmcdxiii{¿Es que cada uno de ellos anhela ser introducido en un jardín de delicia?\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmcdxiv{¡No! Les creamos de lo que saben.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmcdxv{¡Pues no! ¡Juro por el Señor de los Orientes y de los Occidentes, que somos bien capaces\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmcdxvi{de sustituirles por otros mejores que ellos, sin que nadie pueda impedírnoslo!\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmcdxvii{¡Déjales que parloteen y jueguen hasta que les llegue el día con que se les ha amenazado,\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmcdxviii{el día que salgan de las sepulturas, rápidos como si corrieran hacia piedras erectas,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmcdxix{la mirada abatida, cubiertos de humillación! Tal será el día con que se les había amenazado.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmcdxx{\basmalahes Enviamos a Noé a su pueblo: «¡Advierte a tu pueblo antes de que le alcance un castigo doloroso!»\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxxi{Dijo: «¡Pueblo! Soy para vosotros un monitor que habla claro.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdxxii{¡Servid a Alá y temedle! ¡Y obedecedme!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdxxiii{Así, os perdonará vuestros pecados y os remitirá a un plazo fijo. Pero, cuando venza el plazo fijado por Alá, no podrá ya ser retardado. Si supierais...»\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdxxiv{Dijo: «¡Señor! He llamado a mi pueblo noche y día.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdxxv{Mi llamamiento sólo ha servido para que huyan más.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdxxvi{Siempre que les llamo para que Tú les perdones, se ponen los dedos en los oídos, se cubren con la ropa, se obstinan y se muestran en extremo altivos.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdxxvii{Además, les he llamado abiertamente\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdxxviii{y les he hablado en público y en secreto.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdxxix{Y he dicho: '¡Pedid perdón a vuestro Señor -Que es indulgente-\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdxxx{y enviará sobre vosotros del cielo una lluvia abundante!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxi{Os dará mucha hacienda e hijos varones. Pondrá a vuestra disposición jardines, pondrá a vuestra disposición arroyos.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxii{¿Qué os pasa, que no esperáis de Alá magnanimidad,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxiii{habiéndoos creado en fases?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxiv{¿No habéis visto cómo ha creado Alá siete cielos superpuestos\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxv{y puesto en ellos la luna como luz y el sol como lámpara?\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxvi{Alá os ha hecho crecer de la tierra como plantas.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxvii{Después, os hará volver a ella, y os sacará.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxviii{Alá os ha puesto la tierra como alfombra\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdxxxix{para que recorráis en ella caminos, anchos pasos'».\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdxl{Noé dijo: «¡Señor! Me han desobedecido y han seguido a aquéllos cuya hacienda e hijos no hacen sino perderles más.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcdxli{Han perpetrado una enorme intriga.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcdxlii{Y dicen: '¡No abandonéis a vuestros dioses! ¡No abandonéis a Wadd, ni a Suwaa, ni a Yagut, a Yauq y a Nasr!'\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcdxliii{Han extraviado a muchos. A los impíos ¡no hagas sino extraviarles más!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcdxliv{Por sus pecados, fueron anegados e introducidos en un Fuego. No encontraron quien, fuera de Alá, les auxiliara.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdxlv{Noé dijo: «¡Señor! ¡No dejes en la tierra a ningún infiel con vida!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdxlvi{Si les dejas, extraviarán a Tus siervos y no engendrarán sino a pecadores, infieles pertinaces.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdxlvii{¡Señor! ¡Perdónanos, a mi y a mis padres, a quien entre en mi casa como creyente, a los creyentes y a las creyentes! Y a los impíos ¡no hagas sino perderles más!»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdxlviii{\basmalahes Di: «Se me ha revelado que un grupo de genios estaba escuchando y decía: 'Hemos oído una Recitación maravillosa,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxlix{que conduce a la vía recta. Hemos creído en ella y no asociaremos nadie a nuestro Señor'.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdl{Y: 'Nuestro Señor -¡exaltada sea Su grandeza!- no ha tomado compañera ni hijo'\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdli{Y: 'Nuestro loco decía contra Alá una solemne mentira'.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdlii{Y: 'Nosotros creíamos que ni los humanos ni los genios iban a proferir mentira contra Alá'.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdliii{Y: 'Había humanos varones que se refugiaban en los genios varones y éstos enloquecieron más a aquéllos'.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdliv{Y: 'Creían ellos, como vosotros, que Alá no iba a enviar a nadie'.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdlv{Y: 'Hemos palpado el cielo y lo hemos encontrado lleno de guardianes severos y de centellas'.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdlvi{Y: 'Nos sentábamos allí, en sitios apropiados para oír. Pero todo aquél que escucha, al punto encuentra una centella que le acecha'.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdlvii{Y: 'No sabemos si se quiere mal a los que están en la tierra o si su Señor quiere dirigirles bien'.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdlviii{Y: 'Entre nosotros hay unos que son justos y otros que no. Seguimos doctrinas diferentes'.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdlix{Y: 'Creíamos que no podríamos escapar a Alá en la tierra, ni aun huyendo'.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdlx{Y: 'Cuando oímos la Dirección, creímos en ella. Quien cree en su Señor no teme daño ni injuria'.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdlxi{Y: 'Entre nosotros los hay que se someten a Alá y los hay que se apartan. Los que se someten a Alá han elegido la rectitud.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdlxii{Los que se apartan, en cambio, son leña para la gehena'.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdlxiii{Y: 'Si se hubieran mantenido en la vía recta, les habríamos dado de beber agua abundante\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdlxiv{para probarles. A quien se desvíe de la Amonestación de su Señor, Él le conducirá a un duro castigo'.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdlxv{Y: 'Los lugares de culto son de Alá. ¡No invoquéis a nadie junto con Alá!'\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdlxvi{Y: 'Cuando el siervo de Alá se levantó para invocarle, poco les faltó para, en masa, arremeter contra él'».\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdlxvii{Di: «Invoco sólo a mi Señor y no Le asocio nadie».\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdlxviii{Di: «No puedo dañaros ni dirigiros».\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcdlxix{Di: «Nadie me protegerá de Alá y no encontraré asilo fuera de Él.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcdlxx{Sólo un comunicado de Alá y Sus mensajes». A quien desobedezca a Alá y a Su Enviado le espera el fuego de la gehena, en el que estará eternamente, para siempre.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxi{Hasta que, cuando vean aquello con que se les ha amenazado, sabrán quién es el que recibe auxilio más débil y quién es numéricamente inferior.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxii{Di: «No sé si está cerca aquello con que se os ha amenazado o si mi Señor lo retardará aún.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxiii{El Conocedor de lo oculto. No descubre a nadie lo que tiene oculto,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxiv{salvo a aquél a quien acepta como enviado. Entonces, hace que le observen por delante y por detrás,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxv{para saber si han transmitido los mensajes de su Señor. Abarca todo lo concerniente a ellos y lleva cuenta exacta de todo»\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxvi{\basmalahes ¡Tú, el arrebujado!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxvii{¡Vela casi toda la noche,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxviii{o media noche, o algo menos,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxix{o más, y recita el Corán lenta y claramente!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxx{Vamos a comunicarte algo importante:\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxi{la primera noche es más eficaz y de dicción más correcta.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxii{Durante el día estás demasiado ocupado.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxiii{¡Y menciona el nombre de tu Señor y conságrate totalmente a Él!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxiv{El Señor del Oriente y del Occidente. No hay más dios que Él. ¡Tómale, pues, como protector!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxv{¡Ten paciencia con lo que dicen y apártate de ellos discretamente!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxvi{¡Déjame con los desmentidores, que gozan de las comodidades de la vida! ¡Concédeles aún una breve prórroga!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxvii{Disponemos de cadenas y de fuego de gehena,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxviii{de alimento que se atraganta y de castigo doloroso.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcdlxxxix{El día que tiemblen la tierra y las montañas, y se conviertan las montañas en montones dispersos de arena...\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcdxc{Os hemos mandado un Enviado, testigo contra vosotros, como antes habíamos mandado un enviado a Faraón.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcdxci{Faraón desobedeció al enviado y le sorprendimos duramente.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcdxcii{Si no creéis, ¿cómo vais a libraros de un día que hará encanecer a los niños?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcdxciii{El cielo se entreabrirá. Se cumplirá Su promesa.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcdxciv{Esto es un Recuerdo. El que quiera ¡que emprenda camino hacia su Señor!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcdxcv{Tu Señor sabe que pasas en oración casi dos tercios de la noche, la mitad o un tercio de la misma, y lo mismo algunos de los que están contigo. Alá determina la noche y el día. Sabe que no vais a contarlo con exactitud y os perdona. ¡Recitad, pues, lo que buenamente podáis del Corán ! Sabe que entre vosotros habrá unos enfermos, otros de viaje por la tierra buscando el favor de Alá, otros combatiendo por Alá, ¡Recitad, pues, lo que buenamente podáis de él! ¡Haced la azalá! ¡Dad el azaque! ¡Haced un préstamo generoso a Alá! El bien que hagáis como anticipo para vosotros mismos, volveréis a encontrarlo junto a Alá como bien mejor y como recompensa mayor. ¡Y pedid el perdón de Alá! Alá es indulgente, misericordioso.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcdxcvi{\basmalahes ¡Tú, el envuelto en un manto!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcdxcvii{¡Levántate y advierte!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcdxcviii{A tu Señor, ¡ensálzale!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcdxcix{Tu ropa, ¡purifícala!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmd{La abominación, ¡huye de ella!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdi{¡No des esperando ganancia!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdii{La decisión de tu Señor, ¡espérala paciente!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdiii{Cuando suene la trompeta,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdiv{ése será, entonces, un día difícil\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdv{para los infieles, no fácil.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdvi{¡Déjame solo con Mi criatura,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdvii{a quien he dado una gran hacienda,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdviii{e hijos varones que están presentes!\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdix{Todo se lo he facilitado,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdx{pero aún anhela que le dé más.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdxi{¡No! Se ha mostrado hostil a Nuestros signos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdxii{Le haré subir por una cuesta.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdxiii{Ha reflexionado y tomado una decisión,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdxiv{pero ¡qué decisión! ¡Maldito sea!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdxv{Sí, ¡qué decisión! ¡Maldito sea!\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdxvi{Luego, ha mirado.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdxvii{Luego, se ha puesto ceñudo y triste.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdxviii{Luego, ha vuelto la espalda, lleno de altivez.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdxix{Y ha dicho: «¡Esto no es sino magia aprendida!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdxx{¡No es sino la palabra de un mortal!»\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdxxi{¡Lo entregaré al ardor del saqar !\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdxxii{Y ¿cómo sabrás qué es el saqar ?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdxxiii{No deja residuos, no deja nada.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdxxiv{Abrasa al mortal.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdxxv{Hay diecinueve que lo guardan.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdxxvi{No hemos puesto sino a ángeles como guardianes del Fuego y no los hemos puesto en ese número sino para tentar a los infieles, para que los que han recibido la Escritura crean firmemente, para que los creyentes se fortifiquen en su fe, para que no duden ni los que han recibido la Escritura ni los creyentes, para que los enfermos de corazón y los infieles digan: «¿Qué es lo que se propone Alá con esta parábola?» Así es como Alá extravía a quien Él quiere y dirige a quien Él quiere. Nadie sino Él conoce las legiones de tu Señor. No es sino una amonestación dirigida a los mortales.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdxxvii{¡No! ¡Por la luna!\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdxxviii{¡Por la noche cuando declina!\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdxxix{¡Por la mañana cuando apunta!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdxxx{Es, sí, una de las mayores,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdxxxi{a modo de advertencia para los mortales,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdxxxii{para aquéllos de vosotros que quieran adelantarse o rezagarse.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdxxxiii{Cada uno será responsable de lo que haya cometido.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdxxxiv{Pero los de la derecha,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdxxxv{en jardines, se preguntarán unos a otros\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdxxxvi{acerca de los pecadores.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdxxxvii{«¿Qué es lo que os ha conducido al saqar ?»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdxxxviii{Dirán: «No éramos de los que oraban,\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdxxxix{no dábamos de comer al pobre,\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdxl{parloteábamos con los parlones\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdxli{y desmentíamos el día del Juicio,\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdxlii{hasta que vino a nosotros la cierta».\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmdxliii{Los intercesores no podrán hacer nada por ellos.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmdxliv{¿Por qué han tenido que apartarse del Recuerdo,\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmdxlv{como asnos espantados\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmdxlvi{que huyen del león?\qt@no{51}}
\qt@newcmd\qurantrans@es@mmmmmdxlvii{Todos ellos quisieran que se les trajeran hojas desplegadas.\qt@no{52}}
\qt@newcmd\qurantrans@es@mmmmmdxlviii{Pero ¡no! No temen la otra vida.\qt@no{53}}
\qt@newcmd\qurantrans@es@mmmmmdxlix{¡No! Es un Recuerdo,\qt@no{54}}
\qt@newcmd\qurantrans@es@mmmmmdl{que recordará quien quiera.\qt@no{55}}
\qt@newcmd\qurantrans@es@mmmmmdli{Pero no lo tendrán en cuenta, a menos que Alá quiera. Es digno de ser temido y digno de perdonar.\qt@no{56}}
\qt@newcmd\qurantrans@es@mmmmmdlii{\basmalahes ¡No! ¡Juro por el día de la Resurreción!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdliii{¡Que no! ¡Juro por el alma que reprueba!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdliv{¿Cree el hombre que no juntaremos sus huesos?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdlv{¡Claro que sí! Somos capaces de recomponer sus dedos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdlvi{Pero el hombre preferiría continuar viviendo como un libertino.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdlvii{Pregunta: «¿Cuándo será el día de la Resurrección?»\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdlviii{Cuando se ofusque la vista,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdlix{se eclipse la luna,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdlx{se reúnan el sol y la luna,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdlxi{ese día, el hombre dirá: «Y ¿adónde escapar?»\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdlxii{¡No! ¡No habrá escape!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdlxiii{Ese día, el lugar de descanso estará junto a tu Señor.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdlxiv{Ese día, ya se le informará al hombre de lo que hizo y de lo que dejó de hacer.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdlxv{¡Más aún! El hombre testificará contra sí mismo,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdlxvi{aun cuando presente sus excusas.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdlxvii{No muevas la lengua al recitarlo para precipitarla!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdlxviii{¡Somos Nosotros los encargados de juntarlo y de recitarlo!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdlxix{Y, cuando lo recitemos, ¡sigue la recitación!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdlxx{Luego, a Nosotros nos toca explicarlo.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdlxxi{Pero ¡no! En lugar de eso, amáis la vida fugaz\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdlxxii{y descuidáis la otra vida.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdlxxiii{Ese día, unos rostros brillarán,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdlxxiv{mirando a su Señor,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdlxxv{mientras que otros, ese día, estarán tristes,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdlxxvi{pensando que una calamidad les alcance.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdlxxvii{¡No! Cuando suba hasta las clavículas,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdlxxviii{se diga: «¿quién es encantador?»,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdlxxix{crea llegado el momento de la separación\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdlxxx{y se junte una pierna con otra,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxi{ese día la marcha será hacia tu Señor.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxii{No creyó, ni oró,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxiii{antes bien, desmintió y se desvió.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxiv{Luego, se volvió a los suyos con andar altanero.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxv{¡Ay de ti! ¡Ay!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxvi{¡Sí! ¡Ay de ti! ¡Ay!\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxvii{¿Cree el hombre que no van a ocuparse de él?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxviii{¿No fue una gota de esperma eyaculada\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdlxxxix{y, luego, un coágulo de sangre? Él lo creó y le dio forma armoniosa.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdxc{E hizo de él una pareja: varón y hembra.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdxci{Ese tal ¿no será capaz de devolver la vida a los muertos?\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdxcii{\basmalahes ¿Ha pasado el hombre por un período de tiempo en que no era nada digno de mención?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdxciii{Hemos creado al hombre de una gota, de ingredientes, para ponerle a prueba. Le hemos dado el oído, la vista.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdxciv{Agradecido o desagradecido, le hemos dirigido por el Camino.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdxcv{Para los infieles hemos preparado cadenas, argollas y fuego de gehena.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdxcvi{Los justos beberán de copas de una mezcla alcanforada.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdxcvii{de una fuente de la que beberán los siervos de Alá y que harán manar en abundancia.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdxcviii{Fueron fieles a sus promesas y temieron un día cuyo mal será de alcance universal.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdxcix{Por mucho amor que tuvieran al alimento, se lo daban al pobre, al huérfano y al cautivo:\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdc{«Os damos de comer sólo por agradar a Alá. No queremos de vosotros retribución ni gratitud.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdci{Tememos, de nuestro Señor, un día terrible, calamitoso».\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcii{Alá les preservará del mal de ese día y les llenará de esplendor y alegría.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdciii{Les retribuira, por haber tenido paciencia, con un Jardín y con vestiduras de seda.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdciv{Reclinados allí en sofás, estarán resguardados allí del calor y del frío excesivo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcv{Cerca de ellos, les cubrirán sus sombras; sus frutos podrán ser cogidos muy fácilmente.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcvi{Se harán circular entre ellos vasijasa de plata y copas de cristal,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcvii{de un cristal de plata, de medidas determinadas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcviii{Allí se les servirá una copa que contendrá una mezcla de jengibre,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcix{tomada de una fuente de allí, que se llama Salsabil.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcx{Y circularán entre ellos criados jóvenes de eterna juventud. Viéndoles, se les creería perlas desparramadas.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxi{Cuando se mira allá, no se ve sino delicia y suntuosidad.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxii{Vestirán de verde satén y de brocado y llevarán brazaletes de plata. Su Señor les servirá una bebida pura.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxiii{«Esto se os ha dado como retribución. Vuestro esfuerzo ha sido agradecido».\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxiv{Somos Nosotros Quienes te llemos revelado el Corán de hecho.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxv{Espera, pues, paciente, la decisión f de tu Señor y no obedezcas a quien de ellos sea pecador o desagradecido.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxvi{¡Y menciona el nombre de tu Señor mañana y tarde!\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxvii{¡Por la noche, prostérnate ante Él! ¡Glorifícale largamente por la noche!\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxviii{Éstos aman la vida fugaz y descuidan un día grave.\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcxix{Nosotros los hemos creado y hemos fortalecido su constitución. Si quisiéramos, podríamos sustituirlos por otros semejantes.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcxx{Esto es un Recuerdo. El que quiera ¡que emprenda camino hacia su Señor!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcxxi{Pero vosotros no lo querréis, a menos que Alá quiera. Alá es omnisciente, sabio.\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcxxii{lntroduce en Su misericordia a quien Él quiere. Pero a los impíos les ha preparado un castigo doloroso.\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcxxiii{\basmalahes ¡Por los enviados en ráfagas!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcxxiv{¡Por los que soplan violentamente!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcxxv{¡Por los que diseminan en todos los sentidos!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcxxvi{¡Por los que distinguen claramente!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcxxvii{¡Por los que lanzan una amonestación\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcxxviii{a modo de excusa o de advertencia!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcxxix{¡Ciertamente, aquello con que se os amenaza se cumplirá!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcxxx{Cuando las estrellas pierden su luz,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxi{cuando el cielo se hienda,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxii{cuando las montañas sean reducidas a polvo,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxiii{cuando se fije a los enviados su tiempo:\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxiv{«¿Qué día comparecerán?»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxv{«¡El día del Fallo!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxvi{Y ¿cómo sabrás qué es el día del Fallo?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxvii{Ese día, ¡ay de los desmentidores!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxviii{¿No hemos hecho que perecieran los primeros hombres\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcxxxix{y, luego, que les siguieran los últimos?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcxl{Así haremos con los pecadores.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcxli{Ese día, ¡ay de los desmentidores!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxlii{¿No os hemos creado de un líquido vil,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxliii{que hemos depositado en un receptáculo seguro,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxliv{durante un tiempo determinado?\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxlv{Así lo hemos decidido y ¡qué bien que lo hemos decidido!\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxlvi{Ese día ¡ay de los desmentidores!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxlvii{¿No hemos hecho de la tierra lugar de reunión\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxlviii{de vivos y muertos,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxlix{y puesto en ella elevadas montañas? ¿No os hemos dado de beber un agua dulce?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcl{Ese día, ¡ay de los desmentidores!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcli{«¡Id a lo que desmentíais!\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdclii{¡Id a la sombra ramificada en tres,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcliii{sombra tenue, sombra inútil frente a la llama!»\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcliv{Porque arroja chispas grandes como palacios,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdclv{chispas que semejan camellos leonados.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdclvi{Ese día, ¡ay de los desmentidores!\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdclvii{Ése será un día en que no tendrán que decir\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdclviii{ni se les permitirá excusarse.\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdclix{Ese día, ¡ay de los desmentidores!\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdclx{«Éste es el día del Fallo. Os hemos reunido, a vosotros y a los antiguos.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdclxi{Si disponéis de alguna artimaña, ¡empleadla contra mí»\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdclxii{Ese día, ¡ay de los desmentidores!\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdclxiii{Los temerosos de Alá estarán a la sombra y entre fuentes,\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdclxiv{y tendrán la fruta que deseen.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdclxv{«¡Comed y bebed en paz el fruto de vuestras obras!»\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdclxvi{Así retribuimos a quienes hacen el bien.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdclxvii{Ese día, ¡ay de los desmentidores!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdclxviii{«¡Comed y disfrutad aún un poco!, ¡Sois unos pecadores!»\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdclxix{Ese día, ¡ay de los desmentidores!\qt@no{47}}
\qt@newcmd\qurantrans@es@mmmmmdclxx{Cuando se les dice: «¡Inclinaos!», no se inclinan.\qt@no{48}}
\qt@newcmd\qurantrans@es@mmmmmdclxxi{Ese día, ¡ay de los desmentidores!\qt@no{49}}
\qt@newcmd\qurantrans@es@mmmmmdclxxii{¿En qué anuncio, después de éste, van a creer?\qt@no{50}}
\qt@newcmd\qurantrans@es@mmmmmdclxxiii{\basmalahes ¿Por qué cosa se preguntan unos a otros?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdclxxiv{Por la enorme Noticia,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdclxxv{acerca de la cual discrepan.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdclxxvi{¡No! ¡Ya verán...!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdclxxvii{¡No y no! ¡Ya verán...!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdclxxviii{¿No hemos hecho de la tierra lecho\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdclxxix{y de las montañas estacas?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdclxxx{Y os hemos creado por parejas,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxi{hecho de vuestro sueño descanso,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxii{de la noche vestidura,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxiii{del día medio de subsistencia.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxiv{Y hemos edificado encima de vosotros siete cielos firmes,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxv{y colocado una lámpara resplandeciente.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxvi{Y hemos hecho bajar de las nubes un agua abundante\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxvii{para, mediante ella, sacar grano, plantas\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxviii{y frondosos jardines.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdclxxxix{El día del Fallo está ya señalado.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcxc{Día en que se tocará la trompeta y acudiréis en masa.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcxci{El cielo se abrirá, todo puertas;\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcxcii{las montañas, puestas en marcha, serán espejismo.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcxciii{La gehena, al acecho,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcxciv{será refugio de los rebeldes,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcxcv{que permanecerán en ella durante generaciones,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcxcvi{sin probar frescor ni bebida,\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcxcvii{fuera de agua muy caliente y hediondo líquido,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcxcviii{retribución adecuada.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcxcix{No contaban con el ajuste de cuentas\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcc{y desmintieron descaradamente Nuestros signos,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcci{siendo así que habíamos consignado todo en una Escritura.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccii{«¡Gustad, pues! ¡No haremos sino aumentaros el castigo!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcciii{En cambio, a los temerosos de Alá se les deparará el éxito:\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdcciv{vergeles y viñedos,\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccv{de turgidos senos, de una misma edad,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccvi{copa desbordante.\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccvii{No oirán allí vaniloquio, ni falsedad.\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccviii{Es una retribución de tu Señor, regalo bien pensado\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccix{del Señor de los cielos, de la tierra y de lo que entre ellos está, del Compasivo, a Quien no podrán dirigir la palabra.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccx{Día en que el Espíritu y los ángeles estarán de pie, en fila, sin hablar, excepto aquél a quien el Compasivo se lo permita y diga algo oportuno.\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccxi{Ese será el día de la Verdad. El que quiera. encontrará refugio junto a su Señor.\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdccxii{Os hemos prevenido contra un castigo cercano, el día que el hombre medite en sus obras pasadas y diga el infiel: «¡Ojalá fuera yo tierra!»\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccxiii{\basmalahes ¡Por los que arrancan violentamente!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdccxiv{¡Por los que van rápidamente!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccxv{¡Por los que nadan libremente!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccxvi{¡Por los que van a la cabeza!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdccxvii{¡Por los que llevan un asunto!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdccxviii{El día que ocurra el temblor,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdccxix{sucedido por el siguiente,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdccxx{ese día, los corazones se estremecerán,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdccxxi{se humillarán las miradas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdccxxii{Dicen: «¿Es verdad que seremos restituidos a nuestra primera condición,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdccxxiii{luego de convertirnos en pútridos huesos?»\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdccxxiv{Dicen: «¡Sería un retorno pernicioso!»\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdccxxv{No habrá más que un solo Grito\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdccxxvi{y ¡helos despiertos!\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdccxxvii{¿Te has enterado de la historia de Moisés?\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdccxxviii{Cuando su Señor le llamó en el valle sagrado de Tuwa:\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdccxxix{«Ve a Faraón. Se ha excedido.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdccxxx{Y di: '¿Estás dispuesto a purificarte\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxi{y a que te dirija a tu Señor y, así, tengas miedo?»\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxii{Le mostró el signo tan grande.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxiii{Pero él desmintió y desobedeció.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxiv{Luego, volvió la espalda bruscamente.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxv{Y convocó y dirigió una proclama.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxvi{Dijo: «Soy yo vuestro altísimo Señor».\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxvii{Alá le infligió el castigo de la otra vida y de ésta.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxviii{Hay en ello, sí, motivo de reflexión para quien tenga miedo de Alá.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdccxxxix{¿Sois vosotros más difíciles de crear que el cielo que él ha edificado?\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdccxl{Alzó su bóveda y le dio forma armoniosa.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdccxli{Obscureció la noche y sacó la mañana.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccxlii{Extendió, luego, la tierra,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdccxliii{sacó de ella el agua y los pastos,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccxliv{fijó las montañas.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccxlv{Para disfrute vuestro y de vuestros rebaños.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccxlvi{Pero, cuando venga la tan grande Calamidad,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccxlvii{el día que recuerde el hombre sus esfuerzos\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccxlviii{y se haga aparecer el fuego de la gehena a quien pueda ver,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccxlix{quien se haya mostrado rebelde\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccl{y preferido la vida de acá\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccli{tendrá por morada el fuego de la gehena,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdcclii{mientras que quien haya temidoí comparecer ante su Señor y preservado su alma de la pasión\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccliii{tendrá el Jardín por morada.\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdccliv{Te preguntan por la Hora: «¿Cuándo sucederá?»\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdcclv{¡No te ocupes tú de eso!\qt@no{43}}
\qt@newcmd\qurantrans@es@mmmmmdcclvi{A tu Señor Le toca fijarla.\qt@no{44}}
\qt@newcmd\qurantrans@es@mmmmmdcclvii{¡Tú sólo tienes que advertir a quien tiene miedo de ella!\qt@no{45}}
\qt@newcmd\qurantrans@es@mmmmmdcclviii{El día que la vivan, les parecerá no haber permanecido más de una tarde o de una mañana.\qt@no{46}}
\qt@newcmd\qurantrans@es@mmmmmdcclix{\basmalahes Frunció las cejasy volvió la espalda,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcclx{porque el ciego vino a él.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcclxi{¿Quién sabe? Quizá quería purificarse,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcclxii{o dejarse amonestar y que la amonestación le aprovechara.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcclxiii{A quien es rico\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcclxiv{le dispensas una buena acogida\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcclxv{y te tiene sin cuidado que no quiera purificarse.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcclxvi{En cambio, de quien viene a ti, corriendo,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcclxvii{con miedo de Alá,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcclxviii{te despreocupas.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcclxix{¡No! Es un Recuerdo,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcclxx{que recordará quien quiera,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxi{contenido en hojas veneradas,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxii{sublimes, purificadas,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxiii{escrito por mano de escribas\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxiv{nobles, píos.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxv{¡Maldito sea el hombre! ¡Qué desagradecido es!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxvi{¿De qué lo ha creado Él?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxvii{De una gota lo ha creado y determinado;\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxviii{luego, le ha facilitado el camino;\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxix{luego, le ha hecho morir y ser sepultado;\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxx{luego, cuando É quiera, le resucitará.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxi{¡No! No ha cumplido aún lo que Él le ha ordenado.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxii{¡Que mire el hombre su alimento!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxiii{Nosotros hemos derramado el agua en abundancia;!\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxiv{luego, hendido la tierra profundamente\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxv{y hecho crecer en ella grano,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxvi{vides, hortalizas,\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxvii{olivos, palmeras,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxviii{frondosos jardines,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdcclxxxix{frutas, pastos,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccxc{para disfrute vuestro y de vuestros rebaños.\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccxci{Pero, cuando venga el Estruendo,\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccxcii{el día que el hombre huya de su hermano,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccxciii{de su madre y de su padre,\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccxciv{de su compañera y de sus hijos varones,\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccxcv{ese día, cada cual tendrá bastante consigo mismo.\qt@no{37}}
\qt@newcmd\qurantrans@es@mmmmmdccxcvi{Ese día, unos rostros estarán radiantes,\qt@no{38}}
\qt@newcmd\qurantrans@es@mmmmmdccxcvii{risueños, alegres,\qt@no{39}}
\qt@newcmd\qurantrans@es@mmmmmdccxcviii{mientras que otros, ese día, tendrán polvo encima,\qt@no{40}}
\qt@newcmd\qurantrans@es@mmmmmdccxcix{los cubrirá una negrura:\qt@no{41}}
\qt@newcmd\qurantrans@es@mmmmmdccc{ésos serán los infieles, los pecadores.\qt@no{42}}
\qt@newcmd\qurantrans@es@mmmmmdccci{\basmalahes Cuando el sol sea obscurecido,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccii{cuando las estrellas pierdan su brillo,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccciii{cuando las montañas sean puestas en marcha,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccciv{cuando las camellas preñadas de diez meses sean descuidadas,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccv{cuando las bestias salvajes sean agrupadas,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccvi{cuando los mares sean hinchados,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccvii{cuando las almas sean apareadas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccviii{cuando se pregunte a la niña enterrada viva\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccix{qué crimen cometió para que la mataran,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccx{cuando las hojas sean desplegadas,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxi{cuando el cielo sea desollado,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxii{cuando el fuego de la gehena sea avivado,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxiii{cuando el Jardín sea acercado,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxiv{cada cual sabrá lo que presenta.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxv{¡Pues no! ¡Juro por los planetas,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcccxvi{que pasan y desaparecen!\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcccxvii{¡Por la noche cuando se extiende!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcccxviii{¡Por la mañana cuando respira!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcccxix{Sí, es la palabra de un Enviado noble,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcccxx{que dispone de poder junto al Señor del Trono, firme,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxi{obedecido allís de confianza.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxii{¡Vuestro paisano no es un poseso!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxiii{Le ha visto en el claro horizonte,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxiv{no es avaro de lo oculto.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxv{No es la palabra de un demonio maldito.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxvi{¿Adónde iréis, pues?\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxvii{No es sino una amonestación dirigida a todo el mundo,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxviii{para aquéllos de vosotros que quieran seguir la vía recta.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxix{Pero vosotros no lo querréis, a menos que quiera Alá, Señor del universo.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxx{\basmalahes Cuando el cielo se hienda,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxi{cuando las estrellas se dispersen,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxii{cuando los mares sean desbordados,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxiii{cuando las sepulturas sean vueltas al revés,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxiv{sabrá cada cual lo que hizo y lo que dejó de hacer.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxv{¡Hombre! ¿Qué es lo que te ha engañado acerca de tu noble Señor,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxvi{Que te ha creado, dado forma y disposición armoniosas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxvii{Que te ha formado del modo que ha querido?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxviii{¡Pero no! Desmentís el Juicio,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccxxxix{pero hay quienes os guardan:\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxl{nobles, escribas,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxli{que saben lo que hacéis.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlii{Sí, los justos estarán en delicia,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxliii{mientras que los pecadores estarán en fuego de gehena.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxliv{En él arderán el día del Juicio\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlv{y no se ausentarán de él.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlvi{Y ¿cómo sabrás qué es el día del Juicio?\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlvii{Sí, ¿cómo sabrás qué es el día del Juicio?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlviii{El día que nadie pueda hacer nada en favor de nadie. Y será Alá Quien, ese día, decida.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdcccxlix{\basmalahes ¡Ay de los defraudadores,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdcccl{que, cuando piden a otros la medida, la exigen exacta,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdcccli{pero que, cuando ellos miden o pesan para otros, dan menos de lo debido!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccclii{¿No cuentan con ser resucitados\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdcccliii{un día terrible,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccliv{el día que comparezcan los hombres ante el Señor del universo?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdccclv{¡No! La Escritura de los pecadores está, ciertamente, en Sichchín.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdccclvi{Y ¿cómo sabrás qué es Sichchín?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdccclvii{Es una Escritura marcada.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdccclviii{Ese día, ¡ay de los desmentidores,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdccclix{que desmienten el día del Juicio!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdccclx{Y no lo desmiente sino todo violador de la ley, pecador,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdccclxi{que, al serle recitadas Nuestras aleyas, dice: «¡Patrañas de los antiguos!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdccclxii{Pero ¡no! Lo que han cometido ha cubierto de herrumbre sus corazones.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdccclxiii{¡No! Ese día serán separados de su Señor por un velo.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmdccclxiv{Luego, arderán, sí, en el fuego de la gehena.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmdccclxv{Luego, se dirá: «¡He aquí lo que desmentíais!»\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmdccclxvi{¡No! La Escritura de los justos está, ciertamente, en Illiyyun.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmdccclxvii{Y ¿cómo sabrás qué es Illiyyun?\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmdccclxviii{Es una Escritura marcada,\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmdccclxix{que verán con sus propios ojos los allegados.\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmdccclxx{Sí, los justos estarán en delicia,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxi{en sofás, observando...\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxii{Se reconocerá en sus rostros el brillo de la delicia.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxiii{Se les dará de beber un vino generoso y sellado,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxiv{con un dejo de almizcle -¡que lo codicien los codiciosos!-,\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxv{mezclado con agua de Tasnim,\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxvi{fuente de la que beberán los allegados.\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxvii{Los pecadores se reían de los creyentes.\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxviii{Cuando pasaban junto a ellos, se guiñaban el ojo,\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxix{cuando regresaban a los suyos, regresaban burlándose,\qt@no{31}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxx{cuando les veían, decían: «¡Sí, están extraviados!»\qt@no{32}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxi{Pero no han sido enviados para velar por ellos.\qt@no{33}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxii{Ese día, los creyentes se reirán de los infieles,\qt@no{34}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxiii{en sofás, observando...\qt@no{35}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxiv{¿No han sido retribuidos los infieles según sus obras?\qt@no{36}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxv{\basmalahes Cuando el cielo se desgarre\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxvi{y escuche a su Señor -como debe ser-,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxvii{cuando la tierra sea allanada,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxviii{vomite su contenido, vaciándose,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmdccclxxxix{y escuche a su Señor -como debe ser-...\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmdcccxc{¡Hombre! Te esfuerzas con denuedo en encontrar a tu Señor y Le encontrarás.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmdcccxci{Aquél que reciba su Escritura en la diestra\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcii{será juzgado benignamente\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmdcccxciii{y regresará, alegre, a los suyos.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmdcccxciv{Pero aquél que reciba su Escritura detrás de la espalda\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcv{invocará la destrucción,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcvi{pero arderá en fuego de gehena.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcvii{Vivía alegre con los suyos,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcviii{creyendo que no iba a volver.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmdcccxcix{¡Claro que sí! Su Señor le veía bien.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcm{¡Pues no! ¡Juro por el arrebol vespertino,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmi{por la noche y por lo que congrega,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmii{por la luna cuando está llena,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmiii{que habéis de pasar de uno a otro estado!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmiv{Pero ¿qué les pasa que no creen\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmv{y, cuando se les recita el Corán, no se prosternan?\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmvi{¡No! Los infieles desmienten;\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmvii{pero Alá conoce bien lo que ocultan.\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcmviii{Anúnciales, pues, un castigo doloroso!\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcmix{Quienes, en cambio, crean y obren bien, recibirán una recompensa ininterrumpida.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcmx{\basmalahes ¡Por el cielo con sus constelaciones!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxi{¡Por el día con que se ha amenazado!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxii{¡Por el testigo y lo atestiguado!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxiii{¡Malditos sean los hombres del Foso,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxiv{del fuego bien alimentado,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxv{sentados a él,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmxvi{dando testimonio de lo que ellos han hecho a los creyentes,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmxvii{resentidos con ellos sólo porque creyeron en Alá, el Poderoso, el Digno de Alabanza,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmxviii{a Quien pertenece el dominio de los cielos y de la tierra. Alá es testigo de todo.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmxix{Quienes sometan a los creyentes y a las creyentes a una prueba y no se arrepientan luego, tendrán el castigo de la gehena, el castigo de su fuego.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmxx{Quienes, en cambio, hayan creído y obrado bien tendrán jardines por cuyos bajos fluyen arroyos. ¡Ese es el gran éxito!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmxxi{¡Sí, es duro el rigor de tu Señor!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmxxii{Él crea y re-crea.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmxxiii{Él es el Indulgente, el Lleno de Amor,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmxxiv{el Señor del Trono, el Glorioso,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmxxv{Que siempre hace lo que quiere.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmxxvi{¿Te has enterado de la historia de los ejércitos,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmxxvii{de Faraón y de los tamudeos?\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmxxviii{Los infieles, no obstante, persisten en desmentir,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmxxix{pero Alá les tiene a Su merced.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmxxx{¡Sí es un Corán glorioso,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxi{en una Tabla bien guardada!\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxii{\basmalahes ¡Por el cielo y el astro nocturno!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxiii{Y ¿cómo sabrás qué es el astro nocturno?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxiv{Es la estrella de penetrante luz.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxv{No hay nadie que no tenga un guardián.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxvi{¡Que considere el hombre de qué ha sido creado!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxvii{Ha sido creado de un líquido fluente,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxviii{que sale de entre los riñones y las costillas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmxxxix{En verdad, Él es capaz de volverle,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmxl{el día que sean probados los secretos\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmxli{y no tenga ya fuerza ni quien le auxilie.\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmxlii{¡Por el cielo periódico!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmxliii{¡Por la tierra que se abre!\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmxliv{Es, en verdad, una palabra decisiva,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmxlv{seria.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmxlvi{Ellos emplean una artimaña,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmxlvii{y Yo empleo una artimaña,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmxlviii{¡Concede una prórroga a los infieles, un poco más de prórroga!\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmxlix{\basmalahes ¡Glorifica el nombre de tu Señor, el Altísimo,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcml{Que ha creado y dado forma armoniosa,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmli{Que ha determinado y dirigido,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmlii{Que ha sacado el pasto\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmliii{y, luego, hecho de él obscuro heno!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmliv{Te haremos recitar y, así no olvidarás,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmlv{salvo lo que Alá quiera. Él conoce lo patente y lo escondido.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmlvi{Te facilitaremos el acceso a la mayor felicidad.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmlvii{¡Amonesta, pues, si la amonestación aprovecha!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmlviii{Se dejará amonestar quien tenga miedo de Alá,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmlix{y la evitará el infame,\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmlx{que arderá en el tan grande Fuego.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmlxi{sin en él morir ni vivir.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmlxii{¡Bienaventurado, en cambio, quien se purifique,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmlxiii{quien mencione el nombre de su Señor y ore!\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmlxiv{Pero preferís la vida de acá,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmlxv{siendo así que la otra es mejor y más duradera.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmlxvi{Esto se encuentra en las Hojas primeras,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmlxvii{las Hojas de Abraham y de Moisés.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmlxviii{\basmalahes ¿Te has enterado de la historia de la que cubre?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmlxix{Ese día, unos rostros, humillados,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmlxx{preocupados, cansados,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxi{arderán en un fuego abrasador.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxii{Se les dará de beber de una fuente hirviente.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxiii{No tendrán más alimento que de dari,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxiv{que no engorda, ni sacia.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxv{Otros rostros, ese día, estarán alegres,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxvi{satisfechos de su esfuerzo,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxvii{en un Jardín elevado,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxviii{en el que no se oirá vaniloquio.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxix{Habrá allí una fuente caudalosa,\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxx{lechos elevados,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxi{copas preparadas,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxii{cojines alineados\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxiii{y alfombras extendidas.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxiv{¿Es que no consideran cómo han sido creados los camélidos,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxv{cómo alzado el cielo.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxvi{cómo erigidas las montañas,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxvii{cómo extendida la tierra?\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxviii{¡Amonesta, pues! Tú eres sólo un monitor,\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmcmlxxxix{no tienes autoridad sobre ellos.\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmcmxc{Sin embargo, a quien se desvíe y no crea,\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmcmxci{Alá le infligirá el castigo mayor.\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmcmxcii{Volverán todos a Nosotros.\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmcmxciii{Luego, nos tocará a Nosotros pedirles cuentas.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmcmxciv{\basmalahes ¡Por el alba!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmcmxcv{¡Por diez noches!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmcmxcvi{¡Por el par y el impar!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmcmxcvii{¡Por la noche cuando transcurre...\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmcmxcviii{¿No es esto un juramento para el dotado de intelecto?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmcmxcix{¿No has visto cómo ha obrado tu Señor con los aditas,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmm{con Iram, la de las columnas,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmi{sin par en el país,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmii{con los tamudeos, que excavaron la roca en el valle,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmiii{con Faraón el de las estacas,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmiv{que se habían excedido en el país\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmv{y que habían corrompido tanto en él?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmvi{Tu Señor descargó sobre ellos el azote de un castigo.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmvii{Tu Señor está, sí, al acecho.\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmviii{El hombre, cuando su Señor le prueba honrándolo y concediéndole gracias, dice: «¡Mi Señor me ha honrado!»\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmix{En cambio. cuando le prueba restringiéndole su sustento, dice: «¡Mi Señor me ha despreciado!»\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmx{¡No! Sois vosotros, más bien, los que no honráis al huérfano,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmxi{ni os animáis unos a otros a alimentar al pobre,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmxii{sino que devoráis vorazmente la herencia y\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmxiii{amáis la hacienda con desordenado amor.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmxiv{¡No! Cuando la Tierra sea reducida a polvo fino\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmmxv{y venga tu Señor con los ángeles en filas,\qt@no{22}}
\qt@newcmd\qurantrans@es@mmmmmmxvi{ese día se traerá la gehena, ese día el hombre se dejará amonestar -y ¿de qué le servirá entonces la amonestación?-\qt@no{23}}
\qt@newcmd\qurantrans@es@mmmmmmxvii{y dirá: «¡Ojalá hubiera enviado por delante para mi vida!»\qt@no{24}}
\qt@newcmd\qurantrans@es@mmmmmmxviii{Ese día nadie castigará como Él,\qt@no{25}}
\qt@newcmd\qurantrans@es@mmmmmmxix{nadie atará como Él.\qt@no{26}}
\qt@newcmd\qurantrans@es@mmmmmmxx{«¡Alma sosegada!\qt@no{27}}
\qt@newcmd\qurantrans@es@mmmmmmxxi{¡Vuelve a tu Señor, satisfecha, acepta!\qt@no{28}}
\qt@newcmd\qurantrans@es@mmmmmmxxii{¡Y entra con Mis siervos,\qt@no{29}}
\qt@newcmd\qurantrans@es@mmmmmmxxiii{Entra en Mi Jardín!»\qt@no{30}}
\qt@newcmd\qurantrans@es@mmmmmmxxiv{\basmalahes ¡No! ¡Juro por esta ciudad,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxxv{en la que estás avecindado!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxxvi{¡Por todo padre y lo que ha engendrado!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxxvii{Hemos creado al hombre en aflicción.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxxviii{¿Cree que nadie podrá contra él?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxxix{Dice: «He consumido una hacienda considerable».\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmxxx{¿Cree que nadie le ha visto?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmxxxi{¿No le hemos dado dos ojos,\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmxxxii{una lengua y dos labios?\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmxxxiii{¿No le hemos mostrado las dos vías?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmxxxiv{Pues nunca se ha puesto a subir la Cuesta.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmxxxv{Y ¿cómo sabrás qué es la Cuesta?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmxxxvi{Es manumitir a un esclavo,\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmxxxvii{Alimentar en tiempo de hambre\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmxxxviii{A un pariente próximo huérfano,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmxxxix{A un pobre en la miseria.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmxl{Es, también, formar parte de los que creen, de los que se recomiendan mutuamente la paciencia y la misericordia.\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmxli{Ésos son los de la Derecha.\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmxlii{En cambio, los que no creen en Nuestros signos, ésos son los de la izquierda.\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmxliii{Se cerrará un fuego sobre ellos.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmxliv{\basmalahes ¡Por el sol y su claridad!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxlv{¡Por la luna cuando le sigue!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxlvi{¡Por el día cuando lo muestra brillante!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxlvii{¡Por la noche cuando lo vela!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxlviii{¡Por el cielo y Quien lo ha edificado!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxlix{¡Por la tierra y Quien la ha extentido!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmml{¡Por el alma y Quien le ha dado forma armoniosa,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmli{instruyéndole sobre su propensión al pecado y su temor de Dios!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlii{¡Bienaventurado quien la purifique!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmliii{¡Decepcionado, empero, quien la corrompa!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmliv{Los tamudeos, en su arrogancia, desmintieron.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmlv{Cuando el más miserable de entre ellos se alzó.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmlvi{El enviado de Dios les dijo: «¡Dejad a la camella de Dios y que beba!»\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmlvii{Le desmintieron y la desjarretaron. Su Señor, entonces, les aniquiló por su pecado, a todos por igual,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmlviii{sin temer las consecuencias de ello.\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmlix{\basmalahes ¡Por la noche cuando extiende su velo!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmlx{¡Por el día cuando resplandece!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmlxi{¡Por Quien ha creado al varón y a la hembra!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmlxii{Vuestro esfuerzo, en verdad, da resultados diversos.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmlxiii{A quien da, teme a Dios,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmlxiv{y cree en lo más bello,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmlxv{le facilitaremos el acceso a la mayor felicidad.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmlxvi{En cambio, a quien es avaro, cree bastarse a sí mismo\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlxvii{y desmiente lo más bello,\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmlxviii{le facilitaremos el acceso a la mayor adversidad,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmlxix{y de nada le servirá su hacienda cuando sea precipitado.\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmlxx{Sí, es de incumbencia Nuestra la Dirección.\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmlxxi{Sí, es cosa Nuestra la otra vida y ésta.\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmlxxii{Os he prevenido contra un fuego llameante,\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmlxxiii{en el cual sólo arderá el infame,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmlxxiv{que desmiente y se desvía,\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmlxxv{el cual evitará quien de veras teme a Dios,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmlxxvi{que da su hacienda para purificarse,\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmlxxvii{que, cuando hace un favor, no lo hace con ánimo de ser retribuido,\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmlxxviii{sino tan sólo por deseo de agradar a su altísimo Señor.\qt@no{20}}
\qt@newcmd\qurantrans@es@mmmmmmlxxix{¡Sí, ése quedará satisfecho!\qt@no{21}}
\qt@newcmd\qurantrans@es@mmmmmmlxxx{\basmalahes ¡Por la mañana!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxi{¡Por la noche cuando reina la calma!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxii{Tu Señor no te ha abonadonado ni aborrecido\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxiii{Sí, la otra vida será mejor para ti que ésta.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxiv{Tu Señor te dará y quedarás satisfecho.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxv{¿No te encontró huérfano y te recogió?\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxvi{¿No te encontró extraviado y te dirigió?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxvii{¿No te encontró pobre y te enriqueció?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxviii{En cuanto al huérfano, ¡no le oprimas!\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmlxxxix{Y en cuanto al mendigo, ¡no le rechaces!\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmxc{Y en cuanto a la gracia de tu Señor, ¡publícala!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmxci{\basmalahes ¿No te hemos infundido ánimo,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmxcii{Liberado de la carga\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmxciii{Que agobiaba tu espalda\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmxciv{Y alzado tu reputación?\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmxcv{¡La adversidad y la felicidad van a una!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmxcvi{¡La adversidad y la felicidad van a una!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmxcvii{Cuando estés libre, ¡mantente diligente!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmxcviii{Y a tu Señor ¡deséale ardientemente!\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmxcix{\basmalahes ¡Por las higueras y los olivos!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmc{¡Por el monte Sinaí!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmci{¡Por esta ciudad segura!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcii{Hemos creado al hombre dándole la mejor complexión.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmciii{Luego, hemos hecho de él el más abyecto,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmciv{Excepto quienes crean y obren bien, que recibirán una recompensa ininterrumpida.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcv{Cómo puede aún desmentirse el Juicio?\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcvi{¿No es Alá quien mejor decide?\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcvii{\basmalahes ¡Recita en el nombre de tu Señor, Que ha creado,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcviii{ha creado al hombre de sangre coagulada!\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcix{¡Recita! Tu Señor es el Munífico,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcx{que ha enseñado el uso del cálamo,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxi{ha enseñado al hombre lo que no sabía.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxii{¡No! El hombre, en verdad, se rebela,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxiii{ya que cree bastarse a sí mismo.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxiv{Pero todo vuelve a tu Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxv{¿Has visto a quien prohíbe\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmcxvi{A un siervo orar?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmcxvii{¿Te parece que sigue la Dirección\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmcxviii{O que ordena el temor de Dios?\qt@no{12}}
\qt@newcmd\qurantrans@es@mmmmmmcxix{¿No te parece que desmiente y se desvía?\qt@no{13}}
\qt@newcmd\qurantrans@es@mmmmmmcxx{¿No sabe que Dios ve?\qt@no{14}}
\qt@newcmd\qurantrans@es@mmmmmmcxxi{¡No! Si no cesa, hemos de arrastrarle por el copete,\qt@no{15}}
\qt@newcmd\qurantrans@es@mmmmmmcxxii{copete que miente, que peca.\qt@no{16}}
\qt@newcmd\qurantrans@es@mmmmmmcxxiii{Y ¡que llame a sus secuaces,\qt@no{17}}
\qt@newcmd\qurantrans@es@mmmmmmcxxiv{que Nosotros llamaremos a los que precipitan!\qt@no{18}}
\qt@newcmd\qurantrans@es@mmmmmmcxxv{¡No! ¡No le obedezcas, sino prostérnate y acércate!\qt@no{19}}
\qt@newcmd\qurantrans@es@mmmmmmcxxvi{\basmalahes Lo hemos revelado en la noche del Destino.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxxvii{Y ¿cómo sabrás qué es la noche del Destino?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxxviii{La noche del Destino vale más de mil meses.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxxix{Los ángeles y el Espíritu descienden en ella, con permiso de su Señor, para fijarlo todo.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxxx{¡Es una noche de paz, hasta el rayar del alba!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxi{\basmalahes Los que no creen, tanto gente de la Escritura como asociadores, no podían renunciar hasta que les viniera la prueba clara:\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxii{Un Enviado de Dios, que recitara hojas purificadas,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxiii{que contenían Escrituras verdaderas.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxiv{Y quienes recibieron la Escritura no se dividieron sino después de venir a ellos la prueba clara.\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxv{Pero no se les ordenó sino que sirvieran a Dios, rindiéndole culto sincero comohanifes, que hicieran la azalá y dieran el azaque. Ésa es la religión verdadera.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxvi{Los que no crean, tanto gente de la Escritura como asociadores estarán, eternamente, en el fuego de la gehena. Ésos son lo peor de la creación.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxvii{En cambio, los que crean y obren bien, ésos son lo mejor de la creación,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxviii{y tendrán como retribución, junto a su Señor, los jardines del edén, por cuyos bajos fluyen arroyos, en los que estarán eternamente, para siempre. Dios está satisfecho de ellos y ellos lo están de Él. Esto es sólo para quien tiene miedo de su Señor.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxxxix{\basmalahes Cuando sea sacudida la tierra por su terremoto,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxl{expulse la tierra su carga\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxli{y el hombre se pregunte: «¿Qué es lo que le pasa?»,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxlii{ese día contará sus noticias,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxliii{según lo que tu Señor le inspire.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxliv{Ese día los hombres surgirán en grupos, para que se les muestren sus obras.\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcxlv{Quien haya hecho el peso de un átomo de bien, lo verá.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcxlvi{Y quien haya hecho el peso de un átomo de mal, lo verá.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmcxlvii{\basmalahes ¡Por los corceles jadeantes,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxlviii{que hacen saltar chispas,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxlix{cargan el alba,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcl{levantando, así, una nube de polvo\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcli{y rompen a través de una hueste!\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclii{El hombre, en verdad, es muy desagradecido con su Señor,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcliii{y él es, sí, testigo de ello.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmcliv{Y ama ardientemente, sí, los bienes terrenales.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclv{¿No sabe, acaso, que cuando lo que hay en las sepulturas sea vuelto al revés\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclvi{y se haga público lo que hay en los pechos,\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmclvii{ese día, su Señor estará, ciertamente, bien informado de ellos?\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmclviii{\basmalahes ¡La Calamidad!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclix{¿Qué es la Calamidad?\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclx{Y ¿cómo sabrás qué es la calamidad?\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxi{El día que los hombres parezcan mariposas dispersas\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxii{y las montañas copos de lana cardada,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxiii{entonces, el autor de obras de peso\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxiv{gozará de una vida agradable,\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxv{mientras que el autor de obras ligeras\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxvi{tendrá un abismo por morada.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclxvii{Y ¿cómo sabrás qué es?\qt@no{10}}
\qt@newcmd\qurantrans@es@mmmmmmclxviii{¡Un fuego ardiente!\qt@no{11}}
\qt@newcmd\qurantrans@es@mmmmmmclxix{\basmalahes El afán de lucro os distrae\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxx{hasta la hora de la muerte.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxi{¡No! ¡Ya veréis...!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxii{¡No y no! ¡Ya veréis...!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxxiii{¡No! Si supierais a ciencia cierta...\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxxiv{¡Veréis, de seguro, el fuego de la gehena!\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxxv{¡Sí, lo veréis con ojos de certeza!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxxvi{Luego, ese día, se os preguntará, ciertamente, por la delicia.\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxxvii{\basmalahes ¡Por la tarde!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxxviii{En verdad, el hombre camina hacia su perdición,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxix{Excepto quienes crean, obren bien, se recomienden mutuamente la verdad y se recomienden mutuamente la paciencia.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxx{\basmalahes ¡Ay de todo aquél que difame, que critique,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxi{que amase hacienda y la cuente una y otra vez,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxii{creyendo que su hacienda le hará inmortal!\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxiii{¡No! ¡Será precipitado, ciertamente, en la hutama !\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxiv{Y ¿cómo sabrás qué es la hutama ?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxv{Es el fuego de Alá encendido,\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxvi{Que llega hasta las entrañas.\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxvii{Se cerrará sobre ellos\qt@no{8}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxviii{en extensas columnas.\qt@no{9}}
\qt@newcmd\qurantrans@es@mmmmmmclxxxix{\basmalahes ¿No has visto cómo obró tu Señor con los del elefante?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxc{¿No desbarató su artimaña\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxci{y envió contra ellos bandadas de aves,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxcii{que descargaron sobre ellos piedras de arcilla,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxciii{dejándolos como espigas desgranadas?\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcxciv{\basmalahes Por el pacto de los coraixíes,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxcv{pacto relativo a la caravana de invierno y la de verano,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcxcvi{¡que sirvan, pues, al Señor de esta Casa,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcxcvii{que les ha alimentado contra el hambre y dado seguridad frente al temor!\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmcxcviii{\basmalahes ¿Qué te parece el que desmiente el Juicio?\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmcxcix{Es el mismo que rechaza violentamente al huérfano\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmcc{Y no anima a dar de comer al pobre.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmcci{¡Ay de los que oran\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccii{distraídamente,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmcciii{para ser vistos\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmcciv{Y niegan la ayuda!\qt@no{7}}
\qt@newcmd\qurantrans@es@mmmmmmccv{\basmalahes Te hemos dado la abundancia.\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccvi{Ora, pues, a tu Señor y ofrece sacrificios.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccvii{Sí, es quien te odia el privado de posteridad.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccviii{\basmalahes Di: «¡Infieles!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccix{Yo no sirvo lo que vosotros servís,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccx{Y vosotros no servís lo que yo sirvo.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxi{Yo no sirvo lo que vosotros habéis servido\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxii{Y vosotros no servís lo que yo sirvo.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxiii{Vosotros tenéis vuestra religión y yo la mía».\qt@no{6}}
\qt@newcmd\qurantrans@es@mmmmmmccxiv{\basmalahes Cuando venga el auxilio de Alá, así como el éxito,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxv{y veas que los hombres entran en masa en la religión de Alá,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxvi{entonces, ¡celebra las alabanzas de tu Señor y pide Su perdón! Es indulgente.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxvii{\basmalahes ¡Perezcan las manos de Abu Lahab! ¡Perezca él!\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxviii{Ni su hacienda ni sus adquisiciones le servirán de nada.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxix{Arderá en un fuego llameante,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxx{así como su mujer, la acarreadora de leña,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxi{a su cuello una cuerda de fibras.\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxii{\basmalahes Di: «¡Él es Alá, Uno,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxiii{Dios, el Eterno.\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxiv{No ha engendrado, ni ha sido engendrado.\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxv{No tiene par».\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxvi{\basmalahes Di: «Me refugio en el Señor del alba\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxvii{del mal que hacen sus criaturas,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxviii{del mal de la oscuridad cuando se extiende,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxix{del mal de las que soplan en los nudos,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxx{del mal envidioso cuando envidia».\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxi{\basmalahes Di: «Me refugio en el Señor de los hombres,\qt@no{1}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxii{el Rey de los hombres,\qt@no{2}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxiii{el Dios de los hombres,\qt@no{3}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxiv{del mal de la insinuación, del que se escabulle,\qt@no{4}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxv{que insinúa en el ánimo de los hombres,\qt@no{5}}
\qt@newcmd\qurantrans@es@mmmmmmccxxxvi{sea genio, sea hombre».\qt@no{6}}
%% End of file `qurantext-esii.translation.def'.
